#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1705
#define LARGE_STATE_COUNT 45
#define SYMBOL_COUNT 483
#define ALIAS_COUNT 0
#define TOKEN_COUNT 205
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 13
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 17

enum ts_symbol_identifiers {
    anon_sym_short = 1,
    anon_sym_int16 = 2,
    anon_sym_long = 3,
    anon_sym_int32 = 4,
    anon_sym_longlong = 5,
    anon_sym_int64 = 6,
    sym_unsigned_tiny_int = 7,
    sym_boolean_type = 8,
    anon_sym_fixed = 9,
    sym_octet_type = 10,
    sym_signed_tiny_int = 11,
    anon_sym_unsignedshort = 12,
    anon_sym_uint16 = 13,
    anon_sym_unsignedlong = 14,
    anon_sym_uint32 = 15,
    anon_sym_unsignedlonglong = 16,
    anon_sym_uint64 = 17,
    anon_sym_float = 18,
    anon_sym_double = 19,
    anon_sym_longdouble = 20,
    sym_char_type = 21,
    sym_wide_char_type = 22,
    anon_sym_COLON_COLON = 23,
    anon_sym_string = 24,
    anon_sym_LT = 25,
    anon_sym_GT = 26,
    anon_sym_wstring = 27,
    anon_sym_any = 28,
    anon_sym_COMMA = 29,
    anon_sym_sequence = 30,
    anon_sym_map = 31,
    anon_sym_PIPE = 32,
    anon_sym_CARET = 33,
    anon_sym_AMP = 34,
    anon_sym_GT_GT = 35,
    anon_sym_LT_LT = 36,
    anon_sym_PLUS = 37,
    anon_sym_DASH = 38,
    anon_sym_STAR = 39,
    anon_sym_SLASH = 40,
    anon_sym_PERCENT = 41,
    anon_sym_LPAREN = 42,
    anon_sym_RPAREN = 43,
    anon_sym_TILDE = 44,
    sym_bin_number = 45,
    aux_sym_oct_number_token1 = 46,
    aux_sym_oct_number_token2 = 47,
    anon_sym_0 = 48,
    aux_sym_dec_number_token1 = 49,
    sym_hex_number = 50,
    anon_sym_DOT = 51,
    aux_sym_floating_pt_literal_token1 = 52,
    aux_sym_fixed_pt_literal_token1 = 53,
    sym_escape_sequence = 54,
    anon_sym_DQUOTE = 55,
    aux_sym_string_literal_token1 = 56,
    anon_sym_L = 57,
    anon_sym_SQUOTE = 58,
    aux_sym_char_literal_token1 = 59,
    anon_sym_TRUE = 60,
    anon_sym_FALSE = 61,
    anon_sym_POUNDdefine = 62,
    aux_sym_preproc_define_token1 = 63,
    aux_sym_preproc_call_token1 = 64,
    sym_preproc_directive = 65,
    sym_preproc_arg = 66,
    aux_sym_preproc_include_token1 = 67,
    sym_system_lib_path = 68,
    anon_sym_exception = 69,
    anon_sym_LBRACE = 70,
    anon_sym_RBRACE = 71,
    anon_sym_local = 72,
    anon_sym_abstract = 73,
    anon_sym_interface = 74,
    anon_sym_COLON = 75,
    anon_sym_SEMI = 76,
    anon_sym_void = 77,
    anon_sym_in = 78,
    anon_sym_out = 79,
    anon_sym_inout = 80,
    anon_sym_raises = 81,
    anon_sym_readonly = 82,
    anon_sym_attribute = 83,
    anon_sym_getraises = 84,
    anon_sym_setraises = 85,
    anon_sym_bitset = 86,
    anon_sym_bitfield = 87,
    anon_sym_bitmask = 88,
    anon_sym_ATannotation = 89,
    anon_sym_default = 90,
    anon_sym_AT = 91,
    anon_sym_SLASH_SLASH_AT = 92,
    aux_sym_extend_annotation_appl_token1 = 93,
    anon_sym_EQ = 94,
    aux_sym_annotation_appl_id_token1 = 95,
    aux_sym_annotation_appl_autoid_token1 = 96,
    aux_sym_autoid_kind_token1 = 97,
    aux_sym_autoid_kind_token2 = 98,
    aux_sym_annotation_appl_optional_token1 = 99,
    aux_sym_annotation_appl_position_token1 = 100,
    aux_sym_annotation_appl_value_token1 = 101,
    aux_sym_annotation_appl_extensibility_token1 = 102,
    aux_sym_extensibility_kind_token1 = 103,
    aux_sym_extensibility_kind_token2 = 104,
    aux_sym_extensibility_kind_token3 = 105,
    aux_sym_annotation_appl_final_token1 = 106,
    aux_sym_annotation_appl_appendable_token1 = 107,
    aux_sym_annotation_appl_mutable_token1 = 108,
    aux_sym_annotation_appl_key_token1 = 109,
    aux_sym_annotation_appl_must_understand_token1 = 110,
    aux_sym_annotation_appl_default_literal_token1 = 111,
    aux_sym_annotation_appl_default_token1 = 112,
    aux_sym_annotation_appl_range_token1 = 113,
    aux_sym_min_expr_token1 = 114,
    aux_sym_max_expr_token1 = 115,
    aux_sym_annotation_appl_unit_token1 = 116,
    aux_sym_annotation_appl_bit_bound_token1 = 117,
    aux_sym_annotation_appl_external_token1 = 118,
    aux_sym_annotation_appl_nested_token1 = 119,
    aux_sym_annotation_appl_verbatim_token1 = 120,
    aux_sym_verbatim_language_token1 = 121,
    aux_sym_verbatim_language_token2 = 122,
    aux_sym_verbatim_language_token3 = 123,
    aux_sym_verbatim_language_token4 = 124,
    aux_sym_placement_kind_token1 = 125,
    aux_sym_placement_kind_token2 = 126,
    aux_sym_placement_kind_token3 = 127,
    aux_sym_placement_kind_token4 = 128,
    aux_sym_placement_kind_token5 = 129,
    aux_sym_placement_kind_token6 = 130,
    aux_sym_annotation_appl_service_token1 = 131,
    aux_sym_service_platform_token1 = 132,
    aux_sym_service_platform_token2 = 133,
    aux_sym_annotation_appl_oneway_token1 = 134,
    aux_sym_annotation_appl_ami_token1 = 135,
    anon_sym_hashid = 136,
    aux_sym_annotation_appl_default_nested_token1 = 137,
    aux_sym_annotation_appl_ignore_literal_names_token1 = 138,
    aux_sym_annotation_appl_try_construct_token1 = 139,
    aux_sym_try_construct_fail_action_token1 = 140,
    aux_sym_try_construct_fail_action_token2 = 141,
    aux_sym_try_construct_fail_action_token3 = 142,
    aux_sym_annotation_appl_non_serialized_token1 = 143,
    aux_sym_annotation_appl_data_representation_token1 = 144,
    anon_sym_allowed_kinds = 145,
    aux_sym_data_representation_mask_token1 = 146,
    aux_sym_data_representation_mask_token2 = 147,
    aux_sym_data_representation_mask_token3 = 148,
    aux_sym_data_representation_mask_token4 = 149,
    aux_sym_annotation_appl_topic_token1 = 150,
    sym_annotation_appl_choice = 151,
    sym_annotation_appl_empty = 152,
    sym_annotation_appl_dds_service = 153,
    aux_sym_annotation_appl_dds_request_topic_token1 = 154,
    aux_sym_annotation_appl_dds_request_topic_token2 = 155,
    aux_sym_annotation_appl_dds_reply_topic_token1 = 156,
    anon_sym_module = 157,
    anon_sym_typename = 158,
    anon_sym_valuetype = 159,
    anon_sym_eventtype = 160,
    anon_sym_struct = 161,
    anon_sym_union = 162,
    anon_sym_enum = 163,
    anon_sym_const = 164,
    anon_sym_alias = 165,
    anon_sym_custom = 166,
    anon_sym_truncatable = 167,
    anon_sym_supports = 168,
    anon_sym_public = 169,
    anon_sym_private = 170,
    anon_sym_factory = 171,
    anon_sym_typedef = 172,
    anon_sym_LBRACK = 173,
    anon_sym_RBRACK = 174,
    anon_sym_switch = 175,
    anon_sym_case = 176,
    anon_sym_typeid = 177,
    anon_sym_typeprefix = 178,
    anon_sym_import = 179,
    anon_sym_Object = 180,
    anon_sym_oneway = 181,
    anon_sym_context = 182,
    sym_value_base_type = 183,
    anon_sym_component = 184,
    anon_sym_provides = 185,
    anon_sym_uses = 186,
    anon_sym_multiple = 187,
    anon_sym_home = 188,
    anon_sym_manages = 189,
    anon_sym_emits = 190,
    anon_sym_publishes = 191,
    anon_sym_consumes = 192,
    anon_sym_primarykey = 193,
    anon_sym_finder = 194,
    anon_sym_porttype = 195,
    anon_sym_port = 196,
    anon_sym_mirrorport = 197,
    anon_sym_connector = 198,
    anon_sym_native = 199,
    sym_identifier = 200,
    anon_sym_SLASH_SLASH = 201,
    aux_sym_comment_token1 = 202,
    anon_sym_SLASH_STAR = 203,
    aux_sym_comment_token2 = 204,
    sym_specification = 205,
    sym_signed_short_int = 206,
    sym_signed_long_int = 207,
    sym_signed_longlong_int = 208,
    sym_unsigned_int = 209,
    sym_fixed_pt_const_type = 210,
    sym_integer_type = 211,
    sym_signed_int = 212,
    sym_unsigned_short_int = 213,
    sym_unsigned_long_int = 214,
    sym_unsigned_longlong_int = 215,
    sym_floating_pt_type = 216,
    sym_scoped_name = 217,
    sym_string_type = 218,
    sym_wide_string_type = 219,
    sym_type_spec = 220,
    sym_simple_type_spec = 221,
    sym_base_type_spec = 222,
    sym_any_type = 223,
    sym_fixed_pt_type = 224,
    sym_template_type_spec = 225,
    sym_sequence_type = 226,
    sym_map_type = 227,
    sym_positive_int_const = 228,
    sym_const_expr = 229,
    sym_or_expr = 230,
    sym_xor_expr = 231,
    sym_and_expr = 232,
    sym_shift_expr = 233,
    sym_add_expr = 234,
    sym_mult_expr = 235,
    sym_unary_expr = 236,
    sym_primary_expr = 237,
    sym_unary_operator = 238,
    sym_literal = 239,
    sym_integer_literal = 240,
    sym_integer_sign = 241,
    sym_oct_number = 242,
    sym_dec_number = 243,
    sym_floating_pt_literal = 244,
    sym_fixed_pt_literal = 245,
    sym_string_literal = 246,
    sym_wide_string_literal = 247,
    sym_char_literal = 248,
    sym_wide_character_literal = 249,
    sym_boolean_literal = 250,
    sym_preproc_define = 251,
    sym_preproc_call = 252,
    sym_preproc_include = 253,
    sym_system_lib_string = 254,
    sym_except_dcl = 255,
    sym_interface_dcl = 256,
    sym_interface_kind = 257,
    sym_interface_forward_dcl = 258,
    sym_interface_def = 259,
    sym_interface_header = 260,
    sym_interface_inheritance_spec = 261,
    sym_interface_name = 262,
    sym_interface_body = 263,
    sym_export = 264,
    sym_op_dcl = 265,
    sym_op_type_spec = 266,
    sym_parameter_dcls = 267,
    sym_param_dcl = 268,
    sym_param_attribute = 269,
    sym_raises_expr = 270,
    sym_attr_dcl = 271,
    sym_readonly_attr_spec = 272,
    sym_readonly_attr_declarator = 273,
    sym_attr_spec = 274,
    sym_attr_declarator = 275,
    sym_attr_raises_expr = 276,
    sym_get_excep_expr = 277,
    sym_set_excep_expr = 278,
    sym_exception_list = 279,
    sym_bitset_dcl = 280,
    sym_bitfield = 281,
    sym_bitfield_spec = 282,
    sym_destination_type = 283,
    sym_bitmask_dcl = 284,
    sym_bit_value = 285,
    sym_annotation_dcl = 286,
    sym_annotation_body = 287,
    sym_annotation_member = 288,
    sym_annotation_member_type = 289,
    sym_any_const_type = 290,
    sym_annotation_appl = 291,
    sym_extend_annotation_appl = 292,
    sym_annotation_appl_custom_body = 293,
    sym_annotation_appl_params = 294,
    sym_annotation_appl_param = 295,
    sym_annotation_appl_builtin_body = 296,
    sym_annotation_appl_id = 297,
    sym_annotation_appl_autoid = 298,
    sym_autoid_kind = 299,
    sym_annotation_appl_optional = 300,
    sym_annotation_appl_position = 301,
    sym_annotation_appl_value = 302,
    sym_annotation_appl_extensibility = 303,
    sym_extensibility_kind = 304,
    sym_annotation_appl_final = 305,
    sym_annotation_appl_appendable = 306,
    sym_annotation_appl_mutable = 307,
    sym_annotation_appl_key = 308,
    sym_annotation_appl_must_understand = 309,
    sym_annotation_appl_default_literal = 310,
    sym_annotation_appl_default = 311,
    sym_annotation_appl_range = 312,
    sym_min_expr = 313,
    sym_max_expr = 314,
    sym_annotation_appl_min = 315,
    sym_annotation_appl_max = 316,
    sym_annotation_appl_unit = 317,
    sym_annotation_appl_bit_bound = 318,
    sym_annotation_appl_external = 319,
    sym_annotation_appl_nested = 320,
    sym_annotation_appl_verbatim = 321,
    sym_verbatim_language = 322,
    sym_placement_kind = 323,
    sym_annotation_appl_service = 324,
    sym_service_platform = 325,
    sym_annotation_appl_oneway = 326,
    sym_annotation_appl_ami = 327,
    sym_annotation_appl_hashid = 328,
    sym_annotation_appl_default_nested = 329,
    sym_annotation_appl_ignore_literal_names = 330,
    sym_annotation_appl_try_construct = 331,
    sym_try_construct_fail_action = 332,
    sym_annotation_appl_non_serialized = 333,
    sym_annotation_appl_data_representation = 334,
    sym_data_representation_mask = 335,
    sym_annotation_appl_topic = 336,
    sym_topic_platform = 337,
    sym_annotation_appl_dds_request_topic = 338,
    sym_annotation_appl_dds_reply_topic = 339,
    sym_template_module_dcl = 340,
    sym_formal_parameters = 341,
    sym_formal_parameter = 342,
    sym_formal_parameter_type = 343,
    sym_tpl_definition = 344,
    sym_template_module_inst = 345,
    sym_actual_parameters = 346,
    sym_actual_parameter = 347,
    sym_template_module_ref = 348,
    sym_formal_parameter_names = 349,
    sym_value_dcl = 350,
    sym_value_def = 351,
    sym_value_kind = 352,
    sym_value_header = 353,
    sym_value_inheritance_spec = 354,
    sym_value_inheritance = 355,
    sym_value_supports = 356,
    sym_value_name = 357,
    sym_value_element = 358,
    sym_state_member = 359,
    sym_init_dcl = 360,
    sym_init_param_dcls = 361,
    sym_init_param_dcl = 362,
    sym_value_forward_dcl = 363,
    sym_typedef_dcl = 364,
    sym_type_declarator = 365,
    sym_any_declarators = 366,
    sym_any_declarator = 367,
    sym_simple_declarator = 368,
    sym_declarator = 369,
    sym_declarators = 370,
    sym_array_declarator = 371,
    sym_fixed_array_size = 372,
    sym_enum_dcl = 373,
    sym_enumerator = 374,
    sym_union_dcl = 375,
    sym_union_forward_dcl = 376,
    sym_union_def = 377,
    sym_case = 378,
    sym_case_label = 379,
    sym_element_spec = 380,
    sym_switch_type_spec = 381,
    sym_type_id_dcl = 382,
    sym_type_prefix_dcl = 383,
    sym_import_dcl = 384,
    sym_imported_scope = 385,
    sym_object_type = 386,
    sym_op_oneway_dcl = 387,
    sym_in_parameter_dcls = 388,
    sym_in_param_dcl = 389,
    sym_op_with_context = 390,
    sym_context_expr = 391,
    sym_value_box_def = 392,
    sym_value_abs_def = 393,
    sym_component_dcl = 394,
    sym_component_forward_dcl = 395,
    sym_component_def = 396,
    sym_component_header = 397,
    sym_component_inheritance_spec = 398,
    sym_component_body = 399,
    sym_component_export = 400,
    sym_provides_dcl = 401,
    sym_interface_type = 402,
    sym_uses_dcl = 403,
    sym_home_dcl = 404,
    sym_home_header = 405,
    sym_home_inheritance_spec = 406,
    sym_home_body = 407,
    sym_home_export = 408,
    sym_factory_dcl = 409,
    sym_factory_param_dcls = 410,
    sym_factory_param_dcl = 411,
    sym_supported_interface_spec = 412,
    sym_emits_dcl = 413,
    sym_publishes_dcl = 414,
    sym_consumes_dcl = 415,
    sym_primary_key_spec = 416,
    sym_finder_dcl = 417,
    sym_event_dcl = 418,
    sym_event_forward_dcl = 419,
    sym_event_abs_def = 420,
    sym_event_def = 421,
    sym_event_header = 422,
    sym_porttype_dcl = 423,
    sym_porttype_forward_dcl = 424,
    sym_porttype_def = 425,
    sym_port_body = 426,
    sym_port_ref = 427,
    sym_port_export = 428,
    sym_port_dcl = 429,
    sym_connector_dcl = 430,
    sym_connector_header = 431,
    sym_connector_inherit_spec = 432,
    sym_connector_export = 433,
    sym_definition = 434,
    sym_type_dcl = 435,
    sym_constr_type_dcl = 436,
    sym_native_dcl = 437,
    sym_module_dcl = 438,
    sym_struct_dcl = 439,
    sym_struct_forward_dcl = 440,
    sym_struct_def = 441,
    sym_member = 442,
    sym_default = 443,
    sym_const_dcl = 444,
    sym_const_type = 445,
    sym_comment = 446,
    aux_sym_specification_repeat1 = 447,
    aux_sym_string_literal_repeat1 = 448,
    aux_sym_char_literal_repeat1 = 449,
    aux_sym_except_dcl_repeat1 = 450,
    aux_sym_interface_dcl_repeat1 = 451,
    aux_sym_interface_inheritance_spec_repeat1 = 452,
    aux_sym_interface_body_repeat1 = 453,
    aux_sym_parameter_dcls_repeat1 = 454,
    aux_sym_raises_expr_repeat1 = 455,
    aux_sym_readonly_attr_declarator_repeat1 = 456,
    aux_sym_bitset_dcl_repeat1 = 457,
    aux_sym_bitfield_repeat1 = 458,
    aux_sym_bitmask_dcl_repeat1 = 459,
    aux_sym_annotation_dcl_repeat1 = 460,
    aux_sym_annotation_appl_params_repeat1 = 461,
    aux_sym_annotation_appl_data_representation_repeat1 = 462,
    aux_sym_template_module_dcl_repeat1 = 463,
    aux_sym_formal_parameters_repeat1 = 464,
    aux_sym_actual_parameters_repeat1 = 465,
    aux_sym_formal_parameter_names_repeat1 = 466,
    aux_sym_value_def_repeat1 = 467,
    aux_sym_value_inheritance_spec_repeat1 = 468,
    aux_sym_init_param_dcls_repeat1 = 469,
    aux_sym_any_declarators_repeat1 = 470,
    aux_sym_declarators_repeat1 = 471,
    aux_sym_array_declarator_repeat1 = 472,
    aux_sym_enum_dcl_repeat1 = 473,
    aux_sym_union_def_repeat1 = 474,
    aux_sym_case_repeat1 = 475,
    aux_sym_in_parameter_dcls_repeat1 = 476,
    aux_sym_context_expr_repeat1 = 477,
    aux_sym_component_body_repeat1 = 478,
    aux_sym_home_body_repeat1 = 479,
    aux_sym_factory_param_dcls_repeat1 = 480,
    aux_sym_port_body_repeat1 = 481,
    aux_sym_connector_dcl_repeat1 = 482,
};

static const char *const ts_symbol_names[] = {
    [ts_builtin_sym_end] = "end",
    [anon_sym_short] = "short",
    [anon_sym_int16] = "int16",
    [anon_sym_long] = "long",
    [anon_sym_int32] = "int32",
    [anon_sym_longlong] = "long long",
    [anon_sym_int64] = "int64",
    [sym_unsigned_tiny_int] = "unsigned_tiny_int",
    [sym_boolean_type] = "boolean_type",
    [anon_sym_fixed] = "fixed",
    [sym_octet_type] = "octet_type",
    [sym_signed_tiny_int] = "signed_tiny_int",
    [anon_sym_unsignedshort] = "unsigned short",
    [anon_sym_uint16] = "uint16",
    [anon_sym_unsignedlong] = "unsigned long",
    [anon_sym_uint32] = "uint32",
    [anon_sym_unsignedlonglong] = "unsigned long long",
    [anon_sym_uint64] = "uint64",
    [anon_sym_float] = "float",
    [anon_sym_double] = "double",
    [anon_sym_longdouble] = "long double",
    [sym_char_type] = "char_type",
    [sym_wide_char_type] = "wide_char_type",
    [anon_sym_COLON_COLON] = "::",
    [anon_sym_string] = "string",
    [anon_sym_LT] = "<",
    [anon_sym_GT] = ">",
    [anon_sym_wstring] = "wstring",
    [anon_sym_any] = "any",
    [anon_sym_COMMA] = ",",
    [anon_sym_sequence] = "sequence",
    [anon_sym_map] = "map",
    [anon_sym_PIPE] = "|",
    [anon_sym_CARET] = "^",
    [anon_sym_AMP] = "&",
    [anon_sym_GT_GT] = ">>",
    [anon_sym_LT_LT] = "<<",
    [anon_sym_PLUS] = "+",
    [anon_sym_DASH] = "-",
    [anon_sym_STAR] = "*",
    [anon_sym_SLASH] = "/",
    [anon_sym_PERCENT] = "%",
    [anon_sym_LPAREN] = "(",
    [anon_sym_RPAREN] = ")",
    [anon_sym_TILDE] = "~",
    [sym_bin_number] = "bin_number",
    [aux_sym_oct_number_token1] = "oct_number_token1",
    [aux_sym_oct_number_token2] = "oct_number_token2",
    [anon_sym_0] = "0",
    [aux_sym_dec_number_token1] = "dec_number_token1",
    [sym_hex_number] = "hex_number",
    [anon_sym_DOT] = ".",
    [aux_sym_floating_pt_literal_token1] = "floating_pt_literal_token1",
    [aux_sym_fixed_pt_literal_token1] = "fixed_pt_literal_token1",
    [sym_escape_sequence] = "escape_sequence",
    [anon_sym_DQUOTE] = "\"",
    [aux_sym_string_literal_token1] = "string_content",
    [anon_sym_L] = "L",
    [anon_sym_SQUOTE] = "'",
    [aux_sym_char_literal_token1] = "character",
    [anon_sym_TRUE] = "TRUE",
    [anon_sym_FALSE] = "FALSE",
    [anon_sym_POUNDdefine] = "#define",
    [aux_sym_preproc_define_token1] = "args",
    [aux_sym_preproc_call_token1] = "preproc_call_token1",
    [sym_preproc_directive] = "preproc_directive",
    [sym_preproc_arg] = "preproc_arg",
    [aux_sym_preproc_include_token1] = "keyword_include",
    [sym_system_lib_path] = "system_lib_path",
    [anon_sym_exception] = "exception",
    [anon_sym_LBRACE] = "{",
    [anon_sym_RBRACE] = "}",
    [anon_sym_local] = "local",
    [anon_sym_abstract] = "abstract",
    [anon_sym_interface] = "interface",
    [anon_sym_COLON] = ":",
    [anon_sym_SEMI] = ";",
    [anon_sym_void] = "void",
    [anon_sym_in] = "in",
    [anon_sym_out] = "out",
    [anon_sym_inout] = "inout",
    [anon_sym_raises] = "raises",
    [anon_sym_readonly] = "readonly",
    [anon_sym_attribute] = "attribute",
    [anon_sym_getraises] = "getraises",
    [anon_sym_setraises] = "setraises",
    [anon_sym_bitset] = "bitset",
    [anon_sym_bitfield] = "bitfield",
    [anon_sym_bitmask] = "bitmask",
    [anon_sym_ATannotation] = "@annotation",
    [anon_sym_default] = "default",
    [anon_sym_AT] = "@",
    [anon_sym_SLASH_SLASH_AT] = "//@",
    [aux_sym_extend_annotation_appl_token1] = "extend_annotation_appl_token1",
    [anon_sym_EQ] = "=",
    [aux_sym_annotation_appl_id_token1] = "anno_name",
    [aux_sym_annotation_appl_autoid_token1] = "anno_name",
    [aux_sym_autoid_kind_token1] = "autoid_kind_token1",
    [aux_sym_autoid_kind_token2] = "autoid_kind_token2",
    [aux_sym_annotation_appl_optional_token1] = "anno_name",
    [aux_sym_annotation_appl_position_token1] = "anno_name",
    [aux_sym_annotation_appl_value_token1] = "anno_name",
    [aux_sym_annotation_appl_extensibility_token1] = "anno_name",
    [aux_sym_extensibility_kind_token1] = "extensibility_kind_token1",
    [aux_sym_extensibility_kind_token2] = "extensibility_kind_token2",
    [aux_sym_extensibility_kind_token3] = "extensibility_kind_token3",
    [aux_sym_annotation_appl_final_token1] = "anno_name",
    [aux_sym_annotation_appl_appendable_token1] = "anno_name",
    [aux_sym_annotation_appl_mutable_token1] = "anno_name",
    [aux_sym_annotation_appl_key_token1] = "anno_name",
    [aux_sym_annotation_appl_must_understand_token1] = "anno_name",
    [aux_sym_annotation_appl_default_literal_token1] = "anno_name",
    [aux_sym_annotation_appl_default_token1] = "anno_name",
    [aux_sym_annotation_appl_range_token1] = "anno_name",
    [aux_sym_min_expr_token1] = "range_kind",
    [aux_sym_max_expr_token1] = "range_kind",
    [aux_sym_annotation_appl_unit_token1] = "anno_name",
    [aux_sym_annotation_appl_bit_bound_token1] = "anno_name",
    [aux_sym_annotation_appl_external_token1] = "anno_name",
    [aux_sym_annotation_appl_nested_token1] = "anno_name",
    [aux_sym_annotation_appl_verbatim_token1] = "anno_name",
    [aux_sym_verbatim_language_token1] = "verbatim_language_token1",
    [aux_sym_verbatim_language_token2] = "verbatim_language_token2",
    [aux_sym_verbatim_language_token3] = "verbatim_language_token3",
    [aux_sym_verbatim_language_token4] = "verbatim_language_token4",
    [aux_sym_placement_kind_token1] = "placement_kind_token1",
    [aux_sym_placement_kind_token2] = "placement_kind_token2",
    [aux_sym_placement_kind_token3] = "placement_kind_token3",
    [aux_sym_placement_kind_token4] = "placement_kind_token4",
    [aux_sym_placement_kind_token5] = "placement_kind_token5",
    [aux_sym_placement_kind_token6] = "placement_kind_token6",
    [aux_sym_annotation_appl_service_token1] = "anno_name",
    [aux_sym_service_platform_token1] = "service_platform_token1",
    [aux_sym_service_platform_token2] = "service_platform_token2",
    [aux_sym_annotation_appl_oneway_token1] = "anno_name",
    [aux_sym_annotation_appl_ami_token1] = "anno_name",
    [anon_sym_hashid] = "anno_name",
    [aux_sym_annotation_appl_default_nested_token1] = "anno_name",
    [aux_sym_annotation_appl_ignore_literal_names_token1] = "anno_name",
    [aux_sym_annotation_appl_try_construct_token1] = "anno_name",
    [aux_sym_try_construct_fail_action_token1] = "try_construct_fail_action_token1",
    [aux_sym_try_construct_fail_action_token2] = "try_construct_fail_action_token2",
    [aux_sym_try_construct_fail_action_token3] = "try_construct_fail_action_token3",
    [aux_sym_annotation_appl_non_serialized_token1] = "anno_name",
    [aux_sym_annotation_appl_data_representation_token1] = "anno_name",
    [anon_sym_allowed_kinds] = "allowed_kinds",
    [aux_sym_data_representation_mask_token1] = "data_representation_mask_token1",
    [aux_sym_data_representation_mask_token2] = "data_representation_mask_token2",
    [aux_sym_data_representation_mask_token3] = "data_representation_mask_token3",
    [aux_sym_data_representation_mask_token4] = "data_representation_mask_token4",
    [aux_sym_annotation_appl_topic_token1] = "annotation_appl_topic_token1",
    [sym_annotation_appl_choice] = "annotation_appl_choice",
    [sym_annotation_appl_empty] = "annotation_appl_empty",
    [sym_annotation_appl_dds_service] = "annotation_appl_dds_service",
    [aux_sym_annotation_appl_dds_request_topic_token1] = "anno_name",
    [aux_sym_annotation_appl_dds_request_topic_token2] = "arg_key",
    [aux_sym_annotation_appl_dds_reply_topic_token1] = "anno_name",
    [anon_sym_module] = "module",
    [anon_sym_typename] = "typename",
    [anon_sym_valuetype] = "valuetype",
    [anon_sym_eventtype] = "eventtype",
    [anon_sym_struct] = "struct",
    [anon_sym_union] = "union",
    [anon_sym_enum] = "enum",
    [anon_sym_const] = "const",
    [anon_sym_alias] = "alias",
    [anon_sym_custom] = "custom",
    [anon_sym_truncatable] = "truncatable",
    [anon_sym_supports] = "supports",
    [anon_sym_public] = "public",
    [anon_sym_private] = "private",
    [anon_sym_factory] = "factory",
    [anon_sym_typedef] = "typedef",
    [anon_sym_LBRACK] = "[",
    [anon_sym_RBRACK] = "]",
    [anon_sym_switch] = "switch",
    [anon_sym_case] = "case",
    [anon_sym_typeid] = "typeid",
    [anon_sym_typeprefix] = "typeprefix",
    [anon_sym_import] = "import",
    [anon_sym_Object] = "Object",
    [anon_sym_oneway] = "oneway",
    [anon_sym_context] = "context",
    [sym_value_base_type] = "value_base_type",
    [anon_sym_component] = "component",
    [anon_sym_provides] = "provides",
    [anon_sym_uses] = "uses",
    [anon_sym_multiple] = "multiple",
    [anon_sym_home] = "home",
    [anon_sym_manages] = "manages",
    [anon_sym_emits] = "emits",
    [anon_sym_publishes] = "publishes",
    [anon_sym_consumes] = "consumes",
    [anon_sym_primarykey] = "primarykey",
    [anon_sym_finder] = "finder",
    [anon_sym_porttype] = "porttype",
    [anon_sym_port] = "port",
    [anon_sym_mirrorport] = "mirrorport",
    [anon_sym_connector] = "connector",
    [anon_sym_native] = "native",
    [sym_identifier] = "identifier",
    [anon_sym_SLASH_SLASH] = "//",
    [aux_sym_comment_token1] = "comment_token1",
    [anon_sym_SLASH_STAR] = "/*",
    [aux_sym_comment_token2] = "comment_token2",
    [sym_specification] = "specification",
    [sym_signed_short_int] = "signed_short_int",
    [sym_signed_long_int] = "signed_long_int",
    [sym_signed_longlong_int] = "signed_longlong_int",
    [sym_unsigned_int] = "unsigned_int",
    [sym_fixed_pt_const_type] = "fixed_pt_const_type",
    [sym_integer_type] = "integer_type",
    [sym_signed_int] = "signed_int",
    [sym_unsigned_short_int] = "unsigned_short_int",
    [sym_unsigned_long_int] = "unsigned_long_int",
    [sym_unsigned_longlong_int] = "unsigned_longlong_int",
    [sym_floating_pt_type] = "floating_pt_type",
    [sym_scoped_name] = "scoped_name",
    [sym_string_type] = "string_type",
    [sym_wide_string_type] = "wide_string_type",
    [sym_type_spec] = "type_spec",
    [sym_simple_type_spec] = "simple_type_spec",
    [sym_base_type_spec] = "base_type_spec",
    [sym_any_type] = "any_type",
    [sym_fixed_pt_type] = "fixed_pt_type",
    [sym_template_type_spec] = "template_type_spec",
    [sym_sequence_type] = "sequence_type",
    [sym_map_type] = "map_type",
    [sym_positive_int_const] = "positive_int_const",
    [sym_const_expr] = "const_expr",
    [sym_or_expr] = "or_expr",
    [sym_xor_expr] = "xor_expr",
    [sym_and_expr] = "and_expr",
    [sym_shift_expr] = "shift_expr",
    [sym_add_expr] = "add_expr",
    [sym_mult_expr] = "mult_expr",
    [sym_unary_expr] = "unary_expr",
    [sym_primary_expr] = "primary_expr",
    [sym_unary_operator] = "unary_operator",
    [sym_literal] = "literal",
    [sym_integer_literal] = "integer_literal",
    [sym_integer_sign] = "integer_sign",
    [sym_oct_number] = "oct_number",
    [sym_dec_number] = "dec_number",
    [sym_floating_pt_literal] = "floating_pt_literal",
    [sym_fixed_pt_literal] = "fixed_pt_literal",
    [sym_string_literal] = "string_literal",
    [sym_wide_string_literal] = "wide_string_literal",
    [sym_char_literal] = "char_literal",
    [sym_wide_character_literal] = "wide_character_literal",
    [sym_boolean_literal] = "boolean_literal",
    [sym_preproc_define] = "preproc_define",
    [sym_preproc_call] = "preproc_call",
    [sym_preproc_include] = "preproc_include",
    [sym_system_lib_string] = "system_lib_string",
    [sym_except_dcl] = "except_dcl",
    [sym_interface_dcl] = "interface_dcl",
    [sym_interface_kind] = "interface_kind",
    [sym_interface_forward_dcl] = "interface_forward_dcl",
    [sym_interface_def] = "interface_def",
    [sym_interface_header] = "interface_header",
    [sym_interface_inheritance_spec] = "interface_inheritance_spec",
    [sym_interface_name] = "interface_name",
    [sym_interface_body] = "interface_body",
    [sym_export] = "export",
    [sym_op_dcl] = "op_dcl",
    [sym_op_type_spec] = "op_type_spec",
    [sym_parameter_dcls] = "parameter_dcls",
    [sym_param_dcl] = "param_dcl",
    [sym_param_attribute] = "param_attribute",
    [sym_raises_expr] = "raises_expr",
    [sym_attr_dcl] = "attr_dcl",
    [sym_readonly_attr_spec] = "readonly_attr_spec",
    [sym_readonly_attr_declarator] = "readonly_attr_declarator",
    [sym_attr_spec] = "attr_spec",
    [sym_attr_declarator] = "attr_declarator",
    [sym_attr_raises_expr] = "attr_raises_expr",
    [sym_get_excep_expr] = "get_excep_expr",
    [sym_set_excep_expr] = "set_excep_expr",
    [sym_exception_list] = "exception_list",
    [sym_bitset_dcl] = "bitset_dcl",
    [sym_bitfield] = "bitfield",
    [sym_bitfield_spec] = "bitfield_spec",
    [sym_destination_type] = "destination_type",
    [sym_bitmask_dcl] = "bitmask_dcl",
    [sym_bit_value] = "bit_value",
    [sym_annotation_dcl] = "annotation_dcl",
    [sym_annotation_body] = "annotation_body",
    [sym_annotation_member] = "annotation_member",
    [sym_annotation_member_type] = "annotation_member_type",
    [sym_any_const_type] = "any_const_type",
    [sym_annotation_appl] = "annotation_appl",
    [sym_extend_annotation_appl] = "extend_annotation_appl",
    [sym_annotation_appl_custom_body] = "annotation_appl_custom_body",
    [sym_annotation_appl_params] = "annotation_appl_params",
    [sym_annotation_appl_param] = "annotation_appl_param",
    [sym_annotation_appl_builtin_body] = "annotation_appl_builtin_body",
    [sym_annotation_appl_id] = "annotation_appl_id",
    [sym_annotation_appl_autoid] = "annotation_appl_autoid",
    [sym_autoid_kind] = "autoid_kind",
    [sym_annotation_appl_optional] = "annotation_appl_optional",
    [sym_annotation_appl_position] = "annotation_appl_position",
    [sym_annotation_appl_value] = "annotation_appl_value",
    [sym_annotation_appl_extensibility] = "annotation_appl_extensibility",
    [sym_extensibility_kind] = "extensibility_kind",
    [sym_annotation_appl_final] = "annotation_appl_final",
    [sym_annotation_appl_appendable] = "annotation_appl_appendable",
    [sym_annotation_appl_mutable] = "annotation_appl_mutable",
    [sym_annotation_appl_key] = "annotation_appl_key",
    [sym_annotation_appl_must_understand] = "annotation_appl_must_understand",
    [sym_annotation_appl_default_literal] = "annotation_appl_default_literal",
    [sym_annotation_appl_default] = "annotation_appl_default",
    [sym_annotation_appl_range] = "annotation_appl_range",
    [sym_min_expr] = "min_expr",
    [sym_max_expr] = "max_expr",
    [sym_annotation_appl_min] = "annotation_appl_min",
    [sym_annotation_appl_max] = "annotation_appl_max",
    [sym_annotation_appl_unit] = "annotation_appl_unit",
    [sym_annotation_appl_bit_bound] = "annotation_appl_bit_bound",
    [sym_annotation_appl_external] = "annotation_appl_external",
    [sym_annotation_appl_nested] = "annotation_appl_nested",
    [sym_annotation_appl_verbatim] = "annotation_appl_verbatim",
    [sym_verbatim_language] = "verbatim_language",
    [sym_placement_kind] = "placement_kind",
    [sym_annotation_appl_service] = "annotation_appl_service",
    [sym_service_platform] = "service_platform",
    [sym_annotation_appl_oneway] = "annotation_appl_oneway",
    [sym_annotation_appl_ami] = "annotation_appl_ami",
    [sym_annotation_appl_hashid] = "annotation_appl_hashid",
    [sym_annotation_appl_default_nested] = "annotation_appl_default_nested",
    [sym_annotation_appl_ignore_literal_names] = "annotation_appl_ignore_literal_names",
    [sym_annotation_appl_try_construct] = "annotation_appl_try_construct",
    [sym_try_construct_fail_action] = "try_construct_fail_action",
    [sym_annotation_appl_non_serialized] = "annotation_appl_non_serialized",
    [sym_annotation_appl_data_representation] = "annotation_appl_data_representation",
    [sym_data_representation_mask] = "data_representation_mask",
    [sym_annotation_appl_topic] = "annotation_appl_topic",
    [sym_topic_platform] = "topic_platform",
    [sym_annotation_appl_dds_request_topic] = "annotation_appl_dds_request_topic",
    [sym_annotation_appl_dds_reply_topic] = "annotation_appl_dds_reply_topic",
    [sym_template_module_dcl] = "template_module_dcl",
    [sym_formal_parameters] = "formal_parameters",
    [sym_formal_parameter] = "formal_parameter",
    [sym_formal_parameter_type] = "formal_parameter_type",
    [sym_tpl_definition] = "tpl_definition",
    [sym_template_module_inst] = "template_module_inst",
    [sym_actual_parameters] = "actual_parameters",
    [sym_actual_parameter] = "actual_parameter",
    [sym_template_module_ref] = "template_module_ref",
    [sym_formal_parameter_names] = "formal_parameter_names",
    [sym_value_dcl] = "value_dcl",
    [sym_value_def] = "value_def",
    [sym_value_kind] = "value_kind",
    [sym_value_header] = "value_header",
    [sym_value_inheritance_spec] = "value_inheritance_spec",
    [sym_value_inheritance] = "value_inheritance",
    [sym_value_supports] = "value_supports",
    [sym_value_name] = "value_name",
    [sym_value_element] = "value_element",
    [sym_state_member] = "state_member",
    [sym_init_dcl] = "init_dcl",
    [sym_init_param_dcls] = "init_param_dcls",
    [sym_init_param_dcl] = "init_param_dcl",
    [sym_value_forward_dcl] = "value_forward_dcl",
    [sym_typedef_dcl] = "typedef_dcl",
    [sym_type_declarator] = "type_declarator",
    [sym_any_declarators] = "any_declarators",
    [sym_any_declarator] = "any_declarator",
    [sym_simple_declarator] = "simple_declarator",
    [sym_declarator] = "declarator",
    [sym_declarators] = "declarators",
    [sym_array_declarator] = "array_declarator",
    [sym_fixed_array_size] = "fixed_array_size",
    [sym_enum_dcl] = "enum_dcl",
    [sym_enumerator] = "enumerator",
    [sym_union_dcl] = "union_dcl",
    [sym_union_forward_dcl] = "union_forward_dcl",
    [sym_union_def] = "union_def",
    [sym_case] = "case",
    [sym_case_label] = "case_label",
    [sym_element_spec] = "element_spec",
    [sym_switch_type_spec] = "switch_type_spec",
    [sym_type_id_dcl] = "type_id_dcl",
    [sym_type_prefix_dcl] = "type_prefix_dcl",
    [sym_import_dcl] = "import_dcl",
    [sym_imported_scope] = "imported_scope",
    [sym_object_type] = "object_type",
    [sym_op_oneway_dcl] = "op_oneway_dcl",
    [sym_in_parameter_dcls] = "in_parameter_dcls",
    [sym_in_param_dcl] = "in_param_dcl",
    [sym_op_with_context] = "op_with_context",
    [sym_context_expr] = "context_expr",
    [sym_value_box_def] = "value_box_def",
    [sym_value_abs_def] = "value_abs_def",
    [sym_component_dcl] = "component_dcl",
    [sym_component_forward_dcl] = "component_forward_dcl",
    [sym_component_def] = "component_def",
    [sym_component_header] = "component_header",
    [sym_component_inheritance_spec] = "component_inheritance_spec",
    [sym_component_body] = "component_body",
    [sym_component_export] = "component_export",
    [sym_provides_dcl] = "provides_dcl",
    [sym_interface_type] = "interface_type",
    [sym_uses_dcl] = "uses_dcl",
    [sym_home_dcl] = "home_dcl",
    [sym_home_header] = "home_header",
    [sym_home_inheritance_spec] = "home_inheritance_spec",
    [sym_home_body] = "home_body",
    [sym_home_export] = "home_export",
    [sym_factory_dcl] = "factory_dcl",
    [sym_factory_param_dcls] = "factory_param_dcls",
    [sym_factory_param_dcl] = "factory_param_dcl",
    [sym_supported_interface_spec] = "supported_interface_spec",
    [sym_emits_dcl] = "emits_dcl",
    [sym_publishes_dcl] = "publishes_dcl",
    [sym_consumes_dcl] = "consumes_dcl",
    [sym_primary_key_spec] = "primary_key_spec",
    [sym_finder_dcl] = "finder_dcl",
    [sym_event_dcl] = "event_dcl",
    [sym_event_forward_dcl] = "event_forward_dcl",
    [sym_event_abs_def] = "event_abs_def",
    [sym_event_def] = "event_def",
    [sym_event_header] = "event_header",
    [sym_porttype_dcl] = "porttype_dcl",
    [sym_porttype_forward_dcl] = "porttype_forward_dcl",
    [sym_porttype_def] = "porttype_def",
    [sym_port_body] = "port_body",
    [sym_port_ref] = "port_ref",
    [sym_port_export] = "port_export",
    [sym_port_dcl] = "port_dcl",
    [sym_connector_dcl] = "connector_dcl",
    [sym_connector_header] = "connector_header",
    [sym_connector_inherit_spec] = "connector_inherit_spec",
    [sym_connector_export] = "connector_export",
    [sym_definition] = "definition",
    [sym_type_dcl] = "type_dcl",
    [sym_constr_type_dcl] = "constr_type_dcl",
    [sym_native_dcl] = "native_dcl",
    [sym_module_dcl] = "module_dcl",
    [sym_struct_dcl] = "struct_dcl",
    [sym_struct_forward_dcl] = "struct_forward_dcl",
    [sym_struct_def] = "struct_def",
    [sym_member] = "member",
    [sym_default] = "default",
    [sym_const_dcl] = "const_dcl",
    [sym_const_type] = "const_type",
    [sym_comment] = "comment",
    [aux_sym_specification_repeat1] = "specification_repeat1",
    [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
    [aux_sym_char_literal_repeat1] = "char_literal_repeat1",
    [aux_sym_except_dcl_repeat1] = "except_dcl_repeat1",
    [aux_sym_interface_dcl_repeat1] = "interface_dcl_repeat1",
    [aux_sym_interface_inheritance_spec_repeat1] = "interface_inheritance_spec_repeat1",
    [aux_sym_interface_body_repeat1] = "interface_body_repeat1",
    [aux_sym_parameter_dcls_repeat1] = "parameter_dcls_repeat1",
    [aux_sym_raises_expr_repeat1] = "raises_expr_repeat1",
    [aux_sym_readonly_attr_declarator_repeat1] = "readonly_attr_declarator_repeat1",
    [aux_sym_bitset_dcl_repeat1] = "bitset_dcl_repeat1",
    [aux_sym_bitfield_repeat1] = "bitfield_repeat1",
    [aux_sym_bitmask_dcl_repeat1] = "bitmask_dcl_repeat1",
    [aux_sym_annotation_dcl_repeat1] = "annotation_dcl_repeat1",
    [aux_sym_annotation_appl_params_repeat1] = "annotation_appl_params_repeat1",
    [aux_sym_annotation_appl_data_representation_repeat1] = "annotation_appl_data_representation_repeat1",
    [aux_sym_template_module_dcl_repeat1] = "template_module_dcl_repeat1",
    [aux_sym_formal_parameters_repeat1] = "formal_parameters_repeat1",
    [aux_sym_actual_parameters_repeat1] = "actual_parameters_repeat1",
    [aux_sym_formal_parameter_names_repeat1] = "formal_parameter_names_repeat1",
    [aux_sym_value_def_repeat1] = "value_def_repeat1",
    [aux_sym_value_inheritance_spec_repeat1] = "value_inheritance_spec_repeat1",
    [aux_sym_init_param_dcls_repeat1] = "init_param_dcls_repeat1",
    [aux_sym_any_declarators_repeat1] = "any_declarators_repeat1",
    [aux_sym_declarators_repeat1] = "declarators_repeat1",
    [aux_sym_array_declarator_repeat1] = "array_declarator_repeat1",
    [aux_sym_enum_dcl_repeat1] = "enum_dcl_repeat1",
    [aux_sym_union_def_repeat1] = "union_def_repeat1",
    [aux_sym_case_repeat1] = "case_repeat1",
    [aux_sym_in_parameter_dcls_repeat1] = "in_parameter_dcls_repeat1",
    [aux_sym_context_expr_repeat1] = "context_expr_repeat1",
    [aux_sym_component_body_repeat1] = "component_body_repeat1",
    [aux_sym_home_body_repeat1] = "home_body_repeat1",
    [aux_sym_factory_param_dcls_repeat1] = "factory_param_dcls_repeat1",
    [aux_sym_port_body_repeat1] = "port_body_repeat1",
    [aux_sym_connector_dcl_repeat1] = "connector_dcl_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
    [ts_builtin_sym_end] = ts_builtin_sym_end,
    [anon_sym_short] = anon_sym_short,
    [anon_sym_int16] = anon_sym_int16,
    [anon_sym_long] = anon_sym_long,
    [anon_sym_int32] = anon_sym_int32,
    [anon_sym_longlong] = anon_sym_longlong,
    [anon_sym_int64] = anon_sym_int64,
    [sym_unsigned_tiny_int] = sym_unsigned_tiny_int,
    [sym_boolean_type] = sym_boolean_type,
    [anon_sym_fixed] = anon_sym_fixed,
    [sym_octet_type] = sym_octet_type,
    [sym_signed_tiny_int] = sym_signed_tiny_int,
    [anon_sym_unsignedshort] = anon_sym_unsignedshort,
    [anon_sym_uint16] = anon_sym_uint16,
    [anon_sym_unsignedlong] = anon_sym_unsignedlong,
    [anon_sym_uint32] = anon_sym_uint32,
    [anon_sym_unsignedlonglong] = anon_sym_unsignedlonglong,
    [anon_sym_uint64] = anon_sym_uint64,
    [anon_sym_float] = anon_sym_float,
    [anon_sym_double] = anon_sym_double,
    [anon_sym_longdouble] = anon_sym_longdouble,
    [sym_char_type] = sym_char_type,
    [sym_wide_char_type] = sym_wide_char_type,
    [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
    [anon_sym_string] = anon_sym_string,
    [anon_sym_LT] = anon_sym_LT,
    [anon_sym_GT] = anon_sym_GT,
    [anon_sym_wstring] = anon_sym_wstring,
    [anon_sym_any] = anon_sym_any,
    [anon_sym_COMMA] = anon_sym_COMMA,
    [anon_sym_sequence] = anon_sym_sequence,
    [anon_sym_map] = anon_sym_map,
    [anon_sym_PIPE] = anon_sym_PIPE,
    [anon_sym_CARET] = anon_sym_CARET,
    [anon_sym_AMP] = anon_sym_AMP,
    [anon_sym_GT_GT] = anon_sym_GT_GT,
    [anon_sym_LT_LT] = anon_sym_LT_LT,
    [anon_sym_PLUS] = anon_sym_PLUS,
    [anon_sym_DASH] = anon_sym_DASH,
    [anon_sym_STAR] = anon_sym_STAR,
    [anon_sym_SLASH] = anon_sym_SLASH,
    [anon_sym_PERCENT] = anon_sym_PERCENT,
    [anon_sym_LPAREN] = anon_sym_LPAREN,
    [anon_sym_RPAREN] = anon_sym_RPAREN,
    [anon_sym_TILDE] = anon_sym_TILDE,
    [sym_bin_number] = sym_bin_number,
    [aux_sym_oct_number_token1] = aux_sym_oct_number_token1,
    [aux_sym_oct_number_token2] = aux_sym_oct_number_token2,
    [anon_sym_0] = anon_sym_0,
    [aux_sym_dec_number_token1] = aux_sym_dec_number_token1,
    [sym_hex_number] = sym_hex_number,
    [anon_sym_DOT] = anon_sym_DOT,
    [aux_sym_floating_pt_literal_token1] = aux_sym_floating_pt_literal_token1,
    [aux_sym_fixed_pt_literal_token1] = aux_sym_fixed_pt_literal_token1,
    [sym_escape_sequence] = sym_escape_sequence,
    [anon_sym_DQUOTE] = anon_sym_DQUOTE,
    [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
    [anon_sym_L] = anon_sym_L,
    [anon_sym_SQUOTE] = anon_sym_SQUOTE,
    [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
    [anon_sym_TRUE] = anon_sym_TRUE,
    [anon_sym_FALSE] = anon_sym_FALSE,
    [anon_sym_POUNDdefine] = anon_sym_POUNDdefine,
    [aux_sym_preproc_define_token1] = aux_sym_preproc_define_token1,
    [aux_sym_preproc_call_token1] = aux_sym_preproc_call_token1,
    [sym_preproc_directive] = sym_preproc_directive,
    [sym_preproc_arg] = sym_preproc_arg,
    [aux_sym_preproc_include_token1] = aux_sym_preproc_include_token1,
    [sym_system_lib_path] = sym_system_lib_path,
    [anon_sym_exception] = anon_sym_exception,
    [anon_sym_LBRACE] = anon_sym_LBRACE,
    [anon_sym_RBRACE] = anon_sym_RBRACE,
    [anon_sym_local] = anon_sym_local,
    [anon_sym_abstract] = anon_sym_abstract,
    [anon_sym_interface] = anon_sym_interface,
    [anon_sym_COLON] = anon_sym_COLON,
    [anon_sym_SEMI] = anon_sym_SEMI,
    [anon_sym_void] = anon_sym_void,
    [anon_sym_in] = anon_sym_in,
    [anon_sym_out] = anon_sym_out,
    [anon_sym_inout] = anon_sym_inout,
    [anon_sym_raises] = anon_sym_raises,
    [anon_sym_readonly] = anon_sym_readonly,
    [anon_sym_attribute] = anon_sym_attribute,
    [anon_sym_getraises] = anon_sym_getraises,
    [anon_sym_setraises] = anon_sym_setraises,
    [anon_sym_bitset] = anon_sym_bitset,
    [anon_sym_bitfield] = anon_sym_bitfield,
    [anon_sym_bitmask] = anon_sym_bitmask,
    [anon_sym_ATannotation] = anon_sym_ATannotation,
    [anon_sym_default] = anon_sym_default,
    [anon_sym_AT] = anon_sym_AT,
    [anon_sym_SLASH_SLASH_AT] = anon_sym_SLASH_SLASH_AT,
    [aux_sym_extend_annotation_appl_token1] = aux_sym_extend_annotation_appl_token1,
    [anon_sym_EQ] = anon_sym_EQ,
    [aux_sym_annotation_appl_id_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_autoid_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_autoid_kind_token1] = aux_sym_autoid_kind_token1,
    [aux_sym_autoid_kind_token2] = aux_sym_autoid_kind_token2,
    [aux_sym_annotation_appl_optional_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_position_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_value_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_extensibility_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_extensibility_kind_token1] = aux_sym_extensibility_kind_token1,
    [aux_sym_extensibility_kind_token2] = aux_sym_extensibility_kind_token2,
    [aux_sym_extensibility_kind_token3] = aux_sym_extensibility_kind_token3,
    [aux_sym_annotation_appl_final_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_appendable_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_mutable_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_key_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_must_understand_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_default_literal_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_default_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_range_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_min_expr_token1] = aux_sym_min_expr_token1,
    [aux_sym_max_expr_token1] = aux_sym_min_expr_token1,
    [aux_sym_annotation_appl_unit_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_bit_bound_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_external_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_nested_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_verbatim_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_verbatim_language_token1] = aux_sym_verbatim_language_token1,
    [aux_sym_verbatim_language_token2] = aux_sym_verbatim_language_token2,
    [aux_sym_verbatim_language_token3] = aux_sym_verbatim_language_token3,
    [aux_sym_verbatim_language_token4] = aux_sym_verbatim_language_token4,
    [aux_sym_placement_kind_token1] = aux_sym_placement_kind_token1,
    [aux_sym_placement_kind_token2] = aux_sym_placement_kind_token2,
    [aux_sym_placement_kind_token3] = aux_sym_placement_kind_token3,
    [aux_sym_placement_kind_token4] = aux_sym_placement_kind_token4,
    [aux_sym_placement_kind_token5] = aux_sym_placement_kind_token5,
    [aux_sym_placement_kind_token6] = aux_sym_placement_kind_token6,
    [aux_sym_annotation_appl_service_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_service_platform_token1] = aux_sym_service_platform_token1,
    [aux_sym_service_platform_token2] = aux_sym_service_platform_token2,
    [aux_sym_annotation_appl_oneway_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_ami_token1] = aux_sym_annotation_appl_id_token1,
    [anon_sym_hashid] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_default_nested_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_ignore_literal_names_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_try_construct_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_try_construct_fail_action_token1] = aux_sym_try_construct_fail_action_token1,
    [aux_sym_try_construct_fail_action_token2] = aux_sym_try_construct_fail_action_token2,
    [aux_sym_try_construct_fail_action_token3] = aux_sym_try_construct_fail_action_token3,
    [aux_sym_annotation_appl_non_serialized_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_data_representation_token1] = aux_sym_annotation_appl_id_token1,
    [anon_sym_allowed_kinds] = anon_sym_allowed_kinds,
    [aux_sym_data_representation_mask_token1] = aux_sym_data_representation_mask_token1,
    [aux_sym_data_representation_mask_token2] = aux_sym_data_representation_mask_token2,
    [aux_sym_data_representation_mask_token3] = aux_sym_data_representation_mask_token3,
    [aux_sym_data_representation_mask_token4] = aux_sym_data_representation_mask_token4,
    [aux_sym_annotation_appl_topic_token1] = aux_sym_annotation_appl_topic_token1,
    [sym_annotation_appl_choice] = sym_annotation_appl_choice,
    [sym_annotation_appl_empty] = sym_annotation_appl_empty,
    [sym_annotation_appl_dds_service] = sym_annotation_appl_dds_service,
    [aux_sym_annotation_appl_dds_request_topic_token1] = aux_sym_annotation_appl_id_token1,
    [aux_sym_annotation_appl_dds_request_topic_token2] = aux_sym_annotation_appl_dds_request_topic_token2,
    [aux_sym_annotation_appl_dds_reply_topic_token1] = aux_sym_annotation_appl_id_token1,
    [anon_sym_module] = anon_sym_module,
    [anon_sym_typename] = anon_sym_typename,
    [anon_sym_valuetype] = anon_sym_valuetype,
    [anon_sym_eventtype] = anon_sym_eventtype,
    [anon_sym_struct] = anon_sym_struct,
    [anon_sym_union] = anon_sym_union,
    [anon_sym_enum] = anon_sym_enum,
    [anon_sym_const] = anon_sym_const,
    [anon_sym_alias] = anon_sym_alias,
    [anon_sym_custom] = anon_sym_custom,
    [anon_sym_truncatable] = anon_sym_truncatable,
    [anon_sym_supports] = anon_sym_supports,
    [anon_sym_public] = anon_sym_public,
    [anon_sym_private] = anon_sym_private,
    [anon_sym_factory] = anon_sym_factory,
    [anon_sym_typedef] = anon_sym_typedef,
    [anon_sym_LBRACK] = anon_sym_LBRACK,
    [anon_sym_RBRACK] = anon_sym_RBRACK,
    [anon_sym_switch] = anon_sym_switch,
    [anon_sym_case] = anon_sym_case,
    [anon_sym_typeid] = anon_sym_typeid,
    [anon_sym_typeprefix] = anon_sym_typeprefix,
    [anon_sym_import] = anon_sym_import,
    [anon_sym_Object] = anon_sym_Object,
    [anon_sym_oneway] = anon_sym_oneway,
    [anon_sym_context] = anon_sym_context,
    [sym_value_base_type] = sym_value_base_type,
    [anon_sym_component] = anon_sym_component,
    [anon_sym_provides] = anon_sym_provides,
    [anon_sym_uses] = anon_sym_uses,
    [anon_sym_multiple] = anon_sym_multiple,
    [anon_sym_home] = anon_sym_home,
    [anon_sym_manages] = anon_sym_manages,
    [anon_sym_emits] = anon_sym_emits,
    [anon_sym_publishes] = anon_sym_publishes,
    [anon_sym_consumes] = anon_sym_consumes,
    [anon_sym_primarykey] = anon_sym_primarykey,
    [anon_sym_finder] = anon_sym_finder,
    [anon_sym_porttype] = anon_sym_porttype,
    [anon_sym_port] = anon_sym_port,
    [anon_sym_mirrorport] = anon_sym_mirrorport,
    [anon_sym_connector] = anon_sym_connector,
    [anon_sym_native] = anon_sym_native,
    [sym_identifier] = sym_identifier,
    [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
    [aux_sym_comment_token1] = aux_sym_comment_token1,
    [anon_sym_SLASH_STAR] = anon_sym_SLASH_STAR,
    [aux_sym_comment_token2] = aux_sym_comment_token2,
    [sym_specification] = sym_specification,
    [sym_signed_short_int] = sym_signed_short_int,
    [sym_signed_long_int] = sym_signed_long_int,
    [sym_signed_longlong_int] = sym_signed_longlong_int,
    [sym_unsigned_int] = sym_unsigned_int,
    [sym_fixed_pt_const_type] = sym_fixed_pt_const_type,
    [sym_integer_type] = sym_integer_type,
    [sym_signed_int] = sym_signed_int,
    [sym_unsigned_short_int] = sym_unsigned_short_int,
    [sym_unsigned_long_int] = sym_unsigned_long_int,
    [sym_unsigned_longlong_int] = sym_unsigned_longlong_int,
    [sym_floating_pt_type] = sym_floating_pt_type,
    [sym_scoped_name] = sym_scoped_name,
    [sym_string_type] = sym_string_type,
    [sym_wide_string_type] = sym_wide_string_type,
    [sym_type_spec] = sym_type_spec,
    [sym_simple_type_spec] = sym_simple_type_spec,
    [sym_base_type_spec] = sym_base_type_spec,
    [sym_any_type] = sym_any_type,
    [sym_fixed_pt_type] = sym_fixed_pt_type,
    [sym_template_type_spec] = sym_template_type_spec,
    [sym_sequence_type] = sym_sequence_type,
    [sym_map_type] = sym_map_type,
    [sym_positive_int_const] = sym_positive_int_const,
    [sym_const_expr] = sym_const_expr,
    [sym_or_expr] = sym_or_expr,
    [sym_xor_expr] = sym_xor_expr,
    [sym_and_expr] = sym_and_expr,
    [sym_shift_expr] = sym_shift_expr,
    [sym_add_expr] = sym_add_expr,
    [sym_mult_expr] = sym_mult_expr,
    [sym_unary_expr] = sym_unary_expr,
    [sym_primary_expr] = sym_primary_expr,
    [sym_unary_operator] = sym_unary_operator,
    [sym_literal] = sym_literal,
    [sym_integer_literal] = sym_integer_literal,
    [sym_integer_sign] = sym_integer_sign,
    [sym_oct_number] = sym_oct_number,
    [sym_dec_number] = sym_dec_number,
    [sym_floating_pt_literal] = sym_floating_pt_literal,
    [sym_fixed_pt_literal] = sym_fixed_pt_literal,
    [sym_string_literal] = sym_string_literal,
    [sym_wide_string_literal] = sym_wide_string_literal,
    [sym_char_literal] = sym_char_literal,
    [sym_wide_character_literal] = sym_wide_character_literal,
    [sym_boolean_literal] = sym_boolean_literal,
    [sym_preproc_define] = sym_preproc_define,
    [sym_preproc_call] = sym_preproc_call,
    [sym_preproc_include] = sym_preproc_include,
    [sym_system_lib_string] = sym_system_lib_string,
    [sym_except_dcl] = sym_except_dcl,
    [sym_interface_dcl] = sym_interface_dcl,
    [sym_interface_kind] = sym_interface_kind,
    [sym_interface_forward_dcl] = sym_interface_forward_dcl,
    [sym_interface_def] = sym_interface_def,
    [sym_interface_header] = sym_interface_header,
    [sym_interface_inheritance_spec] = sym_interface_inheritance_spec,
    [sym_interface_name] = sym_interface_name,
    [sym_interface_body] = sym_interface_body,
    [sym_export] = sym_export,
    [sym_op_dcl] = sym_op_dcl,
    [sym_op_type_spec] = sym_op_type_spec,
    [sym_parameter_dcls] = sym_parameter_dcls,
    [sym_param_dcl] = sym_param_dcl,
    [sym_param_attribute] = sym_param_attribute,
    [sym_raises_expr] = sym_raises_expr,
    [sym_attr_dcl] = sym_attr_dcl,
    [sym_readonly_attr_spec] = sym_readonly_attr_spec,
    [sym_readonly_attr_declarator] = sym_readonly_attr_declarator,
    [sym_attr_spec] = sym_attr_spec,
    [sym_attr_declarator] = sym_attr_declarator,
    [sym_attr_raises_expr] = sym_attr_raises_expr,
    [sym_get_excep_expr] = sym_get_excep_expr,
    [sym_set_excep_expr] = sym_set_excep_expr,
    [sym_exception_list] = sym_exception_list,
    [sym_bitset_dcl] = sym_bitset_dcl,
    [sym_bitfield] = sym_bitfield,
    [sym_bitfield_spec] = sym_bitfield_spec,
    [sym_destination_type] = sym_destination_type,
    [sym_bitmask_dcl] = sym_bitmask_dcl,
    [sym_bit_value] = sym_bit_value,
    [sym_annotation_dcl] = sym_annotation_dcl,
    [sym_annotation_body] = sym_annotation_body,
    [sym_annotation_member] = sym_annotation_member,
    [sym_annotation_member_type] = sym_annotation_member_type,
    [sym_any_const_type] = sym_any_const_type,
    [sym_annotation_appl] = sym_annotation_appl,
    [sym_extend_annotation_appl] = sym_extend_annotation_appl,
    [sym_annotation_appl_custom_body] = sym_annotation_appl_custom_body,
    [sym_annotation_appl_params] = sym_annotation_appl_params,
    [sym_annotation_appl_param] = sym_annotation_appl_param,
    [sym_annotation_appl_builtin_body] = sym_annotation_appl_builtin_body,
    [sym_annotation_appl_id] = sym_annotation_appl_id,
    [sym_annotation_appl_autoid] = sym_annotation_appl_autoid,
    [sym_autoid_kind] = sym_autoid_kind,
    [sym_annotation_appl_optional] = sym_annotation_appl_optional,
    [sym_annotation_appl_position] = sym_annotation_appl_position,
    [sym_annotation_appl_value] = sym_annotation_appl_value,
    [sym_annotation_appl_extensibility] = sym_annotation_appl_extensibility,
    [sym_extensibility_kind] = sym_extensibility_kind,
    [sym_annotation_appl_final] = sym_annotation_appl_final,
    [sym_annotation_appl_appendable] = sym_annotation_appl_appendable,
    [sym_annotation_appl_mutable] = sym_annotation_appl_mutable,
    [sym_annotation_appl_key] = sym_annotation_appl_key,
    [sym_annotation_appl_must_understand] = sym_annotation_appl_must_understand,
    [sym_annotation_appl_default_literal] = sym_annotation_appl_default_literal,
    [sym_annotation_appl_default] = sym_annotation_appl_default,
    [sym_annotation_appl_range] = sym_annotation_appl_range,
    [sym_min_expr] = sym_min_expr,
    [sym_max_expr] = sym_max_expr,
    [sym_annotation_appl_min] = sym_annotation_appl_min,
    [sym_annotation_appl_max] = sym_annotation_appl_max,
    [sym_annotation_appl_unit] = sym_annotation_appl_unit,
    [sym_annotation_appl_bit_bound] = sym_annotation_appl_bit_bound,
    [sym_annotation_appl_external] = sym_annotation_appl_external,
    [sym_annotation_appl_nested] = sym_annotation_appl_nested,
    [sym_annotation_appl_verbatim] = sym_annotation_appl_verbatim,
    [sym_verbatim_language] = sym_verbatim_language,
    [sym_placement_kind] = sym_placement_kind,
    [sym_annotation_appl_service] = sym_annotation_appl_service,
    [sym_service_platform] = sym_service_platform,
    [sym_annotation_appl_oneway] = sym_annotation_appl_oneway,
    [sym_annotation_appl_ami] = sym_annotation_appl_ami,
    [sym_annotation_appl_hashid] = sym_annotation_appl_hashid,
    [sym_annotation_appl_default_nested] = sym_annotation_appl_default_nested,
    [sym_annotation_appl_ignore_literal_names] = sym_annotation_appl_ignore_literal_names,
    [sym_annotation_appl_try_construct] = sym_annotation_appl_try_construct,
    [sym_try_construct_fail_action] = sym_try_construct_fail_action,
    [sym_annotation_appl_non_serialized] = sym_annotation_appl_non_serialized,
    [sym_annotation_appl_data_representation] = sym_annotation_appl_data_representation,
    [sym_data_representation_mask] = sym_data_representation_mask,
    [sym_annotation_appl_topic] = sym_annotation_appl_topic,
    [sym_topic_platform] = sym_topic_platform,
    [sym_annotation_appl_dds_request_topic] = sym_annotation_appl_dds_request_topic,
    [sym_annotation_appl_dds_reply_topic] = sym_annotation_appl_dds_reply_topic,
    [sym_template_module_dcl] = sym_template_module_dcl,
    [sym_formal_parameters] = sym_formal_parameters,
    [sym_formal_parameter] = sym_formal_parameter,
    [sym_formal_parameter_type] = sym_formal_parameter_type,
    [sym_tpl_definition] = sym_tpl_definition,
    [sym_template_module_inst] = sym_template_module_inst,
    [sym_actual_parameters] = sym_actual_parameters,
    [sym_actual_parameter] = sym_actual_parameter,
    [sym_template_module_ref] = sym_template_module_ref,
    [sym_formal_parameter_names] = sym_formal_parameter_names,
    [sym_value_dcl] = sym_value_dcl,
    [sym_value_def] = sym_value_def,
    [sym_value_kind] = sym_value_kind,
    [sym_value_header] = sym_value_header,
    [sym_value_inheritance_spec] = sym_value_inheritance_spec,
    [sym_value_inheritance] = sym_value_inheritance,
    [sym_value_supports] = sym_value_supports,
    [sym_value_name] = sym_value_name,
    [sym_value_element] = sym_value_element,
    [sym_state_member] = sym_state_member,
    [sym_init_dcl] = sym_init_dcl,
    [sym_init_param_dcls] = sym_init_param_dcls,
    [sym_init_param_dcl] = sym_init_param_dcl,
    [sym_value_forward_dcl] = sym_value_forward_dcl,
    [sym_typedef_dcl] = sym_typedef_dcl,
    [sym_type_declarator] = sym_type_declarator,
    [sym_any_declarators] = sym_any_declarators,
    [sym_any_declarator] = sym_any_declarator,
    [sym_simple_declarator] = sym_simple_declarator,
    [sym_declarator] = sym_declarator,
    [sym_declarators] = sym_declarators,
    [sym_array_declarator] = sym_array_declarator,
    [sym_fixed_array_size] = sym_fixed_array_size,
    [sym_enum_dcl] = sym_enum_dcl,
    [sym_enumerator] = sym_enumerator,
    [sym_union_dcl] = sym_union_dcl,
    [sym_union_forward_dcl] = sym_union_forward_dcl,
    [sym_union_def] = sym_union_def,
    [sym_case] = sym_case,
    [sym_case_label] = sym_case_label,
    [sym_element_spec] = sym_element_spec,
    [sym_switch_type_spec] = sym_switch_type_spec,
    [sym_type_id_dcl] = sym_type_id_dcl,
    [sym_type_prefix_dcl] = sym_type_prefix_dcl,
    [sym_import_dcl] = sym_import_dcl,
    [sym_imported_scope] = sym_imported_scope,
    [sym_object_type] = sym_object_type,
    [sym_op_oneway_dcl] = sym_op_oneway_dcl,
    [sym_in_parameter_dcls] = sym_in_parameter_dcls,
    [sym_in_param_dcl] = sym_in_param_dcl,
    [sym_op_with_context] = sym_op_with_context,
    [sym_context_expr] = sym_context_expr,
    [sym_value_box_def] = sym_value_box_def,
    [sym_value_abs_def] = sym_value_abs_def,
    [sym_component_dcl] = sym_component_dcl,
    [sym_component_forward_dcl] = sym_component_forward_dcl,
    [sym_component_def] = sym_component_def,
    [sym_component_header] = sym_component_header,
    [sym_component_inheritance_spec] = sym_component_inheritance_spec,
    [sym_component_body] = sym_component_body,
    [sym_component_export] = sym_component_export,
    [sym_provides_dcl] = sym_provides_dcl,
    [sym_interface_type] = sym_interface_type,
    [sym_uses_dcl] = sym_uses_dcl,
    [sym_home_dcl] = sym_home_dcl,
    [sym_home_header] = sym_home_header,
    [sym_home_inheritance_spec] = sym_home_inheritance_spec,
    [sym_home_body] = sym_home_body,
    [sym_home_export] = sym_home_export,
    [sym_factory_dcl] = sym_factory_dcl,
    [sym_factory_param_dcls] = sym_factory_param_dcls,
    [sym_factory_param_dcl] = sym_factory_param_dcl,
    [sym_supported_interface_spec] = sym_supported_interface_spec,
    [sym_emits_dcl] = sym_emits_dcl,
    [sym_publishes_dcl] = sym_publishes_dcl,
    [sym_consumes_dcl] = sym_consumes_dcl,
    [sym_primary_key_spec] = sym_primary_key_spec,
    [sym_finder_dcl] = sym_finder_dcl,
    [sym_event_dcl] = sym_event_dcl,
    [sym_event_forward_dcl] = sym_event_forward_dcl,
    [sym_event_abs_def] = sym_event_abs_def,
    [sym_event_def] = sym_event_def,
    [sym_event_header] = sym_event_header,
    [sym_porttype_dcl] = sym_porttype_dcl,
    [sym_porttype_forward_dcl] = sym_porttype_forward_dcl,
    [sym_porttype_def] = sym_porttype_def,
    [sym_port_body] = sym_port_body,
    [sym_port_ref] = sym_port_ref,
    [sym_port_export] = sym_port_export,
    [sym_port_dcl] = sym_port_dcl,
    [sym_connector_dcl] = sym_connector_dcl,
    [sym_connector_header] = sym_connector_header,
    [sym_connector_inherit_spec] = sym_connector_inherit_spec,
    [sym_connector_export] = sym_connector_export,
    [sym_definition] = sym_definition,
    [sym_type_dcl] = sym_type_dcl,
    [sym_constr_type_dcl] = sym_constr_type_dcl,
    [sym_native_dcl] = sym_native_dcl,
    [sym_module_dcl] = sym_module_dcl,
    [sym_struct_dcl] = sym_struct_dcl,
    [sym_struct_forward_dcl] = sym_struct_forward_dcl,
    [sym_struct_def] = sym_struct_def,
    [sym_member] = sym_member,
    [sym_default] = sym_default,
    [sym_const_dcl] = sym_const_dcl,
    [sym_const_type] = sym_const_type,
    [sym_comment] = sym_comment,
    [aux_sym_specification_repeat1] = aux_sym_specification_repeat1,
    [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
    [aux_sym_char_literal_repeat1] = aux_sym_char_literal_repeat1,
    [aux_sym_except_dcl_repeat1] = aux_sym_except_dcl_repeat1,
    [aux_sym_interface_dcl_repeat1] = aux_sym_interface_dcl_repeat1,
    [aux_sym_interface_inheritance_spec_repeat1] = aux_sym_interface_inheritance_spec_repeat1,
    [aux_sym_interface_body_repeat1] = aux_sym_interface_body_repeat1,
    [aux_sym_parameter_dcls_repeat1] = aux_sym_parameter_dcls_repeat1,
    [aux_sym_raises_expr_repeat1] = aux_sym_raises_expr_repeat1,
    [aux_sym_readonly_attr_declarator_repeat1] = aux_sym_readonly_attr_declarator_repeat1,
    [aux_sym_bitset_dcl_repeat1] = aux_sym_bitset_dcl_repeat1,
    [aux_sym_bitfield_repeat1] = aux_sym_bitfield_repeat1,
    [aux_sym_bitmask_dcl_repeat1] = aux_sym_bitmask_dcl_repeat1,
    [aux_sym_annotation_dcl_repeat1] = aux_sym_annotation_dcl_repeat1,
    [aux_sym_annotation_appl_params_repeat1] = aux_sym_annotation_appl_params_repeat1,
    [aux_sym_annotation_appl_data_representation_repeat1] = aux_sym_annotation_appl_data_representation_repeat1,
    [aux_sym_template_module_dcl_repeat1] = aux_sym_template_module_dcl_repeat1,
    [aux_sym_formal_parameters_repeat1] = aux_sym_formal_parameters_repeat1,
    [aux_sym_actual_parameters_repeat1] = aux_sym_actual_parameters_repeat1,
    [aux_sym_formal_parameter_names_repeat1] = aux_sym_formal_parameter_names_repeat1,
    [aux_sym_value_def_repeat1] = aux_sym_value_def_repeat1,
    [aux_sym_value_inheritance_spec_repeat1] = aux_sym_value_inheritance_spec_repeat1,
    [aux_sym_init_param_dcls_repeat1] = aux_sym_init_param_dcls_repeat1,
    [aux_sym_any_declarators_repeat1] = aux_sym_any_declarators_repeat1,
    [aux_sym_declarators_repeat1] = aux_sym_declarators_repeat1,
    [aux_sym_array_declarator_repeat1] = aux_sym_array_declarator_repeat1,
    [aux_sym_enum_dcl_repeat1] = aux_sym_enum_dcl_repeat1,
    [aux_sym_union_def_repeat1] = aux_sym_union_def_repeat1,
    [aux_sym_case_repeat1] = aux_sym_case_repeat1,
    [aux_sym_in_parameter_dcls_repeat1] = aux_sym_in_parameter_dcls_repeat1,
    [aux_sym_context_expr_repeat1] = aux_sym_context_expr_repeat1,
    [aux_sym_component_body_repeat1] = aux_sym_component_body_repeat1,
    [aux_sym_home_body_repeat1] = aux_sym_home_body_repeat1,
    [aux_sym_factory_param_dcls_repeat1] = aux_sym_factory_param_dcls_repeat1,
    [aux_sym_port_body_repeat1] = aux_sym_port_body_repeat1,
    [aux_sym_connector_dcl_repeat1] = aux_sym_connector_dcl_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
    [ts_builtin_sym_end] = {
        .visible = false,
        .named = true,
    },
    [anon_sym_short] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_int16] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_long] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_int32] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_longlong] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_int64] = {
        .visible = true,
        .named = false,
    },
    [sym_unsigned_tiny_int] = {
        .visible = true,
        .named = true,
    },
    [sym_boolean_type] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_fixed] = {
        .visible = true,
        .named = false,
    },
    [sym_octet_type] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_tiny_int] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_unsignedshort] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uint16] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_unsignedlong] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uint32] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_unsignedlonglong] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uint64] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_float] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_double] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_longdouble] = {
        .visible = true,
        .named = false,
    },
    [sym_char_type] = {
        .visible = true,
        .named = true,
    },
    [sym_wide_char_type] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_COLON_COLON] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_string] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_GT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_wstring] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_any] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_COMMA] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_sequence] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_map] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_PIPE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_CARET] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_AMP] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_GT_GT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LT_LT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_PLUS] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_DASH] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_STAR] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SLASH] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_PERCENT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LPAREN] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_RPAREN] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_TILDE] = {
        .visible = true,
        .named = false,
    },
    [sym_bin_number] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_oct_number_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_oct_number_token2] = {
        .visible = false,
        .named = false,
    },
    [anon_sym_0] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_dec_number_token1] = {
        .visible = false,
        .named = false,
    },
    [sym_hex_number] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_DOT] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_floating_pt_literal_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_fixed_pt_literal_token1] = {
        .visible = false,
        .named = false,
    },
    [sym_escape_sequence] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_DQUOTE] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_string_literal_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_L] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SQUOTE] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_char_literal_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_TRUE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_FALSE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_POUNDdefine] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_preproc_define_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_preproc_call_token1] = {
        .visible = false,
        .named = false,
    },
    [sym_preproc_directive] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_arg] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_preproc_include_token1] = {
        .visible = true,
        .named = true,
    },
    [sym_system_lib_path] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_exception] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LBRACE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_RBRACE] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_local] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_abstract] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_interface] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_COLON] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SEMI] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_void] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_in] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_out] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_inout] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_raises] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_readonly] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_attribute] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_getraises] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_setraises] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bitset] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bitfield] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_bitmask] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_ATannotation] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_default] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_AT] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_SLASH_SLASH_AT] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_extend_annotation_appl_token1] = {
        .visible = false,
        .named = false,
    },
    [anon_sym_EQ] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_annotation_appl_id_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_autoid_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_autoid_kind_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_autoid_kind_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_optional_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_position_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_value_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_extensibility_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_extensibility_kind_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_extensibility_kind_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_extensibility_kind_token3] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_final_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_appendable_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_mutable_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_key_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_must_understand_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_default_literal_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_default_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_range_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_min_expr_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_max_expr_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_unit_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_bit_bound_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_external_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_nested_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_verbatim_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_verbatim_language_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_verbatim_language_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_verbatim_language_token3] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_verbatim_language_token4] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_placement_kind_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_placement_kind_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_placement_kind_token3] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_placement_kind_token4] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_placement_kind_token5] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_placement_kind_token6] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_service_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_service_platform_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_service_platform_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_oneway_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_ami_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_hashid] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_default_nested_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_ignore_literal_names_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_try_construct_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_try_construct_fail_action_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_try_construct_fail_action_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_try_construct_fail_action_token3] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_non_serialized_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_data_representation_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_allowed_kinds] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_data_representation_mask_token1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_data_representation_mask_token2] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_data_representation_mask_token3] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_data_representation_mask_token4] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_topic_token1] = {
        .visible = false,
        .named = false,
    },
    [sym_annotation_appl_choice] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_empty] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_dds_service] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_dds_request_topic_token1] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_dds_request_topic_token2] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_annotation_appl_dds_reply_topic_token1] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_module] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typename] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_valuetype] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_eventtype] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_struct] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_union] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_enum] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_const] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_alias] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_custom] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_truncatable] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_supports] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_public] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_private] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_factory] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typedef] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_LBRACK] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_RBRACK] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_switch] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_case] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typeid] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_typeprefix] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_import] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_Object] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_oneway] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_context] = {
        .visible = true,
        .named = false,
    },
    [sym_value_base_type] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_component] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_provides] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_uses] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_multiple] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_home] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_manages] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_emits] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_publishes] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_consumes] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_primarykey] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_finder] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_porttype] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_port] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_mirrorport] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_connector] = {
        .visible = true,
        .named = false,
    },
    [anon_sym_native] = {
        .visible = true,
        .named = false,
    },
    [sym_identifier] = {
        .visible = true,
        .named = true,
    },
    [anon_sym_SLASH_SLASH] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_comment_token1] = {
        .visible = false,
        .named = false,
    },
    [anon_sym_SLASH_STAR] = {
        .visible = true,
        .named = false,
    },
    [aux_sym_comment_token2] = {
        .visible = false,
        .named = false,
    },
    [sym_specification] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_short_int] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_long_int] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_longlong_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_int] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_pt_const_type] = {
        .visible = true,
        .named = true,
    },
    [sym_integer_type] = {
        .visible = true,
        .named = true,
    },
    [sym_signed_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_short_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_long_int] = {
        .visible = true,
        .named = true,
    },
    [sym_unsigned_longlong_int] = {
        .visible = true,
        .named = true,
    },
    [sym_floating_pt_type] = {
        .visible = true,
        .named = true,
    },
    [sym_scoped_name] = {
        .visible = true,
        .named = true,
    },
    [sym_string_type] = {
        .visible = true,
        .named = true,
    },
    [sym_wide_string_type] = {
        .visible = true,
        .named = true,
    },
    [sym_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_simple_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_base_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_any_type] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_pt_type] = {
        .visible = true,
        .named = true,
    },
    [sym_template_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_sequence_type] = {
        .visible = true,
        .named = true,
    },
    [sym_map_type] = {
        .visible = true,
        .named = true,
    },
    [sym_positive_int_const] = {
        .visible = true,
        .named = true,
    },
    [sym_const_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_or_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_xor_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_and_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_shift_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_add_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_mult_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_unary_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_primary_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_unary_operator] = {
        .visible = true,
        .named = true,
    },
    [sym_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_integer_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_integer_sign] = {
        .visible = true,
        .named = true,
    },
    [sym_oct_number] = {
        .visible = true,
        .named = true,
    },
    [sym_dec_number] = {
        .visible = true,
        .named = true,
    },
    [sym_floating_pt_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_pt_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_string_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_wide_string_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_char_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_wide_character_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_boolean_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_define] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_call] = {
        .visible = true,
        .named = true,
    },
    [sym_preproc_include] = {
        .visible = true,
        .named = true,
    },
    [sym_system_lib_string] = {
        .visible = true,
        .named = true,
    },
    [sym_except_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_def] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_header] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_name] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_body] = {
        .visible = true,
        .named = true,
    },
    [sym_export] = {
        .visible = true,
        .named = true,
    },
    [sym_op_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_op_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_parameter_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_param_attribute] = {
        .visible = true,
        .named = true,
    },
    [sym_raises_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_readonly_attr_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_readonly_attr_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_attr_raises_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_get_excep_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_set_excep_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_exception_list] = {
        .visible = true,
        .named = true,
    },
    [sym_bitset_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_bitfield] = {
        .visible = true,
        .named = true,
    },
    [sym_bitfield_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_destination_type] = {
        .visible = true,
        .named = true,
    },
    [sym_bitmask_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_bit_value] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_body] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_member] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_member_type] = {
        .visible = true,
        .named = true,
    },
    [sym_any_const_type] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl] = {
        .visible = true,
        .named = true,
    },
    [sym_extend_annotation_appl] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_custom_body] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_params] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_param] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_builtin_body] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_id] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_autoid] = {
        .visible = true,
        .named = true,
    },
    [sym_autoid_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_optional] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_position] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_value] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_extensibility] = {
        .visible = true,
        .named = true,
    },
    [sym_extensibility_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_final] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_appendable] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_mutable] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_key] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_must_understand] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_default_literal] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_default] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_range] = {
        .visible = true,
        .named = true,
    },
    [sym_min_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_max_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_min] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_max] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_unit] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_bit_bound] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_external] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_nested] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_verbatim] = {
        .visible = true,
        .named = true,
    },
    [sym_verbatim_language] = {
        .visible = true,
        .named = true,
    },
    [sym_placement_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_service] = {
        .visible = true,
        .named = true,
    },
    [sym_service_platform] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_oneway] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_ami] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_hashid] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_default_nested] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_ignore_literal_names] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_try_construct] = {
        .visible = true,
        .named = true,
    },
    [sym_try_construct_fail_action] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_non_serialized] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_data_representation] = {
        .visible = true,
        .named = true,
    },
    [sym_data_representation_mask] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_topic] = {
        .visible = true,
        .named = true,
    },
    [sym_topic_platform] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_dds_request_topic] = {
        .visible = true,
        .named = true,
    },
    [sym_annotation_appl_dds_reply_topic] = {
        .visible = true,
        .named = true,
    },
    [sym_template_module_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameters] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameter] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameter_type] = {
        .visible = true,
        .named = true,
    },
    [sym_tpl_definition] = {
        .visible = true,
        .named = true,
    },
    [sym_template_module_inst] = {
        .visible = true,
        .named = true,
    },
    [sym_actual_parameters] = {
        .visible = true,
        .named = true,
    },
    [sym_actual_parameter] = {
        .visible = true,
        .named = true,
    },
    [sym_template_module_ref] = {
        .visible = true,
        .named = true,
    },
    [sym_formal_parameter_names] = {
        .visible = true,
        .named = true,
    },
    [sym_value_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_value_def] = {
        .visible = true,
        .named = true,
    },
    [sym_value_kind] = {
        .visible = true,
        .named = true,
    },
    [sym_value_header] = {
        .visible = true,
        .named = true,
    },
    [sym_value_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_value_inheritance] = {
        .visible = true,
        .named = true,
    },
    [sym_value_supports] = {
        .visible = true,
        .named = true,
    },
    [sym_value_name] = {
        .visible = true,
        .named = true,
    },
    [sym_value_element] = {
        .visible = true,
        .named = true,
    },
    [sym_state_member] = {
        .visible = true,
        .named = true,
    },
    [sym_init_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_init_param_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_init_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_value_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_typedef_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_type_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_any_declarators] = {
        .visible = true,
        .named = true,
    },
    [sym_any_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_simple_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_declarators] = {
        .visible = true,
        .named = true,
    },
    [sym_array_declarator] = {
        .visible = true,
        .named = true,
    },
    [sym_fixed_array_size] = {
        .visible = true,
        .named = true,
    },
    [sym_enum_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_enumerator] = {
        .visible = true,
        .named = true,
    },
    [sym_union_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_union_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_union_def] = {
        .visible = true,
        .named = true,
    },
    [sym_case] = {
        .visible = true,
        .named = true,
    },
    [sym_case_label] = {
        .visible = true,
        .named = true,
    },
    [sym_element_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_switch_type_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_type_id_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_type_prefix_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_import_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_imported_scope] = {
        .visible = true,
        .named = true,
    },
    [sym_object_type] = {
        .visible = true,
        .named = true,
    },
    [sym_op_oneway_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_in_parameter_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_in_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_op_with_context] = {
        .visible = true,
        .named = true,
    },
    [sym_context_expr] = {
        .visible = true,
        .named = true,
    },
    [sym_value_box_def] = {
        .visible = true,
        .named = true,
    },
    [sym_value_abs_def] = {
        .visible = true,
        .named = true,
    },
    [sym_component_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_component_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_component_def] = {
        .visible = true,
        .named = true,
    },
    [sym_component_header] = {
        .visible = true,
        .named = true,
    },
    [sym_component_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_component_body] = {
        .visible = true,
        .named = true,
    },
    [sym_component_export] = {
        .visible = true,
        .named = true,
    },
    [sym_provides_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_interface_type] = {
        .visible = true,
        .named = true,
    },
    [sym_uses_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_home_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_home_header] = {
        .visible = true,
        .named = true,
    },
    [sym_home_inheritance_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_home_body] = {
        .visible = true,
        .named = true,
    },
    [sym_home_export] = {
        .visible = true,
        .named = true,
    },
    [sym_factory_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_factory_param_dcls] = {
        .visible = true,
        .named = true,
    },
    [sym_factory_param_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_supported_interface_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_emits_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_publishes_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_consumes_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_primary_key_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_finder_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_event_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_event_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_event_abs_def] = {
        .visible = true,
        .named = true,
    },
    [sym_event_def] = {
        .visible = true,
        .named = true,
    },
    [sym_event_header] = {
        .visible = true,
        .named = true,
    },
    [sym_porttype_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_porttype_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_porttype_def] = {
        .visible = true,
        .named = true,
    },
    [sym_port_body] = {
        .visible = true,
        .named = true,
    },
    [sym_port_ref] = {
        .visible = true,
        .named = true,
    },
    [sym_port_export] = {
        .visible = true,
        .named = true,
    },
    [sym_port_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_header] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_inherit_spec] = {
        .visible = true,
        .named = true,
    },
    [sym_connector_export] = {
        .visible = true,
        .named = true,
    },
    [sym_definition] = {
        .visible = true,
        .named = true,
    },
    [sym_type_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_constr_type_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_native_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_module_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_struct_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_struct_forward_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_struct_def] = {
        .visible = true,
        .named = true,
    },
    [sym_member] = {
        .visible = true,
        .named = true,
    },
    [sym_default] = {
        .visible = true,
        .named = true,
    },
    [sym_const_dcl] = {
        .visible = true,
        .named = true,
    },
    [sym_const_type] = {
        .visible = true,
        .named = true,
    },
    [sym_comment] = {
        .visible = true,
        .named = true,
    },
    [aux_sym_specification_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_string_literal_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_char_literal_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_except_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_interface_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_interface_inheritance_spec_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_interface_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_parameter_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_raises_expr_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_readonly_attr_declarator_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_bitset_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_bitfield_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_bitmask_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_params_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_annotation_appl_data_representation_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_template_module_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_formal_parameters_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_actual_parameters_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_formal_parameter_names_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_value_def_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_value_inheritance_spec_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_init_param_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_any_declarators_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_declarators_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_array_declarator_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_enum_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_union_def_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_case_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_in_parameter_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_context_expr_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_component_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_home_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_factory_param_dcls_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_port_body_repeat1] = {
        .visible = false,
        .named = false,
    },
    [aux_sym_connector_dcl_repeat1] = {
        .visible = false,
        .named = false,
    },
};

enum ts_field_identifiers {
    field_argument = 1,
    field_directive = 2,
    field_identifier = 3,
    field_language = 4,
    field_max = 5,
    field_min = 6,
    field_name = 7,
    field_parent = 8,
    field_path = 9,
    field_placement = 10,
    field_platform = 11,
    field_text = 12,
    field_type = 13,
};

static const char *const ts_field_names[] = {
    [0] = NULL,
    [field_argument] = "argument",
    [field_directive] = "directive",
    [field_identifier] = "identifier",
    [field_language] = "language",
    [field_max] = "max",
    [field_min] = "min",
    [field_name] = "name",
    [field_parent] = "parent",
    [field_path] = "path",
    [field_placement] = "placement",
    [field_platform] = "platform",
    [field_text] = "text",
    [field_type] = "type",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
    [1] = { .index = 0, .length = 1 },
    [2] = { .index = 1, .length = 1 },
    [3] = { .index = 2, .length = 2 },
    [4] = { .index = 4, .length = 1 },
    [5] = { .index = 1, .length = 1 },
    [6] = { .index = 5, .length = 2 },
    [7] = { .index = 7, .length = 2 },
    [8] = { .index = 9, .length = 2 },
    [9] = { .index = 11, .length = 2 },
    [10] = { .index = 13, .length = 1 },
    [11] = { .index = 14, .length = 2 },
    [12] = { .index = 16, .length = 3 },
    [13] = { .index = 19, .length = 4 },
    [14] = { .index = 23, .length = 4 },
    [15] = { .index = 27, .length = 3 },
    [16] = { .index = 30, .length = 6 },
};

static const TSFieldMapEntry ts_field_map_entries[] = {
    [0] = { field_directive, 0 },
    [1] = { field_name, 0 },
    [2] = { field_argument, 1 },
    { field_directive, 0 },
    [4] = { field_path, 1 },
    [5] = { field_name, 0 },
    { field_text, 2 },
    [7] = { field_name, 0 },
    { field_name, 2 },
    [9] = { field_name, 0 },
    { field_platform, 2 },
    [11] = { field_identifier, 1 },
    { field_type, 0 },
    [13] = { field_parent, 3 },
    [14] = { field_identifier, 2 },
    { field_type, 1 },
    [16] = { field_max, 4 },
    { field_min, 2 },
    { field_name, 0 },
    [19] = { field_language, 2 },
    { field_language, 3 },
    { field_name, 0 },
    { field_text, 4 },
    [23] = { field_name, 0 },
    { field_placement, 2 },
    { field_placement, 3 },
    { field_text, 4 },
    [27] = { field_name, 0 },
    { field_name, 2 },
    { field_platform, 4 },
    [30] = { field_language, 2 },
    { field_language, 3 },
    { field_name, 0 },
    { field_placement, 4 },
    { field_placement, 5 },
    { field_text, 6 },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
    [0] = { 0 },
    [5] = {
        [0] = aux_sym_annotation_appl_id_token1,
    },
};

static const uint16_t ts_non_terminal_alias_map[] = {
    0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
    [0] = 0,
    [1] = 1,
    [2] = 2,
    [3] = 3,
    [4] = 4,
    [5] = 5,
    [6] = 6,
    [7] = 7,
    [8] = 8,
    [9] = 9,
    [10] = 10,
    [11] = 11,
    [12] = 12,
    [13] = 13,
    [14] = 14,
    [15] = 15,
    [16] = 16,
    [17] = 17,
    [18] = 18,
    [19] = 19,
    [20] = 20,
    [21] = 21,
    [22] = 22,
    [23] = 23,
    [24] = 24,
    [25] = 25,
    [26] = 26,
    [27] = 27,
    [28] = 28,
    [29] = 29,
    [30] = 30,
    [31] = 31,
    [32] = 32,
    [33] = 33,
    [34] = 32,
    [35] = 32,
    [36] = 36,
    [37] = 36,
    [38] = 32,
    [39] = 36,
    [40] = 36,
    [41] = 36,
    [42] = 32,
    [43] = 43,
    [44] = 44,
    [45] = 45,
    [46] = 46,
    [47] = 47,
    [48] = 48,
    [49] = 49,
    [50] = 50,
    [51] = 51,
    [52] = 52,
    [53] = 53,
    [54] = 54,
    [55] = 55,
    [56] = 56,
    [57] = 57,
    [58] = 58,
    [59] = 59,
    [60] = 60,
    [61] = 61,
    [62] = 62,
    [63] = 63,
    [64] = 64,
    [65] = 65,
    [66] = 66,
    [67] = 67,
    [68] = 68,
    [69] = 69,
    [70] = 70,
    [71] = 64,
    [72] = 72,
    [73] = 73,
    [74] = 74,
    [75] = 75,
    [76] = 76,
    [77] = 77,
    [78] = 77,
    [79] = 79,
    [80] = 80,
    [81] = 81,
    [82] = 82,
    [83] = 83,
    [84] = 84,
    [85] = 85,
    [86] = 77,
    [87] = 87,
    [88] = 88,
    [89] = 77,
    [90] = 77,
    [91] = 91,
    [92] = 64,
    [93] = 93,
    [94] = 93,
    [95] = 93,
    [96] = 93,
    [97] = 93,
    [98] = 98,
    [99] = 99,
    [100] = 100,
    [101] = 101,
    [102] = 102,
    [103] = 103,
    [104] = 104,
    [105] = 105,
    [106] = 106,
    [107] = 107,
    [108] = 108,
    [109] = 109,
    [110] = 110,
    [111] = 111,
    [112] = 112,
    [113] = 113,
    [114] = 114,
    [115] = 115,
    [116] = 116,
    [117] = 117,
    [118] = 118,
    [119] = 119,
    [120] = 120,
    [121] = 121,
    [122] = 122,
    [123] = 123,
    [124] = 124,
    [125] = 125,
    [126] = 126,
    [127] = 127,
    [128] = 128,
    [129] = 129,
    [130] = 130,
    [131] = 131,
    [132] = 132,
    [133] = 133,
    [134] = 126,
    [135] = 135,
    [136] = 136,
    [137] = 137,
    [138] = 138,
    [139] = 139,
    [140] = 140,
    [141] = 141,
    [142] = 142,
    [143] = 141,
    [144] = 144,
    [145] = 145,
    [146] = 146,
    [147] = 126,
    [148] = 148,
    [149] = 149,
    [150] = 150,
    [151] = 151,
    [152] = 141,
    [153] = 153,
    [154] = 154,
    [155] = 155,
    [156] = 141,
    [157] = 157,
    [158] = 158,
    [159] = 159,
    [160] = 160,
    [161] = 161,
    [162] = 162,
    [163] = 163,
    [164] = 164,
    [165] = 165,
    [166] = 166,
    [167] = 167,
    [168] = 168,
    [169] = 169,
    [170] = 141,
    [171] = 171,
    [172] = 172,
    [173] = 126,
    [174] = 174,
    [175] = 175,
    [176] = 176,
    [177] = 177,
    [178] = 178,
    [179] = 179,
    [180] = 126,
    [181] = 181,
    [182] = 182,
    [183] = 183,
    [184] = 184,
    [185] = 185,
    [186] = 186,
    [187] = 186,
    [188] = 188,
    [189] = 186,
    [190] = 186,
    [191] = 186,
    [192] = 192,
    [193] = 193,
    [194] = 192,
    [195] = 195,
    [196] = 196,
    [197] = 196,
    [198] = 193,
    [199] = 199,
    [200] = 193,
    [201] = 201,
    [202] = 202,
    [203] = 199,
    [204] = 204,
    [205] = 205,
    [206] = 201,
    [207] = 207,
    [208] = 202,
    [209] = 207,
    [210] = 205,
    [211] = 204,
    [212] = 204,
    [213] = 202,
    [214] = 201,
    [215] = 205,
    [216] = 199,
    [217] = 193,
    [218] = 196,
    [219] = 207,
    [220] = 192,
    [221] = 195,
    [222] = 196,
    [223] = 193,
    [224] = 195,
    [225] = 192,
    [226] = 226,
    [227] = 199,
    [228] = 201,
    [229] = 195,
    [230] = 192,
    [231] = 202,
    [232] = 204,
    [233] = 205,
    [234] = 207,
    [235] = 235,
    [236] = 236,
    [237] = 237,
    [238] = 207,
    [239] = 239,
    [240] = 205,
    [241] = 241,
    [242] = 204,
    [243] = 243,
    [244] = 195,
    [245] = 202,
    [246] = 246,
    [247] = 247,
    [248] = 201,
    [249] = 249,
    [250] = 196,
    [251] = 199,
    [252] = 252,
    [253] = 253,
    [254] = 252,
    [255] = 255,
    [256] = 256,
    [257] = 257,
    [258] = 258,
    [259] = 259,
    [260] = 255,
    [261] = 261,
    [262] = 262,
    [263] = 253,
    [264] = 262,
    [265] = 265,
    [266] = 266,
    [267] = 253,
    [268] = 266,
    [269] = 262,
    [270] = 270,
    [271] = 271,
    [272] = 258,
    [273] = 273,
    [274] = 256,
    [275] = 265,
    [276] = 252,
    [277] = 277,
    [278] = 278,
    [279] = 279,
    [280] = 258,
    [281] = 278,
    [282] = 282,
    [283] = 283,
    [284] = 255,
    [285] = 256,
    [286] = 252,
    [287] = 271,
    [288] = 288,
    [289] = 278,
    [290] = 278,
    [291] = 288,
    [292] = 253,
    [293] = 256,
    [294] = 282,
    [295] = 295,
    [296] = 258,
    [297] = 271,
    [298] = 265,
    [299] = 266,
    [300] = 265,
    [301] = 282,
    [302] = 288,
    [303] = 255,
    [304] = 262,
    [305] = 305,
    [306] = 266,
    [307] = 265,
    [308] = 266,
    [309] = 253,
    [310] = 258,
    [311] = 256,
    [312] = 252,
    [313] = 278,
    [314] = 262,
    [315] = 288,
    [316] = 255,
    [317] = 271,
    [318] = 282,
    [319] = 271,
    [320] = 282,
    [321] = 288,
    [322] = 322,
    [323] = 323,
    [324] = 99,
    [325] = 325,
    [326] = 326,
    [327] = 327,
    [328] = 328,
    [329] = 329,
    [330] = 330,
    [331] = 103,
    [332] = 148,
    [333] = 109,
    [334] = 106,
    [335] = 185,
    [336] = 108,
    [337] = 105,
    [338] = 101,
    [339] = 110,
    [340] = 340,
    [341] = 102,
    [342] = 100,
    [343] = 118,
    [344] = 107,
    [345] = 345,
    [346] = 346,
    [347] = 347,
    [348] = 117,
    [349] = 111,
    [350] = 112,
    [351] = 115,
    [352] = 352,
    [353] = 353,
    [354] = 104,
    [355] = 116,
    [356] = 113,
    [357] = 114,
    [358] = 142,
    [359] = 146,
    [360] = 149,
    [361] = 174,
    [362] = 362,
    [363] = 171,
    [364] = 169,
    [365] = 168,
    [366] = 167,
    [367] = 166,
    [368] = 157,
    [369] = 165,
    [370] = 163,
    [371] = 162,
    [372] = 161,
    [373] = 122,
    [374] = 183,
    [375] = 160,
    [376] = 159,
    [377] = 377,
    [378] = 120,
    [379] = 155,
    [380] = 153,
    [381] = 381,
    [382] = 150,
    [383] = 383,
    [384] = 131,
    [385] = 184,
    [386] = 145,
    [387] = 387,
    [388] = 119,
    [389] = 129,
    [390] = 390,
    [391] = 175,
    [392] = 154,
    [393] = 140,
    [394] = 177,
    [395] = 125,
    [396] = 158,
    [397] = 179,
    [398] = 398,
    [399] = 181,
    [400] = 176,
    [401] = 172,
    [402] = 182,
    [403] = 178,
    [404] = 139,
    [405] = 151,
    [406] = 144,
    [407] = 121,
    [408] = 123,
    [409] = 124,
    [410] = 127,
    [411] = 411,
    [412] = 128,
    [413] = 137,
    [414] = 130,
    [415] = 132,
    [416] = 133,
    [417] = 136,
    [418] = 135,
    [419] = 419,
    [420] = 420,
    [421] = 421,
    [422] = 422,
    [423] = 423,
    [424] = 424,
    [425] = 425,
    [426] = 426,
    [427] = 427,
    [428] = 428,
    [429] = 429,
    [430] = 430,
    [431] = 431,
    [432] = 432,
    [433] = 433,
    [434] = 434,
    [435] = 435,
    [436] = 436,
    [437] = 437,
    [438] = 438,
    [439] = 439,
    [440] = 110,
    [441] = 441,
    [442] = 442,
    [443] = 109,
    [444] = 444,
    [445] = 107,
    [446] = 446,
    [447] = 447,
    [448] = 99,
    [449] = 449,
    [450] = 450,
    [451] = 113,
    [452] = 109,
    [453] = 453,
    [454] = 110,
    [455] = 455,
    [456] = 107,
    [457] = 116,
    [458] = 458,
    [459] = 459,
    [460] = 460,
    [461] = 461,
    [462] = 462,
    [463] = 463,
    [464] = 464,
    [465] = 465,
    [466] = 466,
    [467] = 467,
    [468] = 468,
    [469] = 106,
    [470] = 108,
    [471] = 471,
    [472] = 472,
    [473] = 473,
    [474] = 474,
    [475] = 105,
    [476] = 101,
    [477] = 477,
    [478] = 103,
    [479] = 102,
    [480] = 100,
    [481] = 114,
    [482] = 482,
    [483] = 104,
    [484] = 112,
    [485] = 111,
    [486] = 117,
    [487] = 487,
    [488] = 488,
    [489] = 489,
    [490] = 490,
    [491] = 491,
    [492] = 492,
    [493] = 493,
    [494] = 494,
    [495] = 115,
    [496] = 118,
    [497] = 163,
    [498] = 145,
    [499] = 137,
    [500] = 136,
    [501] = 140,
    [502] = 135,
    [503] = 162,
    [504] = 133,
    [505] = 132,
    [506] = 130,
    [507] = 129,
    [508] = 176,
    [509] = 128,
    [510] = 181,
    [511] = 127,
    [512] = 149,
    [513] = 119,
    [514] = 185,
    [515] = 131,
    [516] = 124,
    [517] = 123,
    [518] = 121,
    [519] = 144,
    [520] = 151,
    [521] = 179,
    [522] = 178,
    [523] = 183,
    [524] = 154,
    [525] = 122,
    [526] = 184,
    [527] = 158,
    [528] = 139,
    [529] = 182,
    [530] = 125,
    [531] = 157,
    [532] = 146,
    [533] = 177,
    [534] = 150,
    [535] = 165,
    [536] = 153,
    [537] = 166,
    [538] = 167,
    [539] = 175,
    [540] = 168,
    [541] = 169,
    [542] = 171,
    [543] = 148,
    [544] = 161,
    [545] = 160,
    [546] = 174,
    [547] = 159,
    [548] = 120,
    [549] = 155,
    [550] = 172,
    [551] = 142,
    [552] = 552,
    [553] = 553,
    [554] = 554,
    [555] = 555,
    [556] = 556,
    [557] = 557,
    [558] = 557,
    [559] = 557,
    [560] = 557,
    [561] = 557,
    [562] = 562,
    [563] = 563,
    [564] = 564,
    [565] = 565,
    [566] = 566,
    [567] = 567,
    [568] = 568,
    [569] = 569,
    [570] = 570,
    [571] = 571,
    [572] = 572,
    [573] = 109,
    [574] = 110,
    [575] = 575,
    [576] = 576,
    [577] = 577,
    [578] = 578,
    [579] = 579,
    [580] = 580,
    [581] = 581,
    [582] = 582,
    [583] = 583,
    [584] = 584,
    [585] = 585,
    [586] = 586,
    [587] = 107,
    [588] = 588,
    [589] = 589,
    [590] = 590,
    [591] = 591,
    [592] = 592,
    [593] = 593,
    [594] = 594,
    [595] = 595,
    [596] = 596,
    [597] = 597,
    [598] = 598,
    [599] = 99,
    [600] = 99,
    [601] = 601,
    [602] = 602,
    [603] = 603,
    [604] = 604,
    [605] = 602,
    [606] = 603,
    [607] = 607,
    [608] = 608,
    [609] = 602,
    [610] = 610,
    [611] = 611,
    [612] = 612,
    [613] = 603,
    [614] = 614,
    [615] = 615,
    [616] = 616,
    [617] = 617,
    [618] = 604,
    [619] = 603,
    [620] = 602,
    [621] = 604,
    [622] = 603,
    [623] = 604,
    [624] = 604,
    [625] = 625,
    [626] = 602,
    [627] = 627,
    [628] = 113,
    [629] = 629,
    [630] = 630,
    [631] = 631,
    [632] = 632,
    [633] = 109,
    [634] = 632,
    [635] = 107,
    [636] = 636,
    [637] = 632,
    [638] = 638,
    [639] = 639,
    [640] = 640,
    [641] = 641,
    [642] = 642,
    [643] = 643,
    [644] = 107,
    [645] = 645,
    [646] = 113,
    [647] = 647,
    [648] = 632,
    [649] = 110,
    [650] = 650,
    [651] = 651,
    [652] = 109,
    [653] = 653,
    [654] = 654,
    [655] = 110,
    [656] = 656,
    [657] = 657,
    [658] = 632,
    [659] = 659,
    [660] = 660,
    [661] = 661,
    [662] = 662,
    [663] = 663,
    [664] = 664,
    [665] = 665,
    [666] = 666,
    [667] = 667,
    [668] = 668,
    [669] = 669,
    [670] = 670,
    [671] = 106,
    [672] = 672,
    [673] = 108,
    [674] = 105,
    [675] = 101,
    [676] = 676,
    [677] = 103,
    [678] = 102,
    [679] = 100,
    [680] = 114,
    [681] = 116,
    [682] = 104,
    [683] = 683,
    [684] = 684,
    [685] = 685,
    [686] = 686,
    [687] = 687,
    [688] = 688,
    [689] = 689,
    [690] = 112,
    [691] = 111,
    [692] = 117,
    [693] = 693,
    [694] = 118,
    [695] = 115,
    [696] = 696,
    [697] = 697,
    [698] = 698,
    [699] = 699,
    [700] = 700,
    [701] = 701,
    [702] = 702,
    [703] = 703,
    [704] = 704,
    [705] = 705,
    [706] = 706,
    [707] = 707,
    [708] = 708,
    [709] = 709,
    [710] = 710,
    [711] = 115,
    [712] = 118,
    [713] = 117,
    [714] = 111,
    [715] = 683,
    [716] = 112,
    [717] = 104,
    [718] = 116,
    [719] = 114,
    [720] = 100,
    [721] = 102,
    [722] = 103,
    [723] = 688,
    [724] = 101,
    [725] = 105,
    [726] = 726,
    [727] = 727,
    [728] = 108,
    [729] = 106,
    [730] = 730,
    [731] = 731,
    [732] = 732,
    [733] = 708,
    [734] = 710,
    [735] = 735,
    [736] = 736,
    [737] = 737,
    [738] = 738,
    [739] = 706,
    [740] = 710,
    [741] = 741,
    [742] = 742,
    [743] = 743,
    [744] = 744,
    [745] = 745,
    [746] = 746,
    [747] = 710,
    [748] = 748,
    [749] = 749,
    [750] = 750,
    [751] = 683,
    [752] = 683,
    [753] = 688,
    [754] = 706,
    [755] = 706,
    [756] = 710,
    [757] = 709,
    [758] = 758,
    [759] = 759,
    [760] = 760,
    [761] = 688,
    [762] = 762,
    [763] = 763,
    [764] = 764,
    [765] = 688,
    [766] = 766,
    [767] = 767,
    [768] = 768,
    [769] = 769,
    [770] = 683,
    [771] = 771,
    [772] = 772,
    [773] = 773,
    [774] = 774,
    [775] = 706,
    [776] = 704,
    [777] = 777,
    [778] = 778,
    [779] = 779,
    [780] = 780,
    [781] = 781,
    [782] = 782,
    [783] = 783,
    [784] = 784,
    [785] = 785,
    [786] = 153,
    [787] = 787,
    [788] = 788,
    [789] = 742,
    [790] = 790,
    [791] = 791,
    [792] = 792,
    [793] = 793,
    [794] = 794,
    [795] = 795,
    [796] = 796,
    [797] = 797,
    [798] = 798,
    [799] = 793,
    [800] = 176,
    [801] = 801,
    [802] = 181,
    [803] = 803,
    [804] = 804,
    [805] = 158,
    [806] = 125,
    [807] = 807,
    [808] = 808,
    [809] = 177,
    [810] = 810,
    [811] = 811,
    [812] = 812,
    [813] = 813,
    [814] = 814,
    [815] = 815,
    [816] = 816,
    [817] = 817,
    [818] = 818,
    [819] = 819,
    [820] = 820,
    [821] = 821,
    [822] = 822,
    [823] = 823,
    [824] = 175,
    [825] = 825,
    [826] = 793,
    [827] = 827,
    [828] = 828,
    [829] = 829,
    [830] = 830,
    [831] = 831,
    [832] = 832,
    [833] = 833,
    [834] = 813,
    [835] = 835,
    [836] = 836,
    [837] = 837,
    [838] = 838,
    [839] = 839,
    [840] = 840,
    [841] = 841,
    [842] = 842,
    [843] = 793,
    [844] = 844,
    [845] = 845,
    [846] = 846,
    [847] = 122,
    [848] = 848,
    [849] = 157,
    [850] = 148,
    [851] = 851,
    [852] = 149,
    [853] = 853,
    [854] = 154,
    [855] = 179,
    [856] = 856,
    [857] = 185,
    [858] = 172,
    [859] = 859,
    [860] = 142,
    [861] = 861,
    [862] = 182,
    [863] = 178,
    [864] = 864,
    [865] = 151,
    [866] = 866,
    [867] = 811,
    [868] = 868,
    [869] = 813,
    [870] = 870,
    [871] = 871,
    [872] = 872,
    [873] = 873,
    [874] = 144,
    [875] = 875,
    [876] = 876,
    [877] = 813,
    [878] = 121,
    [879] = 123,
    [880] = 124,
    [881] = 881,
    [882] = 127,
    [883] = 883,
    [884] = 128,
    [885] = 885,
    [886] = 886,
    [887] = 129,
    [888] = 811,
    [889] = 889,
    [890] = 890,
    [891] = 130,
    [892] = 132,
    [893] = 893,
    [894] = 872,
    [895] = 895,
    [896] = 873,
    [897] = 133,
    [898] = 135,
    [899] = 136,
    [900] = 900,
    [901] = 876,
    [902] = 873,
    [903] = 903,
    [904] = 137,
    [905] = 139,
    [906] = 906,
    [907] = 140,
    [908] = 872,
    [909] = 119,
    [910] = 145,
    [911] = 146,
    [912] = 150,
    [913] = 913,
    [914] = 914,
    [915] = 876,
    [916] = 916,
    [917] = 917,
    [918] = 918,
    [919] = 155,
    [920] = 120,
    [921] = 921,
    [922] = 811,
    [923] = 159,
    [924] = 924,
    [925] = 872,
    [926] = 873,
    [927] = 160,
    [928] = 928,
    [929] = 161,
    [930] = 930,
    [931] = 931,
    [932] = 876,
    [933] = 933,
    [934] = 934,
    [935] = 935,
    [936] = 936,
    [937] = 162,
    [938] = 163,
    [939] = 939,
    [940] = 165,
    [941] = 797,
    [942] = 942,
    [943] = 943,
    [944] = 944,
    [945] = 166,
    [946] = 946,
    [947] = 167,
    [948] = 168,
    [949] = 949,
    [950] = 169,
    [951] = 951,
    [952] = 952,
    [953] = 811,
    [954] = 743,
    [955] = 171,
    [956] = 956,
    [957] = 957,
    [958] = 872,
    [959] = 176,
    [960] = 181,
    [961] = 961,
    [962] = 962,
    [963] = 158,
    [964] = 125,
    [965] = 177,
    [966] = 966,
    [967] = 967,
    [968] = 175,
    [969] = 969,
    [970] = 970,
    [971] = 971,
    [972] = 972,
    [973] = 174,
    [974] = 974,
    [975] = 975,
    [976] = 976,
    [977] = 813,
    [978] = 131,
    [979] = 979,
    [980] = 183,
    [981] = 184,
    [982] = 122,
    [983] = 810,
    [984] = 881,
    [985] = 157,
    [986] = 873,
    [987] = 131,
    [988] = 183,
    [989] = 148,
    [990] = 990,
    [991] = 149,
    [992] = 154,
    [993] = 993,
    [994] = 179,
    [995] = 185,
    [996] = 996,
    [997] = 172,
    [998] = 142,
    [999] = 182,
    [1000] = 178,
    [1001] = 151,
    [1002] = 144,
    [1003] = 121,
    [1004] = 123,
    [1005] = 124,
    [1006] = 127,
    [1007] = 128,
    [1008] = 129,
    [1009] = 130,
    [1010] = 132,
    [1011] = 133,
    [1012] = 135,
    [1013] = 136,
    [1014] = 137,
    [1015] = 139,
    [1016] = 140,
    [1017] = 119,
    [1018] = 145,
    [1019] = 146,
    [1020] = 150,
    [1021] = 153,
    [1022] = 155,
    [1023] = 120,
    [1024] = 159,
    [1025] = 160,
    [1026] = 161,
    [1027] = 162,
    [1028] = 163,
    [1029] = 165,
    [1030] = 166,
    [1031] = 167,
    [1032] = 168,
    [1033] = 169,
    [1034] = 171,
    [1035] = 174,
    [1036] = 184,
    [1037] = 876,
    [1038] = 797,
    [1039] = 793,
    [1040] = 785,
    [1041] = 1041,
    [1042] = 1042,
    [1043] = 1043,
    [1044] = 1044,
    [1045] = 1045,
    [1046] = 1046,
    [1047] = 1047,
    [1048] = 1048,
    [1049] = 1049,
    [1050] = 1050,
    [1051] = 1051,
    [1052] = 1052,
    [1053] = 1053,
    [1054] = 1054,
    [1055] = 1055,
    [1056] = 1056,
    [1057] = 1057,
    [1058] = 183,
    [1059] = 1059,
    [1060] = 1060,
    [1061] = 1061,
    [1062] = 1062,
    [1063] = 1063,
    [1064] = 1064,
    [1065] = 1065,
    [1066] = 1066,
    [1067] = 1067,
    [1068] = 1068,
    [1069] = 1069,
    [1070] = 1070,
    [1071] = 1071,
    [1072] = 1072,
    [1073] = 1073,
    [1074] = 1074,
    [1075] = 1075,
    [1076] = 1076,
    [1077] = 1077,
    [1078] = 1078,
    [1079] = 1079,
    [1080] = 1080,
    [1081] = 1081,
    [1082] = 1082,
    [1083] = 1083,
    [1084] = 1084,
    [1085] = 1085,
    [1086] = 1056,
    [1087] = 1087,
    [1088] = 1088,
    [1089] = 1089,
    [1090] = 1090,
    [1091] = 1091,
    [1092] = 1092,
    [1093] = 1093,
    [1094] = 1094,
    [1095] = 1095,
    [1096] = 1096,
    [1097] = 1097,
    [1098] = 1056,
    [1099] = 1099,
    [1100] = 1100,
    [1101] = 1101,
    [1102] = 1056,
    [1103] = 1103,
    [1104] = 1104,
    [1105] = 1105,
    [1106] = 1106,
    [1107] = 1107,
    [1108] = 1108,
    [1109] = 1109,
    [1110] = 1110,
    [1111] = 1111,
    [1112] = 1112,
    [1113] = 1113,
    [1114] = 1114,
    [1115] = 1047,
    [1116] = 1116,
    [1117] = 1056,
    [1118] = 1118,
    [1119] = 1119,
    [1120] = 1120,
    [1121] = 1121,
    [1122] = 1122,
    [1123] = 1123,
    [1124] = 1048,
    [1125] = 1125,
    [1126] = 1047,
    [1127] = 1127,
    [1128] = 1128,
    [1129] = 1129,
    [1130] = 1130,
    [1131] = 1131,
    [1132] = 1132,
    [1133] = 1133,
    [1134] = 1134,
    [1135] = 1135,
    [1136] = 1136,
    [1137] = 1137,
    [1138] = 1138,
    [1139] = 1139,
    [1140] = 1140,
    [1141] = 1047,
    [1142] = 1142,
    [1143] = 1143,
    [1144] = 1144,
    [1145] = 1145,
    [1146] = 1146,
    [1147] = 1147,
    [1148] = 1148,
    [1149] = 1149,
    [1150] = 1150,
    [1151] = 1048,
    [1152] = 1152,
    [1153] = 1153,
    [1154] = 1154,
    [1155] = 1155,
    [1156] = 1156,
    [1157] = 1157,
    [1158] = 1158,
    [1159] = 1048,
    [1160] = 1160,
    [1161] = 1048,
    [1162] = 1162,
    [1163] = 1163,
    [1164] = 1164,
    [1165] = 1165,
    [1166] = 1166,
    [1167] = 1047,
    [1168] = 1168,
    [1169] = 1169,
    [1170] = 1170,
    [1171] = 1171,
    [1172] = 1172,
    [1173] = 1173,
    [1174] = 1174,
    [1175] = 1175,
    [1176] = 1176,
    [1177] = 1177,
    [1178] = 1178,
    [1179] = 1179,
    [1180] = 1180,
    [1181] = 1181,
    [1182] = 1182,
    [1183] = 1183,
    [1184] = 1184,
    [1185] = 1185,
    [1186] = 1186,
    [1187] = 1187,
    [1188] = 1188,
    [1189] = 1189,
    [1190] = 1190,
    [1191] = 458,
    [1192] = 1192,
    [1193] = 1193,
    [1194] = 1194,
    [1195] = 1195,
    [1196] = 1196,
    [1197] = 1197,
    [1198] = 1198,
    [1199] = 1199,
    [1200] = 1200,
    [1201] = 1201,
    [1202] = 1202,
    [1203] = 1203,
    [1204] = 1204,
    [1205] = 1205,
    [1206] = 1170,
    [1207] = 1207,
    [1208] = 1208,
    [1209] = 1209,
    [1210] = 1210,
    [1211] = 1211,
    [1212] = 1212,
    [1213] = 1213,
    [1214] = 1214,
    [1215] = 1215,
    [1216] = 1216,
    [1217] = 1217,
    [1218] = 1218,
    [1219] = 1219,
    [1220] = 1220,
    [1221] = 1221,
    [1222] = 1222,
    [1223] = 1223,
    [1224] = 1224,
    [1225] = 1225,
    [1226] = 1226,
    [1227] = 1227,
    [1228] = 1228,
    [1229] = 1229,
    [1230] = 1230,
    [1231] = 1231,
    [1232] = 1232,
    [1233] = 1233,
    [1234] = 1234,
    [1235] = 1235,
    [1236] = 1236,
    [1237] = 1237,
    [1238] = 1238,
    [1239] = 1239,
    [1240] = 1240,
    [1241] = 1241,
    [1242] = 1242,
    [1243] = 1243,
    [1244] = 1244,
    [1245] = 1245,
    [1246] = 1246,
    [1247] = 1247,
    [1248] = 1248,
    [1249] = 1249,
    [1250] = 1250,
    [1251] = 1251,
    [1252] = 1252,
    [1253] = 1253,
    [1254] = 1254,
    [1255] = 1255,
    [1256] = 1256,
    [1257] = 1257,
    [1258] = 1258,
    [1259] = 1259,
    [1260] = 1260,
    [1261] = 1261,
    [1262] = 1262,
    [1263] = 131,
    [1264] = 1264,
    [1265] = 1265,
    [1266] = 1266,
    [1267] = 1267,
    [1268] = 1268,
    [1269] = 1269,
    [1270] = 1270,
    [1271] = 1271,
    [1272] = 1272,
    [1273] = 1273,
    [1274] = 1274,
    [1275] = 1275,
    [1276] = 1276,
    [1277] = 1277,
    [1278] = 1278,
    [1279] = 1279,
    [1280] = 1280,
    [1281] = 1281,
    [1282] = 1187,
    [1283] = 1283,
    [1284] = 1201,
    [1285] = 1203,
    [1286] = 1204,
    [1287] = 1205,
    [1288] = 1170,
    [1289] = 1208,
    [1290] = 1210,
    [1291] = 1211,
    [1292] = 1240,
    [1293] = 1219,
    [1294] = 1221,
    [1295] = 1222,
    [1296] = 1223,
    [1297] = 1224,
    [1298] = 1225,
    [1299] = 1228,
    [1300] = 1232,
    [1301] = 1233,
    [1302] = 1234,
    [1303] = 1235,
    [1304] = 1236,
    [1305] = 1237,
    [1306] = 1238,
    [1307] = 1239,
    [1308] = 1308,
    [1309] = 1309,
    [1310] = 1242,
    [1311] = 1244,
    [1312] = 1246,
    [1313] = 1248,
    [1314] = 1314,
    [1315] = 1315,
    [1316] = 1316,
    [1317] = 1317,
    [1318] = 1318,
    [1319] = 1319,
    [1320] = 1320,
    [1321] = 1321,
    [1322] = 1322,
    [1323] = 1323,
    [1324] = 1324,
    [1325] = 1325,
    [1326] = 1326,
    [1327] = 1327,
    [1328] = 1273,
    [1329] = 1329,
    [1330] = 1330,
    [1331] = 1331,
    [1332] = 1278,
    [1333] = 1333,
    [1334] = 1334,
    [1335] = 1187,
    [1336] = 1336,
    [1337] = 1201,
    [1338] = 1203,
    [1339] = 1204,
    [1340] = 1205,
    [1341] = 1170,
    [1342] = 1208,
    [1343] = 1210,
    [1344] = 1211,
    [1345] = 1240,
    [1346] = 1219,
    [1347] = 1221,
    [1348] = 1222,
    [1349] = 1223,
    [1350] = 1224,
    [1351] = 1225,
    [1352] = 1228,
    [1353] = 1232,
    [1354] = 1233,
    [1355] = 1234,
    [1356] = 1235,
    [1357] = 1236,
    [1358] = 1237,
    [1359] = 1238,
    [1360] = 1239,
    [1361] = 1361,
    [1362] = 1362,
    [1363] = 1242,
    [1364] = 1244,
    [1365] = 1246,
    [1366] = 1248,
    [1367] = 1367,
    [1368] = 1317,
    [1369] = 1318,
    [1370] = 1319,
    [1371] = 1371,
    [1372] = 1321,
    [1373] = 1322,
    [1374] = 1323,
    [1375] = 1375,
    [1376] = 1326,
    [1377] = 1377,
    [1378] = 1273,
    [1379] = 1379,
    [1380] = 1380,
    [1381] = 1381,
    [1382] = 1278,
    [1383] = 1383,
    [1384] = 1384,
    [1385] = 1201,
    [1386] = 1203,
    [1387] = 1204,
    [1388] = 1205,
    [1389] = 1170,
    [1390] = 1208,
    [1391] = 1210,
    [1392] = 1211,
    [1393] = 1240,
    [1394] = 1219,
    [1395] = 1221,
    [1396] = 1222,
    [1397] = 1223,
    [1398] = 1224,
    [1399] = 1225,
    [1400] = 1228,
    [1401] = 1232,
    [1402] = 1233,
    [1403] = 1234,
    [1404] = 1235,
    [1405] = 1236,
    [1406] = 1237,
    [1407] = 1238,
    [1408] = 1239,
    [1409] = 1409,
    [1410] = 1410,
    [1411] = 1242,
    [1412] = 1244,
    [1413] = 1246,
    [1414] = 1248,
    [1415] = 1415,
    [1416] = 1317,
    [1417] = 1318,
    [1418] = 1319,
    [1419] = 1419,
    [1420] = 1321,
    [1421] = 1322,
    [1422] = 1323,
    [1423] = 1423,
    [1424] = 1326,
    [1425] = 1425,
    [1426] = 1273,
    [1427] = 1427,
    [1428] = 1428,
    [1429] = 1326,
    [1430] = 1278,
    [1431] = 1431,
    [1432] = 1201,
    [1433] = 1203,
    [1434] = 1204,
    [1435] = 1205,
    [1436] = 1436,
    [1437] = 1208,
    [1438] = 1210,
    [1439] = 1211,
    [1440] = 1240,
    [1441] = 1219,
    [1442] = 1221,
    [1443] = 1222,
    [1444] = 1223,
    [1445] = 1224,
    [1446] = 1225,
    [1447] = 1228,
    [1448] = 1232,
    [1449] = 1233,
    [1450] = 1234,
    [1451] = 1235,
    [1452] = 1236,
    [1453] = 1237,
    [1454] = 1238,
    [1455] = 1239,
    [1456] = 1456,
    [1457] = 1457,
    [1458] = 1242,
    [1459] = 1244,
    [1460] = 1246,
    [1461] = 1248,
    [1462] = 1462,
    [1463] = 1317,
    [1464] = 1318,
    [1465] = 1319,
    [1466] = 1466,
    [1467] = 1321,
    [1468] = 1322,
    [1469] = 1323,
    [1470] = 1470,
    [1471] = 1326,
    [1472] = 1273,
    [1473] = 1273,
    [1474] = 1278,
    [1475] = 1475,
    [1476] = 1476,
    [1477] = 1477,
    [1478] = 1478,
    [1479] = 1479,
    [1480] = 1480,
    [1481] = 1481,
    [1482] = 1482,
    [1483] = 1483,
    [1484] = 488,
    [1485] = 1485,
    [1486] = 1486,
    [1487] = 1487,
    [1488] = 1488,
    [1489] = 1489,
    [1490] = 1490,
    [1491] = 1491,
    [1492] = 1492,
    [1493] = 1493,
    [1494] = 1494,
    [1495] = 1495,
    [1496] = 1496,
    [1497] = 1497,
    [1498] = 1498,
    [1499] = 1499,
    [1500] = 1500,
    [1501] = 1501,
    [1502] = 1502,
    [1503] = 1321,
    [1504] = 1504,
    [1505] = 1505,
    [1506] = 1506,
    [1507] = 1507,
    [1508] = 1508,
    [1509] = 1509,
    [1510] = 1510,
    [1511] = 1511,
    [1512] = 1512,
    [1513] = 1513,
    [1514] = 1514,
    [1515] = 1515,
    [1516] = 1516,
    [1517] = 1517,
    [1518] = 1518,
    [1519] = 1519,
    [1520] = 1520,
    [1521] = 1521,
    [1522] = 1522,
    [1523] = 1523,
    [1524] = 1524,
    [1525] = 1525,
    [1526] = 1526,
    [1527] = 1527,
    [1528] = 1528,
    [1529] = 1529,
    [1530] = 1530,
    [1531] = 1531,
    [1532] = 1532,
    [1533] = 1533,
    [1534] = 1534,
    [1535] = 1535,
    [1536] = 1536,
    [1537] = 1537,
    [1538] = 1538,
    [1539] = 1539,
    [1540] = 1540,
    [1541] = 1487,
    [1542] = 1542,
    [1543] = 1543,
    [1544] = 1544,
    [1545] = 1545,
    [1546] = 1546,
    [1547] = 1547,
    [1548] = 1273,
    [1549] = 1549,
    [1550] = 1550,
    [1551] = 1551,
    [1552] = 1552,
    [1553] = 1553,
    [1554] = 1554,
    [1555] = 1555,
    [1556] = 1556,
    [1557] = 1557,
    [1558] = 1558,
    [1559] = 1559,
    [1560] = 1560,
    [1561] = 1561,
    [1562] = 1562,
    [1563] = 1563,
    [1564] = 1487,
    [1565] = 1565,
    [1566] = 1566,
    [1567] = 1567,
    [1568] = 1323,
    [1569] = 1322,
    [1570] = 1570,
    [1571] = 1571,
    [1572] = 1572,
    [1573] = 1573,
    [1574] = 1574,
    [1575] = 1575,
    [1576] = 1319,
    [1577] = 1577,
    [1578] = 1578,
    [1579] = 1579,
    [1580] = 1580,
    [1581] = 1581,
    [1582] = 1318,
    [1583] = 1583,
    [1584] = 1584,
    [1585] = 1585,
    [1586] = 1317,
    [1587] = 1587,
    [1588] = 1588,
    [1589] = 1589,
    [1590] = 1590,
    [1591] = 1591,
    [1592] = 1592,
    [1593] = 1593,
    [1594] = 1594,
    [1595] = 1595,
    [1596] = 1596,
    [1597] = 1597,
    [1598] = 1598,
    [1599] = 1599,
    [1600] = 1600,
    [1601] = 1601,
    [1602] = 1602,
    [1603] = 1603,
    [1604] = 1604,
    [1605] = 1605,
    [1606] = 1606,
    [1607] = 1607,
    [1608] = 1608,
    [1609] = 1609,
    [1610] = 1610,
    [1611] = 1611,
    [1612] = 1612,
    [1613] = 1613,
    [1614] = 1614,
    [1615] = 1615,
    [1616] = 1616,
    [1617] = 1547,
    [1618] = 1546,
    [1619] = 1545,
    [1620] = 1544,
    [1621] = 1542,
    [1622] = 1540,
    [1623] = 1538,
    [1624] = 1537,
    [1625] = 1536,
    [1626] = 1535,
    [1627] = 1532,
    [1628] = 1531,
    [1629] = 1530,
    [1630] = 1218,
    [1631] = 1229,
    [1632] = 1230,
    [1633] = 1264,
    [1634] = 1243,
    [1635] = 1245,
    [1636] = 1578,
    [1637] = 1547,
    [1638] = 1546,
    [1639] = 1545,
    [1640] = 1544,
    [1641] = 1542,
    [1642] = 1540,
    [1643] = 1538,
    [1644] = 1537,
    [1645] = 1536,
    [1646] = 1535,
    [1647] = 1532,
    [1648] = 1531,
    [1649] = 1530,
    [1650] = 1218,
    [1651] = 1229,
    [1652] = 1230,
    [1653] = 1264,
    [1654] = 1243,
    [1655] = 1245,
    [1656] = 1578,
    [1657] = 1547,
    [1658] = 1546,
    [1659] = 1545,
    [1660] = 1544,
    [1661] = 1542,
    [1662] = 1540,
    [1663] = 1538,
    [1664] = 1537,
    [1665] = 1536,
    [1666] = 1535,
    [1667] = 1532,
    [1668] = 1531,
    [1669] = 1530,
    [1670] = 1218,
    [1671] = 1229,
    [1672] = 1230,
    [1673] = 1264,
    [1674] = 1243,
    [1675] = 1245,
    [1676] = 1578,
    [1677] = 1547,
    [1678] = 1546,
    [1679] = 1545,
    [1680] = 1544,
    [1681] = 1542,
    [1682] = 1540,
    [1683] = 1538,
    [1684] = 1537,
    [1685] = 1536,
    [1686] = 1535,
    [1687] = 1532,
    [1688] = 1531,
    [1689] = 1530,
    [1690] = 1218,
    [1691] = 1229,
    [1692] = 1230,
    [1693] = 1264,
    [1694] = 1243,
    [1695] = 1245,
    [1696] = 1578,
    [1697] = 1697,
    [1698] = 1698,
    [1699] = 1699,
    [1700] = 1700,
    [1701] = 1487,
    [1702] = 1487,
    [1703] = 1703,
    [1704] = 1704,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
    START_LEXER();
    eof = lexer->eof(lexer);
    switch(state) {
        case 0:
            if(eof)
                ADVANCE(945);
            ADVANCE_MAP(
                '"', 1033,
                '#', 257,
                '%', 1012,
                '&', 1004,
                '\'', 1039,
                '(', 1013,
                ')', 1014,
                '*', 1009,
                '+', 1007,
                ',', 997,
                '-', 1008,
                '.', 1022,
                '/', 1010,
                '0', 1019,
                ':', 1089,
                ';', 1090,
                '<', 990,
                '=', 1119,
                '>', 992,
                '@', 1116,
                'A', 728,
                'B', 689,
                'C', 1168,
                'D', 1028,
                'E', 1025,
                'F', 140,
                'H', 626,
                'I', 672,
                'L', 1037,
                'M', 620,
                'N', 621,
                'O', 230,
                'P', 817,
                'R', 630,
                'S', 690,
                'T', 174,
                'U', 798,
                'V', 143,
                '[', 1268,
            );
            if(lookahead == '\\')
                SKIP(938);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == '^')
                ADVANCE(1003);
            if(lookahead == 'a')
                ADVANCE(231);
            if(lookahead == 'b')
                ADVANCE(161);
            if(lookahead == 'c')
                ADVANCE(1166);
            if(lookahead == 'd')
                ADVANCE(1027);
            if(lookahead == 'e')
                ADVANCE(1024);
            if(lookahead == 'f')
                ADVANCE(160);
            if(lookahead == 'g')
                ADVANCE(316);
            if(lookahead == 'h')
                ADVANCE(146);
            if(lookahead == 'i')
                ADVANCE(397);
            if(lookahead == 'l')
                ADVANCE(443);
            if(lookahead == 'm')
                ADVANCE(141);
            if(lookahead == 'n')
                ADVANCE(142);
            if(lookahead == 'o')
                ADVANCE(168);
            if(lookahead == 'p')
                ADVANCE(172);
            if(lookahead == 'r')
                ADVANCE(148);
            if(lookahead == 's')
                ADVANCE(149);
            if(lookahead == 't')
                ADVANCE(175);
            if(lookahead == 'u')
                ADVANCE(167);
            if(lookahead == 'v')
                ADVANCE(144);
            if(lookahead == 'w')
                ADVANCE(241);
            if(lookahead == '{')
                ADVANCE(1080);
            if(lookahead == '|')
                ADVANCE(1002);
            if(lookahead == '}')
                ADVANCE(1081);
            if(lookahead == '~')
                ADVANCE(1015);
            if(lookahead == 'J' ||
               lookahead == 'j')
                ADVANCE(622);
            if(lookahead == 'K' ||
               lookahead == 'k')
                ADVANCE(691);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(661);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(0);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            END_STATE();
        case 1:
            if(lookahead == '\n')
                SKIP(110);
            END_STATE();
        case 2:
            if(lookahead == '\n')
                SKIP(110);
            if(lookahead == '\r')
                SKIP(1);
            END_STATE();
        case 3:
            if(lookahead == '\n')
                SKIP(111);
            END_STATE();
        case 4:
            if(lookahead == '\n')
                SKIP(111);
            if(lookahead == '\r')
                SKIP(3);
            END_STATE();
        case 5:
            if(lookahead == '\n')
                SKIP(102);
            END_STATE();
        case 6:
            if(lookahead == '\n')
                SKIP(102);
            if(lookahead == '\r')
                SKIP(5);
            END_STATE();
        case 7:
            if(lookahead == '\n')
                SKIP(99);
            END_STATE();
        case 8:
            if(lookahead == '\n')
                SKIP(99);
            if(lookahead == '\r')
                SKIP(7);
            END_STATE();
        case 9:
            if(lookahead == '\n')
                SKIP(113);
            END_STATE();
        case 10:
            if(lookahead == '\n')
                SKIP(113);
            if(lookahead == '\r')
                SKIP(9);
            END_STATE();
        case 11:
            if(lookahead == '\n')
                SKIP(116);
            END_STATE();
        case 12:
            if(lookahead == '\n')
                SKIP(116);
            if(lookahead == '\r')
                SKIP(11);
            END_STATE();
        case 13:
            if(lookahead == '\n')
                SKIP(100);
            END_STATE();
        case 14:
            if(lookahead == '\n')
                SKIP(100);
            if(lookahead == '\r')
                SKIP(13);
            END_STATE();
        case 15:
            if(lookahead == '\n')
                SKIP(103);
            END_STATE();
        case 16:
            if(lookahead == '\n')
                SKIP(103);
            if(lookahead == '\r')
                SKIP(15);
            END_STATE();
        case 17:
            if(lookahead == '\n')
                SKIP(115);
            END_STATE();
        case 18:
            if(lookahead == '\n')
                SKIP(115);
            if(lookahead == '\r')
                SKIP(17);
            END_STATE();
        case 19:
            if(lookahead == '\n')
                SKIP(121);
            END_STATE();
        case 20:
            if(lookahead == '\n')
                SKIP(121);
            if(lookahead == '\r')
                SKIP(19);
            END_STATE();
        case 21:
            if(lookahead == '\n')
                SKIP(117);
            END_STATE();
        case 22:
            if(lookahead == '\n')
                SKIP(117);
            if(lookahead == '\r')
                SKIP(21);
            END_STATE();
        case 23:
            if(lookahead == '\n')
                SKIP(118);
            END_STATE();
        case 24:
            if(lookahead == '\n')
                SKIP(118);
            if(lookahead == '\r')
                SKIP(23);
            END_STATE();
        case 25:
            if(lookahead == '\n')
                SKIP(88);
            END_STATE();
        case 26:
            if(lookahead == '\n')
                SKIP(88);
            if(lookahead == '\r')
                SKIP(25);
            END_STATE();
        case 27:
            if(lookahead == '\n')
                SKIP(90);
            END_STATE();
        case 28:
            if(lookahead == '\n')
                SKIP(90);
            if(lookahead == '\r')
                SKIP(27);
            END_STATE();
        case 29:
            if(lookahead == '\n')
                SKIP(122);
            END_STATE();
        case 30:
            if(lookahead == '\n')
                SKIP(122);
            if(lookahead == '\r')
                SKIP(29);
            END_STATE();
        case 31:
            if(lookahead == '\n')
                SKIP(87);
            END_STATE();
        case 32:
            if(lookahead == '\n')
                SKIP(87);
            if(lookahead == '\r')
                SKIP(31);
            END_STATE();
        case 33:
            if(lookahead == '\n')
                SKIP(123);
            END_STATE();
        case 34:
            if(lookahead == '\n')
                SKIP(123);
            if(lookahead == '\r')
                SKIP(33);
            END_STATE();
        case 35:
            if(lookahead == '\n')
                SKIP(89);
            END_STATE();
        case 36:
            if(lookahead == '\n')
                SKIP(89);
            if(lookahead == '\r')
                SKIP(35);
            END_STATE();
        case 37:
            if(lookahead == '\n')
                SKIP(91);
            END_STATE();
        case 38:
            if(lookahead == '\n')
                SKIP(91);
            if(lookahead == '\r')
                SKIP(37);
            END_STATE();
        case 39:
            if(lookahead == '\n')
                SKIP(101);
            END_STATE();
        case 40:
            if(lookahead == '\n')
                SKIP(101);
            if(lookahead == '\r')
                SKIP(39);
            END_STATE();
        case 41:
            if(lookahead == '\n')
                SKIP(124);
            END_STATE();
        case 42:
            if(lookahead == '\n')
                SKIP(124);
            if(lookahead == '\r')
                SKIP(41);
            END_STATE();
        case 43:
            if(lookahead == '\n')
                SKIP(95);
            END_STATE();
        case 44:
            if(lookahead == '\n')
                SKIP(95);
            if(lookahead == '\r')
                SKIP(43);
            END_STATE();
        case 45:
            if(lookahead == '\n')
                SKIP(86);
            END_STATE();
        case 46:
            if(lookahead == '\n')
                SKIP(86);
            if(lookahead == '\r')
                SKIP(45);
            END_STATE();
        case 47:
            if(lookahead == '\n')
                SKIP(94);
            END_STATE();
        case 48:
            if(lookahead == '\n')
                SKIP(94);
            if(lookahead == '\r')
                SKIP(47);
            END_STATE();
        case 49:
            if(lookahead == '\n')
                SKIP(98);
            END_STATE();
        case 50:
            if(lookahead == '\n')
                SKIP(98);
            if(lookahead == '\r')
                SKIP(49);
            END_STATE();
        case 51:
            if(lookahead == '\n')
                SKIP(92);
            END_STATE();
        case 52:
            if(lookahead == '\n')
                SKIP(92);
            if(lookahead == '\r')
                SKIP(51);
            END_STATE();
        case 53:
            if(lookahead == '\n')
                SKIP(96);
            END_STATE();
        case 54:
            if(lookahead == '\n')
                SKIP(96);
            if(lookahead == '\r')
                SKIP(53);
            END_STATE();
        case 55:
            if(lookahead == '\n')
                SKIP(109);
            END_STATE();
        case 56:
            if(lookahead == '\n')
                SKIP(109);
            if(lookahead == '\r')
                SKIP(55);
            END_STATE();
        case 57:
            if(lookahead == '\n')
                SKIP(59);
            END_STATE();
        case 58:
            if(lookahead == '\n')
                SKIP(59);
            if(lookahead == '\r')
                SKIP(57);
            END_STATE();
        case 59:
            if(lookahead == '\n')
                ADVANCE(1118);
            if(lookahead == '\r')
                ADVANCE(59);
            if(lookahead == '(')
                ADVANCE(1013);
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == '\\')
                SKIP(58);
            if(('\t' <= lookahead && lookahead <= '\f') ||
               lookahead == ' ')
                SKIP(59);
            END_STATE();
        case 60:
            if(lookahead == '\n')
                SKIP(119);
            END_STATE();
        case 61:
            if(lookahead == '\n')
                SKIP(119);
            if(lookahead == '\r')
                SKIP(60);
            END_STATE();
        case 62:
            if(lookahead == '\n')
                SKIP(125);
            END_STATE();
        case 63:
            if(lookahead == '\n')
                SKIP(125);
            if(lookahead == '\r')
                SKIP(62);
            END_STATE();
        case 64:
            if(lookahead == '\n')
                SKIP(120);
            END_STATE();
        case 65:
            if(lookahead == '\n')
                SKIP(120);
            if(lookahead == '\r')
                SKIP(64);
            END_STATE();
        case 66:
            if(lookahead == '\n')
                SKIP(93);
            if(lookahead == '"')
                ADVANCE(1033);
            if(lookahead == '/')
                ADVANCE(1034);
            if(lookahead == '\\')
                ADVANCE(67);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1035);
            if(lookahead != 0)
                ADVANCE(1036);
            END_STATE();
        case 67:
            if(lookahead == '\n')
                ADVANCE(1030);
            if(lookahead == '\r')
                ADVANCE(1029);
            if(lookahead == 'U')
                ADVANCE(935);
            if(lookahead == 'u')
                ADVANCE(931);
            if(lookahead == 'x')
                ADVANCE(929);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(1032);
            if(lookahead != 0)
                ADVANCE(1029);
            END_STATE();
        case 68:
            if(lookahead == '\n')
                SKIP(97);
            if(lookahead == '\'')
                ADVANCE(1039);
            if(lookahead == '/')
                ADVANCE(1042);
            if(lookahead == '\\')
                ADVANCE(1041);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1043);
            if(lookahead != 0)
                ADVANCE(1040);
            END_STATE();
        case 69:
            if(lookahead == '\n')
                SKIP(126);
            END_STATE();
        case 70:
            if(lookahead == '\n')
                SKIP(126);
            if(lookahead == '\r')
                SKIP(69);
            END_STATE();
        case 71:
            if(lookahead == '\n')
                SKIP(127);
            END_STATE();
        case 72:
            if(lookahead == '\n')
                SKIP(127);
            if(lookahead == '\r')
                SKIP(71);
            END_STATE();
        case 73:
            if(lookahead == '\n')
                ADVANCE(1053);
            if(lookahead == '\r')
                ADVANCE(75);
            if(lookahead == '/')
                ADVANCE(1069);
            if(lookahead == '\\')
                ADVANCE(1066);
            if(('\t' <= lookahead && lookahead <= '\f') ||
               lookahead == ' ')
                SKIP(114);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 74:
            if(lookahead == '\n')
                ADVANCE(1053);
            if(lookahead == '\r')
                ADVANCE(76);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == '\\')
                SKIP(78);
            if(('\t' <= lookahead && lookahead <= '\f') ||
               lookahead == ' ')
                SKIP(128);
            END_STATE();
        case 75:
            if(lookahead == '\n')
                ADVANCE(1053);
            if(lookahead == '/')
                ADVANCE(1069);
            if(lookahead == '\\')
                ADVANCE(1066);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(114);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 76:
            if(lookahead == '\n')
                ADVANCE(1053);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == '\\')
                SKIP(78);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(128);
            END_STATE();
        case 77:
            if(lookahead == '\n')
                SKIP(128);
            END_STATE();
        case 78:
            if(lookahead == '\n')
                SKIP(128);
            if(lookahead == '\r')
                SKIP(77);
            END_STATE();
        case 79:
            if(lookahead == '\n')
                ADVANCE(1937);
            if(lookahead == '\r')
                ADVANCE(1934);
            if(lookahead == '\\')
                ADVANCE(1935);
            if(lookahead != 0)
                ADVANCE(1938);
            END_STATE();
        case 80:
            if(lookahead == '\n')
                ADVANCE(106);
            if(lookahead == '\r')
                ADVANCE(81);
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead != 0)
                ADVANCE(107);
            END_STATE();
        case 81:
            if(lookahead == '\n')
                ADVANCE(106);
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead != 0)
                ADVANCE(107);
            END_STATE();
        case 82:
            if(lookahead == '\n')
                SKIP(112);
            END_STATE();
        case 83:
            if(lookahead == '\n')
                SKIP(112);
            if(lookahead == '\r')
                SKIP(82);
            END_STATE();
        case 84:
            if(lookahead == '\r')
                ADVANCE(1939);
            if(lookahead == '\\')
                ADVANCE(1935);
            if(lookahead != 0)
                ADVANCE(1938);
            END_STATE();
        case 85:
            if(lookahead == ' ')
                ADVANCE(395);
            END_STATE();
        case 86:
            ADVANCE_MAP(
                '"', 1033,
                '%', 1012,
                '&', 1004,
                ')', 1014,
                '*', 1009,
                '+', 1007,
                ',', 997,
                '-', 1008,
                '/', 1011,
                ':', 1089,
                ';', 1090,
                '<', 139,
                '>', 992,
            );
            if(lookahead == '\\')
                SKIP(46);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == '^')
                ADVANCE(1003);
            if(lookahead == '{')
                ADVANCE(1080);
            if(lookahead == '|')
                ADVANCE(1002);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(86);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 87:
            ADVANCE_MAP(
                '"', 1033,
                '\'', 1039,
                '(', 1013,
                ')', 1014,
                '+', 1007,
                '-', 1008,
                '/', 105,
                '0', 1019,
                ':', 138,
                'F', 1315,
                'L', 1038,
                'T', 1320,
            );
            if(lookahead == '\\')
                SKIP(32);
            if(lookahead == '~')
                ADVANCE(1015);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(87);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 88:
            ADVANCE_MAP(
                '"', 1033,
                '\'', 1039,
                '(', 1013,
                '*', 1009,
                '+', 1007,
                '-', 1008,
                '/', 105,
                '0', 1019,
                ':', 138,
                'C', 1169,
                'F', 1315,
                'L', 1038,
                'T', 1320,
            );
            if(lookahead == '\\')
                SKIP(26);
            if(lookahead == 'c')
                ADVANCE(1167);
            if(lookahead == '~')
                ADVANCE(1015);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1731);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1701);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1814);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1682);
            if(lookahead == 'J' ||
               lookahead == 'j')
                ADVANCE(1622);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(88);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            if(('D' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('d' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 89:
            ADVANCE_MAP(
                '"', 1033,
                '\'', 1039,
                '(', 1013,
                '*', 1009,
                '+', 1007,
                '-', 1008,
                '/', 105,
                '0', 1019,
                ':', 138,
                'F', 1315,
                'L', 1038,
                'T', 1320,
            );
            if(lookahead == '\\')
                SKIP(36);
            if(lookahead == '~')
                ADVANCE(1015);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1679);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(89);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 90:
            ADVANCE_MAP(
                '"', 1033,
                '\'', 1039,
                '(', 1013,
                '+', 1007,
                '-', 1008,
                '/', 105,
                '0', 1019,
                ':', 138,
                'F', 1315,
                'L', 1038,
                'T', 1320,
            );
            if(lookahead == '\\')
                SKIP(28);
            if(lookahead == '~')
                ADVANCE(1015);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1731);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1701);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1814);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(90);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            if(('C' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('c' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 91:
            ADVANCE_MAP(
                '"', 1033,
                '\'', 1039,
                '(', 1013,
                '+', 1007,
                '-', 1008,
                '/', 105,
                '0', 1019,
                ':', 138,
                'F', 1315,
                'L', 1038,
                'T', 1320,
            );
            if(lookahead == '\\')
                SKIP(38);
            if(lookahead == '~')
                ADVANCE(1015);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1640);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(91);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 92:
            ADVANCE_MAP(
                '"', 1033,
                ')', 1014,
                ',', 997,
                '/', 105,
                ':', 138,
                ';', 1090,
                '<', 990,
                '>', 991,
            );
            if(lookahead == '\\')
                SKIP(52);
            if(lookahead == '{')
                ADVANCE(1080);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(92);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 93:
            if(lookahead == '"')
                ADVANCE(1033);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == '\\')
                ADVANCE(67);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(93);
            END_STATE();
        case 94:
            ADVANCE_MAP(
                '%', 1012,
                '&', 1004,
                ')', 1014,
                '*', 1009,
                '+', 1007,
                ',', 997,
                '-', 1008,
                '.', 1022,
                '/', 1011,
                ':', 1088,
                ';', 1090,
                '<', 139,
                '>', 992,
            );
            if(lookahead == '\\')
                SKIP(48);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == '^')
                ADVANCE(1003);
            if(lookahead == 'i')
                ADVANCE(414);
            if(lookahead == 'm')
                ADVANCE(217);
            if(lookahead == 's')
                ADVANCE(593);
            if(lookahead == '{')
                ADVANCE(1080);
            if(lookahead == '|')
                ADVANCE(1002);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1026);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1023);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(94);
            END_STATE();
        case 95:
            ADVANCE_MAP(
                '%', 1012,
                '&', 1004,
                ')', 1014,
                '*', 1009,
                '+', 1007,
                ',', 997,
                '-', 1008,
                '/', 1011,
                ':', 1089,
                ';', 1090,
                '<', 139,
                '>', 992,
                'A', 831,
                'C', 814,
                'D', 681,
                'M', 910,
                'S', 705,
                'U', 865,
                '[', 1268,
            );
            if(lookahead == '\\')
                SKIP(44);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == '^')
                ADVANCE(1003);
            if(lookahead == 'a')
                ADVANCE(384);
            if(lookahead == 'b')
                ADVANCE(367);
            if(lookahead == 'c')
                ADVANCE(171);
            if(lookahead == 'd')
                ADVANCE(319);
            if(lookahead == 'e')
                ADVANCE(604);
            if(lookahead == 'g')
                ADVANCE(316);
            if(lookahead == 'i')
                ADVANCE(435);
            if(lookahead == 'l')
                ADVANCE(466);
            if(lookahead == 'm')
                ADVANCE(218);
            if(lookahead == 'o')
                ADVANCE(243);
            if(lookahead == 'p')
                ADVANCE(473);
            if(lookahead == 'r')
                ADVANCE(228);
            if(lookahead == 's')
                ADVANCE(155);
            if(lookahead == 'u')
                ADVANCE(178);
            if(lookahead == 'v')
                ADVANCE(211);
            if(lookahead == '{')
                ADVANCE(1080);
            if(lookahead == '|')
                ADVANCE(1002);
            if(lookahead == '}')
                ADVANCE(1081);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(734);
            if(lookahead == 'H' ||
               lookahead == 'h')
                ADVANCE(626);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(848);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(661);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(95);
            END_STATE();
        case 96:
            if(lookahead == '&')
                ADVANCE(1004);
            if(lookahead == ')')
                ADVANCE(1014);
            if(lookahead == ',')
                ADVANCE(997);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(1088);
            if(lookahead == ';')
                ADVANCE(1090);
            if(lookahead == '>')
                ADVANCE(991);
            if(lookahead == '\\')
                SKIP(54);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == '^')
                ADVANCE(1003);
            if(lookahead == 'a')
                ADVANCE(1362);
            if(lookahead == 'i')
                ADVANCE(1506);
            if(lookahead == 'l')
                ADVANCE(1515);
            if(lookahead == '|')
                ADVANCE(1002);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(96);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 97:
            if(lookahead == '\'')
                ADVANCE(1039);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == '\\')
                ADVANCE(67);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(97);
            END_STATE();
        case 98:
            if(lookahead == '(')
                ADVANCE(1013);
            if(lookahead == ',')
                ADVANCE(997);
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == '\\')
                SKIP(50);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(98);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 99:
            if(lookahead == '(')
                ADVANCE(1013);
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(8);
            if(lookahead == 'a')
                ADVANCE(1487);
            if(lookahead == 'b')
                ADVANCE(1447);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1491);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'n')
                ADVANCE(1345);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 'r')
                ADVANCE(1417);
            if(lookahead == 's')
                ADVANCE(1393);
            if(lookahead == 't')
                ADVANCE(1616);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'v')
                ADVANCE(1510);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(99);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 100:
            if(lookahead == '(')
                ADVANCE(1013);
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(14);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(100);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 101:
            if(lookahead == '(')
                ADVANCE(1013);
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == '\\')
                SKIP(40);
            if(lookahead == 'a')
                ADVANCE(233);
            if(lookahead == 'b')
                ADVANCE(366);
            if(lookahead == 'c')
                ADVANCE(465);
            if(lookahead == 'e')
                ADVANCE(409);
            if(lookahead == 'i')
                ADVANCE(440);
            if(lookahead == 'l')
                ADVANCE(467);
            if(lookahead == 'm')
                ADVANCE(364);
            if(lookahead == 'n')
                ADVANCE(221);
            if(lookahead == 'p')
                ADVANCE(474);
            if(lookahead == 'r')
                ADVANCE(274);
            if(lookahead == 's')
                ADVANCE(574);
            if(lookahead == 't')
                ADVANCE(619);
            if(lookahead == 'u')
                ADVANCE(431);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(101);
            END_STATE();
        case 102:
            if(lookahead == ')')
                ADVANCE(1014);
            if(lookahead == ',')
                ADVANCE(997);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '<')
                ADVANCE(990);
            if(lookahead == '>')
                ADVANCE(991);
            if(lookahead == '\\')
                SKIP(6);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == 'h')
                ADVANCE(1346);
            if(lookahead == '{')
                ADVANCE(1080);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1793);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1740);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1735);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1624);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1792);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1736);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1670);
            if(lookahead == 'K' ||
               lookahead == 'k')
                ADVANCE(1689);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1619);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1705);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1805);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1823);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1629);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1690);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1821);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1817);
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(1620);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(1656);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(102);
            if(('G' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 103:
            if(lookahead == ')')
                ADVANCE(1014);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(16);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1486);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1374);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(103);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 104:
            if(lookahead == '*')
                ADVANCE(1940);
            if(lookahead == '/')
                ADVANCE(1930);
            END_STATE();
        case 105:
            if(lookahead == '*')
                ADVANCE(1940);
            if(lookahead == '/')
                ADVANCE(1928);
            END_STATE();
        case 106:
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead == '/')
                ADVANCE(108);
            if(lookahead == '\\')
                ADVANCE(80);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(106);
            if(lookahead != 0)
                ADVANCE(107);
            END_STATE();
        case 107:
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead != 0)
                ADVANCE(107);
            END_STATE();
        case 108:
            if(lookahead == '*')
                ADVANCE(1941);
            if(lookahead == '/')
                ADVANCE(1929);
            if(lookahead != 0)
                ADVANCE(107);
            END_STATE();
        case 109:
            if(lookahead == ',')
                ADVANCE(997);
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '<')
                ADVANCE(990);
            if(lookahead == '>')
                ADVANCE(991);
            if(lookahead == '\\')
                SKIP(56);
            if(lookahead == 'm')
                ADVANCE(217);
            if(lookahead == 'p')
                ADVANCE(507);
            if(lookahead == 's')
                ADVANCE(593);
            if(lookahead == '{')
                ADVANCE(1080);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(109);
            END_STATE();
        case 110:
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(2);
            if(lookahead == 'a')
                ADVANCE(1361);
            if(lookahead == 'b')
                ADVANCE(1447);
            if(lookahead == 'c')
                ADVANCE(1439);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1490);
            if(lookahead == 'f')
                ADVANCE(1338);
            if(lookahead == 'i')
                ADVANCE(1477);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'n')
                ADVANCE(1345);
            if(lookahead == 'o')
                ADVANCE(1373);
            if(lookahead == 'p')
                ADVANCE(1535);
            if(lookahead == 'r')
                ADVANCE(1417);
            if(lookahead == 's')
                ADVANCE(1393);
            if(lookahead == 't')
                ADVANCE(1614);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'v')
                ADVANCE(1358);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(110);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 111:
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(4);
            if(lookahead == 'a')
                ADVANCE(1361);
            if(lookahead == 'b')
                ADVANCE(1447);
            if(lookahead == 'c')
                ADVANCE(1439);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1490);
            if(lookahead == 'f')
                ADVANCE(1339);
            if(lookahead == 'i')
                ADVANCE(1477);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'n')
                ADVANCE(1345);
            if(lookahead == 'o')
                ADVANCE(1373);
            if(lookahead == 'r')
                ADVANCE(1417);
            if(lookahead == 's')
                ADVANCE(1393);
            if(lookahead == 't')
                ADVANCE(1614);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'v')
                ADVANCE(1358);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(111);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 112:
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(83);
            if(lookahead == 'a')
                ADVANCE(1361);
            if(lookahead == 'b')
                ADVANCE(1447);
            if(lookahead == 'c')
                ADVANCE(1439);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1490);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1477);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'n')
                ADVANCE(1345);
            if(lookahead == 'o')
                ADVANCE(1373);
            if(lookahead == 'r')
                ADVANCE(1417);
            if(lookahead == 's')
                ADVANCE(1393);
            if(lookahead == 't')
                ADVANCE(1614);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'v')
                ADVANCE(1358);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(112);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 113:
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '@')
                ADVANCE(1115);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(10);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1447);
            if(lookahead == 'c')
                ADVANCE(1353);
            if(lookahead == 'd')
                ADVANCE(1414);
            if(lookahead == 'e')
                ADVANCE(1491);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1393);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(113);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 114:
            if(lookahead == '/')
                ADVANCE(1069);
            if(lookahead == '\\')
                ADVANCE(1066);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(114);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 115:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(1089);
            if(lookahead == ';')
                ADVANCE(1090);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(18);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1395);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '{')
                ADVANCE(1080);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(115);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 116:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(12);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1447);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1491);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1393);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(116);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 117:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(22);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1440);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1489);
            if(lookahead == 'f')
                ADVANCE(1467);
            if(lookahead == 'i')
                ADVANCE(1501);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1394);
            if(lookahead == 't')
                ADVANCE(1617);
            if(lookahead == 'u')
                ADVANCE(1452);
            if(lookahead == 'v')
                ADVANCE(1359);
            if(lookahead == 'w')
                ADVANCE(1368);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(117);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 118:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == 'V')
                ADVANCE(1335);
            if(lookahead == '\\')
                SKIP(24);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(118);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 119:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == '\\')
                SKIP(61);
            if(lookahead == 'm')
                ADVANCE(1601);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(119);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 120:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == 'O')
                ADVANCE(1360);
            if(lookahead == '\\')
                SKIP(65);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(120);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 121:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '\\')
                SKIP(20);
            if(lookahead == 'a')
                ADVANCE(1487);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1440);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'e')
                ADVANCE(1491);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 't')
                ADVANCE(1616);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(121);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('g' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 122:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '\\')
                SKIP(30);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(122);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 123:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '\\')
                SKIP(34);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(123);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 124:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '\\')
                SKIP(42);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1519);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1442);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1368);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(124);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 125:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(138);
            if(lookahead == '\\')
                SKIP(63);
            if(lookahead == 't')
                ADVANCE(1544);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(125);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 126:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ':')
                ADVANCE(1088);
            if(lookahead == ';')
                ADVANCE(1090);
            if(lookahead == '\\')
                SKIP(70);
            if(lookahead == '{')
                ADVANCE(1080);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(126);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 127:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == ';')
                ADVANCE(1090);
            if(lookahead == '\\')
                SKIP(72);
            if(lookahead == 's')
                ADVANCE(1608);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(127);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 128:
            if(lookahead == '/')
                ADVANCE(105);
            if(lookahead == '\\')
                SKIP(78);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(128);
            END_STATE();
        case 129:
            if(lookahead == '1')
                ADVANCE(136);
            if(lookahead == '3')
                ADVANCE(132);
            if(lookahead == '6')
                ADVANCE(134);
            if(lookahead == '8')
                ADVANCE(967);
            END_STATE();
        case 130:
            if(lookahead == '1')
                ADVANCE(136);
            if(lookahead == '3')
                ADVANCE(132);
            if(lookahead == '6')
                ADVANCE(134);
            if(lookahead == '8')
                ADVANCE(967);
            if(lookahead == 'e')
                ADVANCE(495);
            END_STATE();
        case 131:
            if(lookahead == '1')
                ADVANCE(137);
            if(lookahead == '3')
                ADVANCE(133);
            if(lookahead == '6')
                ADVANCE(135);
            if(lookahead == '8')
                ADVANCE(959);
            END_STATE();
        case 132:
            if(lookahead == '2')
                ADVANCE(954);
            END_STATE();
        case 133:
            if(lookahead == '2')
                ADVANCE(973);
            END_STATE();
        case 134:
            if(lookahead == '4')
                ADVANCE(957);
            END_STATE();
        case 135:
            if(lookahead == '4')
                ADVANCE(976);
            END_STATE();
        case 136:
            if(lookahead == '6')
                ADVANCE(948);
            END_STATE();
        case 137:
            if(lookahead == '6')
                ADVANCE(970);
            END_STATE();
        case 138:
            if(lookahead == ':')
                ADVANCE(987);
            END_STATE();
        case 139:
            if(lookahead == '<')
                ADVANCE(1006);
            END_STATE();
        case 140:
            if(lookahead == 'A')
                ADVANCE(163);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(801);
            END_STATE();
        case 141:
            if(lookahead == 'A')
                ADVANCE(918);
            if(lookahead == 'I')
                ADVANCE(790);
            if(lookahead == 'U')
                ADVANCE(866);
            if(lookahead == 'a')
                ADVANCE(420);
            if(lookahead == 'i')
                ADVANCE(499);
            if(lookahead == 'o')
                ADVANCE(264);
            if(lookahead == 'u')
                ADVANCE(382);
            END_STATE();
        case 142:
            if(lookahead == 'A')
                ADVANCE(788);
            if(lookahead == 'a')
                ADVANCE(565);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(873);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(799);
            END_STATE();
        case 143:
            if(lookahead == 'A')
                ADVANCE(781);
            if(lookahead == 'a')
                ADVANCE(165);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(850);
            END_STATE();
        case 144:
            if(lookahead == 'A')
                ADVANCE(781);
            if(lookahead == 'a')
                ADVANCE(166);
            if(lookahead == 'o')
                ADVANCE(350);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(850);
            END_STATE();
        case 145:
            if(lookahead == 'A')
                ADVANCE(905);
            if(lookahead == 'a')
                ADVANCE(182);
            END_STATE();
        case 146:
            if(lookahead == 'A')
                ADVANCE(862);
            if(lookahead == 'a')
                ADVANCE(176);
            if(lookahead == 'o')
                ADVANCE(401);
            END_STATE();
        case 147:
            if(lookahead == 'A')
                ADVANCE(921);
            if(lookahead == 'a')
                ADVANCE(187);
            END_STATE();
        case 148:
            if(lookahead == 'A')
                ADVANCE(791);
            if(lookahead == 'a')
                ADVANCE(369);
            if(lookahead == 'e')
                ADVANCE(203);
            END_STATE();
        case 149:
            if(lookahead == 'E')
                ADVANCE(840);
            if(lookahead == 'e')
                ADVANCE(173);
            if(lookahead == 'h')
                ADVANCE(453);
            if(lookahead == 't')
                ADVANCE(489);
            if(lookahead == 'u')
                ADVANCE(488);
            if(lookahead == 'w')
                ADVANCE(359);
            END_STATE();
        case 150:
            if(lookahead == 'E')
                ADVANCE(917);
            if(lookahead == 'e')
                ADVANCE(186);
            END_STATE();
        case 151:
            if(lookahead == 'E')
                ADVANCE(1044);
            END_STATE();
        case 152:
            if(lookahead == 'E')
                ADVANCE(1046);
            END_STATE();
        case 153:
            if(lookahead == 'E')
                ADVANCE(1131);
            if(lookahead == 'e')
                ADVANCE(1132);
            END_STATE();
        case 154:
            if(lookahead == 'E')
                ADVANCE(1131);
            if(lookahead == 'e')
                ADVANCE(1133);
            END_STATE();
        case 155:
            if(lookahead == 'E')
                ADVANCE(839);
            if(lookahead == 'e')
                ADVANCE(590);
            if(lookahead == 'h')
                ADVANCE(453);
            if(lookahead == 'u')
                ADVANCE(488);
            END_STATE();
        case 156:
            if(lookahead == 'E')
                ADVANCE(191);
            if(lookahead == 'e')
                ADVANCE(192);
            END_STATE();
        case 157:
            if(lookahead == 'E')
                ADVANCE(811);
            if(lookahead == 'e')
                ADVANCE(170);
            END_STATE();
        case 158:
            if(lookahead == 'F')
                ADVANCE(625);
            if(lookahead == 'f')
                ADVANCE(145);
            END_STATE();
        case 159:
            if(lookahead == 'H')
                ADVANCE(1125);
            if(lookahead == 'h')
                ADVANCE(1126);
            END_STATE();
        case 160:
            if(lookahead == 'I')
                ADVANCE(801);
            if(lookahead == 'a')
                ADVANCE(249);
            if(lookahead == 'i')
                ADVANCE(169);
            if(lookahead == 'l')
                ADVANCE(450);
            END_STATE();
        case 161:
            if(lookahead == 'I')
                ADVANCE(875);
            if(lookahead == 'i')
                ADVANCE(179);
            if(lookahead == 'o')
                ADVANCE(445);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(729);
            END_STATE();
        case 162:
            if(lookahead == 'I')
                ADVANCE(876);
            if(lookahead == 'i')
                ADVANCE(452);
            if(lookahead == 's')
                ADVANCE(351);
            END_STATE();
        case 163:
            if(lookahead == 'L')
                ADVANCE(177);
            END_STATE();
        case 164:
            if(lookahead == 'L')
                ADVANCE(877);
            if(lookahead == 'l')
                ADVANCE(180);
            END_STATE();
        case 165:
            if(lookahead == 'L')
                ADVANCE(909);
            if(lookahead == 'l')
                ADVANCE(183);
            END_STATE();
        case 166:
            if(lookahead == 'L')
                ADVANCE(909);
            if(lookahead == 'l')
                ADVANCE(184);
            END_STATE();
        case 167:
            if(lookahead == 'N')
                ADVANCE(747);
            if(lookahead == 'S')
                ADVANCE(708);
            if(lookahead == 'i')
                ADVANCE(427);
            if(lookahead == 'n')
                ADVANCE(162);
            if(lookahead == 's')
                ADVANCE(156);
            END_STATE();
        case 168:
            if(lookahead == 'N')
                ADVANCE(692);
            if(lookahead == 'c')
                ADVANCE(579);
            if(lookahead == 'n')
                ADVANCE(150);
            if(lookahead == 'u')
                ADVANCE(540);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(883);
            END_STATE();
        case 169:
            if(lookahead == 'N')
                ADVANCE(627);
            if(lookahead == 'n')
                ADVANCE(267);
            if(lookahead == 'x')
                ADVANCE(298);
            END_STATE();
        case 170:
            if(lookahead == 'N')
                ADVANCE(896);
            if(lookahead == 'n')
                ADVANCE(253);
            END_STATE();
        case 171:
            if(lookahead == 'O')
                ADVANCE(841);
            if(lookahead == 'a')
                ADVANCE(531);
            if(lookahead == 'o')
                ADVANCE(436);
            END_STATE();
        case 172:
            if(lookahead == 'O')
                ADVANCE(872);
            if(lookahead == 'o')
                ADVANCE(503);
            if(lookahead == 'r')
                ADVANCE(343);
            if(lookahead == 'u')
                ADVANCE(234);
            END_STATE();
        case 173:
            if(lookahead == 'Q')
                ADVANCE(913);
            if(lookahead == 'q')
                ADVANCE(185);
            if(lookahead == 't')
                ADVANCE(514);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(915);
            END_STATE();
        case 174:
            if(lookahead == 'R')
                ADVANCE(181);
            if(lookahead == 'r')
                ADVANCE(738);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(834);
            END_STATE();
        case 175:
            if(lookahead == 'R')
                ADVANCE(738);
            if(lookahead == 'r')
                ADVANCE(594);
            if(lookahead == 'y')
                ADVANCE(477);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(834);
            END_STATE();
        case 176:
            if(lookahead == 'S')
                ADVANCE(733);
            if(lookahead == 's')
                ADVANCE(159);
            END_STATE();
        case 177:
            if(lookahead == 'S')
                ADVANCE(152);
            END_STATE();
        case 178:
            if(lookahead == 'S')
                ADVANCE(708);
            if(lookahead == 'i')
                ADVANCE(427);
            if(lookahead == 'n')
                ADVANCE(533);
            if(lookahead == 's')
                ADVANCE(156);
            END_STATE();
        case 179:
            if(lookahead == 'T')
                ADVANCE(189);
            if(lookahead == 't')
                ADVANCE(190);
            END_STATE();
        case 180:
            if(lookahead == 'T')
                ADVANCE(1148);
            if(lookahead == 't')
                ADVANCE(1113);
            END_STATE();
        case 181:
            if(lookahead == 'U')
                ADVANCE(151);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(786);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(193);
            END_STATE();
        case 182:
            if(lookahead == 'U')
                ADVANCE(771);
            if(lookahead == 'u')
                ADVANCE(164);
            END_STATE();
        case 183:
            if(lookahead == 'U')
                ADVANCE(697);
            if(lookahead == 'u')
                ADVANCE(153);
            END_STATE();
        case 184:
            if(lookahead == 'U')
                ADVANCE(697);
            if(lookahead == 'u')
                ADVANCE(154);
            END_STATE();
        case 185:
            if(lookahead == 'U')
                ADVANCE(714);
            if(lookahead == 'u')
                ADVANCE(157);
            END_STATE();
        case 186:
            if(lookahead == 'W')
                ADVANCE(628);
            if(lookahead == 'w')
                ADVANCE(147);
            END_STATE();
        case 187:
            if(lookahead == 'Y')
                ADVANCE(1194);
            if(lookahead == 'y')
                ADVANCE(1281);
            END_STATE();
        case 188:
            if(lookahead == '_')
                ADVANCE(682);
            END_STATE();
        case 189:
            if(lookahead == '_')
                ADVANCE(652);
            END_STATE();
        case 190:
            if(lookahead == '_')
                ADVANCE(652);
            if(lookahead == 'f')
                ADVANCE(362);
            if(lookahead == 'm')
                ADVANCE(208);
            if(lookahead == 's')
                ADVANCE(315);
            END_STATE();
        case 191:
            if(lookahead == '_')
                ADVANCE(683);
            END_STATE();
        case 192:
            if(lookahead == '_')
                ADVANCE(683);
            if(lookahead == 's')
                ADVANCE(1288);
            END_STATE();
        case 193:
            if(lookahead == '_')
                ADVANCE(662);
            END_STATE();
        case 194:
            if(lookahead == '_')
                ADVANCE(907);
            END_STATE();
        case 195:
            if(lookahead == '_')
                ADVANCE(377);
            END_STATE();
        case 196:
            if(lookahead == '_')
                ADVANCE(847);
            END_STATE();
        case 197:
            if(lookahead == '_')
                ADVANCE(871);
            END_STATE();
        case 198:
            if(lookahead == '_')
                ADVANCE(774);
            END_STATE();
        case 199:
            if(lookahead == '_')
                ADVANCE(686);
            END_STATE();
        case 200:
            if(lookahead == '_')
                ADVANCE(809);
            END_STATE();
        case 201:
            if(lookahead == '_')
                ADVANCE(687);
            END_STATE();
        case 202:
            if(lookahead == '_')
                ADVANCE(688);
            END_STATE();
        case 203:
            if(lookahead == 'a')
                ADVANCE(273);
            END_STATE();
        case 204:
            if(lookahead == 'a')
                ADVANCE(337);
            END_STATE();
        case 205:
            if(lookahead == 'a')
                ADVANCE(518);
            END_STATE();
        case 206:
            if(lookahead == 'a')
                ADVANCE(490);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(739);
            END_STATE();
        case 207:
            if(lookahead == 'a')
                ADVANCE(378);
            END_STATE();
        case 208:
            if(lookahead == 'a')
                ADVANCE(520);
            END_STATE();
        case 209:
            if(lookahead == 'a')
                ADVANCE(491);
            END_STATE();
        case 210:
            if(lookahead == 'a')
                ADVANCE(381);
            END_STATE();
        case 211:
            if(lookahead == 'a')
                ADVANCE(381);
            if(lookahead == 'o')
                ADVANCE(350);
            END_STATE();
        case 212:
            if(lookahead == 'a')
                ADVANCE(595);
            END_STATE();
        case 213:
            if(lookahead == 'a')
                ADVANCE(370);
            END_STATE();
        case 214:
            if(lookahead == 'a')
                ADVANCE(411);
            END_STATE();
        case 215:
            if(lookahead == 'a')
                ADVANCE(496);
            END_STATE();
        case 216:
            if(lookahead == 'a')
                ADVANCE(544);
            END_STATE();
        case 217:
            if(lookahead == 'a')
                ADVANCE(419);
            END_STATE();
        case 218:
            if(lookahead == 'a')
                ADVANCE(419);
            if(lookahead == 'i')
                ADVANCE(498);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(885);
            END_STATE();
        case 219:
            if(lookahead == 'a')
                ADVANCE(576);
            END_STATE();
        case 220:
            if(lookahead == 'a')
                ADVANCE(573);
            END_STATE();
        case 221:
            if(lookahead == 'a')
                ADVANCE(564);
            END_STATE();
        case 222:
            if(lookahead == 'a')
                ADVANCE(254);
            END_STATE();
        case 223:
            if(lookahead == 'a')
                ADVANCE(403);
            END_STATE();
        case 224:
            if(lookahead == 'a')
                ADVANCE(252);
            END_STATE();
        case 225:
            if(lookahead == 'a')
                ADVANCE(538);
            END_STATE();
        case 226:
            if(lookahead == 'a')
                ADVANCE(371);
            END_STATE();
        case 227:
            if(lookahead == 'a')
                ADVANCE(587);
            END_STATE();
        case 228:
            if(lookahead == 'a')
                ADVANCE(368);
            END_STATE();
        case 229:
            if(lookahead == 'a')
                ADVANCE(239);
            END_STATE();
        case 230:
            if(lookahead == 'b')
                ADVANCE(374);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(692);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(883);
            END_STATE();
        case 231:
            ADVANCE_MAP(
                'b', 539,
                'l', 347,
                'n', 610,
                't', 562,
                'F', 882,
                'f', 882,
                'M', 735,
                'm', 735,
                'P', 832,
                'p', 832,
                'U', 895,
                'u', 895,
            );
            END_STATE();
        case 232:
            if(lookahead == 'b')
                ADVANCE(539);
            if(lookahead == 'l')
                ADVANCE(346);
            END_STATE();
        case 233:
            if(lookahead == 'b')
                ADVANCE(539);
            if(lookahead == 't')
                ADVANCE(562);
            END_STATE();
        case 234:
            if(lookahead == 'b')
                ADVANCE(383);
            END_STATE();
        case 235:
            if(lookahead == 'b')
                ADVANCE(387);
            END_STATE();
        case 236:
            if(lookahead == 'b')
                ADVANCE(597);
            END_STATE();
        case 237:
            if(lookahead == 'b')
                ADVANCE(388);
            END_STATE();
        case 238:
            if(lookahead == 'b')
                ADVANCE(391);
            END_STATE();
        case 239:
            if(lookahead == 'b')
                ADVANCE(392);
            END_STATE();
        case 240:
            if(lookahead == 'c')
                ADVANCE(240);
            if(lookahead == 'i')
                ADVANCE(1170);
            END_STATE();
        case 241:
            if(lookahead == 'c')
                ADVANCE(339);
            if(lookahead == 's')
                ADVANCE(580);
            END_STATE();
        case 242:
            if(lookahead == 'c')
                ADVANCE(1260);
            if(lookahead == 's')
                ADVANCE(340);
            END_STATE();
        case 243:
            if(lookahead == 'c')
                ADVANCE(579);
            END_STATE();
        case 244:
            if(lookahead == 'c')
                ADVANCE(338);
            END_STATE();
        case 245:
            if(lookahead == 'c')
                ADVANCE(207);
            END_STATE();
        case 246:
            if(lookahead == 'c')
                ADVANCE(207);
            if(lookahead == 'n')
                ADVANCE(329);
            END_STATE();
        case 247:
            if(lookahead == 'c')
                ADVANCE(297);
            END_STATE();
        case 248:
            if(lookahead == 'c')
                ADVANCE(297);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(693);
            END_STATE();
        case 249:
            if(lookahead == 'c')
                ADVANCE(582);
            END_STATE();
        case 250:
            if(lookahead == 'c')
                ADVANCE(548);
            END_STATE();
        case 251:
            if(lookahead == 'c')
                ADVANCE(551);
            END_STATE();
        case 252:
            if(lookahead == 'c')
                ADVANCE(554);
            END_STATE();
        case 253:
            if(lookahead == 'c')
                ADVANCE(285);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(752);
            END_STATE();
        case 254:
            if(lookahead == 'c')
                ADVANCE(295);
            END_STATE();
        case 255:
            if(lookahead == 'c')
                ADVANCE(220);
            END_STATE();
        case 256:
            if(lookahead == 'c')
                ADVANCE(585);
            END_STATE();
        case 257:
            if(lookahead == 'd')
                ADVANCE(1056);
            if(lookahead == 'i')
                ADVANCE(1062);
            if(lookahead == '\t' ||
               lookahead == ' ')
                ADVANCE(342);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 258:
            if(lookahead == 'd')
                ADVANCE(1091);
            END_STATE();
        case 259:
            if(lookahead == 'd')
                ADVANCE(963);
            END_STATE();
        case 260:
            if(lookahead == 'd')
                ADVANCE(1198);
            END_STATE();
        case 261:
            if(lookahead == 'd')
                ADVANCE(1274);
            END_STATE();
        case 262:
            if(lookahead == 'd')
                ADVANCE(1109);
            END_STATE();
        case 263:
            if(lookahead == 'd')
                ADVANCE(85);
            END_STATE();
        case 264:
            if(lookahead == 'd')
                ADVANCE(601);
            END_STATE();
        case 265:
            if(lookahead == 'd')
                ADVANCE(475);
            if(lookahead == 'l')
                ADVANCE(458);
            END_STATE();
        case 266:
            if(lookahead == 'd')
                ADVANCE(195);
            END_STATE();
        case 267:
            if(lookahead == 'd')
                ADVANCE(307);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(766);
            END_STATE();
        case 268:
            if(lookahead == 'd')
                ADVANCE(529);
            END_STATE();
        case 269:
            if(lookahead == 'd')
                ADVANCE(282);
            END_STATE();
        case 270:
            if(lookahead == 'd')
                ADVANCE(282);
            if(lookahead == 'i')
                ADVANCE(261);
            if(lookahead == 'n')
                ADVANCE(223);
            if(lookahead == 'p')
                ADVANCE(509);
            END_STATE();
        case 271:
            if(lookahead == 'd')
                ADVANCE(282);
            if(lookahead == 'i')
                ADVANCE(261);
            if(lookahead == 'p')
                ADVANCE(509);
            END_STATE();
        case 272:
            if(lookahead == 'd')
                ADVANCE(305);
            END_STATE();
        case 273:
            if(lookahead == 'd')
                ADVANCE(455);
            END_STATE();
        case 274:
            if(lookahead == 'e')
                ADVANCE(203);
            END_STATE();
        case 275:
            if(lookahead == 'e')
                ADVANCE(1272);
            END_STATE();
        case 276:
            if(lookahead == 'e')
                ADVANCE(1291);
            END_STATE();
        case 277:
            if(lookahead == 'e')
                ADVANCE(270);
            END_STATE();
        case 278:
            if(lookahead == 'e')
                ADVANCE(609);
            END_STATE();
        case 279:
            if(lookahead == 'e')
                ADVANCE(980);
            END_STATE();
        case 280:
            if(lookahead == 'e')
                ADVANCE(1238);
            END_STATE();
        case 281:
            if(lookahead == 'e')
                ADVANCE(1303);
            END_STATE();
        case 282:
            if(lookahead == 'e')
                ADVANCE(324);
            END_STATE();
        case 283:
            if(lookahead == 'e')
                ADVANCE(1262);
            END_STATE();
        case 284:
            if(lookahead == 'e')
                ADVANCE(1289);
            END_STATE();
        case 285:
            if(lookahead == 'e')
                ADVANCE(998);
            END_STATE();
        case 286:
            if(lookahead == 'e')
                ADVANCE(1239);
            END_STATE();
        case 287:
            if(lookahead == 'e')
                ADVANCE(1284);
            END_STATE();
        case 288:
            if(lookahead == 'e')
                ADVANCE(1103);
            END_STATE();
        case 289:
            if(lookahead == 'e')
                ADVANCE(1243);
            END_STATE();
        case 290:
            if(lookahead == 'e')
                ADVANCE(1241);
            END_STATE();
        case 291:
            if(lookahead == 'e')
                ADVANCE(982);
            END_STATE();
        case 292:
            if(lookahead == 'e')
                ADVANCE(1256);
            END_STATE();
        case 293:
            if(lookahead == 'e')
                ADVANCE(271);
            END_STATE();
        case 294:
            if(lookahead == 'e')
                ADVANCE(1299);
            END_STATE();
        case 295:
            if(lookahead == 'e')
                ADVANCE(1086);
            END_STATE();
        case 296:
            if(lookahead == 'e')
                ADVANCE(326);
            END_STATE();
        case 297:
            if(lookahead == 'e')
                ADVANCE(483);
            END_STATE();
        case 298:
            if(lookahead == 'e')
                ADVANCE(259);
            END_STATE();
        case 299:
            if(lookahead == 'e')
                ADVANCE(386);
            END_STATE();
        case 300:
            if(lookahead == 'e')
                ADVANCE(521);
            END_STATE();
        case 301:
            if(lookahead == 'e')
                ADVANCE(613);
            END_STATE();
        case 302:
            if(lookahead == 'e')
                ADVANCE(522);
            END_STATE();
        case 303:
            if(lookahead == 'e')
                ADVANCE(523);
            END_STATE();
        case 304:
            if(lookahead == 'e')
                ADVANCE(266);
            END_STATE();
        case 305:
            if(lookahead == 'e')
                ADVANCE(524);
            END_STATE();
        case 306:
            if(lookahead == 'e')
                ADVANCE(214);
            END_STATE();
        case 307:
            if(lookahead == 'e')
                ADVANCE(492);
            END_STATE();
        case 308:
            if(lookahead == 'e')
                ADVANCE(263);
            END_STATE();
        case 309:
            if(lookahead == 'e')
                ADVANCE(526);
            END_STATE();
        case 310:
            if(lookahead == 'e')
                ADVANCE(527);
            END_STATE();
        case 311:
            if(lookahead == 'e')
                ADVANCE(528);
            END_STATE();
        case 312:
            if(lookahead == 'e')
                ADVANCE(546);
            END_STATE();
        case 313:
            if(lookahead == 'e')
                ADVANCE(495);
            END_STATE();
        case 314:
            if(lookahead == 'e')
                ADVANCE(517);
            END_STATE();
        case 315:
            if(lookahead == 'e')
                ADVANCE(549);
            END_STATE();
        case 316:
            if(lookahead == 'e')
                ADVANCE(567);
            END_STATE();
        case 317:
            if(lookahead == 'e')
                ADVANCE(250);
            END_STATE();
        case 318:
            if(lookahead == 'e')
                ADVANCE(428);
            END_STATE();
        case 319:
            if(lookahead == 'e')
                ADVANCE(328);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(864);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(861);
            END_STATE();
        case 320:
            if(lookahead == 'e')
                ADVANCE(269);
            END_STATE();
        case 321:
            if(lookahead == 'e')
                ADVANCE(434);
            END_STATE();
        case 322:
            if(lookahead == 'e')
                ADVANCE(586);
            END_STATE();
        case 323:
            if(lookahead == 'e')
                ADVANCE(256);
            END_STATE();
        case 324:
            if(lookahead == 'f')
                ADVANCE(1266);
            END_STATE();
        case 325:
            if(lookahead == 'f')
                ADVANCE(362);
            END_STATE();
        case 326:
            if(lookahead == 'f')
                ADVANCE(349);
            END_STATE();
        case 327:
            if(lookahead == 'f')
                ADVANCE(222);
            END_STATE();
        case 328:
            if(lookahead == 'f')
                ADVANCE(212);
            END_STATE();
        case 329:
            if(lookahead == 'g')
                ADVANCE(950);
            END_STATE();
        case 330:
            if(lookahead == 'g')
                ADVANCE(988);
            END_STATE();
        case 331:
            if(lookahead == 'g')
                ADVANCE(993);
            END_STATE();
        case 332:
            if(lookahead == 'g')
                ADVANCE(956);
            END_STATE();
        case 333:
            if(lookahead == 'g')
                ADVANCE(972);
            END_STATE();
        case 334:
            if(lookahead == 'g')
                ADVANCE(975);
            END_STATE();
        case 335:
            if(lookahead == 'g')
                ADVANCE(952);
            END_STATE();
        case 336:
            if(lookahead == 'g')
                ADVANCE(433);
            END_STATE();
        case 337:
            if(lookahead == 'g')
                ADVANCE(302);
            END_STATE();
        case 338:
            if(lookahead == 'h')
                ADVANCE(1270);
            END_STATE();
        case 339:
            if(lookahead == 'h')
                ADVANCE(209);
            END_STATE();
        case 340:
            if(lookahead == 'h')
                ADVANCE(310);
            END_STATE();
        case 341:
            if(lookahead == 'h')
                ADVANCE(471);
            END_STATE();
        case 342:
            if(lookahead == 'i')
                ADVANCE(1062);
            if(lookahead == '\t' ||
               lookahead == ' ')
                ADVANCE(342);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 343:
            if(lookahead == 'i')
                ADVANCE(408);
            if(lookahead == 'o')
                ADVANCE(606);
            END_STATE();
        case 344:
            if(lookahead == 'i')
                ADVANCE(242);
            END_STATE();
        case 345:
            if(lookahead == 'i')
                ADVANCE(236);
            END_STATE();
        case 346:
            if(lookahead == 'i')
                ADVANCE(205);
            END_STATE();
        case 347:
            if(lookahead == 'i')
                ADVANCE(205);
            if(lookahead == 'l')
                ADVANCE(447);
            END_STATE();
        case 348:
            if(lookahead == 'i')
                ADVANCE(605);
            END_STATE();
        case 349:
            if(lookahead == 'i')
                ADVANCE(608);
            END_STATE();
        case 350:
            if(lookahead == 'i')
                ADVANCE(258);
            END_STATE();
        case 351:
            if(lookahead == 'i')
                ADVANCE(336);
            END_STATE();
        case 352:
            if(lookahead == 'i')
                ADVANCE(407);
            END_STATE();
        case 353:
            if(lookahead == 'i')
                ADVANCE(407);
            if(lookahead == 'o')
                ADVANCE(606);
            END_STATE();
        case 354:
            if(lookahead == 'i')
                ADVANCE(418);
            if(lookahead == 'u')
                ADVANCE(251);
            END_STATE();
        case 355:
            if(lookahead == 'i')
                ADVANCE(566);
            END_STATE();
        case 356:
            if(lookahead == 'i')
                ADVANCE(566);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(880);
            END_STATE();
        case 357:
            if(lookahead == 'i')
                ADVANCE(484);
            END_STATE();
        case 358:
            if(lookahead == 'i')
                ADVANCE(272);
            END_STATE();
        case 359:
            if(lookahead == 'i')
                ADVANCE(561);
            END_STATE();
        case 360:
            if(lookahead == 'i')
                ADVANCE(422);
            END_STATE();
        case 361:
            if(lookahead == 'i')
                ADVANCE(451);
            END_STATE();
        case 362:
            if(lookahead == 'i')
                ADVANCE(299);
            END_STATE();
        case 363:
            if(lookahead == 'i')
                ADVANCE(429);
            END_STATE();
        case 364:
            if(lookahead == 'i')
                ADVANCE(498);
            if(lookahead == 'o')
                ADVANCE(264);
            END_STATE();
        case 365:
            if(lookahead == 'i')
                ADVANCE(530);
            END_STATE();
        case 366:
            if(lookahead == 'i')
                ADVANCE(558);
            END_STATE();
        case 367:
            if(lookahead == 'i')
                ADVANCE(581);
            if(lookahead == 'o')
                ADVANCE(445);
            END_STATE();
        case 368:
            if(lookahead == 'i')
                ADVANCE(535);
            END_STATE();
        case 369:
            if(lookahead == 'i')
                ADVANCE(535);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(732);
            END_STATE();
        case 370:
            if(lookahead == 'i')
                ADVANCE(536);
            END_STATE();
        case 371:
            if(lookahead == 'i')
                ADVANCE(537);
            END_STATE();
        case 372:
            if(lookahead == 'i')
                ADVANCE(459);
            END_STATE();
        case 373:
            if(lookahead == 'i')
                ADVANCE(461);
            END_STATE();
        case 374:
            if(lookahead == 'j')
                ADVANCE(317);
            END_STATE();
        case 375:
            if(lookahead == 'k')
                ADVANCE(1110);
            END_STATE();
        case 376:
            if(lookahead == 'k')
                ADVANCE(301);
            END_STATE();
        case 377:
            if(lookahead == 'k')
                ADVANCE(363);
            END_STATE();
        case 378:
            if(lookahead == 'l')
                ADVANCE(1082);
            END_STATE();
        case 379:
            if(lookahead == 'l')
                ADVANCE(447);
            END_STATE();
        case 380:
            if(lookahead == 'l')
                ADVANCE(612);
            END_STATE();
        case 381:
            if(lookahead == 'l')
                ADVANCE(602);
            END_STATE();
        case 382:
            if(lookahead == 'l')
                ADVANCE(568);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(888);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(629);
            END_STATE();
        case 383:
            if(lookahead == 'l')
                ADVANCE(344);
            END_STATE();
        case 384:
            if(lookahead == 'l')
                ADVANCE(379);
            if(lookahead == 't')
                ADVANCE(562);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(832);
            END_STATE();
        case 385:
            if(lookahead == 'l')
                ADVANCE(306);
            END_STATE();
        case 386:
            if(lookahead == 'l')
                ADVANCE(262);
            END_STATE();
        case 387:
            if(lookahead == 'l')
                ADVANCE(279);
            END_STATE();
        case 388:
            if(lookahead == 'l')
                ADVANCE(365);
            END_STATE();
        case 389:
            if(lookahead == 'l')
                ADVANCE(280);
            END_STATE();
        case 390:
            if(lookahead == 'l')
                ADVANCE(284);
            END_STATE();
        case 391:
            if(lookahead == 'l')
                ADVANCE(291);
            END_STATE();
        case 392:
            if(lookahead == 'l')
                ADVANCE(292);
            END_STATE();
        case 393:
            if(lookahead == 'l')
                ADVANCE(553);
            END_STATE();
        case 394:
            if(lookahead == 'l')
                ADVANCE(458);
            END_STATE();
        case 395:
            if(lookahead == 'l')
                ADVANCE(462);
            if(lookahead == 's')
                ADVANCE(341);
            END_STATE();
        case 396:
            if(lookahead == 'l')
                ADVANCE(464);
            END_STATE();
        case 397:
            if(lookahead == 'm')
                ADVANCE(485);
            if(lookahead == 'n')
                ADVANCE(1094);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1120);
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(812);
            END_STATE();
        case 398:
            if(lookahead == 'm')
                ADVANCE(485);
            if(lookahead == 'n')
                ADVANCE(578);
            END_STATE();
        case 399:
            if(lookahead == 'm')
                ADVANCE(1249);
            END_STATE();
        case 400:
            if(lookahead == 'm')
                ADVANCE(1254);
            END_STATE();
        case 401:
            if(lookahead == 'm')
                ADVANCE(276);
            END_STATE();
        case 402:
            if(lookahead == 'm')
                ADVANCE(303);
            END_STATE();
        case 403:
            if(lookahead == 'm')
                ADVANCE(286);
            END_STATE();
        case 404:
            if(lookahead == 'm')
                ADVANCE(476);
            if(lookahead == 'n')
                ADVANCE(438);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(654);
            END_STATE();
        case 405:
            if(lookahead == 'm')
                ADVANCE(476);
            if(lookahead == 'n')
                ADVANCE(439);
            END_STATE();
        case 406:
            if(lookahead == 'm')
                ADVANCE(208);
            if(lookahead == 's')
                ADVANCE(315);
            END_STATE();
        case 407:
            if(lookahead == 'm')
                ADVANCE(215);
            END_STATE();
        case 408:
            if(lookahead == 'm')
                ADVANCE(215);
            if(lookahead == 'v')
                ADVANCE(219);
            END_STATE();
        case 409:
            if(lookahead == 'm')
                ADVANCE(355);
            if(lookahead == 'n')
                ADVANCE(591);
            END_STATE();
        case 410:
            if(lookahead == 'n')
                ADVANCE(1247);
            END_STATE();
        case 411:
            if(lookahead == 'n')
                ADVANCE(961);
            END_STATE();
        case 412:
            if(lookahead == 'n')
                ADVANCE(1078);
            END_STATE();
        case 413:
            if(lookahead == 'n')
                ADVANCE(1112);
            END_STATE();
        case 414:
            if(lookahead == 'n')
                ADVANCE(1093);
            END_STATE();
        case 415:
            if(lookahead == 'n')
                ADVANCE(423);
            END_STATE();
        case 416:
            if(lookahead == 'n')
                ADVANCE(255);
            END_STATE();
        case 417:
            if(lookahead == 'n')
                ADVANCE(591);
            if(lookahead == 'v')
                ADVANCE(318);
            if(lookahead == 'x')
                ADVANCE(247);
            END_STATE();
        case 418:
            if(lookahead == 'n')
                ADVANCE(330);
            END_STATE();
        case 419:
            if(lookahead == 'n')
                ADVANCE(204);
            END_STATE();
        case 420:
            if(lookahead == 'n')
                ADVANCE(204);
            if(lookahead == 'p')
                ADVANCE(1000);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(1154);
            END_STATE();
        case 421:
            if(lookahead == 'n')
                ADVANCE(380);
            END_STATE();
        case 422:
            if(lookahead == 'n')
                ADVANCE(331);
            END_STATE();
        case 423:
            if(lookahead == 'n')
                ADVANCE(463);
            END_STATE();
        case 424:
            if(lookahead == 'n')
                ADVANCE(332);
            END_STATE();
        case 425:
            if(lookahead == 'n')
                ADVANCE(333);
            END_STATE();
        case 426:
            if(lookahead == 'n')
                ADVANCE(334);
            END_STATE();
        case 427:
            if(lookahead == 'n')
                ADVANCE(563);
            END_STATE();
        case 428:
            if(lookahead == 'n')
                ADVANCE(575);
            END_STATE();
        case 429:
            if(lookahead == 'n')
                ADVANCE(268);
            END_STATE();
        case 430:
            if(lookahead == 'n')
                ADVANCE(361);
            END_STATE();
        case 431:
            if(lookahead == 'n')
                ADVANCE(361);
            if(lookahead == 's')
                ADVANCE(314);
            END_STATE();
        case 432:
            if(lookahead == 'n')
                ADVANCE(534);
            END_STATE();
        case 433:
            if(lookahead == 'n')
                ADVANCE(308);
            END_STATE();
        case 434:
            if(lookahead == 'n')
                ADVANCE(555);
            END_STATE();
        case 435:
            if(lookahead == 'n')
                ADVANCE(559);
            END_STATE();
        case 436:
            if(lookahead == 'n')
                ADVANCE(570);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(654);
            END_STATE();
        case 437:
            if(lookahead == 'n')
                ADVANCE(335);
            END_STATE();
        case 438:
            if(lookahead == 'n')
                ADVANCE(323);
            if(lookahead == 's')
                ADVANCE(543);
            if(lookahead == 't')
                ADVANCE(278);
            END_STATE();
        case 439:
            if(lookahead == 'n')
                ADVANCE(323);
            if(lookahead == 's')
                ADVANCE(542);
            END_STATE();
        case 440:
            if(lookahead == 'n')
                ADVANCE(578);
            END_STATE();
        case 441:
            if(lookahead == 'n')
                ADVANCE(321);
            END_STATE();
        case 442:
            if(lookahead == 'o')
                ADVANCE(401);
            END_STATE();
        case 443:
            if(lookahead == 'o')
                ADVANCE(246);
            END_STATE();
        case 444:
            if(lookahead == 'o')
                ADVANCE(264);
            END_STATE();
        case 445:
            if(lookahead == 'o')
                ADVANCE(385);
            END_STATE();
        case 446:
            if(lookahead == 'o')
                ADVANCE(606);
            END_STATE();
        case 447:
            if(lookahead == 'o')
                ADVANCE(607);
            END_STATE();
        case 448:
            if(lookahead == 'o')
                ADVANCE(405);
            if(lookahead == 'u')
                ADVANCE(532);
            END_STATE();
        case 449:
            if(lookahead == 'o')
                ADVANCE(400);
            END_STATE();
        case 450:
            if(lookahead == 'o')
                ADVANCE(216);
            END_STATE();
        case 451:
            if(lookahead == 'o')
                ADVANCE(410);
            END_STATE();
        case 452:
            if(lookahead == 'o')
                ADVANCE(410);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1156);
            END_STATE();
        case 453:
            if(lookahead == 'o')
                ADVANCE(506);
            END_STATE();
        case 454:
            if(lookahead == 'o')
                ADVANCE(441);
            END_STATE();
        case 455:
            if(lookahead == 'o')
                ADVANCE(421);
            END_STATE();
        case 456:
            if(lookahead == 'o')
                ADVANCE(494);
            END_STATE();
        case 457:
            if(lookahead == 'o')
                ADVANCE(516);
            END_STATE();
        case 458:
            if(lookahead == 'o')
                ADVANCE(424);
            END_STATE();
        case 459:
            if(lookahead == 'o')
                ADVANCE(412);
            END_STATE();
        case 460:
            if(lookahead == 'o')
                ADVANCE(493);
            END_STATE();
        case 461:
            if(lookahead == 'o')
                ADVANCE(413);
            END_STATE();
        case 462:
            if(lookahead == 'o')
                ADVANCE(425);
            END_STATE();
        case 463:
            if(lookahead == 'o')
                ADVANCE(584);
            END_STATE();
        case 464:
            if(lookahead == 'o')
                ADVANCE(426);
            END_STATE();
        case 465:
            if(lookahead == 'o')
                ADVANCE(432);
            END_STATE();
        case 466:
            if(lookahead == 'o')
                ADVANCE(437);
            END_STATE();
        case 467:
            if(lookahead == 'o')
                ADVANCE(245);
            END_STATE();
        case 468:
            if(lookahead == 'o')
                ADVANCE(508);
            END_STATE();
        case 469:
            if(lookahead == 'o')
                ADVANCE(510);
            END_STATE();
        case 470:
            if(lookahead == 'o')
                ADVANCE(511);
            END_STATE();
        case 471:
            if(lookahead == 'o')
                ADVANCE(512);
            END_STATE();
        case 472:
            if(lookahead == 'o')
                ADVANCE(515);
            END_STATE();
        case 473:
            if(lookahead == 'o')
                ADVANCE(502);
            if(lookahead == 'r')
                ADVANCE(353);
            END_STATE();
        case 474:
            if(lookahead == 'o')
                ADVANCE(502);
            if(lookahead == 'r')
                ADVANCE(446);
            if(lookahead == 'u')
                ADVANCE(237);
            END_STATE();
        case 475:
            if(lookahead == 'o')
                ADVANCE(603);
            END_STATE();
        case 476:
            if(lookahead == 'p')
                ADVANCE(454);
            END_STATE();
        case 477:
            if(lookahead == 'p')
                ADVANCE(277);
            END_STATE();
        case 478:
            if(lookahead == 'p')
                ADVANCE(289);
            END_STATE();
        case 479:
            if(lookahead == 'p')
                ADVANCE(290);
            END_STATE();
        case 480:
            if(lookahead == 'p')
                ADVANCE(293);
            END_STATE();
        case 481:
            if(lookahead == 'p')
                ADVANCE(294);
            END_STATE();
        case 482:
            if(lookahead == 'p')
                ADVANCE(320);
            END_STATE();
        case 483:
            if(lookahead == 'p')
                ADVANCE(572);
            END_STATE();
        case 484:
            if(lookahead == 'p')
                ADVANCE(390);
            END_STATE();
        case 485:
            if(lookahead == 'p')
                ADVANCE(468);
            END_STATE();
        case 486:
            if(lookahead == 'p')
                ADVANCE(469);
            END_STATE();
        case 487:
            if(lookahead == 'p')
                ADVANCE(470);
            END_STATE();
        case 488:
            if(lookahead == 'p')
                ADVANCE(486);
            END_STATE();
        case 489:
            if(lookahead == 'r')
                ADVANCE(354);
            END_STATE();
        case 490:
            if(lookahead == 'r')
                ADVANCE(983);
            END_STATE();
        case 491:
            if(lookahead == 'r')
                ADVANCE(985);
            END_STATE();
        case 492:
            if(lookahead == 'r')
                ADVANCE(1297);
            END_STATE();
        case 493:
            if(lookahead == 'r')
                ADVANCE(1302);
            END_STATE();
        case 494:
            if(lookahead == 'r')
                ADVANCE(611);
            END_STATE();
        case 495:
            if(lookahead == 'r')
                ADVANCE(327);
            END_STATE();
        case 496:
            if(lookahead == 'r')
                ADVANCE(614);
            END_STATE();
        case 497:
            if(lookahead == 'r')
                ADVANCE(600);
            END_STATE();
        case 498:
            if(lookahead == 'r')
                ADVANCE(513);
            END_STATE();
        case 499:
            if(lookahead == 'r')
                ADVANCE(513);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1152);
            END_STATE();
        case 500:
            if(lookahead == 'r')
                ADVANCE(345);
            END_STATE();
        case 501:
            if(lookahead == 'r')
                ADVANCE(213);
            END_STATE();
        case 502:
            if(lookahead == 'r')
                ADVANCE(541);
            END_STATE();
        case 503:
            if(lookahead == 'r')
                ADVANCE(541);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(754);
            END_STATE();
        case 504:
            if(lookahead == 'r')
                ADVANCE(224);
            END_STATE();
        case 505:
            if(lookahead == 'r')
                ADVANCE(360);
            END_STATE();
        case 506:
            if(lookahead == 'r')
                ADVANCE(547);
            END_STATE();
        case 507:
            if(lookahead == 'r')
                ADVANCE(352);
            END_STATE();
        case 508:
            if(lookahead == 'r')
                ADVANCE(550);
            END_STATE();
        case 509:
            if(lookahead == 'r')
                ADVANCE(296);
            END_STATE();
        case 510:
            if(lookahead == 'r')
                ADVANCE(571);
            END_STATE();
        case 511:
            if(lookahead == 'r')
                ADVANCE(556);
            END_STATE();
        case 512:
            if(lookahead == 'r')
                ADVANCE(557);
            END_STATE();
        case 513:
            if(lookahead == 'r')
                ADVANCE(457);
            END_STATE();
        case 514:
            if(lookahead == 'r')
                ADVANCE(226);
            END_STATE();
        case 515:
            if(lookahead == 'r')
                ADVANCE(588);
            END_STATE();
        case 516:
            if(lookahead == 'r')
                ADVANCE(487);
            END_STATE();
        case 517:
            if(lookahead == 's')
                ADVANCE(1288);
            END_STATE();
        case 518:
            if(lookahead == 's')
                ADVANCE(1253);
            END_STATE();
        case 519:
            if(lookahead == 's')
                ADVANCE(1293);
            END_STATE();
        case 520:
            if(lookahead == 's')
                ADVANCE(375);
            END_STATE();
        case 521:
            if(lookahead == 's')
                ADVANCE(1100);
            END_STATE();
        case 522:
            if(lookahead == 's')
                ADVANCE(1292);
            END_STATE();
        case 523:
            if(lookahead == 's')
                ADVANCE(1295);
            END_STATE();
        case 524:
            if(lookahead == 's')
                ADVANCE(1287);
            END_STATE();
        case 525:
            if(lookahead == 's')
                ADVANCE(1258);
            END_STATE();
        case 526:
            if(lookahead == 's')
                ADVANCE(1105);
            END_STATE();
        case 527:
            if(lookahead == 's')
                ADVANCE(1294);
            END_STATE();
        case 528:
            if(lookahead == 's')
                ADVANCE(1106);
            END_STATE();
        case 529:
            if(lookahead == 's')
                ADVANCE(1215);
            END_STATE();
        case 530:
            if(lookahead == 's')
                ADVANCE(340);
            END_STATE();
        case 531:
            if(lookahead == 's')
                ADVANCE(275);
            END_STATE();
        case 532:
            if(lookahead == 's')
                ADVANCE(569);
            END_STATE();
        case 533:
            if(lookahead == 's')
                ADVANCE(351);
            END_STATE();
        case 534:
            if(lookahead == 's')
                ADVANCE(598);
            END_STATE();
        case 535:
            if(lookahead == 's')
                ADVANCE(300);
            END_STATE();
        case 536:
            if(lookahead == 's')
                ADVANCE(309);
            END_STATE();
        case 537:
            if(lookahead == 's')
                ADVANCE(311);
            END_STATE();
        case 538:
            if(lookahead == 's')
                ADVANCE(287);
            END_STATE();
        case 539:
            if(lookahead == 's')
                ADVANCE(583);
            END_STATE();
        case 540:
            if(lookahead == 't')
                ADVANCE(1096);
            END_STATE();
        case 541:
            if(lookahead == 't')
                ADVANCE(1300);
            END_STATE();
        case 542:
            if(lookahead == 't')
                ADVANCE(1251);
            END_STATE();
        case 543:
            if(lookahead == 't')
                ADVANCE(1251);
            if(lookahead == 'u')
                ADVANCE(402);
            END_STATE();
        case 544:
            if(lookahead == 't')
                ADVANCE(978);
            END_STATE();
        case 545:
            if(lookahead == 't')
                ADVANCE(1098);
            END_STATE();
        case 546:
            if(lookahead == 't')
                ADVANCE(965);
            END_STATE();
        case 547:
            if(lookahead == 't')
                ADVANCE(946);
            END_STATE();
        case 548:
            if(lookahead == 't')
                ADVANCE(1279);
            END_STATE();
        case 549:
            if(lookahead == 't')
                ADVANCE(1107);
            END_STATE();
        case 550:
            if(lookahead == 't')
                ADVANCE(1277);
            END_STATE();
        case 551:
            if(lookahead == 't')
                ADVANCE(1245);
            END_STATE();
        case 552:
            if(lookahead == 't')
                ADVANCE(1283);
            END_STATE();
        case 553:
            if(lookahead == 't')
                ADVANCE(1113);
            END_STATE();
        case 554:
            if(lookahead == 't')
                ADVANCE(1084);
            END_STATE();
        case 555:
            if(lookahead == 't')
                ADVANCE(1286);
            END_STATE();
        case 556:
            if(lookahead == 't')
                ADVANCE(1301);
            END_STATE();
        case 557:
            if(lookahead == 't')
                ADVANCE(969);
            END_STATE();
        case 558:
            if(lookahead == 't')
                ADVANCE(406);
            END_STATE();
        case 559:
            if(lookahead == 't')
                ADVANCE(130);
            END_STATE();
        case 560:
            if(lookahead == 't')
                ADVANCE(615);
            END_STATE();
        case 561:
            if(lookahead == 't')
                ADVANCE(244);
            END_STATE();
        case 562:
            if(lookahead == 't')
                ADVANCE(500);
            END_STATE();
        case 563:
            if(lookahead == 't')
                ADVANCE(131);
            END_STATE();
        case 564:
            if(lookahead == 't')
                ADVANCE(348);
            END_STATE();
        case 565:
            if(lookahead == 't')
                ADVANCE(348);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(694);
            END_STATE();
        case 566:
            if(lookahead == 't')
                ADVANCE(519);
            END_STATE();
        case 567:
            if(lookahead == 't')
                ADVANCE(501);
            END_STATE();
        case 568:
            if(lookahead == 't')
                ADVANCE(357);
            END_STATE();
        case 569:
            if(lookahead == 't')
                ADVANCE(449);
            END_STATE();
        case 570:
            if(lookahead == 't')
                ADVANCE(278);
            END_STATE();
        case 571:
            if(lookahead == 't')
                ADVANCE(525);
            END_STATE();
        case 572:
            if(lookahead == 't')
                ADVANCE(372);
            END_STATE();
        case 573:
            if(lookahead == 't')
                ADVANCE(229);
            END_STATE();
        case 574:
            if(lookahead == 't')
                ADVANCE(497);
            END_STATE();
        case 575:
            if(lookahead == 't')
                ADVANCE(560);
            END_STATE();
        case 576:
            if(lookahead == 't')
                ADVANCE(283);
            END_STATE();
        case 577:
            if(lookahead == 't')
                ADVANCE(288);
            END_STATE();
        case 578:
            if(lookahead == 't')
                ADVANCE(313);
            END_STATE();
        case 579:
            if(lookahead == 't')
                ADVANCE(312);
            END_STATE();
        case 580:
            if(lookahead == 't')
                ADVANCE(505);
            END_STATE();
        case 581:
            if(lookahead == 't')
                ADVANCE(325);
            END_STATE();
        case 582:
            if(lookahead == 't')
                ADVANCE(456);
            END_STATE();
        case 583:
            if(lookahead == 't')
                ADVANCE(504);
            END_STATE();
        case 584:
            if(lookahead == 't')
                ADVANCE(227);
            END_STATE();
        case 585:
            if(lookahead == 't')
                ADVANCE(460);
            END_STATE();
        case 586:
            if(lookahead == 't')
                ADVANCE(616);
            END_STATE();
        case 587:
            if(lookahead == 't')
                ADVANCE(373);
            END_STATE();
        case 588:
            if(lookahead == 't')
                ADVANCE(589);
            END_STATE();
        case 589:
            if(lookahead == 't')
                ADVANCE(618);
            END_STATE();
        case 590:
            if(lookahead == 't')
                ADVANCE(514);
            if(lookahead == 'Q' ||
               lookahead == 'q')
                ADVANCE(913);
            END_STATE();
        case 591:
            if(lookahead == 'u')
                ADVANCE(399);
            END_STATE();
        case 592:
            if(lookahead == 'u')
                ADVANCE(399);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(188);
            END_STATE();
        case 593:
            if(lookahead == 'u')
                ADVANCE(488);
            END_STATE();
        case 594:
            if(lookahead == 'u')
                ADVANCE(416);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(786);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(193);
            END_STATE();
        case 595:
            if(lookahead == 'u')
                ADVANCE(393);
            END_STATE();
        case 596:
            if(lookahead == 'u')
                ADVANCE(545);
            END_STATE();
        case 597:
            if(lookahead == 'u')
                ADVANCE(577);
            END_STATE();
        case 598:
            if(lookahead == 'u')
                ADVANCE(402);
            END_STATE();
        case 599:
            if(lookahead == 'u')
                ADVANCE(235);
            END_STATE();
        case 600:
            if(lookahead == 'u')
                ADVANCE(251);
            END_STATE();
        case 601:
            if(lookahead == 'u')
                ADVANCE(389);
            END_STATE();
        case 602:
            if(lookahead == 'u')
                ADVANCE(322);
            END_STATE();
        case 603:
            if(lookahead == 'u')
                ADVANCE(238);
            END_STATE();
        case 604:
            if(lookahead == 'v')
                ADVANCE(318);
            END_STATE();
        case 605:
            if(lookahead == 'v')
                ADVANCE(281);
            END_STATE();
        case 606:
            if(lookahead == 'v')
                ADVANCE(358);
            END_STATE();
        case 607:
            if(lookahead == 'w')
                ADVANCE(304);
            END_STATE();
        case 608:
            if(lookahead == 'x')
                ADVANCE(1276);
            END_STATE();
        case 609:
            if(lookahead == 'x')
                ADVANCE(552);
            END_STATE();
        case 610:
            if(lookahead == 'y')
                ADVANCE(995);
            END_STATE();
        case 611:
            if(lookahead == 'y')
                ADVANCE(1264);
            END_STATE();
        case 612:
            if(lookahead == 'y')
                ADVANCE(1101);
            END_STATE();
        case 613:
            if(lookahead == 'y')
                ADVANCE(1296);
            END_STATE();
        case 614:
            if(lookahead == 'y')
                ADVANCE(376);
            END_STATE();
        case 615:
            if(lookahead == 'y')
                ADVANCE(478);
            END_STATE();
        case 616:
            if(lookahead == 'y')
                ADVANCE(479);
            END_STATE();
        case 617:
            if(lookahead == 'y')
                ADVANCE(480);
            END_STATE();
        case 618:
            if(lookahead == 'y')
                ADVANCE(481);
            END_STATE();
        case 619:
            if(lookahead == 'y')
                ADVANCE(482);
            END_STATE();
        case 620:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(918);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(790);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(866);
            END_STATE();
        case 621:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(788);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(873);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(799);
            END_STATE();
        case 622:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(914);
            END_STATE();
        case 623:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1172);
            END_STATE();
        case 624:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1190);
            END_STATE();
        case 625:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(905);
            END_STATE();
        case 626:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(862);
            END_STATE();
        case 627:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(766);
            END_STATE();
        case 628:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(921);
            END_STATE();
        case 629:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(653);
            END_STATE();
        case 630:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(791);
            END_STATE();
        case 631:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(196);
            END_STATE();
        case 632:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(844);
            END_STATE();
        case 633:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(767);
            END_STATE();
        case 634:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(856);
            END_STATE();
        case 635:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(768);
            END_STATE();
        case 636:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(769);
            END_STATE();
        case 637:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(772);
            END_STATE();
        case 638:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(805);
            END_STATE();
        case 639:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(789);
            END_STATE();
        case 640:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(776);
            END_STATE();
        case 641:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(891);
            END_STATE();
        case 642:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(912);
            END_STATE();
        case 643:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(657);
            END_STATE();
        case 644:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(898);
            END_STATE();
        case 645:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(900);
            END_STATE();
        case 646:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(901);
            END_STATE();
        case 647:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(902);
            END_STATE();
        case 648:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(903);
            END_STATE();
        case 649:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(857);
            END_STATE();
        case 650:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(858);
            END_STATE();
        case 651:
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(859);
            END_STATE();
        case 652:
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(827);
            END_STATE();
        case 653:
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(777);
            END_STATE();
        case 654:
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(624);
            END_STATE();
        case 655:
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(641);
            END_STATE();
        case 656:
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(749);
            END_STATE();
        case 657:
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(779);
            END_STATE();
        case 658:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1224);
            END_STATE();
        case 659:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1236);
            END_STATE();
        case 660:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1232);
            END_STATE();
        case 661:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(679);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(765);
            END_STATE();
        case 662:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(819);
            END_STATE();
        case 663:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(775);
            END_STATE();
        case 664:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(632);
            END_STATE();
        case 665:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(698);
            END_STATE();
        case 666:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(879);
            END_STATE();
        case 667:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(700);
            END_STATE();
        case 668:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(704);
            END_STATE();
        case 669:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(783);
            END_STATE();
        case 670:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(784);
            END_STATE();
        case 671:
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(785);
            END_STATE();
        case 672:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1120);
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(812);
            END_STATE();
        case 673:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1122);
            END_STATE();
        case 674:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1162);
            END_STATE();
        case 675:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1205);
            END_STATE();
        case 676:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1158);
            END_STATE();
        case 677:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1211);
            END_STATE();
        case 678:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1145);
            END_STATE();
        case 679:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(842);
            END_STATE();
        case 680:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(188);
            END_STATE();
        case 681:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(864);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(861);
            END_STATE();
        case 682:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(709);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(755);
            END_STATE();
        case 683:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(723);
            END_STATE();
        case 684:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(718);
            END_STATE();
        case 685:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(643);
            END_STATE();
        case 686:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(724);
            END_STATE();
        case 687:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(725);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(760);
            END_STATE();
        case 688:
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(726);
            END_STATE();
        case 689:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(729);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(875);
            END_STATE();
        case 690:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(840);
            END_STATE();
        case 691:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(919);
            END_STATE();
        case 692:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(917);
            END_STATE();
        case 693:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(802);
            END_STATE();
        case 694:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1234);
            END_STATE();
        case 695:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(835);
            END_STATE();
        case 696:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1150);
            END_STATE();
        case 697:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1131);
            END_STATE();
        case 698:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1226);
            END_STATE();
        case 699:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1139);
            END_STATE();
        case 700:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1188);
            END_STATE();
        case 701:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1186);
            END_STATE();
        case 702:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1138);
            END_STATE();
        case 703:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1176);
            END_STATE();
        case 704:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1230);
            END_STATE();
        case 705:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(839);
            END_STATE();
        case 706:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(852);
            END_STATE();
        case 707:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(838);
            END_STATE();
        case 708:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(191);
            END_STATE();
        case 709:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(663);
            END_STATE();
        case 710:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(854);
            END_STATE();
        case 711:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(674);
            END_STATE();
        case 712:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(800);
            END_STATE();
        case 713:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(845);
            END_STATE();
        case 714:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(811);
            END_STATE();
        case 715:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(198);
            END_STATE();
        case 716:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(874);
            END_STATE();
        case 717:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(677);
            END_STATE();
        case 718:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(853);
            END_STATE();
        case 719:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(863);
            END_STATE();
        case 720:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(808);
            END_STATE();
        case 721:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(869);
            END_STATE();
        case 722:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(846);
            END_STATE();
        case 723:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(731);
            END_STATE();
        case 724:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(669);
            END_STATE();
        case 725:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(670);
            END_STATE();
        case 726:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(671);
            END_STATE();
        case 727:
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(202);
            END_STATE();
        case 728:
            ADVANCE_MAP(
                'F', 882,
                'f', 882,
                'M', 735,
                'm', 735,
                'P', 832,
                'p', 832,
                'U', 895,
                'u', 895,
            );
            END_STATE();
        case 729:
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(816);
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(745);
            END_STATE();
        case 730:
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(625);
            END_STATE();
        case 731:
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(642);
            END_STATE();
        case 732:
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(696);
            END_STATE();
        case 733:
            if(lookahead == 'H' ||
               lookahead == 'h')
                ADVANCE(1125);
            END_STATE();
        case 734:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(801);
            END_STATE();
        case 735:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1196);
            END_STATE();
        case 736:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(924);
            END_STATE();
        case 737:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(786);
            END_STATE();
        case 738:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(786);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(193);
            END_STATE();
        case 739:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(665);
            END_STATE();
        case 740:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(787);
            END_STATE();
        case 741:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(829);
            END_STATE();
        case 742:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(656);
            END_STATE();
        case 743:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(658);
            END_STATE();
        case 744:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(673);
            END_STATE();
        case 745:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(813);
            END_STATE();
        case 746:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(659);
            END_STATE();
        case 747:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(876);
            END_STATE();
        case 748:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(660);
            END_STATE();
        case 749:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(782);
            END_STATE();
        case 750:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(884);
            END_STATE();
        case 751:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(640);
            END_STATE();
        case 752:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(636);
            END_STATE();
        case 753:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(667);
            END_STATE();
        case 754:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(889);
            END_STATE();
        case 755:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(778);
            END_STATE();
        case 756:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(820);
            END_STATE();
        case 757:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(668);
            END_STATE();
        case 758:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(821);
            END_STATE();
        case 759:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(893);
            END_STATE();
        case 760:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(780);
            END_STATE();
        case 761:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(822);
            END_STATE();
        case 762:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(823);
            END_STATE();
        case 763:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(824);
            END_STATE();
        case 764:
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(825);
            END_STATE();
        case 765:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1220);
            END_STATE();
        case 766:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1137);
            END_STATE();
        case 767:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1160);
            END_STATE();
        case 768:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1127);
            END_STATE();
        case 769:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1124);
            END_STATE();
        case 770:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(923);
            END_STATE();
        case 771:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(877);
            END_STATE();
        case 772:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(200);
            END_STATE();
        case 773:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(878);
            END_STATE();
        case 774:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(759);
            END_STATE();
        case 775:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(634);
            END_STATE();
        case 776:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(736);
            END_STATE();
        case 777:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(699);
            END_STATE();
        case 778:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(701);
            END_STATE();
        case 779:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(702);
            END_STATE();
        case 780:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(703);
            END_STATE();
        case 781:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(909);
            END_STATE();
        case 782:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(750);
            END_STATE();
        case 783:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(649);
            END_STATE();
        case 784:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(650);
            END_STATE();
        case 785:
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(651);
            END_STATE();
        case 786:
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1209);
            END_STATE();
        case 787:
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1164);
            END_STATE();
        case 788:
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(694);
            END_STATE();
        case 789:
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(719);
            END_STATE();
        case 790:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1152);
            END_STATE();
        case 791:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(732);
            END_STATE();
        case 792:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1129);
            END_STATE();
        case 793:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1182);
            END_STATE();
        case 794:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1184);
            END_STATE();
        case 795:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1180);
            END_STATE();
        case 796:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1178);
            END_STATE();
        case 797:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1213);
            END_STATE();
        case 798:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(747);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(708);
            END_STATE();
        case 799:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(197);
            END_STATE();
        case 800:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(685);
            END_STATE();
        case 801:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(627);
            END_STATE();
        case 802:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(867);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(806);
            END_STATE();
        case 803:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(868);
            END_STATE();
        case 804:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(676);
            END_STATE();
        case 805:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(678);
            END_STATE();
        case 806:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(633);
            END_STATE();
        case 807:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(635);
            END_STATE();
        case 808:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(904);
            END_STATE();
        case 809:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(639);
            END_STATE();
        case 810:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(684);
            END_STATE();
        case 811:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(896);
            END_STATE();
        case 812:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(828);
            END_STATE();
        case 813:
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(201);
            END_STATE();
        case 814:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(841);
            END_STATE();
        case 815:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(739);
            END_STATE();
        case 816:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(855);
            END_STATE();
        case 817:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(872);
            END_STATE();
        case 818:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(744);
            END_STATE();
        case 819:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(803);
            END_STATE();
        case 820:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(792);
            END_STATE();
        case 821:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(793);
            END_STATE();
        case 822:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(794);
            END_STATE();
        case 823:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(795);
            END_STATE();
        case 824:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(796);
            END_STATE();
        case 825:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(797);
            END_STATE();
        case 826:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(836);
            END_STATE();
        case 827:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(908);
            END_STATE();
        case 828:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(851);
            END_STATE();
        case 829:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(807);
            END_STATE();
        case 830:
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(837);
            END_STATE();
        case 831:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(832);
            END_STATE();
        case 832:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(712);
            END_STATE();
        case 833:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(880);
            END_STATE();
        case 834:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(743);
            END_STATE();
        case 835:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(770);
            if(lookahead == 'Q' ||
               lookahead == 'q')
                ADVANCE(911);
            END_STATE();
        case 836:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(746);
            END_STATE();
        case 837:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(748);
            END_STATE();
        case 838:
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(849);
            END_STATE();
        case 839:
            if(lookahead == 'Q' ||
               lookahead == 'q')
                ADVANCE(913);
            END_STATE();
        case 840:
            if(lookahead == 'Q' ||
               lookahead == 'q')
                ADVANCE(913);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(915);
            END_STATE();
        case 841:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(654);
            END_STATE();
        case 842:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1216);
            END_STATE();
        case 843:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(906);
            END_STATE();
        case 844:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(675);
            END_STATE();
        case 845:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(751);
            END_STATE();
        case 846:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(637);
            END_STATE();
        case 847:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(707);
            END_STATE();
        case 848:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(737);
            END_STATE();
        case 849:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(716);
            END_STATE();
        case 850:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(655);
            END_STATE();
        case 851:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(715);
            END_STATE();
        case 852:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(199);
            END_STATE();
        case 853:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(870);
            END_STATE();
        case 854:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(916);
            END_STATE();
        case 855:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(727);
            END_STATE();
        case 856:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(644);
            END_STATE();
        case 857:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(645);
            END_STATE();
        case 858:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(646);
            END_STATE();
        case 859:
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(647);
            END_STATE();
        case 860:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1192);
            END_STATE();
        case 861:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(664);
            END_STATE();
        case 862:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(733);
            END_STATE();
        case 863:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1201);
            END_STATE();
        case 864:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1191);
            END_STATE();
        case 865:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(708);
            END_STATE();
        case 866:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(888);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(629);
            END_STATE();
        case 867:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(742);
            END_STATE();
        case 868:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(892);
            END_STATE();
        case 869:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(899);
            END_STATE();
        case 870:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(894);
            END_STATE();
        case 871:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(713);
            END_STATE();
        case 872:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(754);
            END_STATE();
        case 873:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(890);
            END_STATE();
        case 874:
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(720);
            END_STATE();
        case 875:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(189);
            END_STATE();
        case 876:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1156);
            END_STATE();
        case 877:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1148);
            END_STATE();
        case 878:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1207);
            END_STATE();
        case 879:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1203);
            END_STATE();
        case 880:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(920);
            END_STATE();
        case 881:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(631);
            END_STATE();
        case 882:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(706);
            END_STATE();
        case 883:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(741);
            END_STATE();
        case 884:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(922);
            END_STATE();
        case 885:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(629);
            END_STATE();
        case 886:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(826);
            END_STATE();
        case 887:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(693);
            END_STATE();
        case 888:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(194);
            END_STATE();
        case 889:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(756);
            END_STATE();
        case 890:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(711);
            END_STATE();
        case 891:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(740);
            END_STATE();
        case 892:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(843);
            END_STATE();
        case 893:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(722);
            END_STATE();
        case 894:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(638);
            END_STATE();
        case 895:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(818);
            END_STATE();
        case 896:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(752);
            END_STATE();
        case 897:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(830);
            END_STATE();
        case 898:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(758);
            END_STATE();
        case 899:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(897);
            END_STATE();
        case 900:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(761);
            END_STATE();
        case 901:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(762);
            END_STATE();
        case 902:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(763);
            END_STATE();
        case 903:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(764);
            END_STATE();
        case 904:
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(648);
            END_STATE();
        case 905:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(771);
            END_STATE();
        case 906:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(666);
            END_STATE();
        case 907:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(810);
            END_STATE();
        case 908:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(804);
            END_STATE();
        case 909:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(697);
            END_STATE();
        case 910:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(885);
            END_STATE();
        case 911:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(721);
            END_STATE();
        case 912:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(773);
            END_STATE();
        case 913:
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(714);
            END_STATE();
        case 914:
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(623);
            END_STATE();
        case 915:
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(753);
            END_STATE();
        case 916:
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(757);
            END_STATE();
        case 917:
            if(lookahead == 'W' ||
               lookahead == 'w')
                ADVANCE(628);
            END_STATE();
        case 918:
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(1154);
            END_STATE();
        case 919:
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1143);
            END_STATE();
        case 920:
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1228);
            END_STATE();
        case 921:
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1194);
            END_STATE();
        case 922:
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1135);
            END_STATE();
        case 923:
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(886);
            END_STATE();
        case 924:
            if(lookahead == 'Z' ||
               lookahead == 'z')
                ADVANCE(717);
            END_STATE();
        case 925:
            if(lookahead == '0' ||
               lookahead == '1')
                ADVANCE(1016);
            END_STATE();
        case 926:
            if(('0' <= lookahead && lookahead <= '8'))
                ADVANCE(1018);
            END_STATE();
        case 927:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(1021);
            END_STATE();
        case 928:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(1029);
            END_STATE();
        case 929:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(928);
            END_STATE();
        case 930:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(929);
            END_STATE();
        case 931:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(930);
            END_STATE();
        case 932:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(931);
            END_STATE();
        case 933:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(932);
            END_STATE();
        case 934:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(933);
            END_STATE();
        case 935:
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(934);
            END_STATE();
        case 936:
            if(lookahead != 0 &&
               lookahead != '*')
                ADVANCE(1070);
            END_STATE();
        case 937:
            if(eof)
                ADVANCE(945);
            if(lookahead == '\n')
                SKIP(0);
            END_STATE();
        case 938:
            if(eof)
                ADVANCE(945);
            if(lookahead == '\n')
                SKIP(0);
            if(lookahead == '\r')
                SKIP(937);
            END_STATE();
        case 939:
            if(eof)
                ADVANCE(945);
            if(lookahead == '\n')
                SKIP(944);
            END_STATE();
        case 940:
            if(eof)
                ADVANCE(945);
            if(lookahead == '\n')
                SKIP(944);
            if(lookahead == '\r')
                SKIP(939);
            END_STATE();
        case 941:
            if(eof)
                ADVANCE(945);
            if(lookahead == '\n')
                SKIP(943);
            END_STATE();
        case 942:
            if(eof)
                ADVANCE(945);
            if(lookahead == '\n')
                SKIP(943);
            if(lookahead == '\r')
                SKIP(941);
            END_STATE();
        case 943:
            if(eof)
                ADVANCE(945);
            ADVANCE_MAP(
                '"', 1033,
                '%', 1012,
                '&', 1004,
                '\'', 1039,
                '(', 1013,
                ')', 1014,
                '*', 1009,
                '+', 1007,
                ',', 997,
                '-', 1008,
                '/', 1011,
                '0', 1019,
                ':', 1089,
                ';', 1090,
                '<', 139,
                '=', 1119,
                '>', 992,
                'F', 1315,
                'L', 1038,
                'O', 1360,
                'T', 1320,
                'V', 1335,
            );
            if(lookahead == '\\')
                SKIP(942);
            if(lookahead == ']')
                ADVANCE(1269);
            if(lookahead == '^')
                ADVANCE(1003);
            if(lookahead == 'a')
                ADVANCE(1488);
            if(lookahead == 'b')
                ADVANCE(1512);
            if(lookahead == 'c')
                ADVANCE(1441);
            if(lookahead == 'd')
                ADVANCE(1507);
            if(lookahead == 'f')
                ADVANCE(1445);
            if(lookahead == 'i')
                ADVANCE(1492);
            if(lookahead == 'l')
                ADVANCE(1509);
            if(lookahead == 'm')
                ADVANCE(1340);
            if(lookahead == 'o')
                ADVANCE(1375);
            if(lookahead == 's')
                ADVANCE(1396);
            if(lookahead == 'u')
                ADVANCE(1453);
            if(lookahead == 'w')
                ADVANCE(1367);
            if(lookahead == '{')
                ADVANCE(1080);
            if(lookahead == '|')
                ADVANCE(1002);
            if(lookahead == '}')
                ADVANCE(1081);
            if(lookahead == '~')
                ADVANCE(1015);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(943);
            if(('1' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            if(('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('e' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 944:
            if(eof)
                ADVANCE(945);
            if(lookahead == '#')
                ADVANCE(257);
            if(lookahead == '/')
                ADVANCE(104);
            if(lookahead == '@')
                ADVANCE(1116);
            if(lookahead == '\\')
                SKIP(940);
            if(lookahead == 'a')
                ADVANCE(232);
            if(lookahead == 'b')
                ADVANCE(366);
            if(lookahead == 'c')
                ADVANCE(448);
            if(lookahead == 'e')
                ADVANCE(417);
            if(lookahead == 'h')
                ADVANCE(442);
            if(lookahead == 'i')
                ADVANCE(398);
            if(lookahead == 'l')
                ADVANCE(467);
            if(lookahead == 'm')
                ADVANCE(444);
            if(lookahead == 'n')
                ADVANCE(221);
            if(lookahead == 'p')
                ADVANCE(472);
            if(lookahead == 's')
                ADVANCE(574);
            if(lookahead == 't')
                ADVANCE(617);
            if(lookahead == 'u')
                ADVANCE(430);
            if(lookahead == 'v')
                ADVANCE(210);
            if(lookahead == '}')
                ADVANCE(1081);
            if(('\t' <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                SKIP(944);
            END_STATE();
        case 945:
            ACCEPT_TOKEN(ts_builtin_sym_end);
            END_STATE();
        case 946:
            ACCEPT_TOKEN(anon_sym_short);
            END_STATE();
        case 947:
            ACCEPT_TOKEN(anon_sym_short);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 948:
            ACCEPT_TOKEN(anon_sym_int16);
            END_STATE();
        case 949:
            ACCEPT_TOKEN(anon_sym_int16);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 950:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(265);
            END_STATE();
        case 951:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(265);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 952:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(394);
            END_STATE();
        case 953:
            ACCEPT_TOKEN(anon_sym_long);
            if(lookahead == ' ')
                ADVANCE(394);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 954:
            ACCEPT_TOKEN(anon_sym_int32);
            END_STATE();
        case 955:
            ACCEPT_TOKEN(anon_sym_int32);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 956:
            ACCEPT_TOKEN(anon_sym_longlong);
            END_STATE();
        case 957:
            ACCEPT_TOKEN(anon_sym_int64);
            END_STATE();
        case 958:
            ACCEPT_TOKEN(anon_sym_int64);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 959:
            ACCEPT_TOKEN(sym_unsigned_tiny_int);
            END_STATE();
        case 960:
            ACCEPT_TOKEN(sym_unsigned_tiny_int);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 961:
            ACCEPT_TOKEN(sym_boolean_type);
            END_STATE();
        case 962:
            ACCEPT_TOKEN(sym_boolean_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 963:
            ACCEPT_TOKEN(anon_sym_fixed);
            END_STATE();
        case 964:
            ACCEPT_TOKEN(anon_sym_fixed);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 965:
            ACCEPT_TOKEN(sym_octet_type);
            END_STATE();
        case 966:
            ACCEPT_TOKEN(sym_octet_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 967:
            ACCEPT_TOKEN(sym_signed_tiny_int);
            END_STATE();
        case 968:
            ACCEPT_TOKEN(sym_signed_tiny_int);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 969:
            ACCEPT_TOKEN(anon_sym_unsignedshort);
            END_STATE();
        case 970:
            ACCEPT_TOKEN(anon_sym_uint16);
            END_STATE();
        case 971:
            ACCEPT_TOKEN(anon_sym_uint16);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 972:
            ACCEPT_TOKEN(anon_sym_unsignedlong);
            if(lookahead == ' ')
                ADVANCE(396);
            END_STATE();
        case 973:
            ACCEPT_TOKEN(anon_sym_uint32);
            END_STATE();
        case 974:
            ACCEPT_TOKEN(anon_sym_uint32);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 975:
            ACCEPT_TOKEN(anon_sym_unsignedlonglong);
            END_STATE();
        case 976:
            ACCEPT_TOKEN(anon_sym_uint64);
            END_STATE();
        case 977:
            ACCEPT_TOKEN(anon_sym_uint64);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 978:
            ACCEPT_TOKEN(anon_sym_float);
            END_STATE();
        case 979:
            ACCEPT_TOKEN(anon_sym_float);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 980:
            ACCEPT_TOKEN(anon_sym_double);
            END_STATE();
        case 981:
            ACCEPT_TOKEN(anon_sym_double);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 982:
            ACCEPT_TOKEN(anon_sym_longdouble);
            END_STATE();
        case 983:
            ACCEPT_TOKEN(sym_char_type);
            END_STATE();
        case 984:
            ACCEPT_TOKEN(sym_char_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 985:
            ACCEPT_TOKEN(sym_wide_char_type);
            END_STATE();
        case 986:
            ACCEPT_TOKEN(sym_wide_char_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 987:
            ACCEPT_TOKEN(anon_sym_COLON_COLON);
            END_STATE();
        case 988:
            ACCEPT_TOKEN(anon_sym_string);
            END_STATE();
        case 989:
            ACCEPT_TOKEN(anon_sym_string);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 990:
            ACCEPT_TOKEN(anon_sym_LT);
            END_STATE();
        case 991:
            ACCEPT_TOKEN(anon_sym_GT);
            END_STATE();
        case 992:
            ACCEPT_TOKEN(anon_sym_GT);
            if(lookahead == '>')
                ADVANCE(1005);
            END_STATE();
        case 993:
            ACCEPT_TOKEN(anon_sym_wstring);
            END_STATE();
        case 994:
            ACCEPT_TOKEN(anon_sym_wstring);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 995:
            ACCEPT_TOKEN(anon_sym_any);
            END_STATE();
        case 996:
            ACCEPT_TOKEN(anon_sym_any);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 997:
            ACCEPT_TOKEN(anon_sym_COMMA);
            END_STATE();
        case 998:
            ACCEPT_TOKEN(anon_sym_sequence);
            END_STATE();
        case 999:
            ACCEPT_TOKEN(anon_sym_sequence);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1000:
            ACCEPT_TOKEN(anon_sym_map);
            END_STATE();
        case 1001:
            ACCEPT_TOKEN(anon_sym_map);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1002:
            ACCEPT_TOKEN(anon_sym_PIPE);
            END_STATE();
        case 1003:
            ACCEPT_TOKEN(anon_sym_CARET);
            END_STATE();
        case 1004:
            ACCEPT_TOKEN(anon_sym_AMP);
            END_STATE();
        case 1005:
            ACCEPT_TOKEN(anon_sym_GT_GT);
            END_STATE();
        case 1006:
            ACCEPT_TOKEN(anon_sym_LT_LT);
            END_STATE();
        case 1007:
            ACCEPT_TOKEN(anon_sym_PLUS);
            END_STATE();
        case 1008:
            ACCEPT_TOKEN(anon_sym_DASH);
            END_STATE();
        case 1009:
            ACCEPT_TOKEN(anon_sym_STAR);
            END_STATE();
        case 1010:
            ACCEPT_TOKEN(anon_sym_SLASH);
            if(lookahead == '*')
                ADVANCE(1940);
            if(lookahead == '/')
                ADVANCE(1930);
            END_STATE();
        case 1011:
            ACCEPT_TOKEN(anon_sym_SLASH);
            if(lookahead == '*')
                ADVANCE(1940);
            if(lookahead == '/')
                ADVANCE(1928);
            END_STATE();
        case 1012:
            ACCEPT_TOKEN(anon_sym_PERCENT);
            END_STATE();
        case 1013:
            ACCEPT_TOKEN(anon_sym_LPAREN);
            END_STATE();
        case 1014:
            ACCEPT_TOKEN(anon_sym_RPAREN);
            END_STATE();
        case 1015:
            ACCEPT_TOKEN(anon_sym_TILDE);
            END_STATE();
        case 1016:
            ACCEPT_TOKEN(sym_bin_number);
            if(lookahead == '0' ||
               lookahead == '1')
                ADVANCE(1016);
            END_STATE();
        case 1017:
            ACCEPT_TOKEN(aux_sym_oct_number_token1);
            if(('0' <= lookahead && lookahead <= '8'))
                ADVANCE(1017);
            END_STATE();
        case 1018:
            ACCEPT_TOKEN(aux_sym_oct_number_token2);
            if(('0' <= lookahead && lookahead <= '8'))
                ADVANCE(1018);
            END_STATE();
        case 1019:
            ACCEPT_TOKEN(anon_sym_0);
            if(lookahead == 'o')
                ADVANCE(926);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(925);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(927);
            if(('0' <= lookahead && lookahead <= '8'))
                ADVANCE(1017);
            END_STATE();
        case 1020:
            ACCEPT_TOKEN(aux_sym_dec_number_token1);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(1020);
            END_STATE();
        case 1021:
            ACCEPT_TOKEN(sym_hex_number);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'F') ||
               ('a' <= lookahead && lookahead <= 'f'))
                ADVANCE(1021);
            END_STATE();
        case 1022:
            ACCEPT_TOKEN(anon_sym_DOT);
            END_STATE();
        case 1023:
            ACCEPT_TOKEN(aux_sym_floating_pt_literal_token1);
            END_STATE();
        case 1024:
            ACCEPT_TOKEN(aux_sym_floating_pt_literal_token1);
            if(lookahead == 'M')
                ADVANCE(833);
            if(lookahead == 'N')
                ADVANCE(680);
            if(lookahead == 'X')
                ADVANCE(887);
            if(lookahead == 'm')
                ADVANCE(356);
            if(lookahead == 'n')
                ADVANCE(592);
            if(lookahead == 'v')
                ADVANCE(318);
            if(lookahead == 'x')
                ADVANCE(248);
            END_STATE();
        case 1025:
            ACCEPT_TOKEN(aux_sym_floating_pt_literal_token1);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(833);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(680);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(887);
            END_STATE();
        case 1026:
            ACCEPT_TOKEN(aux_sym_fixed_pt_literal_token1);
            END_STATE();
        case 1027:
            ACCEPT_TOKEN(aux_sym_fixed_pt_literal_token1);
            ADVANCE_MAP(
                'E', 730,
                'e', 158,
                'o', 599,
                'A', 881,
                'a', 881,
                'D', 860,
                'd', 860,
                'I', 861,
                'i', 861,
            );
            END_STATE();
        case 1028:
            ACCEPT_TOKEN(aux_sym_fixed_pt_literal_token1);
            ADVANCE_MAP(
                'A', 881,
                'a', 881,
                'D', 860,
                'd', 860,
                'E', 730,
                'e', 730,
                'I', 861,
                'i', 861,
            );
            END_STATE();
        case 1029:
            ACCEPT_TOKEN(sym_escape_sequence);
            END_STATE();
        case 1030:
            ACCEPT_TOKEN(sym_escape_sequence);
            if(lookahead == '\\')
                ADVANCE(67);
            END_STATE();
        case 1031:
            ACCEPT_TOKEN(sym_escape_sequence);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(1029);
            END_STATE();
        case 1032:
            ACCEPT_TOKEN(sym_escape_sequence);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(1031);
            END_STATE();
        case 1033:
            ACCEPT_TOKEN(anon_sym_DQUOTE);
            END_STATE();
        case 1034:
            ACCEPT_TOKEN(aux_sym_string_literal_token1);
            if(lookahead == '*')
                ADVANCE(1036);
            if(lookahead == '/')
                ADVANCE(1036);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '"' &&
               lookahead != '\\')
                ADVANCE(1036);
            END_STATE();
        case 1035:
            ACCEPT_TOKEN(aux_sym_string_literal_token1);
            if(lookahead == '/')
                ADVANCE(1034);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1035);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead) &&
               lookahead != '"' &&
               lookahead != '\\')
                ADVANCE(1036);
            END_STATE();
        case 1036:
            ACCEPT_TOKEN(aux_sym_string_literal_token1);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '"' &&
               lookahead != '\\')
                ADVANCE(1036);
            END_STATE();
        case 1037:
            ACCEPT_TOKEN(anon_sym_L);
            END_STATE();
        case 1038:
            ACCEPT_TOKEN(anon_sym_L);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1039:
            ACCEPT_TOKEN(anon_sym_SQUOTE);
            END_STATE();
        case 1040:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            END_STATE();
        case 1041:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            if(lookahead == '\n')
                ADVANCE(1030);
            if(lookahead == '\r')
                ADVANCE(1029);
            if(lookahead == 'U')
                ADVANCE(935);
            if(lookahead == 'u')
                ADVANCE(931);
            if(lookahead == 'x')
                ADVANCE(929);
            if(('0' <= lookahead && lookahead <= '9'))
                ADVANCE(1032);
            if(lookahead != 0)
                ADVANCE(1029);
            END_STATE();
        case 1042:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            if(lookahead == '*')
                ADVANCE(1940);
            if(lookahead == '/')
                ADVANCE(1928);
            END_STATE();
        case 1043:
            ACCEPT_TOKEN(aux_sym_char_literal_token1);
            if(lookahead == '\\')
                ADVANCE(67);
            END_STATE();
        case 1044:
            ACCEPT_TOKEN(anon_sym_TRUE);
            END_STATE();
        case 1045:
            ACCEPT_TOKEN(anon_sym_TRUE);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1046:
            ACCEPT_TOKEN(anon_sym_FALSE);
            END_STATE();
        case 1047:
            ACCEPT_TOKEN(anon_sym_FALSE);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1048:
            ACCEPT_TOKEN(anon_sym_POUNDdefine);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1049:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead == '\r')
                ADVANCE(1052);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1052);
            END_STATE();
        case 1050:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead == '*')
                ADVANCE(1944);
            if(lookahead == '/')
                ADVANCE(1933);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1052);
            END_STATE();
        case 1051:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead == '/')
                ADVANCE(1050);
            if(lookahead == '\\')
                ADVANCE(1049);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1051);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead))
                ADVANCE(1052);
            END_STATE();
        case 1052:
            ACCEPT_TOKEN(aux_sym_preproc_define_token1);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1052);
            END_STATE();
        case 1053:
            ACCEPT_TOKEN(aux_sym_preproc_call_token1);
            END_STATE();
        case 1054:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'c')
                ADVANCE(1061);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1055:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'd')
                ADVANCE(1058);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1056:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'e')
                ADVANCE(1059);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1057:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'e')
                ADVANCE(1048);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1058:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'e')
                ADVANCE(1072);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1059:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'f')
                ADVANCE(1060);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1060:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'i')
                ADVANCE(1063);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1061:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'l')
                ADVANCE(1064);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1062:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'n')
                ADVANCE(1054);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1063:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'n')
                ADVANCE(1057);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1064:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(lookahead == 'u')
                ADVANCE(1055);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1065:
            ACCEPT_TOKEN(sym_preproc_directive);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1065);
            END_STATE();
        case 1066:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '\n')
                SKIP(114);
            if(lookahead == '\r')
                ADVANCE(1067);
            if(lookahead == '/')
                ADVANCE(936);
            if(lookahead == '\\')
                ADVANCE(1068);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 1067:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '\n')
                SKIP(114);
            if(lookahead == '/')
                ADVANCE(936);
            if(lookahead == '\\')
                ADVANCE(1068);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 1068:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '\r')
                ADVANCE(1071);
            if(lookahead == '/')
                ADVANCE(936);
            if(lookahead == '\\')
                ADVANCE(1068);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 1069:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '*')
                ADVANCE(1940);
            if(lookahead == '/')
                ADVANCE(1928);
            if(lookahead == '\\')
                ADVANCE(1068);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1070);
            END_STATE();
        case 1070:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '/')
                ADVANCE(936);
            if(lookahead == '\\')
                ADVANCE(1068);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1070);
            END_STATE();
        case 1071:
            ACCEPT_TOKEN(sym_preproc_arg);
            if(lookahead == '/')
                ADVANCE(936);
            if(lookahead == '\\')
                ADVANCE(1068);
            if(lookahead != 0)
                ADVANCE(1070);
            END_STATE();
        case 1072:
            ACCEPT_TOKEN(aux_sym_preproc_include_token1);
            END_STATE();
        case 1073:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '\r')
                ADVANCE(1076);
            if(lookahead == '\\')
                ADVANCE(1077);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1076);
            END_STATE();
        case 1074:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '*')
                ADVANCE(1943);
            if(lookahead == '/')
                ADVANCE(1932);
            if(lookahead == '\\')
                ADVANCE(1077);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(1076);
            END_STATE();
        case 1075:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '/')
                ADVANCE(1074);
            if(lookahead == '\\')
                ADVANCE(1073);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1075);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead) &&
               lookahead != '>')
                ADVANCE(1076);
            END_STATE();
        case 1076:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '\\')
                ADVANCE(1077);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(1076);
            END_STATE();
        case 1077:
            ACCEPT_TOKEN(sym_system_lib_path);
            if(lookahead == '\\')
                ADVANCE(1077);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1076);
            END_STATE();
        case 1078:
            ACCEPT_TOKEN(anon_sym_exception);
            END_STATE();
        case 1079:
            ACCEPT_TOKEN(anon_sym_exception);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1080:
            ACCEPT_TOKEN(anon_sym_LBRACE);
            END_STATE();
        case 1081:
            ACCEPT_TOKEN(anon_sym_RBRACE);
            END_STATE();
        case 1082:
            ACCEPT_TOKEN(anon_sym_local);
            END_STATE();
        case 1083:
            ACCEPT_TOKEN(anon_sym_local);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1084:
            ACCEPT_TOKEN(anon_sym_abstract);
            END_STATE();
        case 1085:
            ACCEPT_TOKEN(anon_sym_abstract);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1086:
            ACCEPT_TOKEN(anon_sym_interface);
            END_STATE();
        case 1087:
            ACCEPT_TOKEN(anon_sym_interface);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1088:
            ACCEPT_TOKEN(anon_sym_COLON);
            END_STATE();
        case 1089:
            ACCEPT_TOKEN(anon_sym_COLON);
            if(lookahead == ':')
                ADVANCE(987);
            END_STATE();
        case 1090:
            ACCEPT_TOKEN(anon_sym_SEMI);
            END_STATE();
        case 1091:
            ACCEPT_TOKEN(anon_sym_void);
            END_STATE();
        case 1092:
            ACCEPT_TOKEN(anon_sym_void);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1093:
            ACCEPT_TOKEN(anon_sym_in);
            END_STATE();
        case 1094:
            ACCEPT_TOKEN(anon_sym_in);
            if(lookahead == 'o')
                ADVANCE(596);
            if(lookahead == 't')
                ADVANCE(129);
            END_STATE();
        case 1095:
            ACCEPT_TOKEN(anon_sym_in);
            if(lookahead == 'o')
                ADVANCE(1599);
            if(lookahead == 't')
                ADVANCE(1307);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1096:
            ACCEPT_TOKEN(anon_sym_out);
            END_STATE();
        case 1097:
            ACCEPT_TOKEN(anon_sym_out);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1098:
            ACCEPT_TOKEN(anon_sym_inout);
            END_STATE();
        case 1099:
            ACCEPT_TOKEN(anon_sym_inout);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1100:
            ACCEPT_TOKEN(anon_sym_raises);
            END_STATE();
        case 1101:
            ACCEPT_TOKEN(anon_sym_readonly);
            END_STATE();
        case 1102:
            ACCEPT_TOKEN(anon_sym_readonly);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1103:
            ACCEPT_TOKEN(anon_sym_attribute);
            END_STATE();
        case 1104:
            ACCEPT_TOKEN(anon_sym_attribute);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1105:
            ACCEPT_TOKEN(anon_sym_getraises);
            END_STATE();
        case 1106:
            ACCEPT_TOKEN(anon_sym_setraises);
            END_STATE();
        case 1107:
            ACCEPT_TOKEN(anon_sym_bitset);
            END_STATE();
        case 1108:
            ACCEPT_TOKEN(anon_sym_bitset);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1109:
            ACCEPT_TOKEN(anon_sym_bitfield);
            END_STATE();
        case 1110:
            ACCEPT_TOKEN(anon_sym_bitmask);
            END_STATE();
        case 1111:
            ACCEPT_TOKEN(anon_sym_bitmask);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1112:
            ACCEPT_TOKEN(anon_sym_ATannotation);
            END_STATE();
        case 1113:
            ACCEPT_TOKEN(anon_sym_default);
            END_STATE();
        case 1114:
            ACCEPT_TOKEN(anon_sym_default);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1115:
            ACCEPT_TOKEN(anon_sym_AT);
            END_STATE();
        case 1116:
            ACCEPT_TOKEN(anon_sym_AT);
            if(lookahead == 'a')
                ADVANCE(415);
            END_STATE();
        case 1117:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH_AT);
            END_STATE();
        case 1118:
            ACCEPT_TOKEN(aux_sym_extend_annotation_appl_token1);
            if(lookahead == '\n')
                ADVANCE(1118);
            if(lookahead == '\r')
                ADVANCE(59);
            if(lookahead == '/')
                ADVANCE(104);
            END_STATE();
        case 1119:
            ACCEPT_TOKEN(anon_sym_EQ);
            END_STATE();
        case 1120:
            ACCEPT_TOKEN(aux_sym_annotation_appl_id_token1);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1174);
            END_STATE();
        case 1121:
            ACCEPT_TOKEN(aux_sym_annotation_appl_id_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1122:
            ACCEPT_TOKEN(aux_sym_annotation_appl_autoid_token1);
            END_STATE();
        case 1123:
            ACCEPT_TOKEN(aux_sym_annotation_appl_autoid_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1124:
            ACCEPT_TOKEN(aux_sym_autoid_kind_token1);
            END_STATE();
        case 1125:
            ACCEPT_TOKEN(aux_sym_autoid_kind_token2);
            END_STATE();
        case 1126:
            ACCEPT_TOKEN(aux_sym_autoid_kind_token2);
            if(lookahead == 'i')
                ADVANCE(260);
            END_STATE();
        case 1127:
            ACCEPT_TOKEN(aux_sym_annotation_appl_optional_token1);
            END_STATE();
        case 1128:
            ACCEPT_TOKEN(aux_sym_annotation_appl_optional_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1129:
            ACCEPT_TOKEN(aux_sym_annotation_appl_position_token1);
            END_STATE();
        case 1130:
            ACCEPT_TOKEN(aux_sym_annotation_appl_position_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1131:
            ACCEPT_TOKEN(aux_sym_annotation_appl_value_token1);
            END_STATE();
        case 1132:
            ACCEPT_TOKEN(aux_sym_annotation_appl_value_token1);
            if(lookahead == 'B')
                ADVANCE(225);
            END_STATE();
        case 1133:
            ACCEPT_TOKEN(aux_sym_annotation_appl_value_token1);
            if(lookahead == 't')
                ADVANCE(616);
            END_STATE();
        case 1134:
            ACCEPT_TOKEN(aux_sym_annotation_appl_value_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1135:
            ACCEPT_TOKEN(aux_sym_annotation_appl_extensibility_token1);
            END_STATE();
        case 1136:
            ACCEPT_TOKEN(aux_sym_annotation_appl_extensibility_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1137:
            ACCEPT_TOKEN(aux_sym_extensibility_kind_token1);
            END_STATE();
        case 1138:
            ACCEPT_TOKEN(aux_sym_extensibility_kind_token2);
            END_STATE();
        case 1139:
            ACCEPT_TOKEN(aux_sym_extensibility_kind_token3);
            END_STATE();
        case 1140:
            ACCEPT_TOKEN(aux_sym_annotation_appl_final_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1141:
            ACCEPT_TOKEN(aux_sym_annotation_appl_appendable_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1142:
            ACCEPT_TOKEN(aux_sym_annotation_appl_mutable_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1143:
            ACCEPT_TOKEN(aux_sym_annotation_appl_key_token1);
            END_STATE();
        case 1144:
            ACCEPT_TOKEN(aux_sym_annotation_appl_key_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1145:
            ACCEPT_TOKEN(aux_sym_annotation_appl_must_understand_token1);
            END_STATE();
        case 1146:
            ACCEPT_TOKEN(aux_sym_annotation_appl_must_understand_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1147:
            ACCEPT_TOKEN(aux_sym_annotation_appl_default_literal_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1148:
            ACCEPT_TOKEN(aux_sym_annotation_appl_default_token1);
            END_STATE();
        case 1149:
            ACCEPT_TOKEN(aux_sym_annotation_appl_default_token1);
            if(lookahead == '_')
                ADVANCE(1785);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1150:
            ACCEPT_TOKEN(aux_sym_annotation_appl_range_token1);
            END_STATE();
        case 1151:
            ACCEPT_TOKEN(aux_sym_annotation_appl_range_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1152:
            ACCEPT_TOKEN(aux_sym_min_expr_token1);
            END_STATE();
        case 1153:
            ACCEPT_TOKEN(aux_sym_min_expr_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1154:
            ACCEPT_TOKEN(aux_sym_max_expr_token1);
            END_STATE();
        case 1155:
            ACCEPT_TOKEN(aux_sym_max_expr_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1156:
            ACCEPT_TOKEN(aux_sym_annotation_appl_unit_token1);
            END_STATE();
        case 1157:
            ACCEPT_TOKEN(aux_sym_annotation_appl_unit_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1158:
            ACCEPT_TOKEN(aux_sym_annotation_appl_bit_bound_token1);
            END_STATE();
        case 1159:
            ACCEPT_TOKEN(aux_sym_annotation_appl_bit_bound_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1160:
            ACCEPT_TOKEN(aux_sym_annotation_appl_external_token1);
            END_STATE();
        case 1161:
            ACCEPT_TOKEN(aux_sym_annotation_appl_external_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1162:
            ACCEPT_TOKEN(aux_sym_annotation_appl_nested_token1);
            END_STATE();
        case 1163:
            ACCEPT_TOKEN(aux_sym_annotation_appl_nested_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1164:
            ACCEPT_TOKEN(aux_sym_annotation_appl_verbatim_token1);
            END_STATE();
        case 1165:
            ACCEPT_TOKEN(aux_sym_annotation_appl_verbatim_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1166:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token1);
            ADVANCE_MAP(
                'H', 815,
                'O', 841,
                'a', 531,
                'c', 240,
                'h', 206,
                'i', 1170,
                'o', 404,
                'u', 532,
            );
            END_STATE();
        case 1167:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token1);
            if(lookahead == 'c')
                ADVANCE(1370);
            if(lookahead == 'i')
                ADVANCE(1171);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1168:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token1);
            if(lookahead == 'H' ||
               lookahead == 'h')
                ADVANCE(815);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(841);
            END_STATE();
        case 1169:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1170:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token2);
            if(lookahead == 'i')
                ADVANCE(1170);
            END_STATE();
        case 1171:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token2);
            if(lookahead == 'i')
                ADVANCE(1171);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1172:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token3);
            END_STATE();
        case 1173:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token3);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1174:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token4);
            END_STATE();
        case 1175:
            ACCEPT_TOKEN(aux_sym_verbatim_language_token4);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1176:
            ACCEPT_TOKEN(aux_sym_placement_kind_token1);
            END_STATE();
        case 1177:
            ACCEPT_TOKEN(aux_sym_placement_kind_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1178:
            ACCEPT_TOKEN(aux_sym_placement_kind_token2);
            END_STATE();
        case 1179:
            ACCEPT_TOKEN(aux_sym_placement_kind_token2);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1180:
            ACCEPT_TOKEN(aux_sym_placement_kind_token3);
            END_STATE();
        case 1181:
            ACCEPT_TOKEN(aux_sym_placement_kind_token3);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1182:
            ACCEPT_TOKEN(aux_sym_placement_kind_token4);
            END_STATE();
        case 1183:
            ACCEPT_TOKEN(aux_sym_placement_kind_token4);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1184:
            ACCEPT_TOKEN(aux_sym_placement_kind_token5);
            END_STATE();
        case 1185:
            ACCEPT_TOKEN(aux_sym_placement_kind_token5);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1186:
            ACCEPT_TOKEN(aux_sym_placement_kind_token6);
            END_STATE();
        case 1187:
            ACCEPT_TOKEN(aux_sym_placement_kind_token6);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1188:
            ACCEPT_TOKEN(aux_sym_annotation_appl_service_token1);
            END_STATE();
        case 1189:
            ACCEPT_TOKEN(aux_sym_annotation_appl_service_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1190:
            ACCEPT_TOKEN(aux_sym_service_platform_token1);
            END_STATE();
        case 1191:
            ACCEPT_TOKEN(aux_sym_service_platform_token2);
            END_STATE();
        case 1192:
            ACCEPT_TOKEN(aux_sym_service_platform_token2);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(695);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(710);
            END_STATE();
        case 1193:
            ACCEPT_TOKEN(aux_sym_service_platform_token2);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1194:
            ACCEPT_TOKEN(aux_sym_annotation_appl_oneway_token1);
            END_STATE();
        case 1195:
            ACCEPT_TOKEN(aux_sym_annotation_appl_oneway_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1196:
            ACCEPT_TOKEN(aux_sym_annotation_appl_ami_token1);
            END_STATE();
        case 1197:
            ACCEPT_TOKEN(aux_sym_annotation_appl_ami_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1198:
            ACCEPT_TOKEN(anon_sym_hashid);
            END_STATE();
        case 1199:
            ACCEPT_TOKEN(anon_sym_hashid);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1200:
            ACCEPT_TOKEN(aux_sym_annotation_appl_default_nested_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1201:
            ACCEPT_TOKEN(aux_sym_annotation_appl_ignore_literal_names_token1);
            END_STATE();
        case 1202:
            ACCEPT_TOKEN(aux_sym_annotation_appl_ignore_literal_names_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1203:
            ACCEPT_TOKEN(aux_sym_annotation_appl_try_construct_token1);
            END_STATE();
        case 1204:
            ACCEPT_TOKEN(aux_sym_annotation_appl_try_construct_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1205:
            ACCEPT_TOKEN(aux_sym_try_construct_fail_action_token1);
            END_STATE();
        case 1206:
            ACCEPT_TOKEN(aux_sym_try_construct_fail_action_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1207:
            ACCEPT_TOKEN(aux_sym_try_construct_fail_action_token2);
            END_STATE();
        case 1208:
            ACCEPT_TOKEN(aux_sym_try_construct_fail_action_token2);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1209:
            ACCEPT_TOKEN(aux_sym_try_construct_fail_action_token3);
            END_STATE();
        case 1210:
            ACCEPT_TOKEN(aux_sym_try_construct_fail_action_token3);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1211:
            ACCEPT_TOKEN(aux_sym_annotation_appl_non_serialized_token1);
            END_STATE();
        case 1212:
            ACCEPT_TOKEN(aux_sym_annotation_appl_non_serialized_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1213:
            ACCEPT_TOKEN(aux_sym_annotation_appl_data_representation_token1);
            END_STATE();
        case 1214:
            ACCEPT_TOKEN(aux_sym_annotation_appl_data_representation_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1215:
            ACCEPT_TOKEN(anon_sym_allowed_kinds);
            END_STATE();
        case 1216:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token1);
            if(lookahead == '1')
                ADVANCE(1218);
            if(lookahead == '2')
                ADVANCE(1222);
            END_STATE();
        case 1217:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token1);
            if(lookahead == '1')
                ADVANCE(1219);
            if(lookahead == '2')
                ADVANCE(1223);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1218:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token2);
            END_STATE();
        case 1219:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token2);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1220:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token3);
            END_STATE();
        case 1221:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token3);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1222:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token4);
            END_STATE();
        case 1223:
            ACCEPT_TOKEN(aux_sym_data_representation_mask_token4);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1224:
            ACCEPT_TOKEN(aux_sym_annotation_appl_topic_token1);
            END_STATE();
        case 1225:
            ACCEPT_TOKEN(aux_sym_annotation_appl_topic_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1226:
            ACCEPT_TOKEN(sym_annotation_appl_choice);
            END_STATE();
        case 1227:
            ACCEPT_TOKEN(sym_annotation_appl_choice);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1228:
            ACCEPT_TOKEN(sym_annotation_appl_empty);
            END_STATE();
        case 1229:
            ACCEPT_TOKEN(sym_annotation_appl_empty);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1230:
            ACCEPT_TOKEN(sym_annotation_appl_dds_service);
            END_STATE();
        case 1231:
            ACCEPT_TOKEN(sym_annotation_appl_dds_service);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1232:
            ACCEPT_TOKEN(aux_sym_annotation_appl_dds_request_topic_token1);
            END_STATE();
        case 1233:
            ACCEPT_TOKEN(aux_sym_annotation_appl_dds_request_topic_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1234:
            ACCEPT_TOKEN(aux_sym_annotation_appl_dds_request_topic_token2);
            END_STATE();
        case 1235:
            ACCEPT_TOKEN(aux_sym_annotation_appl_dds_request_topic_token2);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1236:
            ACCEPT_TOKEN(aux_sym_annotation_appl_dds_reply_topic_token1);
            END_STATE();
        case 1237:
            ACCEPT_TOKEN(aux_sym_annotation_appl_dds_reply_topic_token1);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1238:
            ACCEPT_TOKEN(anon_sym_module);
            END_STATE();
        case 1239:
            ACCEPT_TOKEN(anon_sym_typename);
            END_STATE();
        case 1240:
            ACCEPT_TOKEN(anon_sym_typename);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1241:
            ACCEPT_TOKEN(anon_sym_valuetype);
            END_STATE();
        case 1242:
            ACCEPT_TOKEN(anon_sym_valuetype);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1243:
            ACCEPT_TOKEN(anon_sym_eventtype);
            END_STATE();
        case 1244:
            ACCEPT_TOKEN(anon_sym_eventtype);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1245:
            ACCEPT_TOKEN(anon_sym_struct);
            END_STATE();
        case 1246:
            ACCEPT_TOKEN(anon_sym_struct);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1247:
            ACCEPT_TOKEN(anon_sym_union);
            END_STATE();
        case 1248:
            ACCEPT_TOKEN(anon_sym_union);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1249:
            ACCEPT_TOKEN(anon_sym_enum);
            END_STATE();
        case 1250:
            ACCEPT_TOKEN(anon_sym_enum);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1251:
            ACCEPT_TOKEN(anon_sym_const);
            END_STATE();
        case 1252:
            ACCEPT_TOKEN(anon_sym_const);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1253:
            ACCEPT_TOKEN(anon_sym_alias);
            END_STATE();
        case 1254:
            ACCEPT_TOKEN(anon_sym_custom);
            END_STATE();
        case 1255:
            ACCEPT_TOKEN(anon_sym_custom);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1256:
            ACCEPT_TOKEN(anon_sym_truncatable);
            END_STATE();
        case 1257:
            ACCEPT_TOKEN(anon_sym_truncatable);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1258:
            ACCEPT_TOKEN(anon_sym_supports);
            END_STATE();
        case 1259:
            ACCEPT_TOKEN(anon_sym_supports);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1260:
            ACCEPT_TOKEN(anon_sym_public);
            END_STATE();
        case 1261:
            ACCEPT_TOKEN(anon_sym_public);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1262:
            ACCEPT_TOKEN(anon_sym_private);
            END_STATE();
        case 1263:
            ACCEPT_TOKEN(anon_sym_private);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1264:
            ACCEPT_TOKEN(anon_sym_factory);
            END_STATE();
        case 1265:
            ACCEPT_TOKEN(anon_sym_factory);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1266:
            ACCEPT_TOKEN(anon_sym_typedef);
            END_STATE();
        case 1267:
            ACCEPT_TOKEN(anon_sym_typedef);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1268:
            ACCEPT_TOKEN(anon_sym_LBRACK);
            END_STATE();
        case 1269:
            ACCEPT_TOKEN(anon_sym_RBRACK);
            END_STATE();
        case 1270:
            ACCEPT_TOKEN(anon_sym_switch);
            END_STATE();
        case 1271:
            ACCEPT_TOKEN(anon_sym_switch);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1272:
            ACCEPT_TOKEN(anon_sym_case);
            END_STATE();
        case 1273:
            ACCEPT_TOKEN(anon_sym_case);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1274:
            ACCEPT_TOKEN(anon_sym_typeid);
            END_STATE();
        case 1275:
            ACCEPT_TOKEN(anon_sym_typeid);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1276:
            ACCEPT_TOKEN(anon_sym_typeprefix);
            END_STATE();
        case 1277:
            ACCEPT_TOKEN(anon_sym_import);
            END_STATE();
        case 1278:
            ACCEPT_TOKEN(anon_sym_import);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1279:
            ACCEPT_TOKEN(anon_sym_Object);
            END_STATE();
        case 1280:
            ACCEPT_TOKEN(anon_sym_Object);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1281:
            ACCEPT_TOKEN(anon_sym_oneway);
            END_STATE();
        case 1282:
            ACCEPT_TOKEN(anon_sym_oneway);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1283:
            ACCEPT_TOKEN(anon_sym_context);
            END_STATE();
        case 1284:
            ACCEPT_TOKEN(sym_value_base_type);
            END_STATE();
        case 1285:
            ACCEPT_TOKEN(sym_value_base_type);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1286:
            ACCEPT_TOKEN(anon_sym_component);
            END_STATE();
        case 1287:
            ACCEPT_TOKEN(anon_sym_provides);
            END_STATE();
        case 1288:
            ACCEPT_TOKEN(anon_sym_uses);
            END_STATE();
        case 1289:
            ACCEPT_TOKEN(anon_sym_multiple);
            END_STATE();
        case 1290:
            ACCEPT_TOKEN(anon_sym_multiple);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1291:
            ACCEPT_TOKEN(anon_sym_home);
            END_STATE();
        case 1292:
            ACCEPT_TOKEN(anon_sym_manages);
            END_STATE();
        case 1293:
            ACCEPT_TOKEN(anon_sym_emits);
            END_STATE();
        case 1294:
            ACCEPT_TOKEN(anon_sym_publishes);
            END_STATE();
        case 1295:
            ACCEPT_TOKEN(anon_sym_consumes);
            END_STATE();
        case 1296:
            ACCEPT_TOKEN(anon_sym_primarykey);
            END_STATE();
        case 1297:
            ACCEPT_TOKEN(anon_sym_finder);
            END_STATE();
        case 1298:
            ACCEPT_TOKEN(anon_sym_finder);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1299:
            ACCEPT_TOKEN(anon_sym_porttype);
            END_STATE();
        case 1300:
            ACCEPT_TOKEN(anon_sym_port);
            END_STATE();
        case 1301:
            ACCEPT_TOKEN(anon_sym_mirrorport);
            END_STATE();
        case 1302:
            ACCEPT_TOKEN(anon_sym_connector);
            END_STATE();
        case 1303:
            ACCEPT_TOKEN(anon_sym_native);
            END_STATE();
        case 1304:
            ACCEPT_TOKEN(anon_sym_native);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1305:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == ' ')
                ADVANCE(395);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1306:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '1')
                ADVANCE(1313);
            if(lookahead == '3')
                ADVANCE(1309);
            if(lookahead == '6')
                ADVANCE(1311);
            if(lookahead == '8')
                ADVANCE(968);
            if(lookahead == 'e')
                ADVANCE(1550);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1307:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '1')
                ADVANCE(1313);
            if(lookahead == '3')
                ADVANCE(1309);
            if(lookahead == '6')
                ADVANCE(1311);
            if(lookahead == '8')
                ADVANCE(968);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1308:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '1')
                ADVANCE(1314);
            if(lookahead == '3')
                ADVANCE(1310);
            if(lookahead == '6')
                ADVANCE(1312);
            if(lookahead == '8')
                ADVANCE(960);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1309:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '2')
                ADVANCE(955);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1310:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '2')
                ADVANCE(974);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1311:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '4')
                ADVANCE(958);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1312:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '4')
                ADVANCE(977);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1313:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '6')
                ADVANCE(949);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1314:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '6')
                ADVANCE(971);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1315:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A')
                ADVANCE(1319);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1316:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B')
                ADVANCE(1342);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1317:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E')
                ADVANCE(1045);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1318:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E')
                ADVANCE(1047);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1319:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L')
                ADVANCE(1321);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1320:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R')
                ADVANCE(1322);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1321:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S')
                ADVANCE(1318);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1322:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U')
                ADVANCE(1317);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1323:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1684);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1324:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1681);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1325:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1651);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1326:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1911);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1327:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1660);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1328:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1871);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1329:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1854);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1330:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1784);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1331:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1686);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1332:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1815);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1333:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1687);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1334:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == '_')
                ADVANCE(1688);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1335:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1466);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1336:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1392);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1337:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1551);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1338:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'i')
                ADVANCE(1609);
            if(lookahead == 'l')
                ADVANCE(1520);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1339:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1376);
            if(lookahead == 'i')
                ADVANCE(1497);
            if(lookahead == 'l')
                ADVANCE(1520);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1340:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1523);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1341:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1611);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1342:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1557);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1343:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1537);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1344:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1481);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1345:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1589);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1346:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1553);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1347:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1595);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1348:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1538);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1349:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1465);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1350:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1563);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1351:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1484);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1352:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1586);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1353:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1558);
            if(lookahead == 'h')
                ADVANCE(1343);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1354:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1585);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1355:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1381);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1356:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1366);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1357:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1380);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1358:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1476);
            if(lookahead == 'o')
                ADVANCE(1450);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1359:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'a')
                ADVANCE(1476);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1360:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1463);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1361:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1559);
            if(lookahead == 'n')
                ADVANCE(1610);
            if(lookahead == 't')
                ADVANCE(1575);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1362:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1559);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1363:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1469);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1364:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1470);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1365:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1603);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1366:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'b')
                ADVANCE(1474);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1367:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1443);
            if(lookahead == 's')
                ADVANCE(1590);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1368:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1443);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1369:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1261);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1370:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1370);
            if(lookahead == 'i')
                ADVANCE(1171);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1371:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1416);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1372:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1438);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1373:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1579);
            if(lookahead == 'n')
                ADVANCE(1397);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1374:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1579);
            if(lookahead == 'u')
                ADVANCE(1572);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1375:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1579);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1376:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1581);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1377:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1566);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1378:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1404);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1379:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1569);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1380:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1570);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1381:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1411);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1382:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1349);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1383:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'c')
                ADVANCE(1352);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1384:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1092);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1385:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(964);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1386:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1275);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1387:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1305);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1388:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1199);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1389:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1402);
            if(lookahead == 'i')
                ADVANCE(1386);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1390:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1402);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1391:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1420);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1392:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'd')
                ADVANCE(1516);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1393:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1534);
            if(lookahead == 'h')
                ADVANCE(1513);
            if(lookahead == 't')
                ADVANCE(1536);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1394:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1534);
            if(lookahead == 'h')
                ADVANCE(1513);
            if(lookahead == 't')
                ADVANCE(1542);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1395:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1534);
            if(lookahead == 'h')
                ADVANCE(1513);
            if(lookahead == 't')
                ADVANCE(1545);
            if(lookahead == 'u')
                ADVANCE(1533);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1396:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1534);
            if(lookahead == 'h')
                ADVANCE(1513);
            if(lookahead == 't')
                ADVANCE(1545);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1397:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1607);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1398:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1389);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1399:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1316);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1400:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(981);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1401:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1304);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1402:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1430);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1403:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1263);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1404:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(999);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1405:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1285);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1406:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1104);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1407:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1242);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1408:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1273);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1409:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1240);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1410:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1244);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1411:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1087);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1412:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1290);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1413:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1257);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1414:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1431);
            if(lookahead == 'o')
                ADVANCE(1600);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1415:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1385);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1416:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1525);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1417:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1336);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1418:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1387);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1419:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1503);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1420:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1539);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1421:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1351);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1422:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1550);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1423:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1564);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1424:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1567);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1425:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1499);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1426:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1591);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1427:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1377);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1428:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1390);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1429:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'e')
                ADVANCE(1502);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1430:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1267);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1431:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1347);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1432:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'f')
                ADVANCE(1355);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1433:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(951);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1434:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(989);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1435:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(994);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1436:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(953);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1437:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'g')
                ADVANCE(1500);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1438:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1271);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1439:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1343);
            if(lookahead == 'o')
                ADVANCE(1505);
            if(lookahead == 'u')
                ADVANCE(1555);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1440:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1343);
            if(lookahead == 'o')
                ADVANCE(1505);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1441:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1343);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1442:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1513);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1443:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1348);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1444:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'h')
                ADVANCE(1458);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1445:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1609);
            if(lookahead == 'l')
                ADVANCE(1520);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1446:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1606);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1447:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1560);
            if(lookahead == 'o')
                ADVANCE(1508);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1448:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1437);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1449:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1605);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1450:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1384);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1451:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1365);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1452:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1498);
            if(lookahead == 'n')
                ADVANCE(1461);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1453:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1498);
            if(lookahead == 'n')
                ADVANCE(1554);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1454:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1369);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1455:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1493);
            if(lookahead == 'u')
                ADVANCE(1379);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1456:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1493);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1457:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1530);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1458:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1388);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1459:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1494);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1460:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1582);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1461:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1514);
            if(lookahead == 's')
                ADVANCE(1448);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1462:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'i')
                ADVANCE(1518);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1463:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'j')
                ADVANCE(1427);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1464:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'k')
                ADVANCE(1111);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1465:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1083);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1466:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1596);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1467:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1520);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1468:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1613);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1469:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1454);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1470:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1400);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1471:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1571);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1472:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1584);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1473:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1412);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1474:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1413);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1475:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1421);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1476:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'l')
                ADVANCE(1604);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1477:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1531);
            if(lookahead == 'n')
                ADVANCE(1561);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1478:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1250);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1479:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1255);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1480:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1337);
            if(lookahead == 's')
                ADVANCE(1424);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1481:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'm')
                ADVANCE(1409);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1482:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1433);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1483:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1248);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1484:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(962);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1485:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1079);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1486:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1095);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1487:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1610);
            if(lookahead == 't')
                ADVANCE(1575);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1488:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1610);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1489:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1594);
            if(lookahead == 'v')
                ADVANCE(1429);
            if(lookahead == 'x')
                ADVANCE(1371);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1490:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1594);
            if(lookahead == 'x')
                ADVANCE(1371);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1491:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1594);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1492:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1561);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1493:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1434);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1494:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1435);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1495:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1468);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1496:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1383);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1497:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1391);
            if(lookahead == 'x')
                ADVANCE(1415);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1498:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1576);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1499:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1344);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1500:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1418);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1501:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1574);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1502:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1593);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1503:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1378);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1504:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1436);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1505:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1556);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1506:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'n')
                ADVANCE(1588);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1507:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1600);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1508:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1475);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1509:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1482);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1510:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1450);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1511:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1479);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1512:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1508);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1513:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1547);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1514:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1483);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1515:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1382);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1516:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1495);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1517:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1540);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1518:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1485);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1519:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1504);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1520:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1350);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1521:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1548);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1522:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'o')
                ADVANCE(1549);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1523:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1001);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1524:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1398);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1525:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1583);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1526:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1407);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1527:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1428);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1528:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1425);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1529:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1410);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1530:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1473);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1531:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1521);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1532:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1522);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1533:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'p')
                ADVANCE(1532);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1534:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'q')
                ADVANCE(1597);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1535:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1446);
            if(lookahead == 'u')
                ADVANCE(1363);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1536:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1455);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1537:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(984);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1538:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(986);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1539:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1298);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1540:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1612);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1541:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1451);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1542:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1602);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1543:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1459);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1544:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1598);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1545:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1456);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1546:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1357);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1547:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1565);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1548:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1568);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1549:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1580);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1550:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'r')
                ADVANCE(1432);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1551:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1464);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1552:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1259);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1553:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1444);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1554:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1448);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1555:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1578);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1556:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1562);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1557:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1405);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1558:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1408);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1559:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 's')
                ADVANCE(1577);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1560:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1480);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1561:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1307);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1562:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1252);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1563:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(979);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1564:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(966);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1565:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(947);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1566:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1280);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1567:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1108);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1568:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1278);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1569:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1246);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1570:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1085);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1571:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1114);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1572:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1097);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1573:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1099);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1574:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1306);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1575:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1541);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1576:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1308);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1577:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1546);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1578:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1511);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1579:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1423);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1580:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1552);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1581:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1517);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1582:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1372);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1583:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1462);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1584:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1457);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1585:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1403);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1586:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1356);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1587:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1406);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1588:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1422);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1589:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1449);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1590:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1543);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1591:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1615);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1592:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1618);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1593:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 't')
                ADVANCE(1592);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1594:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1478);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1595:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1471);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1596:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1399);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1597:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1419);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1598:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1496);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1599:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1573);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1600:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1364);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1601:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1472);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1602:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1379);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1603:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1587);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1604:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'u')
                ADVANCE(1426);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1605:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'v')
                ADVANCE(1401);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1606:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'v')
                ADVANCE(1354);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1607:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'w')
                ADVANCE(1341);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1608:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'w')
                ADVANCE(1460);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1609:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'x')
                ADVANCE(1415);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1610:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(996);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1611:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1282);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1612:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1265);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1613:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1102);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1614:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1524);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1615:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1526);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1616:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1527);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1617:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1528);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1618:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'y')
                ADVANCE(1529);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1619:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1920);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1796);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1869);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1620:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1767);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1846);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1621:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1173);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1622:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1916);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1623:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1909);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1624:
            ACCEPT_TOKEN(sym_identifier);
            ADVANCE_MAP(
                'A', 1884,
                'a', 1884,
                'D', 1865,
                'd', 1865,
                'E', 1730,
                'e', 1730,
                'I', 1866,
                'i', 1866,
            );
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1625:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1923);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1626:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1769);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1627:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1794);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1628:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1652);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1629:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1797);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1630:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1329);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1631:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1849);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1632:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1770);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1633:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1771);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1634:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1894);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1635:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1777);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1636:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1775);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1637:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1813);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1638:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1861);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1639:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1772);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1640:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1795);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1641:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1915);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1642:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1655);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1643:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1903);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1644:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1905);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1645:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1906);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1646:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1907);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1647:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1908);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1648:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1862);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1649:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1863);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1650:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'A' ||
               lookahead == 'a')
                ADVANCE(1864);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('B' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('b' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1651:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1834);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1652:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1779);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1653:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1634);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1654:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1766);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1655:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'B' ||
               lookahead == 'b')
                ADVANCE(1780);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1656:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1678);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1768);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1657:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1225);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1658:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1237);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1659:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1233);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1660:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1826);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1661:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1631);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1662:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1696);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1663:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1783);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1664:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1698);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1665:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1883);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1666:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1700);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1667:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1787);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1668:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1788);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1669:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'C' ||
               lookahead == 'c')
                ADVANCE(1789);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1670:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1121);
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(1806);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1671:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1123);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1672:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1163);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1673:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1206);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1674:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1159);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1675:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1200);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1676:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1212);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1677:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1146);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1678:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1847);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1679:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1868);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1680:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1323);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1681:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1724);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1682:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1773);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1683:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1714);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1684:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1716);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1758);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1685:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1642);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1686:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1726);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1687:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1727);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1761);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1688:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'D' ||
               lookahead == 'd')
                ADVANCE(1728);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1689:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1921);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1690:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1845);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1691:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1919);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1692:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1809);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1693:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1841);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1694:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1151);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1695:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1134);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1696:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1227);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1697:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1142);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1698:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1189);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1699:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1141);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1700:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1231);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1701:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1732);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1702:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1187);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1703:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1177);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1704:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1235);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1705:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1875);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1804);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1706:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1844);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1707:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1324);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1708:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1672);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1709:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1807);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1710:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1876);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1711:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1851);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1712:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1330);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1713:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1867);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1714:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1858);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1715:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1675);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1716:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1663);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1717:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1676);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1718:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1852);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1719:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1816);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1720:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1857);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1721:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1853);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1722:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1873);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1723:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1878);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1724:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1733);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1725:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1859);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1726:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1667);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1727:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1668);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1728:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1669);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1729:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'E' ||
               lookahead == 'e')
                ADVANCE(1334);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1730:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1623);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1731:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1897);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1732:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1835);
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(1753);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1733:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'F' ||
               lookahead == 'f')
                ADVANCE(1641);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1734:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'G' ||
               lookahead == 'g')
                ADVANCE(1694);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1735:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'H' ||
               lookahead == 'h')
                ADVANCE(1822);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1736:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1808);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1737:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1197);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1738:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1790);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1327);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1739:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1926);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1740:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1879);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1741:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1662);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1742:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1791);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1743:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1657);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1744:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1836);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1745:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1671);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1746:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1654);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1747:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1658);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1748:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1659);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1749:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1880);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1750:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1891);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1751:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1635);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1752:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1887);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1753:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1820);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1754:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1664);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1755:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1827);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1756:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1666);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1757:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1895);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1758:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1781);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1759:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1828);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1760:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1901);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1761:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1782);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1762:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1829);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1763:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1830);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1764:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1831);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1765:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1832);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1766:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'I' ||
               lookahead == 'i')
                ADVANCE(1786);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1767:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1913);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1768:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1221);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1769:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1140);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1770:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1161);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1771:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1128);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1772:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1147);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1773:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1175);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1774:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1925);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1775:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1332);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1776:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1881);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1777:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1739);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1778:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1882);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1779:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1697);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1780:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1699);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1781:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1702);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1782:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1703);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1783:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1638);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1784:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1757);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1785:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1760);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1723);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1786:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1752);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1787:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1648);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1788:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1649);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1789:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'L' ||
               lookahead == 'l')
                ADVANCE(1650);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1790:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1210);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1791:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1165);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1792:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1840);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(1888);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1793:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1737);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1838);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1899);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1794:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1713);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1795:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'M' ||
               lookahead == 'm')
                ADVANCE(1704);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1796:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1153);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1797:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1734);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1798:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1130);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1799:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1214);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1800:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1183);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1801:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1185);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1802:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1181);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1803:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1179);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1804:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1328);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1805:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1691);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1886);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1806:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1824);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1807:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1685);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1808:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1626);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1809:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1870);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1811);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1810:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1674);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1811:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1632);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1812:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1633);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1813:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1677);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1814:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1680);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1815:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1627);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1816:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1900);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1817:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1749);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1707);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1818:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1683);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1819:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1872);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1820:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'N' ||
               lookahead == 'n')
                ADVANCE(1333);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1821:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1839);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1738);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1822:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1741);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1823:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1877);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1824:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1856);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1825:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1745);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1826:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1819);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1827:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1798);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1828:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1799);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1829:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1800);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1830:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1801);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1831:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1802);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1832:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1803);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1833:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1842);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1834:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1912);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1835:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1860);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1836:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1812);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1837:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'O' ||
               lookahead == 'o')
                ADVANCE(1843);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1838:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1709);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1839:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1743);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1840:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1885);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1841:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1774);
            if(lookahead == 'Q' ||
               lookahead == 'q')
                ADVANCE(1914);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1842:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1747);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1843:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1748);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1844:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'P' ||
               lookahead == 'p')
                ADVANCE(1855);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1845:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1917);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1846:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1653);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1847:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1217);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1848:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1910);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1849:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1673);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1850:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1693);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1725);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1851:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1751);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1852:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1636);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1853:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1639);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1854:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1706);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1855:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1710);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1856:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1712);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1857:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1331);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1858:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1874);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1859:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1918);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1860:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1729);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1861:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1644);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1862:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1645);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1863:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1646);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1864:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'R' ||
               lookahead == 'r')
                ADVANCE(1647);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1865:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1850);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1866:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1661);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1867:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1202);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1868:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1193);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1869:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1889);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1628);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1870:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1746);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1871:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1711);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1872:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1893);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1873:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1904);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1874:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1898);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1875:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1892);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1876:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1719);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1877:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1750);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1878:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'S' ||
               lookahead == 's')
                ADVANCE(1896);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1879:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1325);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1880:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1157);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1881:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1149);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1882:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1208);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1883:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1204);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1884:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1630);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1885:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1922);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1886:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1744);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1887:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1924);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1888:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1692);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1889:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1326);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1890:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1833);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1891:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1755);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1892:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1708);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1893:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1848);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1894:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1742);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1895:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1718);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1896:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1715);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1897:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1720);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1898:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1637);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1899:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1825);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1900:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1643);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1901:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1721);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1902:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1837);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1903:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1759);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1904:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1902);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1905:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1762);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1906:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1763);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1907:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1764);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1908:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'T' ||
               lookahead == 't')
                ADVANCE(1765);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1909:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1776);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1910:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1665);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1911:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1818);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1912:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1810);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1913:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1695);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1914:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1722);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1915:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'U' ||
               lookahead == 'u')
                ADVANCE(1778);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1916:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(1621);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1917:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(1754);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1918:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'V' ||
               lookahead == 'v')
                ADVANCE(1756);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1919:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'W' ||
               lookahead == 'w')
                ADVANCE(1625);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1920:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'X' ||
               lookahead == 'x')
                ADVANCE(1155);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1921:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1144);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1922:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1229);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1923:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1195);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1924:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1136);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1925:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'Y' ||
               lookahead == 'y')
                ADVANCE(1890);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1926:
            ACCEPT_TOKEN(sym_identifier);
            if(lookahead == 'Z' ||
               lookahead == 'z')
                ADVANCE(1717);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Y') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'y'))
                ADVANCE(1927);
            END_STATE();
        case 1927:
            ACCEPT_TOKEN(sym_identifier);
            if(('0' <= lookahead && lookahead <= '9') ||
               ('A' <= lookahead && lookahead <= 'Z') ||
               lookahead == '_' ||
               ('a' <= lookahead && lookahead <= 'z'))
                ADVANCE(1927);
            END_STATE();
        case 1928:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            END_STATE();
        case 1929:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead != 0)
                ADVANCE(107);
            END_STATE();
        case 1930:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '@')
                ADVANCE(1117);
            END_STATE();
        case 1931:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '\\')
                ADVANCE(84);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1938);
            END_STATE();
        case 1932:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead == '\\')
                ADVANCE(1077);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(1076);
            END_STATE();
        case 1933:
            ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1052);
            END_STATE();
        case 1934:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\n')
                ADVANCE(1937);
            if(lookahead == '\\')
                ADVANCE(84);
            if(lookahead != 0)
                ADVANCE(1938);
            END_STATE();
        case 1935:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\r')
                ADVANCE(1939);
            if(lookahead == '\\')
                ADVANCE(1935);
            if(lookahead != 0)
                ADVANCE(1938);
            END_STATE();
        case 1936:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '*')
                ADVANCE(1942);
            if(lookahead == '/')
                ADVANCE(1931);
            if(lookahead == '\\')
                ADVANCE(84);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1938);
            END_STATE();
        case 1937:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '/')
                ADVANCE(1936);
            if(lookahead == '\\')
                ADVANCE(79);
            if(lookahead == '\t' ||
               (0x0b <= lookahead && lookahead <= '\r') ||
               lookahead == ' ')
                ADVANCE(1937);
            if(lookahead != 0 &&
               (lookahead < '\t' || '\r' < lookahead))
                ADVANCE(1938);
            END_STATE();
        case 1938:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\\')
                ADVANCE(84);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1938);
            END_STATE();
        case 1939:
            ACCEPT_TOKEN(aux_sym_comment_token1);
            if(lookahead == '\\')
                ADVANCE(84);
            if(lookahead != 0)
                ADVANCE(1938);
            END_STATE();
        case 1940:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            END_STATE();
        case 1941:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead != 0 &&
               lookahead != '/')
                ADVANCE(107);
            END_STATE();
        case 1942:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead == '\\')
                ADVANCE(84);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1938);
            END_STATE();
        case 1943:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead == '\\')
                ADVANCE(1077);
            if(lookahead != 0 &&
               lookahead != '\n' &&
               lookahead != '>')
                ADVANCE(1076);
            END_STATE();
        case 1944:
            ACCEPT_TOKEN(anon_sym_SLASH_STAR);
            if(lookahead != 0 &&
               lookahead != '\n')
                ADVANCE(1052);
            END_STATE();
        case 1945:
            ACCEPT_TOKEN(aux_sym_comment_token2);
            if(lookahead == '*')
                ADVANCE(1945);
            if(lookahead != 0 &&
               lookahead != '/')
                ADVANCE(107);
            END_STATE();
        default:
            return false;
    }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
    [0] = { .lex_state = 0 },
    [1] = { .lex_state = 944 },
    [2] = { .lex_state = 110 },
    [3] = { .lex_state = 110 },
    [4] = { .lex_state = 110 },
    [5] = { .lex_state = 111 },
    [6] = { .lex_state = 110 },
    [7] = { .lex_state = 110 },
    [8] = { .lex_state = 111 },
    [9] = { .lex_state = 111 },
    [10] = { .lex_state = 112 },
    [11] = { .lex_state = 112 },
    [12] = { .lex_state = 112 },
    [13] = { .lex_state = 112 },
    [14] = { .lex_state = 112 },
    [15] = { .lex_state = 112 },
    [16] = { .lex_state = 112 },
    [17] = { .lex_state = 112 },
    [18] = { .lex_state = 112 },
    [19] = { .lex_state = 112 },
    [20] = { .lex_state = 112 },
    [21] = { .lex_state = 943 },
    [22] = { .lex_state = 944 },
    [23] = { .lex_state = 944 },
    [24] = { .lex_state = 944 },
    [25] = { .lex_state = 943 },
    [26] = { .lex_state = 944 },
    [27] = { .lex_state = 944 },
    [28] = { .lex_state = 944 },
    [29] = { .lex_state = 944 },
    [30] = { .lex_state = 944 },
    [31] = { .lex_state = 944 },
    [32] = { .lex_state = 102 },
    [33] = { .lex_state = 99 },
    [34] = { .lex_state = 102 },
    [35] = { .lex_state = 102 },
    [36] = { .lex_state = 102 },
    [37] = { .lex_state = 102 },
    [38] = { .lex_state = 102 },
    [39] = { .lex_state = 102 },
    [40] = { .lex_state = 102 },
    [41] = { .lex_state = 102 },
    [42] = { .lex_state = 102 },
    [43] = { .lex_state = 113 },
    [44] = { .lex_state = 116 },
    [45] = { .lex_state = 100 },
    [46] = { .lex_state = 100 },
    [47] = { .lex_state = 100 },
    [48] = { .lex_state = 100 },
    [49] = { .lex_state = 100 },
    [50] = { .lex_state = 100 },
    [51] = { .lex_state = 100 },
    [52] = { .lex_state = 103 },
    [53] = { .lex_state = 115 },
    [54] = { .lex_state = 103 },
    [55] = { .lex_state = 103 },
    [56] = { .lex_state = 100 },
    [57] = { .lex_state = 100 },
    [58] = { .lex_state = 121 },
    [59] = { .lex_state = 121 },
    [60] = { .lex_state = 121 },
    [61] = { .lex_state = 121 },
    [62] = { .lex_state = 121 },
    [63] = { .lex_state = 110 },
    [64] = { .lex_state = 110 },
    [65] = { .lex_state = 110 },
    [66] = { .lex_state = 110 },
    [67] = { .lex_state = 117 },
    [68] = { .lex_state = 110 },
    [69] = { .lex_state = 110 },
    [70] = { .lex_state = 110 },
    [71] = { .lex_state = 111 },
    [72] = { .lex_state = 117 },
    [73] = { .lex_state = 111 },
    [74] = { .lex_state = 111 },
    [75] = { .lex_state = 111 },
    [76] = { .lex_state = 118 },
    [77] = { .lex_state = 88 },
    [78] = { .lex_state = 88 },
    [79] = { .lex_state = 118 },
    [80] = { .lex_state = 118 },
    [81] = { .lex_state = 118 },
    [82] = { .lex_state = 118 },
    [83] = { .lex_state = 118 },
    [84] = { .lex_state = 118 },
    [85] = { .lex_state = 118 },
    [86] = { .lex_state = 88 },
    [87] = { .lex_state = 118 },
    [88] = { .lex_state = 118 },
    [89] = { .lex_state = 88 },
    [90] = { .lex_state = 88 },
    [91] = { .lex_state = 112 },
    [92] = { .lex_state = 112 },
    [93] = { .lex_state = 90 },
    [94] = { .lex_state = 90 },
    [95] = { .lex_state = 90 },
    [96] = { .lex_state = 90 },
    [97] = { .lex_state = 90 },
    [98] = { .lex_state = 122 },
    [99] = { .lex_state = 99 },
    [100] = { .lex_state = 99 },
    [101] = { .lex_state = 99 },
    [102] = { .lex_state = 99 },
    [103] = { .lex_state = 99 },
    [104] = { .lex_state = 99 },
    [105] = { .lex_state = 99 },
    [106] = { .lex_state = 99 },
    [107] = { .lex_state = 99 },
    [108] = { .lex_state = 99 },
    [109] = { .lex_state = 99 },
    [110] = { .lex_state = 99 },
    [111] = { .lex_state = 99 },
    [112] = { .lex_state = 99 },
    [113] = { .lex_state = 99 },
    [114] = { .lex_state = 99 },
    [115] = { .lex_state = 99 },
    [116] = { .lex_state = 99 },
    [117] = { .lex_state = 99 },
    [118] = { .lex_state = 99 },
    [119] = { .lex_state = 99 },
    [120] = { .lex_state = 99 },
    [121] = { .lex_state = 99 },
    [122] = { .lex_state = 99 },
    [123] = { .lex_state = 99 },
    [124] = { .lex_state = 99 },
    [125] = { .lex_state = 99 },
    [126] = { .lex_state = 87 },
    [127] = { .lex_state = 99 },
    [128] = { .lex_state = 99 },
    [129] = { .lex_state = 99 },
    [130] = { .lex_state = 99 },
    [131] = { .lex_state = 99 },
    [132] = { .lex_state = 99 },
    [133] = { .lex_state = 99 },
    [134] = { .lex_state = 87 },
    [135] = { .lex_state = 99 },
    [136] = { .lex_state = 99 },
    [137] = { .lex_state = 99 },
    [138] = { .lex_state = 123 },
    [139] = { .lex_state = 99 },
    [140] = { .lex_state = 99 },
    [141] = { .lex_state = 89 },
    [142] = { .lex_state = 99 },
    [143] = { .lex_state = 89 },
    [144] = { .lex_state = 99 },
    [145] = { .lex_state = 99 },
    [146] = { .lex_state = 99 },
    [147] = { .lex_state = 87 },
    [148] = { .lex_state = 99 },
    [149] = { .lex_state = 99 },
    [150] = { .lex_state = 99 },
    [151] = { .lex_state = 99 },
    [152] = { .lex_state = 89 },
    [153] = { .lex_state = 99 },
    [154] = { .lex_state = 99 },
    [155] = { .lex_state = 99 },
    [156] = { .lex_state = 89 },
    [157] = { .lex_state = 99 },
    [158] = { .lex_state = 99 },
    [159] = { .lex_state = 99 },
    [160] = { .lex_state = 99 },
    [161] = { .lex_state = 99 },
    [162] = { .lex_state = 99 },
    [163] = { .lex_state = 99 },
    [164] = { .lex_state = 123 },
    [165] = { .lex_state = 99 },
    [166] = { .lex_state = 99 },
    [167] = { .lex_state = 99 },
    [168] = { .lex_state = 99 },
    [169] = { .lex_state = 99 },
    [170] = { .lex_state = 89 },
    [171] = { .lex_state = 99 },
    [172] = { .lex_state = 99 },
    [173] = { .lex_state = 87 },
    [174] = { .lex_state = 99 },
    [175] = { .lex_state = 99 },
    [176] = { .lex_state = 99 },
    [177] = { .lex_state = 99 },
    [178] = { .lex_state = 99 },
    [179] = { .lex_state = 99 },
    [180] = { .lex_state = 87 },
    [181] = { .lex_state = 99 },
    [182] = { .lex_state = 99 },
    [183] = { .lex_state = 99 },
    [184] = { .lex_state = 99 },
    [185] = { .lex_state = 99 },
    [186] = { .lex_state = 87 },
    [187] = { .lex_state = 87 },
    [188] = { .lex_state = 113 },
    [189] = { .lex_state = 87 },
    [190] = { .lex_state = 87 },
    [191] = { .lex_state = 87 },
    [192] = { .lex_state = 91 },
    [193] = { .lex_state = 87 },
    [194] = { .lex_state = 91 },
    [195] = { .lex_state = 91 },
    [196] = { .lex_state = 87 },
    [197] = { .lex_state = 87 },
    [198] = { .lex_state = 87 },
    [199] = { .lex_state = 87 },
    [200] = { .lex_state = 87 },
    [201] = { .lex_state = 87 },
    [202] = { .lex_state = 87 },
    [203] = { .lex_state = 87 },
    [204] = { .lex_state = 87 },
    [205] = { .lex_state = 87 },
    [206] = { .lex_state = 87 },
    [207] = { .lex_state = 87 },
    [208] = { .lex_state = 87 },
    [209] = { .lex_state = 87 },
    [210] = { .lex_state = 87 },
    [211] = { .lex_state = 87 },
    [212] = { .lex_state = 87 },
    [213] = { .lex_state = 87 },
    [214] = { .lex_state = 87 },
    [215] = { .lex_state = 87 },
    [216] = { .lex_state = 87 },
    [217] = { .lex_state = 87 },
    [218] = { .lex_state = 87 },
    [219] = { .lex_state = 87 },
    [220] = { .lex_state = 91 },
    [221] = { .lex_state = 91 },
    [222] = { .lex_state = 87 },
    [223] = { .lex_state = 87 },
    [224] = { .lex_state = 91 },
    [225] = { .lex_state = 91 },
    [226] = { .lex_state = 87 },
    [227] = { .lex_state = 87 },
    [228] = { .lex_state = 87 },
    [229] = { .lex_state = 91 },
    [230] = { .lex_state = 91 },
    [231] = { .lex_state = 87 },
    [232] = { .lex_state = 87 },
    [233] = { .lex_state = 87 },
    [234] = { .lex_state = 87 },
    [235] = { .lex_state = 87 },
    [236] = { .lex_state = 87 },
    [237] = { .lex_state = 87 },
    [238] = { .lex_state = 87 },
    [239] = { .lex_state = 87 },
    [240] = { .lex_state = 87 },
    [241] = { .lex_state = 87 },
    [242] = { .lex_state = 87 },
    [243] = { .lex_state = 87 },
    [244] = { .lex_state = 91 },
    [245] = { .lex_state = 87 },
    [246] = { .lex_state = 87 },
    [247] = { .lex_state = 87 },
    [248] = { .lex_state = 87 },
    [249] = { .lex_state = 87 },
    [250] = { .lex_state = 87 },
    [251] = { .lex_state = 87 },
    [252] = { .lex_state = 87 },
    [253] = { .lex_state = 87 },
    [254] = { .lex_state = 87 },
    [255] = { .lex_state = 87 },
    [256] = { .lex_state = 87 },
    [257] = { .lex_state = 87 },
    [258] = { .lex_state = 87 },
    [259] = { .lex_state = 87 },
    [260] = { .lex_state = 87 },
    [261] = { .lex_state = 113 },
    [262] = { .lex_state = 87 },
    [263] = { .lex_state = 87 },
    [264] = { .lex_state = 87 },
    [265] = { .lex_state = 87 },
    [266] = { .lex_state = 87 },
    [267] = { .lex_state = 87 },
    [268] = { .lex_state = 87 },
    [269] = { .lex_state = 87 },
    [270] = { .lex_state = 87 },
    [271] = { .lex_state = 87 },
    [272] = { .lex_state = 87 },
    [273] = { .lex_state = 113 },
    [274] = { .lex_state = 87 },
    [275] = { .lex_state = 87 },
    [276] = { .lex_state = 87 },
    [277] = { .lex_state = 87 },
    [278] = { .lex_state = 87 },
    [279] = { .lex_state = 87 },
    [280] = { .lex_state = 87 },
    [281] = { .lex_state = 87 },
    [282] = { .lex_state = 87 },
    [283] = { .lex_state = 87 },
    [284] = { .lex_state = 87 },
    [285] = { .lex_state = 87 },
    [286] = { .lex_state = 87 },
    [287] = { .lex_state = 87 },
    [288] = { .lex_state = 87 },
    [289] = { .lex_state = 87 },
    [290] = { .lex_state = 87 },
    [291] = { .lex_state = 87 },
    [292] = { .lex_state = 87 },
    [293] = { .lex_state = 87 },
    [294] = { .lex_state = 87 },
    [295] = { .lex_state = 113 },
    [296] = { .lex_state = 87 },
    [297] = { .lex_state = 87 },
    [298] = { .lex_state = 87 },
    [299] = { .lex_state = 87 },
    [300] = { .lex_state = 87 },
    [301] = { .lex_state = 87 },
    [302] = { .lex_state = 87 },
    [303] = { .lex_state = 87 },
    [304] = { .lex_state = 87 },
    [305] = { .lex_state = 87 },
    [306] = { .lex_state = 87 },
    [307] = { .lex_state = 87 },
    [308] = { .lex_state = 87 },
    [309] = { .lex_state = 87 },
    [310] = { .lex_state = 87 },
    [311] = { .lex_state = 87 },
    [312] = { .lex_state = 87 },
    [313] = { .lex_state = 87 },
    [314] = { .lex_state = 87 },
    [315] = { .lex_state = 87 },
    [316] = { .lex_state = 87 },
    [317] = { .lex_state = 87 },
    [318] = { .lex_state = 87 },
    [319] = { .lex_state = 87 },
    [320] = { .lex_state = 87 },
    [321] = { .lex_state = 87 },
    [322] = { .lex_state = 87 },
    [323] = { .lex_state = 87 },
    [324] = { .lex_state = 100 },
    [325] = { .lex_state = 87 },
    [326] = { .lex_state = 100 },
    [327] = { .lex_state = 100 },
    [328] = { .lex_state = 100 },
    [329] = { .lex_state = 100 },
    [330] = { .lex_state = 87 },
    [331] = { .lex_state = 100 },
    [332] = { .lex_state = 100 },
    [333] = { .lex_state = 100 },
    [334] = { .lex_state = 100 },
    [335] = { .lex_state = 100 },
    [336] = { .lex_state = 100 },
    [337] = { .lex_state = 100 },
    [338] = { .lex_state = 100 },
    [339] = { .lex_state = 100 },
    [340] = { .lex_state = 100 },
    [341] = { .lex_state = 100 },
    [342] = { .lex_state = 100 },
    [343] = { .lex_state = 100 },
    [344] = { .lex_state = 100 },
    [345] = { .lex_state = 100 },
    [346] = { .lex_state = 100 },
    [347] = { .lex_state = 100 },
    [348] = { .lex_state = 100 },
    [349] = { .lex_state = 100 },
    [350] = { .lex_state = 100 },
    [351] = { .lex_state = 100 },
    [352] = { .lex_state = 87 },
    [353] = { .lex_state = 100 },
    [354] = { .lex_state = 100 },
    [355] = { .lex_state = 100 },
    [356] = { .lex_state = 100 },
    [357] = { .lex_state = 100 },
    [358] = { .lex_state = 100 },
    [359] = { .lex_state = 100 },
    [360] = { .lex_state = 100 },
    [361] = { .lex_state = 100 },
    [362] = { .lex_state = 121 },
    [363] = { .lex_state = 100 },
    [364] = { .lex_state = 100 },
    [365] = { .lex_state = 100 },
    [366] = { .lex_state = 100 },
    [367] = { .lex_state = 100 },
    [368] = { .lex_state = 100 },
    [369] = { .lex_state = 100 },
    [370] = { .lex_state = 100 },
    [371] = { .lex_state = 100 },
    [372] = { .lex_state = 100 },
    [373] = { .lex_state = 100 },
    [374] = { .lex_state = 100 },
    [375] = { .lex_state = 100 },
    [376] = { .lex_state = 100 },
    [377] = { .lex_state = 121 },
    [378] = { .lex_state = 100 },
    [379] = { .lex_state = 100 },
    [380] = { .lex_state = 100 },
    [381] = { .lex_state = 121 },
    [382] = { .lex_state = 100 },
    [383] = { .lex_state = 87 },
    [384] = { .lex_state = 100 },
    [385] = { .lex_state = 100 },
    [386] = { .lex_state = 100 },
    [387] = { .lex_state = 121 },
    [388] = { .lex_state = 100 },
    [389] = { .lex_state = 100 },
    [390] = { .lex_state = 121 },
    [391] = { .lex_state = 100 },
    [392] = { .lex_state = 100 },
    [393] = { .lex_state = 100 },
    [394] = { .lex_state = 100 },
    [395] = { .lex_state = 100 },
    [396] = { .lex_state = 100 },
    [397] = { .lex_state = 100 },
    [398] = { .lex_state = 121 },
    [399] = { .lex_state = 100 },
    [400] = { .lex_state = 100 },
    [401] = { .lex_state = 100 },
    [402] = { .lex_state = 100 },
    [403] = { .lex_state = 100 },
    [404] = { .lex_state = 100 },
    [405] = { .lex_state = 100 },
    [406] = { .lex_state = 100 },
    [407] = { .lex_state = 100 },
    [408] = { .lex_state = 100 },
    [409] = { .lex_state = 100 },
    [410] = { .lex_state = 100 },
    [411] = { .lex_state = 121 },
    [412] = { .lex_state = 100 },
    [413] = { .lex_state = 100 },
    [414] = { .lex_state = 100 },
    [415] = { .lex_state = 100 },
    [416] = { .lex_state = 100 },
    [417] = { .lex_state = 100 },
    [418] = { .lex_state = 100 },
    [419] = { .lex_state = 944 },
    [420] = { .lex_state = 944 },
    [421] = { .lex_state = 944 },
    [422] = { .lex_state = 101 },
    [423] = { .lex_state = 944 },
    [424] = { .lex_state = 944 },
    [425] = { .lex_state = 944 },
    [426] = { .lex_state = 124 },
    [427] = { .lex_state = 944 },
    [428] = { .lex_state = 118 },
    [429] = { .lex_state = 944 },
    [430] = { .lex_state = 944 },
    [431] = { .lex_state = 944 },
    [432] = { .lex_state = 87 },
    [433] = { .lex_state = 101 },
    [434] = { .lex_state = 101 },
    [435] = { .lex_state = 95 },
    [436] = { .lex_state = 101 },
    [437] = { .lex_state = 101 },
    [438] = { .lex_state = 101 },
    [439] = { .lex_state = 101 },
    [440] = { .lex_state = 95 },
    [441] = { .lex_state = 101 },
    [442] = { .lex_state = 101 },
    [443] = { .lex_state = 95 },
    [444] = { .lex_state = 101 },
    [445] = { .lex_state = 86 },
    [446] = { .lex_state = 94 },
    [447] = { .lex_state = 94 },
    [448] = { .lex_state = 101 },
    [449] = { .lex_state = 94 },
    [450] = { .lex_state = 943 },
    [451] = { .lex_state = 101 },
    [452] = { .lex_state = 101 },
    [453] = { .lex_state = 94 },
    [454] = { .lex_state = 101 },
    [455] = { .lex_state = 94 },
    [456] = { .lex_state = 101 },
    [457] = { .lex_state = 101 },
    [458] = { .lex_state = 94 },
    [459] = { .lex_state = 94 },
    [460] = { .lex_state = 94 },
    [461] = { .lex_state = 94 },
    [462] = { .lex_state = 94 },
    [463] = { .lex_state = 94 },
    [464] = { .lex_state = 94 },
    [465] = { .lex_state = 94 },
    [466] = { .lex_state = 87 },
    [467] = { .lex_state = 87 },
    [468] = { .lex_state = 94 },
    [469] = { .lex_state = 101 },
    [470] = { .lex_state = 101 },
    [471] = { .lex_state = 94 },
    [472] = { .lex_state = 94 },
    [473] = { .lex_state = 94 },
    [474] = { .lex_state = 94 },
    [475] = { .lex_state = 101 },
    [476] = { .lex_state = 101 },
    [477] = { .lex_state = 94 },
    [478] = { .lex_state = 101 },
    [479] = { .lex_state = 101 },
    [480] = { .lex_state = 101 },
    [481] = { .lex_state = 101 },
    [482] = { .lex_state = 94 },
    [483] = { .lex_state = 101 },
    [484] = { .lex_state = 101 },
    [485] = { .lex_state = 101 },
    [486] = { .lex_state = 101 },
    [487] = { .lex_state = 94 },
    [488] = { .lex_state = 94 },
    [489] = { .lex_state = 94 },
    [490] = { .lex_state = 94 },
    [491] = { .lex_state = 94 },
    [492] = { .lex_state = 94 },
    [493] = { .lex_state = 94 },
    [494] = { .lex_state = 94 },
    [495] = { .lex_state = 101 },
    [496] = { .lex_state = 101 },
    [497] = { .lex_state = 101 },
    [498] = { .lex_state = 101 },
    [499] = { .lex_state = 101 },
    [500] = { .lex_state = 101 },
    [501] = { .lex_state = 101 },
    [502] = { .lex_state = 101 },
    [503] = { .lex_state = 101 },
    [504] = { .lex_state = 101 },
    [505] = { .lex_state = 101 },
    [506] = { .lex_state = 101 },
    [507] = { .lex_state = 101 },
    [508] = { .lex_state = 101 },
    [509] = { .lex_state = 101 },
    [510] = { .lex_state = 101 },
    [511] = { .lex_state = 101 },
    [512] = { .lex_state = 101 },
    [513] = { .lex_state = 101 },
    [514] = { .lex_state = 101 },
    [515] = { .lex_state = 101 },
    [516] = { .lex_state = 101 },
    [517] = { .lex_state = 101 },
    [518] = { .lex_state = 101 },
    [519] = { .lex_state = 101 },
    [520] = { .lex_state = 101 },
    [521] = { .lex_state = 101 },
    [522] = { .lex_state = 101 },
    [523] = { .lex_state = 101 },
    [524] = { .lex_state = 101 },
    [525] = { .lex_state = 101 },
    [526] = { .lex_state = 101 },
    [527] = { .lex_state = 101 },
    [528] = { .lex_state = 101 },
    [529] = { .lex_state = 101 },
    [530] = { .lex_state = 101 },
    [531] = { .lex_state = 101 },
    [532] = { .lex_state = 101 },
    [533] = { .lex_state = 101 },
    [534] = { .lex_state = 101 },
    [535] = { .lex_state = 101 },
    [536] = { .lex_state = 101 },
    [537] = { .lex_state = 101 },
    [538] = { .lex_state = 101 },
    [539] = { .lex_state = 101 },
    [540] = { .lex_state = 101 },
    [541] = { .lex_state = 101 },
    [542] = { .lex_state = 101 },
    [543] = { .lex_state = 101 },
    [544] = { .lex_state = 101 },
    [545] = { .lex_state = 101 },
    [546] = { .lex_state = 101 },
    [547] = { .lex_state = 101 },
    [548] = { .lex_state = 101 },
    [549] = { .lex_state = 101 },
    [550] = { .lex_state = 101 },
    [551] = { .lex_state = 101 },
    [552] = { .lex_state = 943 },
    [553] = { .lex_state = 94 },
    [554] = { .lex_state = 94 },
    [555] = { .lex_state = 943 },
    [556] = { .lex_state = 101 },
    [557] = { .lex_state = 943 },
    [558] = { .lex_state = 943 },
    [559] = { .lex_state = 943 },
    [560] = { .lex_state = 943 },
    [561] = { .lex_state = 943 },
    [562] = { .lex_state = 101 },
    [563] = { .lex_state = 94 },
    [564] = { .lex_state = 94 },
    [565] = { .lex_state = 95 },
    [566] = { .lex_state = 101 },
    [567] = { .lex_state = 101 },
    [568] = { .lex_state = 101 },
    [569] = { .lex_state = 98 },
    [570] = { .lex_state = 101 },
    [571] = { .lex_state = 101 },
    [572] = { .lex_state = 101 },
    [573] = { .lex_state = 92 },
    [574] = { .lex_state = 92 },
    [575] = { .lex_state = 96 },
    [576] = { .lex_state = 101 },
    [577] = { .lex_state = 101 },
    [578] = { .lex_state = 98 },
    [579] = { .lex_state = 96 },
    [580] = { .lex_state = 96 },
    [581] = { .lex_state = 98 },
    [582] = { .lex_state = 943 },
    [583] = { .lex_state = 96 },
    [584] = { .lex_state = 943 },
    [585] = { .lex_state = 95 },
    [586] = { .lex_state = 98 },
    [587] = { .lex_state = 109 },
    [588] = { .lex_state = 98 },
    [589] = { .lex_state = 98 },
    [590] = { .lex_state = 98 },
    [591] = { .lex_state = 94 },
    [592] = { .lex_state = 94 },
    [593] = { .lex_state = 95 },
    [594] = { .lex_state = 95 },
    [595] = { .lex_state = 96 },
    [596] = { .lex_state = 98 },
    [597] = { .lex_state = 95 },
    [598] = { .lex_state = 95 },
    [599] = { .lex_state = 98 },
    [600] = { .lex_state = 59 },
    [601] = { .lex_state = 943 },
    [602] = { .lex_state = 59 },
    [603] = { .lex_state = 95 },
    [604] = { .lex_state = 59 },
    [605] = { .lex_state = 59 },
    [606] = { .lex_state = 95 },
    [607] = { .lex_state = 98 },
    [608] = { .lex_state = 119 },
    [609] = { .lex_state = 59 },
    [610] = { .lex_state = 94 },
    [611] = { .lex_state = 86 },
    [612] = { .lex_state = 95 },
    [613] = { .lex_state = 95 },
    [614] = { .lex_state = 98 },
    [615] = { .lex_state = 94 },
    [616] = { .lex_state = 94 },
    [617] = { .lex_state = 95 },
    [618] = { .lex_state = 59 },
    [619] = { .lex_state = 95 },
    [620] = { .lex_state = 59 },
    [621] = { .lex_state = 59 },
    [622] = { .lex_state = 95 },
    [623] = { .lex_state = 59 },
    [624] = { .lex_state = 59 },
    [625] = { .lex_state = 95 },
    [626] = { .lex_state = 59 },
    [627] = { .lex_state = 92 },
    [628] = { .lex_state = 98 },
    [629] = { .lex_state = 92 },
    [630] = { .lex_state = 86 },
    [631] = { .lex_state = 86 },
    [632] = { .lex_state = 95 },
    [633] = { .lex_state = 98 },
    [634] = { .lex_state = 95 },
    [635] = { .lex_state = 98 },
    [636] = { .lex_state = 92 },
    [637] = { .lex_state = 95 },
    [638] = { .lex_state = 92 },
    [639] = { .lex_state = 95 },
    [640] = { .lex_state = 92 },
    [641] = { .lex_state = 92 },
    [642] = { .lex_state = 94 },
    [643] = { .lex_state = 92 },
    [644] = { .lex_state = 59 },
    [645] = { .lex_state = 92 },
    [646] = { .lex_state = 59 },
    [647] = { .lex_state = 86 },
    [648] = { .lex_state = 95 },
    [649] = { .lex_state = 98 },
    [650] = { .lex_state = 92 },
    [651] = { .lex_state = 125 },
    [652] = { .lex_state = 59 },
    [653] = { .lex_state = 95 },
    [654] = { .lex_state = 92 },
    [655] = { .lex_state = 59 },
    [656] = { .lex_state = 120 },
    [657] = { .lex_state = 95 },
    [658] = { .lex_state = 95 },
    [659] = { .lex_state = 95 },
    [660] = { .lex_state = 95 },
    [661] = { .lex_state = 95 },
    [662] = { .lex_state = 92 },
    [663] = { .lex_state = 95 },
    [664] = { .lex_state = 92 },
    [665] = { .lex_state = 96 },
    [666] = { .lex_state = 120 },
    [667] = { .lex_state = 86 },
    [668] = { .lex_state = 92 },
    [669] = { .lex_state = 95 },
    [670] = { .lex_state = 92 },
    [671] = { .lex_state = 98 },
    [672] = { .lex_state = 66 },
    [673] = { .lex_state = 98 },
    [674] = { .lex_state = 98 },
    [675] = { .lex_state = 98 },
    [676] = { .lex_state = 94 },
    [677] = { .lex_state = 98 },
    [678] = { .lex_state = 98 },
    [679] = { .lex_state = 98 },
    [680] = { .lex_state = 98 },
    [681] = { .lex_state = 98 },
    [682] = { .lex_state = 98 },
    [683] = { .lex_state = 95 },
    [684] = { .lex_state = 94 },
    [685] = { .lex_state = 94 },
    [686] = { .lex_state = 86 },
    [687] = { .lex_state = 95 },
    [688] = { .lex_state = 95 },
    [689] = { .lex_state = 102 },
    [690] = { .lex_state = 98 },
    [691] = { .lex_state = 98 },
    [692] = { .lex_state = 98 },
    [693] = { .lex_state = 92 },
    [694] = { .lex_state = 98 },
    [695] = { .lex_state = 98 },
    [696] = { .lex_state = 86 },
    [697] = { .lex_state = 95 },
    [698] = { .lex_state = 95 },
    [699] = { .lex_state = 95 },
    [700] = { .lex_state = 86 },
    [701] = { .lex_state = 66 },
    [702] = { .lex_state = 68 },
    [703] = { .lex_state = 68 },
    [704] = { .lex_state = 943 },
    [705] = { .lex_state = 95 },
    [706] = { .lex_state = 95 },
    [707] = { .lex_state = 86 },
    [708] = { .lex_state = 66 },
    [709] = { .lex_state = 66 },
    [710] = { .lex_state = 95 },
    [711] = { .lex_state = 59 },
    [712] = { .lex_state = 59 },
    [713] = { .lex_state = 59 },
    [714] = { .lex_state = 59 },
    [715] = { .lex_state = 95 },
    [716] = { .lex_state = 59 },
    [717] = { .lex_state = 59 },
    [718] = { .lex_state = 59 },
    [719] = { .lex_state = 59 },
    [720] = { .lex_state = 59 },
    [721] = { .lex_state = 59 },
    [722] = { .lex_state = 59 },
    [723] = { .lex_state = 95 },
    [724] = { .lex_state = 59 },
    [725] = { .lex_state = 59 },
    [726] = { .lex_state = 86 },
    [727] = { .lex_state = 95 },
    [728] = { .lex_state = 59 },
    [729] = { .lex_state = 59 },
    [730] = { .lex_state = 95 },
    [731] = { .lex_state = 86 },
    [732] = { .lex_state = 86 },
    [733] = { .lex_state = 66 },
    [734] = { .lex_state = 95 },
    [735] = { .lex_state = 943 },
    [736] = { .lex_state = 92 },
    [737] = { .lex_state = 95 },
    [738] = { .lex_state = 86 },
    [739] = { .lex_state = 95 },
    [740] = { .lex_state = 95 },
    [741] = { .lex_state = 95 },
    [742] = { .lex_state = 943 },
    [743] = { .lex_state = 943 },
    [744] = { .lex_state = 95 },
    [745] = { .lex_state = 943 },
    [746] = { .lex_state = 95 },
    [747] = { .lex_state = 95 },
    [748] = { .lex_state = 86 },
    [749] = { .lex_state = 66 },
    [750] = { .lex_state = 68 },
    [751] = { .lex_state = 95 },
    [752] = { .lex_state = 95 },
    [753] = { .lex_state = 95 },
    [754] = { .lex_state = 95 },
    [755] = { .lex_state = 95 },
    [756] = { .lex_state = 95 },
    [757] = { .lex_state = 66 },
    [758] = { .lex_state = 92 },
    [759] = { .lex_state = 92 },
    [760] = { .lex_state = 94 },
    [761] = { .lex_state = 95 },
    [762] = { .lex_state = 92 },
    [763] = { .lex_state = 95 },
    [764] = { .lex_state = 92 },
    [765] = { .lex_state = 95 },
    [766] = { .lex_state = 126 },
    [767] = { .lex_state = 86 },
    [768] = { .lex_state = 95 },
    [769] = { .lex_state = 94 },
    [770] = { .lex_state = 95 },
    [771] = { .lex_state = 95 },
    [772] = { .lex_state = 86 },
    [773] = { .lex_state = 86 },
    [774] = { .lex_state = 95 },
    [775] = { .lex_state = 95 },
    [776] = { .lex_state = 95 },
    [777] = { .lex_state = 92 },
    [778] = { .lex_state = 92 },
    [779] = { .lex_state = 92 },
    [780] = { .lex_state = 92 },
    [781] = { .lex_state = 92 },
    [782] = { .lex_state = 92 },
    [783] = { .lex_state = 92 },
    [784] = { .lex_state = 95 },
    [785] = { .lex_state = 86 },
    [786] = { .lex_state = 98 },
    [787] = { .lex_state = 943 },
    [788] = { .lex_state = 95 },
    [789] = { .lex_state = 95 },
    [790] = { .lex_state = 95 },
    [791] = { .lex_state = 943 },
    [792] = { .lex_state = 86 },
    [793] = { .lex_state = 89 },
    [794] = { .lex_state = 943 },
    [795] = { .lex_state = 86 },
    [796] = { .lex_state = 86 },
    [797] = { .lex_state = 95 },
    [798] = { .lex_state = 86 },
    [799] = { .lex_state = 89 },
    [800] = { .lex_state = 98 },
    [801] = { .lex_state = 943 },
    [802] = { .lex_state = 98 },
    [803] = { .lex_state = 943 },
    [804] = { .lex_state = 943 },
    [805] = { .lex_state = 98 },
    [806] = { .lex_state = 98 },
    [807] = { .lex_state = 95 },
    [808] = { .lex_state = 943 },
    [809] = { .lex_state = 98 },
    [810] = { .lex_state = 943 },
    [811] = { .lex_state = 943 },
    [812] = { .lex_state = 102 },
    [813] = { .lex_state = 943 },
    [814] = { .lex_state = 95 },
    [815] = { .lex_state = 86 },
    [816] = { .lex_state = 86 },
    [817] = { .lex_state = 943 },
    [818] = { .lex_state = 94 },
    [819] = { .lex_state = 102 },
    [820] = { .lex_state = 86 },
    [821] = { .lex_state = 943 },
    [822] = { .lex_state = 127 },
    [823] = { .lex_state = 943 },
    [824] = { .lex_state = 98 },
    [825] = { .lex_state = 943 },
    [826] = { .lex_state = 89 },
    [827] = { .lex_state = 943 },
    [828] = { .lex_state = 95 },
    [829] = { .lex_state = 86 },
    [830] = { .lex_state = 943 },
    [831] = { .lex_state = 86 },
    [832] = { .lex_state = 943 },
    [833] = { .lex_state = 66 },
    [834] = { .lex_state = 943 },
    [835] = { .lex_state = 943 },
    [836] = { .lex_state = 68 },
    [837] = { .lex_state = 86 },
    [838] = { .lex_state = 95 },
    [839] = { .lex_state = 86 },
    [840] = { .lex_state = 95 },
    [841] = { .lex_state = 943 },
    [842] = { .lex_state = 86 },
    [843] = { .lex_state = 89 },
    [844] = { .lex_state = 102 },
    [845] = { .lex_state = 943 },
    [846] = { .lex_state = 86 },
    [847] = { .lex_state = 98 },
    [848] = { .lex_state = 943 },
    [849] = { .lex_state = 98 },
    [850] = { .lex_state = 98 },
    [851] = { .lex_state = 95 },
    [852] = { .lex_state = 98 },
    [853] = { .lex_state = 943 },
    [854] = { .lex_state = 98 },
    [855] = { .lex_state = 98 },
    [856] = { .lex_state = 943 },
    [857] = { .lex_state = 98 },
    [858] = { .lex_state = 98 },
    [859] = { .lex_state = 95 },
    [860] = { .lex_state = 98 },
    [861] = { .lex_state = 943 },
    [862] = { .lex_state = 98 },
    [863] = { .lex_state = 98 },
    [864] = { .lex_state = 95 },
    [865] = { .lex_state = 98 },
    [866] = { .lex_state = 943 },
    [867] = { .lex_state = 943 },
    [868] = { .lex_state = 95 },
    [869] = { .lex_state = 943 },
    [870] = { .lex_state = 68 },
    [871] = { .lex_state = 68 },
    [872] = { .lex_state = 943 },
    [873] = { .lex_state = 943 },
    [874] = { .lex_state = 98 },
    [875] = { .lex_state = 943 },
    [876] = { .lex_state = 943 },
    [877] = { .lex_state = 943 },
    [878] = { .lex_state = 98 },
    [879] = { .lex_state = 98 },
    [880] = { .lex_state = 98 },
    [881] = { .lex_state = 86 },
    [882] = { .lex_state = 98 },
    [883] = { .lex_state = 95 },
    [884] = { .lex_state = 98 },
    [885] = { .lex_state = 943 },
    [886] = { .lex_state = 943 },
    [887] = { .lex_state = 98 },
    [888] = { .lex_state = 943 },
    [889] = { .lex_state = 943 },
    [890] = { .lex_state = 95 },
    [891] = { .lex_state = 98 },
    [892] = { .lex_state = 98 },
    [893] = { .lex_state = 86 },
    [894] = { .lex_state = 943 },
    [895] = { .lex_state = 86 },
    [896] = { .lex_state = 943 },
    [897] = { .lex_state = 98 },
    [898] = { .lex_state = 98 },
    [899] = { .lex_state = 98 },
    [900] = { .lex_state = 943 },
    [901] = { .lex_state = 943 },
    [902] = { .lex_state = 943 },
    [903] = { .lex_state = 943 },
    [904] = { .lex_state = 98 },
    [905] = { .lex_state = 98 },
    [906] = { .lex_state = 943 },
    [907] = { .lex_state = 98 },
    [908] = { .lex_state = 943 },
    [909] = { .lex_state = 98 },
    [910] = { .lex_state = 98 },
    [911] = { .lex_state = 98 },
    [912] = { .lex_state = 98 },
    [913] = { .lex_state = 943 },
    [914] = { .lex_state = 95 },
    [915] = { .lex_state = 943 },
    [916] = { .lex_state = 943 },
    [917] = { .lex_state = 943 },
    [918] = { .lex_state = 86 },
    [919] = { .lex_state = 98 },
    [920] = { .lex_state = 98 },
    [921] = { .lex_state = 102 },
    [922] = { .lex_state = 943 },
    [923] = { .lex_state = 98 },
    [924] = { .lex_state = 943 },
    [925] = { .lex_state = 943 },
    [926] = { .lex_state = 943 },
    [927] = { .lex_state = 98 },
    [928] = { .lex_state = 95 },
    [929] = { .lex_state = 98 },
    [930] = { .lex_state = 102 },
    [931] = { .lex_state = 943 },
    [932] = { .lex_state = 943 },
    [933] = { .lex_state = 943 },
    [934] = { .lex_state = 943 },
    [935] = { .lex_state = 943 },
    [936] = { .lex_state = 943 },
    [937] = { .lex_state = 98 },
    [938] = { .lex_state = 98 },
    [939] = { .lex_state = 943 },
    [940] = { .lex_state = 98 },
    [941] = { .lex_state = 95 },
    [942] = { .lex_state = 102 },
    [943] = { .lex_state = 943 },
    [944] = { .lex_state = 943 },
    [945] = { .lex_state = 98 },
    [946] = { .lex_state = 95 },
    [947] = { .lex_state = 98 },
    [948] = { .lex_state = 98 },
    [949] = { .lex_state = 943 },
    [950] = { .lex_state = 98 },
    [951] = { .lex_state = 86 },
    [952] = { .lex_state = 102 },
    [953] = { .lex_state = 943 },
    [954] = { .lex_state = 95 },
    [955] = { .lex_state = 98 },
    [956] = { .lex_state = 86 },
    [957] = { .lex_state = 102 },
    [958] = { .lex_state = 943 },
    [959] = { .lex_state = 59 },
    [960] = { .lex_state = 59 },
    [961] = { .lex_state = 943 },
    [962] = { .lex_state = 943 },
    [963] = { .lex_state = 59 },
    [964] = { .lex_state = 59 },
    [965] = { .lex_state = 59 },
    [966] = { .lex_state = 95 },
    [967] = { .lex_state = 102 },
    [968] = { .lex_state = 59 },
    [969] = { .lex_state = 943 },
    [970] = { .lex_state = 102 },
    [971] = { .lex_state = 95 },
    [972] = { .lex_state = 943 },
    [973] = { .lex_state = 98 },
    [974] = { .lex_state = 943 },
    [975] = { .lex_state = 95 },
    [976] = { .lex_state = 86 },
    [977] = { .lex_state = 943 },
    [978] = { .lex_state = 59 },
    [979] = { .lex_state = 943 },
    [980] = { .lex_state = 59 },
    [981] = { .lex_state = 98 },
    [982] = { .lex_state = 59 },
    [983] = { .lex_state = 95 },
    [984] = { .lex_state = 86 },
    [985] = { .lex_state = 59 },
    [986] = { .lex_state = 943 },
    [987] = { .lex_state = 98 },
    [988] = { .lex_state = 98 },
    [989] = { .lex_state = 59 },
    [990] = { .lex_state = 86 },
    [991] = { .lex_state = 59 },
    [992] = { .lex_state = 59 },
    [993] = { .lex_state = 943 },
    [994] = { .lex_state = 59 },
    [995] = { .lex_state = 59 },
    [996] = { .lex_state = 86 },
    [997] = { .lex_state = 59 },
    [998] = { .lex_state = 59 },
    [999] = { .lex_state = 59 },
    [1000] = { .lex_state = 59 },
    [1001] = { .lex_state = 59 },
    [1002] = { .lex_state = 59 },
    [1003] = { .lex_state = 59 },
    [1004] = { .lex_state = 59 },
    [1005] = { .lex_state = 59 },
    [1006] = { .lex_state = 59 },
    [1007] = { .lex_state = 59 },
    [1008] = { .lex_state = 59 },
    [1009] = { .lex_state = 59 },
    [1010] = { .lex_state = 59 },
    [1011] = { .lex_state = 59 },
    [1012] = { .lex_state = 59 },
    [1013] = { .lex_state = 59 },
    [1014] = { .lex_state = 59 },
    [1015] = { .lex_state = 59 },
    [1016] = { .lex_state = 59 },
    [1017] = { .lex_state = 59 },
    [1018] = { .lex_state = 59 },
    [1019] = { .lex_state = 59 },
    [1020] = { .lex_state = 59 },
    [1021] = { .lex_state = 59 },
    [1022] = { .lex_state = 59 },
    [1023] = { .lex_state = 59 },
    [1024] = { .lex_state = 59 },
    [1025] = { .lex_state = 59 },
    [1026] = { .lex_state = 59 },
    [1027] = { .lex_state = 59 },
    [1028] = { .lex_state = 59 },
    [1029] = { .lex_state = 59 },
    [1030] = { .lex_state = 59 },
    [1031] = { .lex_state = 59 },
    [1032] = { .lex_state = 59 },
    [1033] = { .lex_state = 59 },
    [1034] = { .lex_state = 59 },
    [1035] = { .lex_state = 59 },
    [1036] = { .lex_state = 59 },
    [1037] = { .lex_state = 943 },
    [1038] = { .lex_state = 95 },
    [1039] = { .lex_state = 89 },
    [1040] = { .lex_state = 86 },
    [1041] = { .lex_state = 86 },
    [1042] = { .lex_state = 95 },
    [1043] = { .lex_state = 86 },
    [1044] = { .lex_state = 86 },
    [1045] = { .lex_state = 102 },
    [1046] = { .lex_state = 86 },
    [1047] = { .lex_state = 102 },
    [1048] = { .lex_state = 102 },
    [1049] = { .lex_state = 86 },
    [1050] = { .lex_state = 86 },
    [1051] = { .lex_state = 86 },
    [1052] = { .lex_state = 943 },
    [1053] = { .lex_state = 86 },
    [1054] = { .lex_state = 86 },
    [1055] = { .lex_state = 86 },
    [1056] = { .lex_state = 943 },
    [1057] = { .lex_state = 943 },
    [1058] = { .lex_state = 943 },
    [1059] = { .lex_state = 86 },
    [1060] = { .lex_state = 86 },
    [1061] = { .lex_state = 943 },
    [1062] = { .lex_state = 86 },
    [1063] = { .lex_state = 943 },
    [1064] = { .lex_state = 102 },
    [1065] = { .lex_state = 102 },
    [1066] = { .lex_state = 86 },
    [1067] = { .lex_state = 102 },
    [1068] = { .lex_state = 95 },
    [1069] = { .lex_state = 95 },
    [1070] = { .lex_state = 102 },
    [1071] = { .lex_state = 95 },
    [1072] = { .lex_state = 86 },
    [1073] = { .lex_state = 943 },
    [1074] = { .lex_state = 943 },
    [1075] = { .lex_state = 86 },
    [1076] = { .lex_state = 943 },
    [1077] = { .lex_state = 943 },
    [1078] = { .lex_state = 86 },
    [1079] = { .lex_state = 95 },
    [1080] = { .lex_state = 943 },
    [1081] = { .lex_state = 943 },
    [1082] = { .lex_state = 95 },
    [1083] = { .lex_state = 95 },
    [1084] = { .lex_state = 943 },
    [1085] = { .lex_state = 94 },
    [1086] = { .lex_state = 943 },
    [1087] = { .lex_state = 102 },
    [1088] = { .lex_state = 102 },
    [1089] = { .lex_state = 86 },
    [1090] = { .lex_state = 86 },
    [1091] = { .lex_state = 943 },
    [1092] = { .lex_state = 943 },
    [1093] = { .lex_state = 92 },
    [1094] = { .lex_state = 95 },
    [1095] = { .lex_state = 943 },
    [1096] = { .lex_state = 943 },
    [1097] = { .lex_state = 943 },
    [1098] = { .lex_state = 943 },
    [1099] = { .lex_state = 943 },
    [1100] = { .lex_state = 86 },
    [1101] = { .lex_state = 943 },
    [1102] = { .lex_state = 943 },
    [1103] = { .lex_state = 943 },
    [1104] = { .lex_state = 95 },
    [1105] = { .lex_state = 943 },
    [1106] = { .lex_state = 94 },
    [1107] = { .lex_state = 95 },
    [1108] = { .lex_state = 86 },
    [1109] = { .lex_state = 86 },
    [1110] = { .lex_state = 86 },
    [1111] = { .lex_state = 86 },
    [1112] = { .lex_state = 943 },
    [1113] = { .lex_state = 86 },
    [1114] = { .lex_state = 95 },
    [1115] = { .lex_state = 102 },
    [1116] = { .lex_state = 943 },
    [1117] = { .lex_state = 943 },
    [1118] = { .lex_state = 94 },
    [1119] = { .lex_state = 86 },
    [1120] = { .lex_state = 86 },
    [1121] = { .lex_state = 94 },
    [1122] = { .lex_state = 86 },
    [1123] = { .lex_state = 943 },
    [1124] = { .lex_state = 102 },
    [1125] = { .lex_state = 86 },
    [1126] = { .lex_state = 102 },
    [1127] = { .lex_state = 943 },
    [1128] = { .lex_state = 95 },
    [1129] = { .lex_state = 86 },
    [1130] = { .lex_state = 86 },
    [1131] = { .lex_state = 943 },
    [1132] = { .lex_state = 95 },
    [1133] = { .lex_state = 102 },
    [1134] = { .lex_state = 943 },
    [1135] = { .lex_state = 95 },
    [1136] = { .lex_state = 95 },
    [1137] = { .lex_state = 95 },
    [1138] = { .lex_state = 943 },
    [1139] = { .lex_state = 943 },
    [1140] = { .lex_state = 102 },
    [1141] = { .lex_state = 102 },
    [1142] = { .lex_state = 86 },
    [1143] = { .lex_state = 86 },
    [1144] = { .lex_state = 86 },
    [1145] = { .lex_state = 86 },
    [1146] = { .lex_state = 86 },
    [1147] = { .lex_state = 73 },
    [1148] = { .lex_state = 86 },
    [1149] = { .lex_state = 943 },
    [1150] = { .lex_state = 86 },
    [1151] = { .lex_state = 102 },
    [1152] = { .lex_state = 943 },
    [1153] = { .lex_state = 102 },
    [1154] = { .lex_state = 95 },
    [1155] = { .lex_state = 943 },
    [1156] = { .lex_state = 86 },
    [1157] = { .lex_state = 86 },
    [1158] = { .lex_state = 86 },
    [1159] = { .lex_state = 102 },
    [1160] = { .lex_state = 943 },
    [1161] = { .lex_state = 102 },
    [1162] = { .lex_state = 943 },
    [1163] = { .lex_state = 86 },
    [1164] = { .lex_state = 943 },
    [1165] = { .lex_state = 86 },
    [1166] = { .lex_state = 86 },
    [1167] = { .lex_state = 102 },
    [1168] = { .lex_state = 86 },
    [1169] = { .lex_state = 943 },
    [1170] = { .lex_state = 943 },
    [1171] = { .lex_state = 943 },
    [1172] = { .lex_state = 943 },
    [1173] = { .lex_state = 86 },
    [1174] = { .lex_state = 86 },
    [1175] = { .lex_state = 943 },
    [1176] = { .lex_state = 943 },
    [1177] = { .lex_state = 943 },
    [1178] = { .lex_state = 943 },
    [1179] = { .lex_state = 86 },
    [1180] = { .lex_state = 943 },
    [1181] = { .lex_state = 943 },
    [1182] = { .lex_state = 943 },
    [1183] = { .lex_state = 943 },
    [1184] = { .lex_state = 86 },
    [1185] = { .lex_state = 943 },
    [1186] = { .lex_state = 943 },
    [1187] = { .lex_state = 943 },
    [1188] = { .lex_state = 943 },
    [1189] = { .lex_state = 95 },
    [1190] = { .lex_state = 74 },
    [1191] = { .lex_state = 74 },
    [1192] = { .lex_state = 943 },
    [1193] = { .lex_state = 943 },
    [1194] = { .lex_state = 943 },
    [1195] = { .lex_state = 102 },
    [1196] = { .lex_state = 943 },
    [1197] = { .lex_state = 86 },
    [1198] = { .lex_state = 943 },
    [1199] = { .lex_state = 86 },
    [1200] = { .lex_state = 943 },
    [1201] = { .lex_state = 943 },
    [1202] = { .lex_state = 943 },
    [1203] = { .lex_state = 943 },
    [1204] = { .lex_state = 943 },
    [1205] = { .lex_state = 943 },
    [1206] = { .lex_state = 943 },
    [1207] = { .lex_state = 943 },
    [1208] = { .lex_state = 943 },
    [1209] = { .lex_state = 95 },
    [1210] = { .lex_state = 943 },
    [1211] = { .lex_state = 943 },
    [1212] = { .lex_state = 95 },
    [1213] = { .lex_state = 95 },
    [1214] = { .lex_state = 943 },
    [1215] = { .lex_state = 86 },
    [1216] = { .lex_state = 95 },
    [1217] = { .lex_state = 943 },
    [1218] = { .lex_state = 943 },
    [1219] = { .lex_state = 943 },
    [1220] = { .lex_state = 943 },
    [1221] = { .lex_state = 943 },
    [1222] = { .lex_state = 943 },
    [1223] = { .lex_state = 943 },
    [1224] = { .lex_state = 943 },
    [1225] = { .lex_state = 943 },
    [1226] = { .lex_state = 943 },
    [1227] = { .lex_state = 943 },
    [1228] = { .lex_state = 943 },
    [1229] = { .lex_state = 943 },
    [1230] = { .lex_state = 943 },
    [1231] = { .lex_state = 943 },
    [1232] = { .lex_state = 943 },
    [1233] = { .lex_state = 943 },
    [1234] = { .lex_state = 943 },
    [1235] = { .lex_state = 943 },
    [1236] = { .lex_state = 943 },
    [1237] = { .lex_state = 943 },
    [1238] = { .lex_state = 943 },
    [1239] = { .lex_state = 943 },
    [1240] = { .lex_state = 943 },
    [1241] = { .lex_state = 943 },
    [1242] = { .lex_state = 943 },
    [1243] = { .lex_state = 943 },
    [1244] = { .lex_state = 943 },
    [1245] = { .lex_state = 943 },
    [1246] = { .lex_state = 943 },
    [1247] = { .lex_state = 943 },
    [1248] = { .lex_state = 943 },
    [1249] = { .lex_state = 86 },
    [1250] = { .lex_state = 102 },
    [1251] = { .lex_state = 86 },
    [1252] = { .lex_state = 943 },
    [1253] = { .lex_state = 102 },
    [1254] = { .lex_state = 943 },
    [1255] = { .lex_state = 943 },
    [1256] = { .lex_state = 943 },
    [1257] = { .lex_state = 102 },
    [1258] = { .lex_state = 102 },
    [1259] = { .lex_state = 943 },
    [1260] = { .lex_state = 943 },
    [1261] = { .lex_state = 943 },
    [1262] = { .lex_state = 943 },
    [1263] = { .lex_state = 943 },
    [1264] = { .lex_state = 943 },
    [1265] = { .lex_state = 943 },
    [1266] = { .lex_state = 943 },
    [1267] = { .lex_state = 943 },
    [1268] = { .lex_state = 943 },
    [1269] = { .lex_state = 95 },
    [1270] = { .lex_state = 86 },
    [1271] = { .lex_state = 943 },
    [1272] = { .lex_state = 943 },
    [1273] = { .lex_state = 86 },
    [1274] = { .lex_state = 943 },
    [1275] = { .lex_state = 943 },
    [1276] = { .lex_state = 86 },
    [1277] = { .lex_state = 943 },
    [1278] = { .lex_state = 86 },
    [1279] = { .lex_state = 943 },
    [1280] = { .lex_state = 943 },
    [1281] = { .lex_state = 943 },
    [1282] = { .lex_state = 943 },
    [1283] = { .lex_state = 86 },
    [1284] = { .lex_state = 943 },
    [1285] = { .lex_state = 943 },
    [1286] = { .lex_state = 943 },
    [1287] = { .lex_state = 943 },
    [1288] = { .lex_state = 943 },
    [1289] = { .lex_state = 943 },
    [1290] = { .lex_state = 943 },
    [1291] = { .lex_state = 943 },
    [1292] = { .lex_state = 943 },
    [1293] = { .lex_state = 943 },
    [1294] = { .lex_state = 943 },
    [1295] = { .lex_state = 943 },
    [1296] = { .lex_state = 943 },
    [1297] = { .lex_state = 943 },
    [1298] = { .lex_state = 943 },
    [1299] = { .lex_state = 943 },
    [1300] = { .lex_state = 943 },
    [1301] = { .lex_state = 943 },
    [1302] = { .lex_state = 943 },
    [1303] = { .lex_state = 943 },
    [1304] = { .lex_state = 943 },
    [1305] = { .lex_state = 943 },
    [1306] = { .lex_state = 943 },
    [1307] = { .lex_state = 943 },
    [1308] = { .lex_state = 86 },
    [1309] = { .lex_state = 86 },
    [1310] = { .lex_state = 943 },
    [1311] = { .lex_state = 943 },
    [1312] = { .lex_state = 943 },
    [1313] = { .lex_state = 943 },
    [1314] = { .lex_state = 943 },
    [1315] = { .lex_state = 943 },
    [1316] = { .lex_state = 943 },
    [1317] = { .lex_state = 943 },
    [1318] = { .lex_state = 943 },
    [1319] = { .lex_state = 943 },
    [1320] = { .lex_state = 943 },
    [1321] = { .lex_state = 943 },
    [1322] = { .lex_state = 943 },
    [1323] = { .lex_state = 943 },
    [1324] = { .lex_state = 943 },
    [1325] = { .lex_state = 943 },
    [1326] = { .lex_state = 943 },
    [1327] = { .lex_state = 86 },
    [1328] = { .lex_state = 86 },
    [1329] = { .lex_state = 943 },
    [1330] = { .lex_state = 86 },
    [1331] = { .lex_state = 943 },
    [1332] = { .lex_state = 86 },
    [1333] = { .lex_state = 943 },
    [1334] = { .lex_state = 943 },
    [1335] = { .lex_state = 943 },
    [1336] = { .lex_state = 102 },
    [1337] = { .lex_state = 943 },
    [1338] = { .lex_state = 943 },
    [1339] = { .lex_state = 943 },
    [1340] = { .lex_state = 943 },
    [1341] = { .lex_state = 943 },
    [1342] = { .lex_state = 943 },
    [1343] = { .lex_state = 943 },
    [1344] = { .lex_state = 943 },
    [1345] = { .lex_state = 943 },
    [1346] = { .lex_state = 943 },
    [1347] = { .lex_state = 943 },
    [1348] = { .lex_state = 943 },
    [1349] = { .lex_state = 943 },
    [1350] = { .lex_state = 943 },
    [1351] = { .lex_state = 943 },
    [1352] = { .lex_state = 943 },
    [1353] = { .lex_state = 943 },
    [1354] = { .lex_state = 943 },
    [1355] = { .lex_state = 943 },
    [1356] = { .lex_state = 943 },
    [1357] = { .lex_state = 943 },
    [1358] = { .lex_state = 943 },
    [1359] = { .lex_state = 943 },
    [1360] = { .lex_state = 943 },
    [1361] = { .lex_state = 943 },
    [1362] = { .lex_state = 943 },
    [1363] = { .lex_state = 943 },
    [1364] = { .lex_state = 943 },
    [1365] = { .lex_state = 943 },
    [1366] = { .lex_state = 943 },
    [1367] = { .lex_state = 943 },
    [1368] = { .lex_state = 943 },
    [1369] = { .lex_state = 943 },
    [1370] = { .lex_state = 943 },
    [1371] = { .lex_state = 94 },
    [1372] = { .lex_state = 943 },
    [1373] = { .lex_state = 943 },
    [1374] = { .lex_state = 943 },
    [1375] = { .lex_state = 943 },
    [1376] = { .lex_state = 943 },
    [1377] = { .lex_state = 943 },
    [1378] = { .lex_state = 86 },
    [1379] = { .lex_state = 943 },
    [1380] = { .lex_state = 943 },
    [1381] = { .lex_state = 943 },
    [1382] = { .lex_state = 86 },
    [1383] = { .lex_state = 943 },
    [1384] = { .lex_state = 943 },
    [1385] = { .lex_state = 943 },
    [1386] = { .lex_state = 943 },
    [1387] = { .lex_state = 943 },
    [1388] = { .lex_state = 943 },
    [1389] = { .lex_state = 943 },
    [1390] = { .lex_state = 943 },
    [1391] = { .lex_state = 943 },
    [1392] = { .lex_state = 943 },
    [1393] = { .lex_state = 943 },
    [1394] = { .lex_state = 943 },
    [1395] = { .lex_state = 943 },
    [1396] = { .lex_state = 943 },
    [1397] = { .lex_state = 943 },
    [1398] = { .lex_state = 943 },
    [1399] = { .lex_state = 943 },
    [1400] = { .lex_state = 943 },
    [1401] = { .lex_state = 943 },
    [1402] = { .lex_state = 943 },
    [1403] = { .lex_state = 943 },
    [1404] = { .lex_state = 943 },
    [1405] = { .lex_state = 943 },
    [1406] = { .lex_state = 943 },
    [1407] = { .lex_state = 943 },
    [1408] = { .lex_state = 943 },
    [1409] = { .lex_state = 943 },
    [1410] = { .lex_state = 943 },
    [1411] = { .lex_state = 943 },
    [1412] = { .lex_state = 943 },
    [1413] = { .lex_state = 943 },
    [1414] = { .lex_state = 943 },
    [1415] = { .lex_state = 943 },
    [1416] = { .lex_state = 943 },
    [1417] = { .lex_state = 943 },
    [1418] = { .lex_state = 943 },
    [1419] = { .lex_state = 943 },
    [1420] = { .lex_state = 943 },
    [1421] = { .lex_state = 943 },
    [1422] = { .lex_state = 943 },
    [1423] = { .lex_state = 102 },
    [1424] = { .lex_state = 943 },
    [1425] = { .lex_state = 94 },
    [1426] = { .lex_state = 86 },
    [1427] = { .lex_state = 943 },
    [1428] = { .lex_state = 943 },
    [1429] = { .lex_state = 943 },
    [1430] = { .lex_state = 86 },
    [1431] = { .lex_state = 943 },
    [1432] = { .lex_state = 943 },
    [1433] = { .lex_state = 943 },
    [1434] = { .lex_state = 943 },
    [1435] = { .lex_state = 943 },
    [1436] = { .lex_state = 943 },
    [1437] = { .lex_state = 943 },
    [1438] = { .lex_state = 943 },
    [1439] = { .lex_state = 943 },
    [1440] = { .lex_state = 943 },
    [1441] = { .lex_state = 943 },
    [1442] = { .lex_state = 943 },
    [1443] = { .lex_state = 943 },
    [1444] = { .lex_state = 943 },
    [1445] = { .lex_state = 943 },
    [1446] = { .lex_state = 943 },
    [1447] = { .lex_state = 943 },
    [1448] = { .lex_state = 943 },
    [1449] = { .lex_state = 943 },
    [1450] = { .lex_state = 943 },
    [1451] = { .lex_state = 943 },
    [1452] = { .lex_state = 943 },
    [1453] = { .lex_state = 943 },
    [1454] = { .lex_state = 943 },
    [1455] = { .lex_state = 943 },
    [1456] = { .lex_state = 943 },
    [1457] = { .lex_state = 943 },
    [1458] = { .lex_state = 943 },
    [1459] = { .lex_state = 943 },
    [1460] = { .lex_state = 943 },
    [1461] = { .lex_state = 943 },
    [1462] = { .lex_state = 943 },
    [1463] = { .lex_state = 943 },
    [1464] = { .lex_state = 943 },
    [1465] = { .lex_state = 943 },
    [1466] = { .lex_state = 102 },
    [1467] = { .lex_state = 943 },
    [1468] = { .lex_state = 943 },
    [1469] = { .lex_state = 943 },
    [1470] = { .lex_state = 102 },
    [1471] = { .lex_state = 943 },
    [1472] = { .lex_state = 86 },
    [1473] = { .lex_state = 86 },
    [1474] = { .lex_state = 86 },
    [1475] = { .lex_state = 943 },
    [1476] = { .lex_state = 943 },
    [1477] = { .lex_state = 943 },
    [1478] = { .lex_state = 943 },
    [1479] = { .lex_state = 943 },
    [1480] = { .lex_state = 943 },
    [1481] = { .lex_state = 943 },
    [1482] = { .lex_state = 943 },
    [1483] = { .lex_state = 943 },
    [1484] = { .lex_state = 74 },
    [1485] = { .lex_state = 943 },
    [1486] = { .lex_state = 102 },
    [1487] = { .lex_state = 943 },
    [1488] = { .lex_state = 943 },
    [1489] = { .lex_state = 943 },
    [1490] = { .lex_state = 943 },
    [1491] = { .lex_state = 86 },
    [1492] = { .lex_state = 86 },
    [1493] = { .lex_state = 943 },
    [1494] = { .lex_state = 943 },
    [1495] = { .lex_state = 943 },
    [1496] = { .lex_state = 943 },
    [1497] = { .lex_state = 943 },
    [1498] = { .lex_state = 943 },
    [1499] = { .lex_state = 943 },
    [1500] = { .lex_state = 86 },
    [1501] = { .lex_state = 943 },
    [1502] = { .lex_state = 943 },
    [1503] = { .lex_state = 943 },
    [1504] = { .lex_state = 943 },
    [1505] = { .lex_state = 943 },
    [1506] = { .lex_state = 943 },
    [1507] = { .lex_state = 943 },
    [1508] = { .lex_state = 943 },
    [1509] = { .lex_state = 943 },
    [1510] = { .lex_state = 943 },
    [1511] = { .lex_state = 102 },
    [1512] = { .lex_state = 943 },
    [1513] = { .lex_state = 102 },
    [1514] = { .lex_state = 943 },
    [1515] = { .lex_state = 86 },
    [1516] = { .lex_state = 943 },
    [1517] = { .lex_state = 86 },
    [1518] = { .lex_state = 86 },
    [1519] = { .lex_state = 943 },
    [1520] = { .lex_state = 102 },
    [1521] = { .lex_state = 1937 },
    [1522] = { .lex_state = 86 },
    [1523] = { .lex_state = 86 },
    [1524] = { .lex_state = 943 },
    [1525] = { .lex_state = 943 },
    [1526] = { .lex_state = 943 },
    [1527] = { .lex_state = 943 },
    [1528] = { .lex_state = 943 },
    [1529] = { .lex_state = 943 },
    [1530] = { .lex_state = 943 },
    [1531] = { .lex_state = 943 },
    [1532] = { .lex_state = 943 },
    [1533] = { .lex_state = 943 },
    [1534] = { .lex_state = 943 },
    [1535] = { .lex_state = 943 },
    [1536] = { .lex_state = 943 },
    [1537] = { .lex_state = 943 },
    [1538] = { .lex_state = 943 },
    [1539] = { .lex_state = 943 },
    [1540] = { .lex_state = 943 },
    [1541] = { .lex_state = 943 },
    [1542] = { .lex_state = 943 },
    [1543] = { .lex_state = 943 },
    [1544] = { .lex_state = 943 },
    [1545] = { .lex_state = 943 },
    [1546] = { .lex_state = 943 },
    [1547] = { .lex_state = 943 },
    [1548] = { .lex_state = 86 },
    [1549] = { .lex_state = 86 },
    [1550] = { .lex_state = 943 },
    [1551] = { .lex_state = 943 },
    [1552] = { .lex_state = 943 },
    [1553] = { .lex_state = 102 },
    [1554] = { .lex_state = 86 },
    [1555] = { .lex_state = 86 },
    [1556] = { .lex_state = 86 },
    [1557] = { .lex_state = 943 },
    [1558] = { .lex_state = 74 },
    [1559] = { .lex_state = 102 },
    [1560] = { .lex_state = 1075 },
    [1561] = { .lex_state = 74 },
    [1562] = { .lex_state = 943 },
    [1563] = { .lex_state = 943 },
    [1564] = { .lex_state = 943 },
    [1565] = { .lex_state = 943 },
    [1566] = { .lex_state = 943 },
    [1567] = { .lex_state = 943 },
    [1568] = { .lex_state = 943 },
    [1569] = { .lex_state = 943 },
    [1570] = { .lex_state = 943 },
    [1571] = { .lex_state = 943 },
    [1572] = { .lex_state = 943 },
    [1573] = { .lex_state = 943 },
    [1574] = { .lex_state = 943 },
    [1575] = { .lex_state = 943 },
    [1576] = { .lex_state = 943 },
    [1577] = { .lex_state = 943 },
    [1578] = { .lex_state = 943 },
    [1579] = { .lex_state = 943 },
    [1580] = { .lex_state = 86 },
    [1581] = { .lex_state = 943 },
    [1582] = { .lex_state = 943 },
    [1583] = { .lex_state = 943 },
    [1584] = { .lex_state = 943 },
    [1585] = { .lex_state = 86 },
    [1586] = { .lex_state = 943 },
    [1587] = { .lex_state = 943 },
    [1588] = { .lex_state = 943 },
    [1589] = { .lex_state = 943 },
    [1590] = { .lex_state = 86 },
    [1591] = { .lex_state = 86 },
    [1592] = { .lex_state = 86 },
    [1593] = { .lex_state = 86 },
    [1594] = { .lex_state = 943 },
    [1595] = { .lex_state = 943 },
    [1596] = { .lex_state = 943 },
    [1597] = { .lex_state = 943 },
    [1598] = { .lex_state = 86 },
    [1599] = { .lex_state = 86 },
    [1600] = { .lex_state = 86 },
    [1601] = { .lex_state = 86 },
    [1602] = { .lex_state = 86 },
    [1603] = { .lex_state = 943 },
    [1604] = { .lex_state = 943 },
    [1605] = { .lex_state = 943 },
    [1606] = { .lex_state = 86 },
    [1607] = { .lex_state = 86 },
    [1608] = { .lex_state = 86 },
    [1609] = { .lex_state = 943 },
    [1610] = { .lex_state = 943 },
    [1611] = { .lex_state = 95 },
    [1612] = { .lex_state = 86 },
    [1613] = { .lex_state = 943 },
    [1614] = { .lex_state = 86 },
    [1615] = { .lex_state = 1051 },
    [1616] = { .lex_state = 106 },
    [1617] = { .lex_state = 943 },
    [1618] = { .lex_state = 943 },
    [1619] = { .lex_state = 943 },
    [1620] = { .lex_state = 943 },
    [1621] = { .lex_state = 943 },
    [1622] = { .lex_state = 943 },
    [1623] = { .lex_state = 943 },
    [1624] = { .lex_state = 943 },
    [1625] = { .lex_state = 943 },
    [1626] = { .lex_state = 943 },
    [1627] = { .lex_state = 943 },
    [1628] = { .lex_state = 943 },
    [1629] = { .lex_state = 943 },
    [1630] = { .lex_state = 943 },
    [1631] = { .lex_state = 943 },
    [1632] = { .lex_state = 943 },
    [1633] = { .lex_state = 943 },
    [1634] = { .lex_state = 943 },
    [1635] = { .lex_state = 943 },
    [1636] = { .lex_state = 943 },
    [1637] = { .lex_state = 943 },
    [1638] = { .lex_state = 943 },
    [1639] = { .lex_state = 943 },
    [1640] = { .lex_state = 943 },
    [1641] = { .lex_state = 943 },
    [1642] = { .lex_state = 943 },
    [1643] = { .lex_state = 943 },
    [1644] = { .lex_state = 943 },
    [1645] = { .lex_state = 943 },
    [1646] = { .lex_state = 943 },
    [1647] = { .lex_state = 943 },
    [1648] = { .lex_state = 943 },
    [1649] = { .lex_state = 943 },
    [1650] = { .lex_state = 943 },
    [1651] = { .lex_state = 943 },
    [1652] = { .lex_state = 943 },
    [1653] = { .lex_state = 943 },
    [1654] = { .lex_state = 943 },
    [1655] = { .lex_state = 943 },
    [1656] = { .lex_state = 943 },
    [1657] = { .lex_state = 943 },
    [1658] = { .lex_state = 943 },
    [1659] = { .lex_state = 943 },
    [1660] = { .lex_state = 943 },
    [1661] = { .lex_state = 943 },
    [1662] = { .lex_state = 943 },
    [1663] = { .lex_state = 943 },
    [1664] = { .lex_state = 943 },
    [1665] = { .lex_state = 943 },
    [1666] = { .lex_state = 943 },
    [1667] = { .lex_state = 943 },
    [1668] = { .lex_state = 943 },
    [1669] = { .lex_state = 943 },
    [1670] = { .lex_state = 943 },
    [1671] = { .lex_state = 943 },
    [1672] = { .lex_state = 943 },
    [1673] = { .lex_state = 943 },
    [1674] = { .lex_state = 943 },
    [1675] = { .lex_state = 943 },
    [1676] = { .lex_state = 943 },
    [1677] = { .lex_state = 943 },
    [1678] = { .lex_state = 943 },
    [1679] = { .lex_state = 943 },
    [1680] = { .lex_state = 943 },
    [1681] = { .lex_state = 943 },
    [1682] = { .lex_state = 943 },
    [1683] = { .lex_state = 943 },
    [1684] = { .lex_state = 943 },
    [1685] = { .lex_state = 943 },
    [1686] = { .lex_state = 943 },
    [1687] = { .lex_state = 943 },
    [1688] = { .lex_state = 943 },
    [1689] = { .lex_state = 943 },
    [1690] = { .lex_state = 943 },
    [1691] = { .lex_state = 943 },
    [1692] = { .lex_state = 943 },
    [1693] = { .lex_state = 943 },
    [1694] = { .lex_state = 943 },
    [1695] = { .lex_state = 943 },
    [1696] = { .lex_state = 943 },
    [1697] = { .lex_state = 943 },
    [1698] = { .lex_state = 943 },
    [1699] = { .lex_state = 943 },
    [1700] = { .lex_state = 943 },
    [1701] = { .lex_state = 943 },
    [1702] = { .lex_state = 943 },
    [1703] = { (TSStateId)(-1) },
    [1704] = { (TSStateId)(-1) },
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
    [0] = {
        [sym_comment] = STATE(0),
        [ts_builtin_sym_end] = ACTIONS(1),
        [anon_sym_short] = ACTIONS(1),
        [anon_sym_int16] = ACTIONS(1),
        [anon_sym_long] = ACTIONS(1),
        [anon_sym_int32] = ACTIONS(1),
        [anon_sym_longlong] = ACTIONS(1),
        [anon_sym_int64] = ACTIONS(1),
        [sym_unsigned_tiny_int] = ACTIONS(1),
        [sym_boolean_type] = ACTIONS(1),
        [anon_sym_fixed] = ACTIONS(1),
        [sym_octet_type] = ACTIONS(1),
        [sym_signed_tiny_int] = ACTIONS(1),
        [anon_sym_unsignedshort] = ACTIONS(1),
        [anon_sym_uint16] = ACTIONS(1),
        [anon_sym_unsignedlong] = ACTIONS(1),
        [anon_sym_uint32] = ACTIONS(1),
        [anon_sym_unsignedlonglong] = ACTIONS(1),
        [anon_sym_uint64] = ACTIONS(1),
        [anon_sym_float] = ACTIONS(1),
        [anon_sym_double] = ACTIONS(1),
        [anon_sym_longdouble] = ACTIONS(1),
        [sym_char_type] = ACTIONS(1),
        [sym_wide_char_type] = ACTIONS(1),
        [anon_sym_COLON_COLON] = ACTIONS(1),
        [anon_sym_string] = ACTIONS(1),
        [anon_sym_LT] = ACTIONS(1),
        [anon_sym_GT] = ACTIONS(1),
        [anon_sym_wstring] = ACTIONS(1),
        [anon_sym_any] = ACTIONS(1),
        [anon_sym_COMMA] = ACTIONS(1),
        [anon_sym_sequence] = ACTIONS(1),
        [anon_sym_map] = ACTIONS(1),
        [anon_sym_PIPE] = ACTIONS(1),
        [anon_sym_CARET] = ACTIONS(1),
        [anon_sym_AMP] = ACTIONS(1),
        [anon_sym_GT_GT] = ACTIONS(1),
        [anon_sym_PLUS] = ACTIONS(1),
        [anon_sym_DASH] = ACTIONS(1),
        [anon_sym_STAR] = ACTIONS(1),
        [anon_sym_SLASH] = ACTIONS(1),
        [anon_sym_PERCENT] = ACTIONS(1),
        [anon_sym_LPAREN] = ACTIONS(1),
        [anon_sym_RPAREN] = ACTIONS(1),
        [anon_sym_TILDE] = ACTIONS(1),
        [sym_bin_number] = ACTIONS(1),
        [aux_sym_oct_number_token1] = ACTIONS(1),
        [aux_sym_oct_number_token2] = ACTIONS(1),
        [anon_sym_0] = ACTIONS(1),
        [aux_sym_dec_number_token1] = ACTIONS(1),
        [sym_hex_number] = ACTIONS(1),
        [anon_sym_DOT] = ACTIONS(1),
        [aux_sym_floating_pt_literal_token1] = ACTIONS(1),
        [aux_sym_fixed_pt_literal_token1] = ACTIONS(1),
        [anon_sym_DQUOTE] = ACTIONS(1),
        [anon_sym_L] = ACTIONS(1),
        [anon_sym_SQUOTE] = ACTIONS(1),
        [anon_sym_TRUE] = ACTIONS(1),
        [anon_sym_FALSE] = ACTIONS(1),
        [anon_sym_POUNDdefine] = ACTIONS(1),
        [sym_preproc_directive] = ACTIONS(1),
        [aux_sym_preproc_include_token1] = ACTIONS(1),
        [anon_sym_exception] = ACTIONS(1),
        [anon_sym_LBRACE] = ACTIONS(1),
        [anon_sym_RBRACE] = ACTIONS(1),
        [anon_sym_local] = ACTIONS(1),
        [anon_sym_abstract] = ACTIONS(1),
        [anon_sym_COLON] = ACTIONS(1),
        [anon_sym_SEMI] = ACTIONS(1),
        [anon_sym_void] = ACTIONS(1),
        [anon_sym_in] = ACTIONS(1),
        [anon_sym_out] = ACTIONS(1),
        [anon_sym_inout] = ACTIONS(1),
        [anon_sym_raises] = ACTIONS(1),
        [anon_sym_readonly] = ACTIONS(1),
        [anon_sym_attribute] = ACTIONS(1),
        [anon_sym_getraises] = ACTIONS(1),
        [anon_sym_setraises] = ACTIONS(1),
        [anon_sym_bitset] = ACTIONS(1),
        [anon_sym_bitfield] = ACTIONS(1),
        [anon_sym_bitmask] = ACTIONS(1),
        [anon_sym_ATannotation] = ACTIONS(1),
        [anon_sym_default] = ACTIONS(1),
        [anon_sym_AT] = ACTIONS(1),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(1),
        [anon_sym_EQ] = ACTIONS(1),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1),
        [aux_sym_autoid_kind_token1] = ACTIONS(1),
        [aux_sym_autoid_kind_token2] = ACTIONS(1),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1),
        [aux_sym_extensibility_kind_token1] = ACTIONS(1),
        [aux_sym_extensibility_kind_token2] = ACTIONS(1),
        [aux_sym_extensibility_kind_token3] = ACTIONS(1),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1),
        [aux_sym_min_expr_token1] = ACTIONS(1),
        [aux_sym_max_expr_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1),
        [aux_sym_verbatim_language_token1] = ACTIONS(1),
        [aux_sym_verbatim_language_token2] = ACTIONS(1),
        [aux_sym_verbatim_language_token3] = ACTIONS(1),
        [aux_sym_verbatim_language_token4] = ACTIONS(1),
        [aux_sym_placement_kind_token1] = ACTIONS(1),
        [aux_sym_placement_kind_token2] = ACTIONS(1),
        [aux_sym_placement_kind_token3] = ACTIONS(1),
        [aux_sym_placement_kind_token4] = ACTIONS(1),
        [aux_sym_placement_kind_token5] = ACTIONS(1),
        [aux_sym_placement_kind_token6] = ACTIONS(1),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1),
        [aux_sym_service_platform_token1] = ACTIONS(1),
        [aux_sym_service_platform_token2] = ACTIONS(1),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1),
        [anon_sym_hashid] = ACTIONS(1),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1),
        [anon_sym_allowed_kinds] = ACTIONS(1),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1),
        [sym_annotation_appl_choice] = ACTIONS(1),
        [sym_annotation_appl_empty] = ACTIONS(1),
        [sym_annotation_appl_dds_service] = ACTIONS(1),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1),
        [aux_sym_annotation_appl_dds_request_topic_token2] = ACTIONS(1),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1),
        [anon_sym_module] = ACTIONS(1),
        [anon_sym_typename] = ACTIONS(1),
        [anon_sym_valuetype] = ACTIONS(1),
        [anon_sym_eventtype] = ACTIONS(1),
        [anon_sym_struct] = ACTIONS(1),
        [anon_sym_union] = ACTIONS(1),
        [anon_sym_enum] = ACTIONS(1),
        [anon_sym_const] = ACTIONS(1),
        [anon_sym_alias] = ACTIONS(1),
        [anon_sym_custom] = ACTIONS(1),
        [anon_sym_truncatable] = ACTIONS(1),
        [anon_sym_supports] = ACTIONS(1),
        [anon_sym_public] = ACTIONS(1),
        [anon_sym_private] = ACTIONS(1),
        [anon_sym_factory] = ACTIONS(1),
        [anon_sym_typedef] = ACTIONS(1),
        [anon_sym_LBRACK] = ACTIONS(1),
        [anon_sym_RBRACK] = ACTIONS(1),
        [anon_sym_switch] = ACTIONS(1),
        [anon_sym_case] = ACTIONS(1),
        [anon_sym_typeid] = ACTIONS(1),
        [anon_sym_typeprefix] = ACTIONS(1),
        [anon_sym_import] = ACTIONS(1),
        [anon_sym_Object] = ACTIONS(1),
        [anon_sym_oneway] = ACTIONS(1),
        [anon_sym_context] = ACTIONS(1),
        [sym_value_base_type] = ACTIONS(1),
        [anon_sym_component] = ACTIONS(1),
        [anon_sym_provides] = ACTIONS(1),
        [anon_sym_uses] = ACTIONS(1),
        [anon_sym_multiple] = ACTIONS(1),
        [anon_sym_home] = ACTIONS(1),
        [anon_sym_manages] = ACTIONS(1),
        [anon_sym_emits] = ACTIONS(1),
        [anon_sym_publishes] = ACTIONS(1),
        [anon_sym_consumes] = ACTIONS(1),
        [anon_sym_primarykey] = ACTIONS(1),
        [anon_sym_finder] = ACTIONS(1),
        [anon_sym_port] = ACTIONS(1),
        [anon_sym_mirrorport] = ACTIONS(1),
        [anon_sym_connector] = ACTIONS(1),
        [anon_sym_native] = ACTIONS(1),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [1] = {
        [sym_specification] = STATE(1588),
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(1),
        [aux_sym_specification_repeat1] = STATE(29),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [ts_builtin_sym_end] = ACTIONS(7),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [2] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1282),
        [sym_export] = STATE(69),
        [sym_op_dcl] = STATE(1038),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1282),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1282),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_element] = STATE(70),
        [sym_state_member] = STATE(69),
        [sym_init_dcl] = STATE(69),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1282),
        [sym_import_dcl] = STATE(1282),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(1038),
        [sym_op_with_context] = STATE(1282),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1282),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1282),
        [sym_comment] = STATE(2),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_value_def_repeat1] = STATE(3),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(111),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [3] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1282),
        [sym_export] = STATE(69),
        [sym_op_dcl] = STATE(1038),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1282),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1282),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_element] = STATE(70),
        [sym_state_member] = STATE(69),
        [sym_init_dcl] = STATE(69),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1282),
        [sym_import_dcl] = STATE(1282),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(1038),
        [sym_op_with_context] = STATE(1282),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1282),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1282),
        [sym_comment] = STATE(3),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_value_def_repeat1] = STATE(3),
        [anon_sym_short] = ACTIONS(159),
        [anon_sym_int16] = ACTIONS(159),
        [anon_sym_long] = ACTIONS(162),
        [anon_sym_int32] = ACTIONS(162),
        [anon_sym_longlong] = ACTIONS(165),
        [anon_sym_int64] = ACTIONS(168),
        [sym_unsigned_tiny_int] = ACTIONS(171),
        [sym_boolean_type] = ACTIONS(174),
        [anon_sym_fixed] = ACTIONS(177),
        [sym_octet_type] = ACTIONS(174),
        [sym_signed_tiny_int] = ACTIONS(180),
        [anon_sym_unsignedshort] = ACTIONS(183),
        [anon_sym_uint16] = ACTIONS(186),
        [anon_sym_unsignedlong] = ACTIONS(189),
        [anon_sym_uint32] = ACTIONS(189),
        [anon_sym_unsignedlonglong] = ACTIONS(192),
        [anon_sym_uint64] = ACTIONS(195),
        [anon_sym_float] = ACTIONS(198),
        [anon_sym_double] = ACTIONS(198),
        [anon_sym_longdouble] = ACTIONS(201),
        [sym_char_type] = ACTIONS(174),
        [sym_wide_char_type] = ACTIONS(174),
        [anon_sym_COLON_COLON] = ACTIONS(204),
        [anon_sym_string] = ACTIONS(207),
        [anon_sym_wstring] = ACTIONS(210),
        [anon_sym_any] = ACTIONS(213),
        [anon_sym_sequence] = ACTIONS(216),
        [anon_sym_map] = ACTIONS(219),
        [anon_sym_exception] = ACTIONS(222),
        [anon_sym_RBRACE] = ACTIONS(225),
        [anon_sym_abstract] = ACTIONS(227),
        [anon_sym_void] = ACTIONS(230),
        [anon_sym_readonly] = ACTIONS(233),
        [anon_sym_attribute] = ACTIONS(236),
        [anon_sym_bitset] = ACTIONS(239),
        [anon_sym_bitmask] = ACTIONS(242),
        [anon_sym_AT] = ACTIONS(245),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(248),
        [anon_sym_valuetype] = ACTIONS(251),
        [anon_sym_struct] = ACTIONS(254),
        [anon_sym_union] = ACTIONS(257),
        [anon_sym_enum] = ACTIONS(260),
        [anon_sym_const] = ACTIONS(263),
        [anon_sym_custom] = ACTIONS(266),
        [anon_sym_public] = ACTIONS(269),
        [anon_sym_private] = ACTIONS(269),
        [anon_sym_factory] = ACTIONS(272),
        [anon_sym_typedef] = ACTIONS(275),
        [anon_sym_typeid] = ACTIONS(278),
        [anon_sym_import] = ACTIONS(281),
        [anon_sym_Object] = ACTIONS(284),
        [anon_sym_oneway] = ACTIONS(287),
        [sym_value_base_type] = ACTIONS(174),
        [anon_sym_native] = ACTIONS(290),
        [sym_identifier] = ACTIONS(293),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [4] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1282),
        [sym_export] = STATE(69),
        [sym_op_dcl] = STATE(1038),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1282),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1282),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_element] = STATE(70),
        [sym_state_member] = STATE(69),
        [sym_init_dcl] = STATE(69),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1282),
        [sym_import_dcl] = STATE(1282),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(1038),
        [sym_op_with_context] = STATE(1282),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1282),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1282),
        [sym_comment] = STATE(4),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_value_def_repeat1] = STATE(3),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(296),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [5] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1335),
        [sym_export] = STATE(73),
        [sym_op_dcl] = STATE(941),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1335),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1335),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1335),
        [sym_import_dcl] = STATE(1335),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(941),
        [sym_op_with_context] = STATE(1335),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_home_body] = STATE(1172),
        [sym_home_export] = STATE(75),
        [sym_factory_dcl] = STATE(1171),
        [sym_finder_dcl] = STATE(1171),
        [sym_type_dcl] = STATE(1335),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1335),
        [sym_comment] = STATE(5),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_home_body_repeat1] = STATE(9),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(298),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_factory] = ACTIONS(300),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_finder] = ACTIONS(302),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [6] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1282),
        [sym_export] = STATE(69),
        [sym_op_dcl] = STATE(1038),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1282),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1282),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_element] = STATE(70),
        [sym_state_member] = STATE(69),
        [sym_init_dcl] = STATE(69),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1282),
        [sym_import_dcl] = STATE(1282),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(1038),
        [sym_op_with_context] = STATE(1282),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1282),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1282),
        [sym_comment] = STATE(6),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_value_def_repeat1] = STATE(4),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(304),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [7] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1282),
        [sym_export] = STATE(69),
        [sym_op_dcl] = STATE(1038),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1282),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1282),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_element] = STATE(70),
        [sym_state_member] = STATE(69),
        [sym_init_dcl] = STATE(69),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1282),
        [sym_import_dcl] = STATE(1282),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(1038),
        [sym_op_with_context] = STATE(1282),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1282),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1282),
        [sym_comment] = STATE(7),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_value_def_repeat1] = STATE(2),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(306),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_public] = ACTIONS(141),
        [anon_sym_private] = ACTIONS(141),
        [anon_sym_factory] = ACTIONS(143),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [8] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1335),
        [sym_export] = STATE(73),
        [sym_op_dcl] = STATE(941),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1335),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1335),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1335),
        [sym_import_dcl] = STATE(1335),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(941),
        [sym_op_with_context] = STATE(1335),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_home_export] = STATE(75),
        [sym_factory_dcl] = STATE(1171),
        [sym_finder_dcl] = STATE(1171),
        [sym_type_dcl] = STATE(1335),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1335),
        [sym_comment] = STATE(8),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_home_body_repeat1] = STATE(8),
        [anon_sym_short] = ACTIONS(308),
        [anon_sym_int16] = ACTIONS(308),
        [anon_sym_long] = ACTIONS(311),
        [anon_sym_int32] = ACTIONS(311),
        [anon_sym_longlong] = ACTIONS(314),
        [anon_sym_int64] = ACTIONS(317),
        [sym_unsigned_tiny_int] = ACTIONS(320),
        [sym_boolean_type] = ACTIONS(323),
        [anon_sym_fixed] = ACTIONS(326),
        [sym_octet_type] = ACTIONS(323),
        [sym_signed_tiny_int] = ACTIONS(329),
        [anon_sym_unsignedshort] = ACTIONS(332),
        [anon_sym_uint16] = ACTIONS(335),
        [anon_sym_unsignedlong] = ACTIONS(338),
        [anon_sym_uint32] = ACTIONS(338),
        [anon_sym_unsignedlonglong] = ACTIONS(341),
        [anon_sym_uint64] = ACTIONS(344),
        [anon_sym_float] = ACTIONS(347),
        [anon_sym_double] = ACTIONS(347),
        [anon_sym_longdouble] = ACTIONS(350),
        [sym_char_type] = ACTIONS(323),
        [sym_wide_char_type] = ACTIONS(323),
        [anon_sym_COLON_COLON] = ACTIONS(353),
        [anon_sym_string] = ACTIONS(356),
        [anon_sym_wstring] = ACTIONS(359),
        [anon_sym_any] = ACTIONS(362),
        [anon_sym_sequence] = ACTIONS(365),
        [anon_sym_map] = ACTIONS(368),
        [anon_sym_exception] = ACTIONS(371),
        [anon_sym_RBRACE] = ACTIONS(374),
        [anon_sym_abstract] = ACTIONS(376),
        [anon_sym_void] = ACTIONS(379),
        [anon_sym_readonly] = ACTIONS(382),
        [anon_sym_attribute] = ACTIONS(385),
        [anon_sym_bitset] = ACTIONS(388),
        [anon_sym_bitmask] = ACTIONS(391),
        [anon_sym_AT] = ACTIONS(394),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(397),
        [anon_sym_valuetype] = ACTIONS(400),
        [anon_sym_struct] = ACTIONS(403),
        [anon_sym_union] = ACTIONS(406),
        [anon_sym_enum] = ACTIONS(409),
        [anon_sym_const] = ACTIONS(412),
        [anon_sym_custom] = ACTIONS(415),
        [anon_sym_factory] = ACTIONS(418),
        [anon_sym_typedef] = ACTIONS(421),
        [anon_sym_typeid] = ACTIONS(424),
        [anon_sym_import] = ACTIONS(427),
        [anon_sym_Object] = ACTIONS(430),
        [anon_sym_oneway] = ACTIONS(433),
        [sym_value_base_type] = ACTIONS(323),
        [anon_sym_finder] = ACTIONS(436),
        [anon_sym_native] = ACTIONS(439),
        [sym_identifier] = ACTIONS(442),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [9] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1335),
        [sym_export] = STATE(73),
        [sym_op_dcl] = STATE(941),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1335),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1335),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1335),
        [sym_import_dcl] = STATE(1335),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(941),
        [sym_op_with_context] = STATE(1335),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_home_export] = STATE(75),
        [sym_factory_dcl] = STATE(1171),
        [sym_finder_dcl] = STATE(1171),
        [sym_type_dcl] = STATE(1335),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1335),
        [sym_comment] = STATE(9),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_home_body_repeat1] = STATE(8),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(445),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_factory] = ACTIONS(300),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_finder] = ACTIONS(302),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [10] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_interface_body] = STATE(1169),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(10),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(18),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(447),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [11] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(11),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(12),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(449),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [12] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(12),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(451),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [13] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(13),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(453),
        [anon_sym_int16] = ACTIONS(453),
        [anon_sym_long] = ACTIONS(456),
        [anon_sym_int32] = ACTIONS(456),
        [anon_sym_longlong] = ACTIONS(459),
        [anon_sym_int64] = ACTIONS(462),
        [sym_unsigned_tiny_int] = ACTIONS(465),
        [sym_boolean_type] = ACTIONS(468),
        [anon_sym_fixed] = ACTIONS(471),
        [sym_octet_type] = ACTIONS(468),
        [sym_signed_tiny_int] = ACTIONS(474),
        [anon_sym_unsignedshort] = ACTIONS(477),
        [anon_sym_uint16] = ACTIONS(480),
        [anon_sym_unsignedlong] = ACTIONS(483),
        [anon_sym_uint32] = ACTIONS(483),
        [anon_sym_unsignedlonglong] = ACTIONS(486),
        [anon_sym_uint64] = ACTIONS(489),
        [anon_sym_float] = ACTIONS(492),
        [anon_sym_double] = ACTIONS(492),
        [anon_sym_longdouble] = ACTIONS(495),
        [sym_char_type] = ACTIONS(468),
        [sym_wide_char_type] = ACTIONS(468),
        [anon_sym_COLON_COLON] = ACTIONS(498),
        [anon_sym_string] = ACTIONS(501),
        [anon_sym_wstring] = ACTIONS(504),
        [anon_sym_any] = ACTIONS(507),
        [anon_sym_sequence] = ACTIONS(510),
        [anon_sym_map] = ACTIONS(513),
        [anon_sym_exception] = ACTIONS(516),
        [anon_sym_RBRACE] = ACTIONS(519),
        [anon_sym_abstract] = ACTIONS(521),
        [anon_sym_void] = ACTIONS(524),
        [anon_sym_readonly] = ACTIONS(527),
        [anon_sym_attribute] = ACTIONS(530),
        [anon_sym_bitset] = ACTIONS(533),
        [anon_sym_bitmask] = ACTIONS(536),
        [anon_sym_AT] = ACTIONS(539),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(542),
        [anon_sym_valuetype] = ACTIONS(545),
        [anon_sym_struct] = ACTIONS(548),
        [anon_sym_union] = ACTIONS(551),
        [anon_sym_enum] = ACTIONS(554),
        [anon_sym_const] = ACTIONS(557),
        [anon_sym_custom] = ACTIONS(560),
        [anon_sym_typedef] = ACTIONS(563),
        [anon_sym_typeid] = ACTIONS(566),
        [anon_sym_import] = ACTIONS(569),
        [anon_sym_Object] = ACTIONS(572),
        [anon_sym_oneway] = ACTIONS(575),
        [sym_value_base_type] = ACTIONS(468),
        [anon_sym_native] = ACTIONS(578),
        [sym_identifier] = ACTIONS(581),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [14] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(14),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(20),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(451),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [15] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(15),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(17),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(584),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [16] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(16),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(584),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [17] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(17),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(586),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [18] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(18),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(588),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [19] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(19),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(16),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(590),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [20] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_except_dcl] = STATE(1187),
        [sym_export] = STATE(91),
        [sym_op_dcl] = STATE(797),
        [sym_op_type_spec] = STATE(1184),
        [sym_attr_dcl] = STATE(1187),
        [sym_readonly_attr_spec] = STATE(1183),
        [sym_attr_spec] = STATE(1183),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_value_dcl] = STATE(1187),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1187),
        [sym_import_dcl] = STATE(1187),
        [sym_object_type] = STATE(778),
        [sym_op_oneway_dcl] = STATE(797),
        [sym_op_with_context] = STATE(1187),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_type_dcl] = STATE(1187),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1187),
        [sym_comment] = STATE(20),
        [aux_sym_interface_dcl_repeat1] = STATE(33),
        [aux_sym_interface_body_repeat1] = STATE(13),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_exception] = ACTIONS(109),
        [anon_sym_RBRACE] = ACTIONS(592),
        [anon_sym_abstract] = ACTIONS(113),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_valuetype] = ACTIONS(129),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_const] = ACTIONS(137),
        [anon_sym_custom] = ACTIONS(139),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_typeid] = ACTIONS(147),
        [anon_sym_import] = ACTIONS(149),
        [anon_sym_Object] = ACTIONS(151),
        [anon_sym_oneway] = ACTIONS(153),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [21] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(555),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1087),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_const_expr] = STATE(1087),
        [sym_or_expr] = STATE(595),
        [sym_xor_expr] = STATE(580),
        [sym_and_expr] = STATE(579),
        [sym_shift_expr] = STATE(563),
        [sym_add_expr] = STATE(553),
        [sym_mult_expr] = STATE(477),
        [sym_unary_expr] = STATE(482),
        [sym_primary_expr] = STATE(494),
        [sym_unary_operator] = STATE(432),
        [sym_literal] = STATE(489),
        [sym_integer_literal] = STATE(492),
        [sym_integer_sign] = STATE(582),
        [sym_oct_number] = STATE(459),
        [sym_dec_number] = STATE(455),
        [sym_floating_pt_literal] = STATE(492),
        [sym_fixed_pt_literal] = STATE(492),
        [sym_string_literal] = STATE(492),
        [sym_wide_string_literal] = STATE(492),
        [sym_char_literal] = STATE(492),
        [sym_wide_character_literal] = STATE(492),
        [sym_boolean_literal] = STATE(492),
        [sym_actual_parameters] = STATE(1253),
        [sym_actual_parameter] = STATE(930),
        [sym_object_type] = STATE(778),
        [sym_comment] = STATE(21),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(594),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_PLUS] = ACTIONS(596),
        [anon_sym_DASH] = ACTIONS(596),
        [anon_sym_LPAREN] = ACTIONS(598),
        [anon_sym_TILDE] = ACTIONS(600),
        [sym_bin_number] = ACTIONS(602),
        [aux_sym_oct_number_token1] = ACTIONS(604),
        [aux_sym_oct_number_token2] = ACTIONS(604),
        [anon_sym_0] = ACTIONS(606),
        [aux_sym_dec_number_token1] = ACTIONS(608),
        [sym_hex_number] = ACTIONS(602),
        [anon_sym_DQUOTE] = ACTIONS(610),
        [anon_sym_L] = ACTIONS(612),
        [anon_sym_SQUOTE] = ACTIONS(614),
        [anon_sym_TRUE] = ACTIONS(616),
        [anon_sym_FALSE] = ACTIONS(616),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(77),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [22] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_tpl_definition] = STATE(431),
        [sym_template_module_inst] = STATE(1587),
        [sym_template_module_ref] = STATE(1495),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(427),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(22),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [aux_sym_template_module_dcl_repeat1] = STATE(23),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(620),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_alias] = ACTIONS(622),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [23] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_tpl_definition] = STATE(431),
        [sym_template_module_inst] = STATE(1587),
        [sym_template_module_ref] = STATE(1495),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(427),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(23),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [aux_sym_template_module_dcl_repeat1] = STATE(24),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(624),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_alias] = ACTIONS(622),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [24] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_tpl_definition] = STATE(431),
        [sym_template_module_inst] = STATE(1587),
        [sym_template_module_ref] = STATE(1495),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(427),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(24),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [aux_sym_template_module_dcl_repeat1] = STATE(24),
        [anon_sym_POUNDdefine] = ACTIONS(626),
        [sym_preproc_directive] = ACTIONS(629),
        [aux_sym_preproc_include_token1] = ACTIONS(632),
        [anon_sym_exception] = ACTIONS(635),
        [anon_sym_RBRACE] = ACTIONS(638),
        [anon_sym_local] = ACTIONS(640),
        [anon_sym_abstract] = ACTIONS(643),
        [anon_sym_interface] = ACTIONS(646),
        [anon_sym_bitset] = ACTIONS(649),
        [anon_sym_bitmask] = ACTIONS(652),
        [anon_sym_ATannotation] = ACTIONS(655),
        [anon_sym_AT] = ACTIONS(658),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(661),
        [anon_sym_module] = ACTIONS(664),
        [anon_sym_valuetype] = ACTIONS(667),
        [anon_sym_eventtype] = ACTIONS(670),
        [anon_sym_struct] = ACTIONS(673),
        [anon_sym_union] = ACTIONS(676),
        [anon_sym_enum] = ACTIONS(679),
        [anon_sym_const] = ACTIONS(682),
        [anon_sym_alias] = ACTIONS(685),
        [anon_sym_custom] = ACTIONS(688),
        [anon_sym_typedef] = ACTIONS(691),
        [anon_sym_typeid] = ACTIONS(694),
        [anon_sym_typeprefix] = ACTIONS(697),
        [anon_sym_import] = ACTIONS(700),
        [anon_sym_component] = ACTIONS(703),
        [anon_sym_home] = ACTIONS(706),
        [anon_sym_porttype] = ACTIONS(709),
        [anon_sym_connector] = ACTIONS(712),
        [anon_sym_native] = ACTIONS(715),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [25] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(555),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1087),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_const_expr] = STATE(1087),
        [sym_or_expr] = STATE(595),
        [sym_xor_expr] = STATE(580),
        [sym_and_expr] = STATE(579),
        [sym_shift_expr] = STATE(563),
        [sym_add_expr] = STATE(553),
        [sym_mult_expr] = STATE(477),
        [sym_unary_expr] = STATE(482),
        [sym_primary_expr] = STATE(494),
        [sym_unary_operator] = STATE(432),
        [sym_literal] = STATE(489),
        [sym_integer_literal] = STATE(492),
        [sym_integer_sign] = STATE(582),
        [sym_oct_number] = STATE(459),
        [sym_dec_number] = STATE(455),
        [sym_floating_pt_literal] = STATE(492),
        [sym_fixed_pt_literal] = STATE(492),
        [sym_string_literal] = STATE(492),
        [sym_wide_string_literal] = STATE(492),
        [sym_char_literal] = STATE(492),
        [sym_wide_character_literal] = STATE(492),
        [sym_boolean_literal] = STATE(492),
        [sym_actual_parameter] = STATE(1065),
        [sym_object_type] = STATE(778),
        [sym_comment] = STATE(25),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(594),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_PLUS] = ACTIONS(596),
        [anon_sym_DASH] = ACTIONS(596),
        [anon_sym_LPAREN] = ACTIONS(598),
        [anon_sym_TILDE] = ACTIONS(600),
        [sym_bin_number] = ACTIONS(602),
        [aux_sym_oct_number_token1] = ACTIONS(604),
        [aux_sym_oct_number_token2] = ACTIONS(604),
        [anon_sym_0] = ACTIONS(606),
        [aux_sym_dec_number_token1] = ACTIONS(608),
        [sym_hex_number] = ACTIONS(602),
        [anon_sym_DQUOTE] = ACTIONS(610),
        [anon_sym_L] = ACTIONS(612),
        [anon_sym_SQUOTE] = ACTIONS(614),
        [anon_sym_TRUE] = ACTIONS(616),
        [anon_sym_FALSE] = ACTIONS(616),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(77),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [26] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(26),
        [aux_sym_specification_repeat1] = STATE(26),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [ts_builtin_sym_end] = ACTIONS(718),
        [anon_sym_POUNDdefine] = ACTIONS(720),
        [sym_preproc_directive] = ACTIONS(723),
        [aux_sym_preproc_include_token1] = ACTIONS(726),
        [anon_sym_exception] = ACTIONS(729),
        [anon_sym_RBRACE] = ACTIONS(718),
        [anon_sym_local] = ACTIONS(732),
        [anon_sym_abstract] = ACTIONS(735),
        [anon_sym_interface] = ACTIONS(738),
        [anon_sym_bitset] = ACTIONS(741),
        [anon_sym_bitmask] = ACTIONS(744),
        [anon_sym_ATannotation] = ACTIONS(747),
        [anon_sym_AT] = ACTIONS(750),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(753),
        [anon_sym_module] = ACTIONS(756),
        [anon_sym_valuetype] = ACTIONS(759),
        [anon_sym_eventtype] = ACTIONS(762),
        [anon_sym_struct] = ACTIONS(765),
        [anon_sym_union] = ACTIONS(768),
        [anon_sym_enum] = ACTIONS(771),
        [anon_sym_const] = ACTIONS(774),
        [anon_sym_custom] = ACTIONS(777),
        [anon_sym_typedef] = ACTIONS(780),
        [anon_sym_typeid] = ACTIONS(783),
        [anon_sym_typeprefix] = ACTIONS(786),
        [anon_sym_import] = ACTIONS(789),
        [anon_sym_component] = ACTIONS(792),
        [anon_sym_home] = ACTIONS(795),
        [anon_sym_porttype] = ACTIONS(798),
        [anon_sym_connector] = ACTIONS(801),
        [anon_sym_native] = ACTIONS(804),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [27] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(27),
        [aux_sym_specification_repeat1] = STATE(26),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(807),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [28] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(28),
        [aux_sym_specification_repeat1] = STATE(26),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(809),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [29] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(29),
        [aux_sym_specification_repeat1] = STATE(26),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [ts_builtin_sym_end] = ACTIONS(811),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [30] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(30),
        [aux_sym_specification_repeat1] = STATE(27),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(813),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [31] = {
        [sym_preproc_define] = STATE(420),
        [sym_preproc_call] = STATE(420),
        [sym_preproc_include] = STATE(420),
        [sym_except_dcl] = STATE(1587),
        [sym_interface_dcl] = STATE(1587),
        [sym_interface_kind] = STATE(1585),
        [sym_interface_forward_dcl] = STATE(1584),
        [sym_interface_def] = STATE(1584),
        [sym_interface_header] = STATE(1583),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_dcl] = STATE(1587),
        [sym_annotation_appl] = STATE(508),
        [sym_extend_annotation_appl] = STATE(510),
        [sym_template_module_dcl] = STATE(1587),
        [sym_template_module_inst] = STATE(1587),
        [sym_value_dcl] = STATE(1587),
        [sym_value_def] = STATE(1581),
        [sym_value_kind] = STATE(1580),
        [sym_value_header] = STATE(1579),
        [sym_value_forward_dcl] = STATE(1581),
        [sym_typedef_dcl] = STATE(1577),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_type_id_dcl] = STATE(1587),
        [sym_type_prefix_dcl] = STATE(1587),
        [sym_import_dcl] = STATE(1587),
        [sym_value_box_def] = STATE(1581),
        [sym_value_abs_def] = STATE(1581),
        [sym_component_dcl] = STATE(1587),
        [sym_component_forward_dcl] = STATE(1575),
        [sym_component_def] = STATE(1575),
        [sym_component_header] = STATE(1573),
        [sym_home_dcl] = STATE(1587),
        [sym_home_header] = STATE(1572),
        [sym_event_dcl] = STATE(1587),
        [sym_event_forward_dcl] = STATE(1571),
        [sym_event_abs_def] = STATE(1571),
        [sym_event_def] = STATE(1571),
        [sym_event_header] = STATE(1570),
        [sym_porttype_dcl] = STATE(1587),
        [sym_porttype_forward_dcl] = STATE(1567),
        [sym_porttype_def] = STATE(1567),
        [sym_connector_dcl] = STATE(1587),
        [sym_connector_header] = STATE(1566),
        [sym_definition] = STATE(430),
        [sym_type_dcl] = STATE(1587),
        [sym_constr_type_dcl] = STATE(1577),
        [sym_native_dcl] = STATE(1577),
        [sym_module_dcl] = STATE(1587),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_const_dcl] = STATE(1587),
        [sym_comment] = STATE(31),
        [aux_sym_specification_repeat1] = STATE(28),
        [aux_sym_interface_dcl_repeat1] = STATE(422),
        [anon_sym_POUNDdefine] = ACTIONS(9),
        [sym_preproc_directive] = ACTIONS(11),
        [aux_sym_preproc_include_token1] = ACTIONS(13),
        [anon_sym_exception] = ACTIONS(15),
        [anon_sym_RBRACE] = ACTIONS(807),
        [anon_sym_local] = ACTIONS(17),
        [anon_sym_abstract] = ACTIONS(19),
        [anon_sym_interface] = ACTIONS(21),
        [anon_sym_bitset] = ACTIONS(23),
        [anon_sym_bitmask] = ACTIONS(25),
        [anon_sym_ATannotation] = ACTIONS(27),
        [anon_sym_AT] = ACTIONS(29),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(31),
        [anon_sym_module] = ACTIONS(33),
        [anon_sym_valuetype] = ACTIONS(35),
        [anon_sym_eventtype] = ACTIONS(37),
        [anon_sym_struct] = ACTIONS(39),
        [anon_sym_union] = ACTIONS(41),
        [anon_sym_enum] = ACTIONS(43),
        [anon_sym_const] = ACTIONS(45),
        [anon_sym_custom] = ACTIONS(47),
        [anon_sym_typedef] = ACTIONS(49),
        [anon_sym_typeid] = ACTIONS(51),
        [anon_sym_typeprefix] = ACTIONS(53),
        [anon_sym_import] = ACTIONS(55),
        [anon_sym_component] = ACTIONS(57),
        [anon_sym_home] = ACTIONS(59),
        [anon_sym_porttype] = ACTIONS(61),
        [anon_sym_connector] = ACTIONS(63),
        [anon_sym_native] = ACTIONS(65),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [32] = {
        [sym_scoped_name] = STATE(628),
        [sym_annotation_appl_custom_body] = STATE(849),
        [sym_annotation_appl_builtin_body] = STATE(849),
        [sym_annotation_appl_id] = STATE(847),
        [sym_annotation_appl_autoid] = STATE(847),
        [sym_annotation_appl_optional] = STATE(847),
        [sym_annotation_appl_position] = STATE(847),
        [sym_annotation_appl_value] = STATE(847),
        [sym_annotation_appl_extensibility] = STATE(847),
        [sym_annotation_appl_final] = STATE(847),
        [sym_annotation_appl_appendable] = STATE(847),
        [sym_annotation_appl_mutable] = STATE(847),
        [sym_annotation_appl_key] = STATE(847),
        [sym_annotation_appl_must_understand] = STATE(847),
        [sym_annotation_appl_default_literal] = STATE(847),
        [sym_annotation_appl_default] = STATE(847),
        [sym_annotation_appl_range] = STATE(847),
        [sym_annotation_appl_min] = STATE(847),
        [sym_annotation_appl_max] = STATE(847),
        [sym_annotation_appl_unit] = STATE(847),
        [sym_annotation_appl_bit_bound] = STATE(847),
        [sym_annotation_appl_external] = STATE(847),
        [sym_annotation_appl_nested] = STATE(847),
        [sym_annotation_appl_verbatim] = STATE(847),
        [sym_annotation_appl_service] = STATE(847),
        [sym_annotation_appl_oneway] = STATE(847),
        [sym_annotation_appl_ami] = STATE(847),
        [sym_annotation_appl_hashid] = STATE(847),
        [sym_annotation_appl_default_nested] = STATE(847),
        [sym_annotation_appl_ignore_literal_names] = STATE(847),
        [sym_annotation_appl_try_construct] = STATE(847),
        [sym_try_construct_fail_action] = STATE(847),
        [sym_annotation_appl_non_serialized] = STATE(847),
        [sym_annotation_appl_data_representation] = STATE(847),
        [sym_data_representation_mask] = STATE(847),
        [sym_annotation_appl_topic] = STATE(847),
        [sym_annotation_appl_dds_request_topic] = STATE(847),
        [sym_annotation_appl_dds_reply_topic] = STATE(847),
        [sym_comment] = STATE(32),
        [anon_sym_COLON_COLON] = ACTIONS(815),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(817),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(819),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(821),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(823),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(825),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(827),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(829),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(831),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(833),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(835),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(837),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(839),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(841),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(843),
        [aux_sym_min_expr_token1] = ACTIONS(845),
        [aux_sym_max_expr_token1] = ACTIONS(847),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(849),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(851),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(853),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(855),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(857),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(859),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(861),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(863),
        [anon_sym_hashid] = ACTIONS(865),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(867),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(869),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(871),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(873),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(873),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(873),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(875),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(877),
        [aux_sym_data_representation_mask_token1] = ACTIONS(879),
        [aux_sym_data_representation_mask_token2] = ACTIONS(879),
        [aux_sym_data_representation_mask_token3] = ACTIONS(879),
        [aux_sym_data_representation_mask_token4] = ACTIONS(879),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(881),
        [sym_annotation_appl_choice] = ACTIONS(883),
        [sym_annotation_appl_empty] = ACTIONS(883),
        [sym_annotation_appl_dds_service] = ACTIONS(883),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(885),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(887),
        [sym_identifier] = ACTIONS(889),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [33] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(1215),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_op_type_spec] = STATE(1276),
        [sym_readonly_attr_spec] = STATE(1279),
        [sym_attr_spec] = STATE(1279),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(176),
        [sym_extend_annotation_appl] = STATE(181),
        [sym_typedef_dcl] = STATE(1488),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_object_type] = STATE(778),
        [sym_constr_type_dcl] = STATE(1488),
        [sym_native_dcl] = STATE(1488),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_comment] = STATE(33),
        [aux_sym_interface_dcl_repeat1] = STATE(99),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_void] = ACTIONS(115),
        [anon_sym_readonly] = ACTIONS(117),
        [anon_sym_attribute] = ACTIONS(119),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_AT] = ACTIONS(125),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(127),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_typedef] = ACTIONS(145),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(77),
        [anon_sym_native] = ACTIONS(155),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [34] = {
        [sym_scoped_name] = STATE(451),
        [sym_annotation_appl_custom_body] = STATE(531),
        [sym_annotation_appl_builtin_body] = STATE(531),
        [sym_annotation_appl_id] = STATE(525),
        [sym_annotation_appl_autoid] = STATE(525),
        [sym_annotation_appl_optional] = STATE(525),
        [sym_annotation_appl_position] = STATE(525),
        [sym_annotation_appl_value] = STATE(525),
        [sym_annotation_appl_extensibility] = STATE(525),
        [sym_annotation_appl_final] = STATE(525),
        [sym_annotation_appl_appendable] = STATE(525),
        [sym_annotation_appl_mutable] = STATE(525),
        [sym_annotation_appl_key] = STATE(525),
        [sym_annotation_appl_must_understand] = STATE(525),
        [sym_annotation_appl_default_literal] = STATE(525),
        [sym_annotation_appl_default] = STATE(525),
        [sym_annotation_appl_range] = STATE(525),
        [sym_annotation_appl_min] = STATE(525),
        [sym_annotation_appl_max] = STATE(525),
        [sym_annotation_appl_unit] = STATE(525),
        [sym_annotation_appl_bit_bound] = STATE(525),
        [sym_annotation_appl_external] = STATE(525),
        [sym_annotation_appl_nested] = STATE(525),
        [sym_annotation_appl_verbatim] = STATE(525),
        [sym_annotation_appl_service] = STATE(525),
        [sym_annotation_appl_oneway] = STATE(525),
        [sym_annotation_appl_ami] = STATE(525),
        [sym_annotation_appl_hashid] = STATE(525),
        [sym_annotation_appl_default_nested] = STATE(525),
        [sym_annotation_appl_ignore_literal_names] = STATE(525),
        [sym_annotation_appl_try_construct] = STATE(525),
        [sym_try_construct_fail_action] = STATE(525),
        [sym_annotation_appl_non_serialized] = STATE(525),
        [sym_annotation_appl_data_representation] = STATE(525),
        [sym_data_representation_mask] = STATE(525),
        [sym_annotation_appl_topic] = STATE(525),
        [sym_annotation_appl_dds_request_topic] = STATE(525),
        [sym_annotation_appl_dds_reply_topic] = STATE(525),
        [sym_comment] = STATE(34),
        [anon_sym_COLON_COLON] = ACTIONS(891),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(893),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(895),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(897),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(899),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(901),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(903),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(905),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(907),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(909),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(911),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(913),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(915),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(917),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(919),
        [aux_sym_min_expr_token1] = ACTIONS(921),
        [aux_sym_max_expr_token1] = ACTIONS(923),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(925),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(927),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(929),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(931),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(933),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(935),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(937),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(939),
        [anon_sym_hashid] = ACTIONS(941),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(943),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(945),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(947),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(949),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(949),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(949),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(951),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(953),
        [aux_sym_data_representation_mask_token1] = ACTIONS(955),
        [aux_sym_data_representation_mask_token2] = ACTIONS(955),
        [aux_sym_data_representation_mask_token3] = ACTIONS(955),
        [aux_sym_data_representation_mask_token4] = ACTIONS(955),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(957),
        [sym_annotation_appl_choice] = ACTIONS(959),
        [sym_annotation_appl_empty] = ACTIONS(959),
        [sym_annotation_appl_dds_service] = ACTIONS(959),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(961),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(963),
        [sym_identifier] = ACTIONS(965),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [35] = {
        [sym_scoped_name] = STATE(113),
        [sym_annotation_appl_custom_body] = STATE(157),
        [sym_annotation_appl_builtin_body] = STATE(157),
        [sym_annotation_appl_id] = STATE(122),
        [sym_annotation_appl_autoid] = STATE(122),
        [sym_annotation_appl_optional] = STATE(122),
        [sym_annotation_appl_position] = STATE(122),
        [sym_annotation_appl_value] = STATE(122),
        [sym_annotation_appl_extensibility] = STATE(122),
        [sym_annotation_appl_final] = STATE(122),
        [sym_annotation_appl_appendable] = STATE(122),
        [sym_annotation_appl_mutable] = STATE(122),
        [sym_annotation_appl_key] = STATE(122),
        [sym_annotation_appl_must_understand] = STATE(122),
        [sym_annotation_appl_default_literal] = STATE(122),
        [sym_annotation_appl_default] = STATE(122),
        [sym_annotation_appl_range] = STATE(122),
        [sym_annotation_appl_min] = STATE(122),
        [sym_annotation_appl_max] = STATE(122),
        [sym_annotation_appl_unit] = STATE(122),
        [sym_annotation_appl_bit_bound] = STATE(122),
        [sym_annotation_appl_external] = STATE(122),
        [sym_annotation_appl_nested] = STATE(122),
        [sym_annotation_appl_verbatim] = STATE(122),
        [sym_annotation_appl_service] = STATE(122),
        [sym_annotation_appl_oneway] = STATE(122),
        [sym_annotation_appl_ami] = STATE(122),
        [sym_annotation_appl_hashid] = STATE(122),
        [sym_annotation_appl_default_nested] = STATE(122),
        [sym_annotation_appl_ignore_literal_names] = STATE(122),
        [sym_annotation_appl_try_construct] = STATE(122),
        [sym_try_construct_fail_action] = STATE(122),
        [sym_annotation_appl_non_serialized] = STATE(122),
        [sym_annotation_appl_data_representation] = STATE(122),
        [sym_data_representation_mask] = STATE(122),
        [sym_annotation_appl_topic] = STATE(122),
        [sym_annotation_appl_dds_request_topic] = STATE(122),
        [sym_annotation_appl_dds_reply_topic] = STATE(122),
        [sym_comment] = STATE(35),
        [anon_sym_COLON_COLON] = ACTIONS(967),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(969),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(971),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(973),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(975),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(977),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(979),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(981),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(983),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(985),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(987),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(989),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(991),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(993),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(995),
        [aux_sym_min_expr_token1] = ACTIONS(997),
        [aux_sym_max_expr_token1] = ACTIONS(999),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1001),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1003),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1005),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1007),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1009),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1011),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1013),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1015),
        [anon_sym_hashid] = ACTIONS(1017),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1019),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1021),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1023),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1025),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1025),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1025),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1027),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1029),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1031),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1031),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1031),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1031),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1033),
        [sym_annotation_appl_choice] = ACTIONS(1035),
        [sym_annotation_appl_empty] = ACTIONS(1035),
        [sym_annotation_appl_dds_service] = ACTIONS(1035),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1037),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1039),
        [sym_identifier] = ACTIONS(1041),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [36] = {
        [sym_scoped_name] = STATE(646),
        [sym_annotation_appl_custom_body] = STATE(626),
        [sym_annotation_appl_builtin_body] = STATE(626),
        [sym_annotation_appl_id] = STATE(982),
        [sym_annotation_appl_autoid] = STATE(982),
        [sym_annotation_appl_optional] = STATE(982),
        [sym_annotation_appl_position] = STATE(982),
        [sym_annotation_appl_value] = STATE(982),
        [sym_annotation_appl_extensibility] = STATE(982),
        [sym_annotation_appl_final] = STATE(982),
        [sym_annotation_appl_appendable] = STATE(982),
        [sym_annotation_appl_mutable] = STATE(982),
        [sym_annotation_appl_key] = STATE(982),
        [sym_annotation_appl_must_understand] = STATE(982),
        [sym_annotation_appl_default_literal] = STATE(982),
        [sym_annotation_appl_default] = STATE(982),
        [sym_annotation_appl_range] = STATE(982),
        [sym_annotation_appl_min] = STATE(982),
        [sym_annotation_appl_max] = STATE(982),
        [sym_annotation_appl_unit] = STATE(982),
        [sym_annotation_appl_bit_bound] = STATE(982),
        [sym_annotation_appl_external] = STATE(982),
        [sym_annotation_appl_nested] = STATE(982),
        [sym_annotation_appl_verbatim] = STATE(982),
        [sym_annotation_appl_service] = STATE(982),
        [sym_annotation_appl_oneway] = STATE(982),
        [sym_annotation_appl_ami] = STATE(982),
        [sym_annotation_appl_hashid] = STATE(982),
        [sym_annotation_appl_default_nested] = STATE(982),
        [sym_annotation_appl_ignore_literal_names] = STATE(982),
        [sym_annotation_appl_try_construct] = STATE(982),
        [sym_try_construct_fail_action] = STATE(982),
        [sym_annotation_appl_non_serialized] = STATE(982),
        [sym_annotation_appl_data_representation] = STATE(982),
        [sym_data_representation_mask] = STATE(982),
        [sym_annotation_appl_topic] = STATE(982),
        [sym_annotation_appl_dds_request_topic] = STATE(982),
        [sym_annotation_appl_dds_reply_topic] = STATE(982),
        [sym_comment] = STATE(36),
        [anon_sym_COLON_COLON] = ACTIONS(1043),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1045),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1047),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1049),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1051),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1053),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1055),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1057),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1059),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1061),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1063),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1065),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1067),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1069),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1071),
        [aux_sym_min_expr_token1] = ACTIONS(1073),
        [aux_sym_max_expr_token1] = ACTIONS(1075),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1077),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1079),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1081),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1083),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1085),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1087),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1089),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1091),
        [anon_sym_hashid] = ACTIONS(1093),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1095),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1097),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1099),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1101),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1103),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1105),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1107),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1109),
        [sym_annotation_appl_choice] = ACTIONS(1111),
        [sym_annotation_appl_empty] = ACTIONS(1111),
        [sym_annotation_appl_dds_service] = ACTIONS(1111),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1113),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1115),
        [sym_identifier] = ACTIONS(1117),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [37] = {
        [sym_scoped_name] = STATE(646),
        [sym_annotation_appl_custom_body] = STATE(602),
        [sym_annotation_appl_builtin_body] = STATE(602),
        [sym_annotation_appl_id] = STATE(982),
        [sym_annotation_appl_autoid] = STATE(982),
        [sym_annotation_appl_optional] = STATE(982),
        [sym_annotation_appl_position] = STATE(982),
        [sym_annotation_appl_value] = STATE(982),
        [sym_annotation_appl_extensibility] = STATE(982),
        [sym_annotation_appl_final] = STATE(982),
        [sym_annotation_appl_appendable] = STATE(982),
        [sym_annotation_appl_mutable] = STATE(982),
        [sym_annotation_appl_key] = STATE(982),
        [sym_annotation_appl_must_understand] = STATE(982),
        [sym_annotation_appl_default_literal] = STATE(982),
        [sym_annotation_appl_default] = STATE(982),
        [sym_annotation_appl_range] = STATE(982),
        [sym_annotation_appl_min] = STATE(982),
        [sym_annotation_appl_max] = STATE(982),
        [sym_annotation_appl_unit] = STATE(982),
        [sym_annotation_appl_bit_bound] = STATE(982),
        [sym_annotation_appl_external] = STATE(982),
        [sym_annotation_appl_nested] = STATE(982),
        [sym_annotation_appl_verbatim] = STATE(982),
        [sym_annotation_appl_service] = STATE(982),
        [sym_annotation_appl_oneway] = STATE(982),
        [sym_annotation_appl_ami] = STATE(982),
        [sym_annotation_appl_hashid] = STATE(982),
        [sym_annotation_appl_default_nested] = STATE(982),
        [sym_annotation_appl_ignore_literal_names] = STATE(982),
        [sym_annotation_appl_try_construct] = STATE(982),
        [sym_try_construct_fail_action] = STATE(982),
        [sym_annotation_appl_non_serialized] = STATE(982),
        [sym_annotation_appl_data_representation] = STATE(982),
        [sym_data_representation_mask] = STATE(982),
        [sym_annotation_appl_topic] = STATE(982),
        [sym_annotation_appl_dds_request_topic] = STATE(982),
        [sym_annotation_appl_dds_reply_topic] = STATE(982),
        [sym_comment] = STATE(37),
        [anon_sym_COLON_COLON] = ACTIONS(1043),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1045),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1047),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1049),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1051),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1053),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1055),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1057),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1059),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1061),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1063),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1065),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1067),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1069),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1071),
        [aux_sym_min_expr_token1] = ACTIONS(1073),
        [aux_sym_max_expr_token1] = ACTIONS(1075),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1077),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1079),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1081),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1083),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1085),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1087),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1089),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1091),
        [anon_sym_hashid] = ACTIONS(1093),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1095),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1097),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1099),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1101),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1103),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1105),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1107),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1109),
        [sym_annotation_appl_choice] = ACTIONS(1111),
        [sym_annotation_appl_empty] = ACTIONS(1111),
        [sym_annotation_appl_dds_service] = ACTIONS(1111),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1113),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1115),
        [sym_identifier] = ACTIONS(1117),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [38] = {
        [sym_scoped_name] = STATE(646),
        [sym_annotation_appl_custom_body] = STATE(985),
        [sym_annotation_appl_builtin_body] = STATE(985),
        [sym_annotation_appl_id] = STATE(982),
        [sym_annotation_appl_autoid] = STATE(982),
        [sym_annotation_appl_optional] = STATE(982),
        [sym_annotation_appl_position] = STATE(982),
        [sym_annotation_appl_value] = STATE(982),
        [sym_annotation_appl_extensibility] = STATE(982),
        [sym_annotation_appl_final] = STATE(982),
        [sym_annotation_appl_appendable] = STATE(982),
        [sym_annotation_appl_mutable] = STATE(982),
        [sym_annotation_appl_key] = STATE(982),
        [sym_annotation_appl_must_understand] = STATE(982),
        [sym_annotation_appl_default_literal] = STATE(982),
        [sym_annotation_appl_default] = STATE(982),
        [sym_annotation_appl_range] = STATE(982),
        [sym_annotation_appl_min] = STATE(982),
        [sym_annotation_appl_max] = STATE(982),
        [sym_annotation_appl_unit] = STATE(982),
        [sym_annotation_appl_bit_bound] = STATE(982),
        [sym_annotation_appl_external] = STATE(982),
        [sym_annotation_appl_nested] = STATE(982),
        [sym_annotation_appl_verbatim] = STATE(982),
        [sym_annotation_appl_service] = STATE(982),
        [sym_annotation_appl_oneway] = STATE(982),
        [sym_annotation_appl_ami] = STATE(982),
        [sym_annotation_appl_hashid] = STATE(982),
        [sym_annotation_appl_default_nested] = STATE(982),
        [sym_annotation_appl_ignore_literal_names] = STATE(982),
        [sym_annotation_appl_try_construct] = STATE(982),
        [sym_try_construct_fail_action] = STATE(982),
        [sym_annotation_appl_non_serialized] = STATE(982),
        [sym_annotation_appl_data_representation] = STATE(982),
        [sym_data_representation_mask] = STATE(982),
        [sym_annotation_appl_topic] = STATE(982),
        [sym_annotation_appl_dds_request_topic] = STATE(982),
        [sym_annotation_appl_dds_reply_topic] = STATE(982),
        [sym_comment] = STATE(38),
        [anon_sym_COLON_COLON] = ACTIONS(1043),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1045),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1047),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1049),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1051),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1053),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1055),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1057),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1059),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1061),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1063),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1065),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1067),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1069),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1071),
        [aux_sym_min_expr_token1] = ACTIONS(1073),
        [aux_sym_max_expr_token1] = ACTIONS(1075),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1077),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1079),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1081),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1083),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1085),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1087),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1089),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1091),
        [anon_sym_hashid] = ACTIONS(1093),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1095),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1097),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1099),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1101),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1103),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1105),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1107),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1109),
        [sym_annotation_appl_choice] = ACTIONS(1111),
        [sym_annotation_appl_empty] = ACTIONS(1111),
        [sym_annotation_appl_dds_service] = ACTIONS(1111),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1113),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1115),
        [sym_identifier] = ACTIONS(1117),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [39] = {
        [sym_scoped_name] = STATE(646),
        [sym_annotation_appl_custom_body] = STATE(620),
        [sym_annotation_appl_builtin_body] = STATE(620),
        [sym_annotation_appl_id] = STATE(982),
        [sym_annotation_appl_autoid] = STATE(982),
        [sym_annotation_appl_optional] = STATE(982),
        [sym_annotation_appl_position] = STATE(982),
        [sym_annotation_appl_value] = STATE(982),
        [sym_annotation_appl_extensibility] = STATE(982),
        [sym_annotation_appl_final] = STATE(982),
        [sym_annotation_appl_appendable] = STATE(982),
        [sym_annotation_appl_mutable] = STATE(982),
        [sym_annotation_appl_key] = STATE(982),
        [sym_annotation_appl_must_understand] = STATE(982),
        [sym_annotation_appl_default_literal] = STATE(982),
        [sym_annotation_appl_default] = STATE(982),
        [sym_annotation_appl_range] = STATE(982),
        [sym_annotation_appl_min] = STATE(982),
        [sym_annotation_appl_max] = STATE(982),
        [sym_annotation_appl_unit] = STATE(982),
        [sym_annotation_appl_bit_bound] = STATE(982),
        [sym_annotation_appl_external] = STATE(982),
        [sym_annotation_appl_nested] = STATE(982),
        [sym_annotation_appl_verbatim] = STATE(982),
        [sym_annotation_appl_service] = STATE(982),
        [sym_annotation_appl_oneway] = STATE(982),
        [sym_annotation_appl_ami] = STATE(982),
        [sym_annotation_appl_hashid] = STATE(982),
        [sym_annotation_appl_default_nested] = STATE(982),
        [sym_annotation_appl_ignore_literal_names] = STATE(982),
        [sym_annotation_appl_try_construct] = STATE(982),
        [sym_try_construct_fail_action] = STATE(982),
        [sym_annotation_appl_non_serialized] = STATE(982),
        [sym_annotation_appl_data_representation] = STATE(982),
        [sym_data_representation_mask] = STATE(982),
        [sym_annotation_appl_topic] = STATE(982),
        [sym_annotation_appl_dds_request_topic] = STATE(982),
        [sym_annotation_appl_dds_reply_topic] = STATE(982),
        [sym_comment] = STATE(39),
        [anon_sym_COLON_COLON] = ACTIONS(1043),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1045),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1047),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1049),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1051),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1053),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1055),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1057),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1059),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1061),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1063),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1065),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1067),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1069),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1071),
        [aux_sym_min_expr_token1] = ACTIONS(1073),
        [aux_sym_max_expr_token1] = ACTIONS(1075),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1077),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1079),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1081),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1083),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1085),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1087),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1089),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1091),
        [anon_sym_hashid] = ACTIONS(1093),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1095),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1097),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1099),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1101),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1103),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1105),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1107),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1109),
        [sym_annotation_appl_choice] = ACTIONS(1111),
        [sym_annotation_appl_empty] = ACTIONS(1111),
        [sym_annotation_appl_dds_service] = ACTIONS(1111),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1113),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1115),
        [sym_identifier] = ACTIONS(1117),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [40] = {
        [sym_scoped_name] = STATE(646),
        [sym_annotation_appl_custom_body] = STATE(605),
        [sym_annotation_appl_builtin_body] = STATE(605),
        [sym_annotation_appl_id] = STATE(982),
        [sym_annotation_appl_autoid] = STATE(982),
        [sym_annotation_appl_optional] = STATE(982),
        [sym_annotation_appl_position] = STATE(982),
        [sym_annotation_appl_value] = STATE(982),
        [sym_annotation_appl_extensibility] = STATE(982),
        [sym_annotation_appl_final] = STATE(982),
        [sym_annotation_appl_appendable] = STATE(982),
        [sym_annotation_appl_mutable] = STATE(982),
        [sym_annotation_appl_key] = STATE(982),
        [sym_annotation_appl_must_understand] = STATE(982),
        [sym_annotation_appl_default_literal] = STATE(982),
        [sym_annotation_appl_default] = STATE(982),
        [sym_annotation_appl_range] = STATE(982),
        [sym_annotation_appl_min] = STATE(982),
        [sym_annotation_appl_max] = STATE(982),
        [sym_annotation_appl_unit] = STATE(982),
        [sym_annotation_appl_bit_bound] = STATE(982),
        [sym_annotation_appl_external] = STATE(982),
        [sym_annotation_appl_nested] = STATE(982),
        [sym_annotation_appl_verbatim] = STATE(982),
        [sym_annotation_appl_service] = STATE(982),
        [sym_annotation_appl_oneway] = STATE(982),
        [sym_annotation_appl_ami] = STATE(982),
        [sym_annotation_appl_hashid] = STATE(982),
        [sym_annotation_appl_default_nested] = STATE(982),
        [sym_annotation_appl_ignore_literal_names] = STATE(982),
        [sym_annotation_appl_try_construct] = STATE(982),
        [sym_try_construct_fail_action] = STATE(982),
        [sym_annotation_appl_non_serialized] = STATE(982),
        [sym_annotation_appl_data_representation] = STATE(982),
        [sym_data_representation_mask] = STATE(982),
        [sym_annotation_appl_topic] = STATE(982),
        [sym_annotation_appl_dds_request_topic] = STATE(982),
        [sym_annotation_appl_dds_reply_topic] = STATE(982),
        [sym_comment] = STATE(40),
        [anon_sym_COLON_COLON] = ACTIONS(1043),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1045),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1047),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1049),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1051),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1053),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1055),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1057),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1059),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1061),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1063),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1065),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1067),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1069),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1071),
        [aux_sym_min_expr_token1] = ACTIONS(1073),
        [aux_sym_max_expr_token1] = ACTIONS(1075),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1077),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1079),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1081),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1083),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1085),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1087),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1089),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1091),
        [anon_sym_hashid] = ACTIONS(1093),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1095),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1097),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1099),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1101),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1103),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1105),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1107),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1109),
        [sym_annotation_appl_choice] = ACTIONS(1111),
        [sym_annotation_appl_empty] = ACTIONS(1111),
        [sym_annotation_appl_dds_service] = ACTIONS(1111),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1113),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1115),
        [sym_identifier] = ACTIONS(1117),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [41] = {
        [sym_scoped_name] = STATE(646),
        [sym_annotation_appl_custom_body] = STATE(609),
        [sym_annotation_appl_builtin_body] = STATE(609),
        [sym_annotation_appl_id] = STATE(982),
        [sym_annotation_appl_autoid] = STATE(982),
        [sym_annotation_appl_optional] = STATE(982),
        [sym_annotation_appl_position] = STATE(982),
        [sym_annotation_appl_value] = STATE(982),
        [sym_annotation_appl_extensibility] = STATE(982),
        [sym_annotation_appl_final] = STATE(982),
        [sym_annotation_appl_appendable] = STATE(982),
        [sym_annotation_appl_mutable] = STATE(982),
        [sym_annotation_appl_key] = STATE(982),
        [sym_annotation_appl_must_understand] = STATE(982),
        [sym_annotation_appl_default_literal] = STATE(982),
        [sym_annotation_appl_default] = STATE(982),
        [sym_annotation_appl_range] = STATE(982),
        [sym_annotation_appl_min] = STATE(982),
        [sym_annotation_appl_max] = STATE(982),
        [sym_annotation_appl_unit] = STATE(982),
        [sym_annotation_appl_bit_bound] = STATE(982),
        [sym_annotation_appl_external] = STATE(982),
        [sym_annotation_appl_nested] = STATE(982),
        [sym_annotation_appl_verbatim] = STATE(982),
        [sym_annotation_appl_service] = STATE(982),
        [sym_annotation_appl_oneway] = STATE(982),
        [sym_annotation_appl_ami] = STATE(982),
        [sym_annotation_appl_hashid] = STATE(982),
        [sym_annotation_appl_default_nested] = STATE(982),
        [sym_annotation_appl_ignore_literal_names] = STATE(982),
        [sym_annotation_appl_try_construct] = STATE(982),
        [sym_try_construct_fail_action] = STATE(982),
        [sym_annotation_appl_non_serialized] = STATE(982),
        [sym_annotation_appl_data_representation] = STATE(982),
        [sym_data_representation_mask] = STATE(982),
        [sym_annotation_appl_topic] = STATE(982),
        [sym_annotation_appl_dds_request_topic] = STATE(982),
        [sym_annotation_appl_dds_reply_topic] = STATE(982),
        [sym_comment] = STATE(41),
        [anon_sym_COLON_COLON] = ACTIONS(1043),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1045),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1047),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1049),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1051),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1053),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1055),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1057),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1059),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1061),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1063),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1065),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1067),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1069),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1071),
        [aux_sym_min_expr_token1] = ACTIONS(1073),
        [aux_sym_max_expr_token1] = ACTIONS(1075),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1077),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1079),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1081),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1083),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1085),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1087),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1089),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1091),
        [anon_sym_hashid] = ACTIONS(1093),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1095),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1097),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1099),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1101),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1101),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1103),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1105),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1107),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1107),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1109),
        [sym_annotation_appl_choice] = ACTIONS(1111),
        [sym_annotation_appl_empty] = ACTIONS(1111),
        [sym_annotation_appl_dds_service] = ACTIONS(1111),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1113),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1115),
        [sym_identifier] = ACTIONS(1117),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [42] = {
        [sym_scoped_name] = STATE(356),
        [sym_annotation_appl_custom_body] = STATE(368),
        [sym_annotation_appl_builtin_body] = STATE(368),
        [sym_annotation_appl_id] = STATE(373),
        [sym_annotation_appl_autoid] = STATE(373),
        [sym_annotation_appl_optional] = STATE(373),
        [sym_annotation_appl_position] = STATE(373),
        [sym_annotation_appl_value] = STATE(373),
        [sym_annotation_appl_extensibility] = STATE(373),
        [sym_annotation_appl_final] = STATE(373),
        [sym_annotation_appl_appendable] = STATE(373),
        [sym_annotation_appl_mutable] = STATE(373),
        [sym_annotation_appl_key] = STATE(373),
        [sym_annotation_appl_must_understand] = STATE(373),
        [sym_annotation_appl_default_literal] = STATE(373),
        [sym_annotation_appl_default] = STATE(373),
        [sym_annotation_appl_range] = STATE(373),
        [sym_annotation_appl_min] = STATE(373),
        [sym_annotation_appl_max] = STATE(373),
        [sym_annotation_appl_unit] = STATE(373),
        [sym_annotation_appl_bit_bound] = STATE(373),
        [sym_annotation_appl_external] = STATE(373),
        [sym_annotation_appl_nested] = STATE(373),
        [sym_annotation_appl_verbatim] = STATE(373),
        [sym_annotation_appl_service] = STATE(373),
        [sym_annotation_appl_oneway] = STATE(373),
        [sym_annotation_appl_ami] = STATE(373),
        [sym_annotation_appl_hashid] = STATE(373),
        [sym_annotation_appl_default_nested] = STATE(373),
        [sym_annotation_appl_ignore_literal_names] = STATE(373),
        [sym_annotation_appl_try_construct] = STATE(373),
        [sym_try_construct_fail_action] = STATE(373),
        [sym_annotation_appl_non_serialized] = STATE(373),
        [sym_annotation_appl_data_representation] = STATE(373),
        [sym_data_representation_mask] = STATE(373),
        [sym_annotation_appl_topic] = STATE(373),
        [sym_annotation_appl_dds_request_topic] = STATE(373),
        [sym_annotation_appl_dds_reply_topic] = STATE(373),
        [sym_comment] = STATE(42),
        [anon_sym_COLON_COLON] = ACTIONS(1119),
        [aux_sym_annotation_appl_id_token1] = ACTIONS(1121),
        [aux_sym_annotation_appl_autoid_token1] = ACTIONS(1123),
        [aux_sym_annotation_appl_optional_token1] = ACTIONS(1125),
        [aux_sym_annotation_appl_position_token1] = ACTIONS(1127),
        [aux_sym_annotation_appl_value_token1] = ACTIONS(1129),
        [aux_sym_annotation_appl_extensibility_token1] = ACTIONS(1131),
        [aux_sym_annotation_appl_final_token1] = ACTIONS(1133),
        [aux_sym_annotation_appl_appendable_token1] = ACTIONS(1135),
        [aux_sym_annotation_appl_mutable_token1] = ACTIONS(1137),
        [aux_sym_annotation_appl_key_token1] = ACTIONS(1139),
        [aux_sym_annotation_appl_must_understand_token1] = ACTIONS(1141),
        [aux_sym_annotation_appl_default_literal_token1] = ACTIONS(1143),
        [aux_sym_annotation_appl_default_token1] = ACTIONS(1145),
        [aux_sym_annotation_appl_range_token1] = ACTIONS(1147),
        [aux_sym_min_expr_token1] = ACTIONS(1149),
        [aux_sym_max_expr_token1] = ACTIONS(1151),
        [aux_sym_annotation_appl_unit_token1] = ACTIONS(1153),
        [aux_sym_annotation_appl_bit_bound_token1] = ACTIONS(1155),
        [aux_sym_annotation_appl_external_token1] = ACTIONS(1157),
        [aux_sym_annotation_appl_nested_token1] = ACTIONS(1159),
        [aux_sym_annotation_appl_verbatim_token1] = ACTIONS(1161),
        [aux_sym_annotation_appl_service_token1] = ACTIONS(1163),
        [aux_sym_annotation_appl_oneway_token1] = ACTIONS(1165),
        [aux_sym_annotation_appl_ami_token1] = ACTIONS(1167),
        [anon_sym_hashid] = ACTIONS(1169),
        [aux_sym_annotation_appl_default_nested_token1] = ACTIONS(1171),
        [aux_sym_annotation_appl_ignore_literal_names_token1] = ACTIONS(1173),
        [aux_sym_annotation_appl_try_construct_token1] = ACTIONS(1175),
        [aux_sym_try_construct_fail_action_token1] = ACTIONS(1177),
        [aux_sym_try_construct_fail_action_token2] = ACTIONS(1177),
        [aux_sym_try_construct_fail_action_token3] = ACTIONS(1177),
        [aux_sym_annotation_appl_non_serialized_token1] = ACTIONS(1179),
        [aux_sym_annotation_appl_data_representation_token1] = ACTIONS(1181),
        [aux_sym_data_representation_mask_token1] = ACTIONS(1183),
        [aux_sym_data_representation_mask_token2] = ACTIONS(1183),
        [aux_sym_data_representation_mask_token3] = ACTIONS(1183),
        [aux_sym_data_representation_mask_token4] = ACTIONS(1183),
        [aux_sym_annotation_appl_topic_token1] = ACTIONS(1185),
        [sym_annotation_appl_choice] = ACTIONS(1187),
        [sym_annotation_appl_empty] = ACTIONS(1187),
        [sym_annotation_appl_dds_service] = ACTIONS(1187),
        [aux_sym_annotation_appl_dds_request_topic_token1] = ACTIONS(1189),
        [aux_sym_annotation_appl_dds_reply_topic_token1] = ACTIONS(1191),
        [sym_identifier] = ACTIONS(1193),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [43] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_type_spec] = STATE(738),
        [sym_simple_type_spec] = STATE(693),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(693),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_annotation_appl] = STATE(400),
        [sym_extend_annotation_appl] = STATE(399),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_case_label] = STATE(273),
        [sym_element_spec] = STATE(1320),
        [sym_object_type] = STATE(778),
        [sym_constr_type_dcl] = STATE(738),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_comment] = STATE(43),
        [aux_sym_interface_dcl_repeat1] = STATE(56),
        [aux_sym_case_repeat1] = STATE(188),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_default] = ACTIONS(1195),
        [anon_sym_AT] = ACTIONS(1197),
        [anon_sym_SLASH_SLASH_AT] = ACTIONS(1199),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_case] = ACTIONS(1201),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(77),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(3),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
    [44] = {
        [sym_signed_short_int] = STATE(662),
        [sym_signed_long_int] = STATE(662),
        [sym_signed_longlong_int] = STATE(662),
        [sym_unsigned_int] = STATE(638),
        [sym_integer_type] = STATE(778),
        [sym_signed_int] = STATE(638),
        [sym_unsigned_short_int] = STATE(664),
        [sym_unsigned_long_int] = STATE(664),
        [sym_unsigned_longlong_int] = STATE(664),
        [sym_floating_pt_type] = STATE(778),
        [sym_scoped_name] = STATE(636),
        [sym_string_type] = STATE(780),
        [sym_wide_string_type] = STATE(780),
        [sym_simple_type_spec] = STATE(630),
        [sym_base_type_spec] = STATE(783),
        [sym_any_type] = STATE(778),
        [sym_fixed_pt_type] = STATE(780),
        [sym_template_type_spec] = STATE(630),
        [sym_sequence_type] = STATE(780),
        [sym_map_type] = STATE(780),
        [sym_bitset_dcl] = STATE(1059),
        [sym_bitmask_dcl] = STATE(1059),
        [sym_type_declarator] = STATE(1505),
        [sym_enum_dcl] = STATE(1059),
        [sym_union_dcl] = STATE(1059),
        [sym_union_forward_dcl] = STATE(1046),
        [sym_union_def] = STATE(1046),
        [sym_object_type] = STATE(778),
        [sym_constr_type_dcl] = STATE(630),
        [sym_struct_dcl] = STATE(1059),
        [sym_struct_forward_dcl] = STATE(1060),
        [sym_struct_def] = STATE(1060),
        [sym_comment] = STATE(44),
        [anon_sym_short] = ACTIONS(67),
        [anon_sym_int16] = ACTIONS(67),
        [anon_sym_long] = ACTIONS(69),
        [anon_sym_int32] = ACTIONS(69),
        [anon_sym_longlong] = ACTIONS(71),
        [anon_sym_int64] = ACTIONS(73),
        [sym_unsigned_tiny_int] = ACTIONS(75),
        [sym_boolean_type] = ACTIONS(77),
        [anon_sym_fixed] = ACTIONS(79),
        [sym_octet_type] = ACTIONS(77),
        [sym_signed_tiny_int] = ACTIONS(81),
        [anon_sym_unsignedshort] = ACTIONS(83),
        [anon_sym_uint16] = ACTIONS(85),
        [anon_sym_unsignedlong] = ACTIONS(87),
        [anon_sym_uint32] = ACTIONS(87),
        [anon_sym_unsignedlonglong] = ACTIONS(89),
        [anon_sym_uint64] = ACTIONS(91),
        [anon_sym_float] = ACTIONS(93),
        [anon_sym_double] = ACTIONS(93),
        [anon_sym_longdouble] = ACTIONS(95),
        [sym_char_type] = ACTIONS(77),
        [sym_wide_char_type] = ACTIONS(77),
        [anon_sym_COLON_COLON] = ACTIONS(97),
        [anon_sym_string] = ACTIONS(99),
        [anon_sym_wstring] = ACTIONS(101),
        [anon_sym_any] = ACTIONS(103),
        [anon_sym_sequence] = ACTIONS(105),
        [anon_sym_map] = ACTIONS(107),
        [anon_sym_bitset] = ACTIONS(121),
        [anon_sym_bitmask] = ACTIONS(123),
        [anon_sym_struct] = ACTIONS(131),
        [anon_sym_union] = ACTIONS(133),
        [anon_sym_enum] = ACTIONS(135),
        [anon_sym_Object] = ACTIONS(151),
        [sym_value_base_type] = ACTIONS(77),
        [sym_identifier] = ACTIONS(157),
        [anon_sym_SLASH_SLASH] = ACTIONS(618),
        [anon_sym_SLASH_STAR] = ACTIONS(5),
    },
};

static const uint16_t ts_small_parse_table[] = {
    [0] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1203),
    1,
    anon_sym_RBRACE,
    STATE(45),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [151] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1205),
    1,
    anon_sym_RBRACE,
    STATE(46),
    1,
    sym_comment,
    STATE(48),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [302] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1207),
    1,
    anon_sym_RBRACE,
    STATE(45),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(47),
    1,
    sym_comment,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [453] = 42,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1215),
    1,
    anon_sym_longlong,
    ACTIONS(1218),
    1,
    anon_sym_int64,
    ACTIONS(1221),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(1227),
    1,
    anon_sym_fixed,
    ACTIONS(1230),
    1,
    sym_signed_tiny_int,
    ACTIONS(1233),
    1,
    anon_sym_unsignedshort,
    ACTIONS(1236),
    1,
    anon_sym_uint16,
    ACTIONS(1242),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(1245),
    1,
    anon_sym_uint64,
    ACTIONS(1251),
    1,
    anon_sym_longdouble,
    ACTIONS(1254),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1257),
    1,
    anon_sym_string,
    ACTIONS(1260),
    1,
    anon_sym_wstring,
    ACTIONS(1263),
    1,
    anon_sym_any,
    ACTIONS(1266),
    1,
    anon_sym_sequence,
    ACTIONS(1269),
    1,
    anon_sym_map,
    ACTIONS(1272),
    1,
    anon_sym_RBRACE,
    ACTIONS(1274),
    1,
    anon_sym_AT,
    ACTIONS(1277),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1280),
    1,
    anon_sym_Object,
    ACTIONS(1283),
    1,
    sym_identifier,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(1209),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(1212),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(1239),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(1248),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(48),
    2,
    sym_comment,
    aux_sym_except_dcl_repeat1,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(1224),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [602] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1286),
    1,
    anon_sym_RBRACE,
    STATE(49),
    1,
    sym_comment,
    STATE(51),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [753] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1288),
    1,
    anon_sym_RBRACE,
    STATE(46),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(50),
    1,
    sym_comment,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [904] = 43,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1290),
    1,
    anon_sym_RBRACE,
    STATE(48),
    1,
    aux_sym_except_dcl_repeat1,
    STATE(51),
    1,
    sym_comment,
    STATE(57),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(340),
    1,
    sym_member,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(667),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1055] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1292),
    1,
    anon_sym_RPAREN,
    STATE(52),
    1,
    sym_comment,
    STATE(88),
    1,
    sym_param_attribute,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(825),
    1,
    sym_param_dcl,
    STATE(1143),
    1,
    sym_type_spec,
    STATE(1527),
    1,
    sym_parameter_dcls,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(1294),
    3,
    anon_sym_in,
    anon_sym_out,
    anon_sym_inout,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1199] = 42,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1296),
    1,
    anon_sym_LBRACE,
    ACTIONS(1298),
    1,
    anon_sym_COLON,
    ACTIONS(1300),
    1,
    anon_sym_SEMI,
    ACTIONS(1302),
    1,
    anon_sym_supports,
    STATE(53),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(883),
    1,
    sym_value_inheritance,
    STATE(1181),
    1,
    sym_value_inheritance_spec,
    STATE(1182),
    1,
    sym_type_spec,
    STATE(1384),
    1,
    sym_value_supports,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1347] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1304),
    1,
    anon_sym_RPAREN,
    STATE(54),
    1,
    sym_comment,
    STATE(88),
    1,
    sym_param_attribute,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(825),
    1,
    sym_param_dcl,
    STATE(1143),
    1,
    sym_type_spec,
    STATE(1478),
    1,
    sym_parameter_dcls,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(1294),
    3,
    anon_sym_in,
    anon_sym_out,
    anon_sym_inout,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1491] = 38,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(55),
    1,
    sym_comment,
    STATE(88),
    1,
    sym_param_attribute,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1103),
    1,
    sym_param_dcl,
    STATE(1143),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    ACTIONS(1294),
    3,
    anon_sym_in,
    anon_sym_out,
    anon_sym_inout,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1629] = 40,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(56),
    1,
    sym_comment,
    STATE(324),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(731),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1771] = 40,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(1197),
    1,
    anon_sym_AT,
    ACTIONS(1199),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(57),
    1,
    sym_comment,
    STATE(324),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(647),
    1,
    sym_type_spec,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [1913] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(135),
    1,
    anon_sym_enum,
    ACTIONS(137),
    1,
    anon_sym_const,
    ACTIONS(145),
    1,
    anon_sym_typedef,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    ACTIONS(1310),
    1,
    anon_sym_any,
    ACTIONS(1312),
    1,
    anon_sym_RBRACE,
    ACTIONS(1314),
    1,
    anon_sym_attribute,
    STATE(58),
    1,
    sym_comment,
    STATE(60),
    1,
    aux_sym_annotation_dcl_repeat1,
    STATE(381),
    1,
    sym_annotation_member,
    STATE(390),
    1,
    sym_annotation_body,
    STATE(1144),
    1,
    sym_annotation_member_type,
    STATE(1145),
    1,
    sym_scoped_name,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1199),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(1200),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [2054] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(135),
    1,
    anon_sym_enum,
    ACTIONS(137),
    1,
    anon_sym_const,
    ACTIONS(145),
    1,
    anon_sym_typedef,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    ACTIONS(1310),
    1,
    anon_sym_any,
    ACTIONS(1312),
    1,
    anon_sym_RBRACE,
    ACTIONS(1314),
    1,
    anon_sym_attribute,
    STATE(59),
    1,
    sym_comment,
    STATE(61),
    1,
    aux_sym_annotation_dcl_repeat1,
    STATE(381),
    1,
    sym_annotation_member,
    STATE(390),
    1,
    sym_annotation_body,
    STATE(1144),
    1,
    sym_annotation_member_type,
    STATE(1145),
    1,
    sym_scoped_name,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1199),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(1200),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [2195] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(135),
    1,
    anon_sym_enum,
    ACTIONS(137),
    1,
    anon_sym_const,
    ACTIONS(145),
    1,
    anon_sym_typedef,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    ACTIONS(1310),
    1,
    anon_sym_any,
    ACTIONS(1314),
    1,
    anon_sym_attribute,
    ACTIONS(1316),
    1,
    anon_sym_RBRACE,
    STATE(60),
    1,
    sym_comment,
    STATE(61),
    1,
    aux_sym_annotation_dcl_repeat1,
    STATE(381),
    1,
    sym_annotation_member,
    STATE(390),
    1,
    sym_annotation_body,
    STATE(1144),
    1,
    sym_annotation_member_type,
    STATE(1145),
    1,
    sym_scoped_name,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1199),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(1200),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [2336] = 39,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1324),
    1,
    anon_sym_longlong,
    ACTIONS(1327),
    1,
    anon_sym_int64,
    ACTIONS(1330),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(1336),
    1,
    anon_sym_fixed,
    ACTIONS(1339),
    1,
    sym_signed_tiny_int,
    ACTIONS(1342),
    1,
    anon_sym_unsignedshort,
    ACTIONS(1345),
    1,
    anon_sym_uint16,
    ACTIONS(1351),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(1354),
    1,
    anon_sym_uint64,
    ACTIONS(1360),
    1,
    anon_sym_longdouble,
    ACTIONS(1363),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(1366),
    1,
    anon_sym_string,
    ACTIONS(1369),
    1,
    anon_sym_wstring,
    ACTIONS(1372),
    1,
    anon_sym_any,
    ACTIONS(1375),
    1,
    anon_sym_sequence,
    ACTIONS(1378),
    1,
    anon_sym_RBRACE,
    ACTIONS(1380),
    1,
    anon_sym_attribute,
    ACTIONS(1383),
    1,
    anon_sym_enum,
    ACTIONS(1386),
    1,
    anon_sym_const,
    ACTIONS(1389),
    1,
    anon_sym_typedef,
    ACTIONS(1392),
    1,
    sym_identifier,
    STATE(381),
    1,
    sym_annotation_member,
    STATE(390),
    1,
    sym_annotation_body,
    STATE(1144),
    1,
    sym_annotation_member_type,
    STATE(1145),
    1,
    sym_scoped_name,
    ACTIONS(1318),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(1321),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(1348),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(1357),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(61),
    2,
    sym_comment,
    aux_sym_annotation_dcl_repeat1,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1199),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(1200),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    ACTIONS(1333),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [2475] = 40,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(135),
    1,
    anon_sym_enum,
    ACTIONS(137),
    1,
    anon_sym_const,
    ACTIONS(145),
    1,
    anon_sym_typedef,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    ACTIONS(1310),
    1,
    anon_sym_any,
    ACTIONS(1314),
    1,
    anon_sym_attribute,
    ACTIONS(1395),
    1,
    anon_sym_RBRACE,
    STATE(59),
    1,
    aux_sym_annotation_dcl_repeat1,
    STATE(62),
    1,
    sym_comment,
    STATE(381),
    1,
    sym_annotation_member,
    STATE(390),
    1,
    sym_annotation_body,
    STATE(1144),
    1,
    sym_annotation_member_type,
    STATE(1145),
    1,
    sym_scoped_name,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1199),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(1200),
    3,
    sym_typedef_dcl,
    sym_enum_dcl,
    sym_const_dcl,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [2616] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(63),
    1,
    sym_comment,
    ACTIONS(1399),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1397),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2685] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(64),
    1,
    sym_comment,
    ACTIONS(1403),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1401),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2754] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(65),
    1,
    sym_comment,
    ACTIONS(1407),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1405),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2823] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(66),
    1,
    sym_comment,
    ACTIONS(1411),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1409),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [2892] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1413),
    1,
    anon_sym_sequence,
    ACTIONS(1417),
    1,
    anon_sym_const,
    STATE(67),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(921),
    1,
    sym_formal_parameter,
    STATE(1250),
    1,
    sym_formal_parameters,
    STATE(1251),
    1,
    sym_formal_parameter_type,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1249),
    2,
    sym_simple_type_spec,
    sym_sequence_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    ACTIONS(1415),
    8,
    anon_sym_exception,
    anon_sym_interface,
    anon_sym_typename,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    [3019] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(68),
    1,
    sym_comment,
    ACTIONS(1421),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1419),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3088] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(69),
    1,
    sym_comment,
    ACTIONS(1425),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1423),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3157] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(70),
    1,
    sym_comment,
    ACTIONS(1429),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1427),
    47,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_public,
    anon_sym_private,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [3226] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(71),
    1,
    sym_comment,
    ACTIONS(1403),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1401),
    46,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3294] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1413),
    1,
    anon_sym_sequence,
    ACTIONS(1417),
    1,
    anon_sym_const,
    STATE(72),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1064),
    1,
    sym_formal_parameter,
    STATE(1251),
    1,
    sym_formal_parameter_type,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1249),
    2,
    sym_simple_type_spec,
    sym_sequence_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    ACTIONS(1415),
    8,
    anon_sym_exception,
    anon_sym_interface,
    anon_sym_typename,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    [3418] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(73),
    1,
    sym_comment,
    ACTIONS(1433),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1431),
    46,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3486] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(74),
    1,
    sym_comment,
    ACTIONS(1437),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1435),
    46,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3554] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(75),
    1,
    sym_comment,
    ACTIONS(1441),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1439),
    46,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_factory,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_finder,
    anon_sym_native,
    sym_identifier,
    [3622] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(76),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1119),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [3749] = 37,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1443),
    1,
    anon_sym_STAR,
    STATE(77),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1299),
    1,
    sym_const_expr,
    STATE(1631),
    1,
    sym_verbatim_language,
    STATE(1632),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1445),
    4,
    aux_sym_verbatim_language_token1,
    aux_sym_verbatim_language_token2,
    aux_sym_verbatim_language_token3,
    aux_sym_verbatim_language_token4,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [3880] = 37,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1443),
    1,
    anon_sym_STAR,
    STATE(78),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1447),
    1,
    sym_const_expr,
    STATE(1691),
    1,
    sym_verbatim_language,
    STATE(1692),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1445),
    4,
    aux_sym_verbatim_language_token1,
    aux_sym_verbatim_language_token2,
    aux_sym_verbatim_language_token3,
    aux_sym_verbatim_language_token4,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [4011] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1449),
    1,
    sym_identifier,
    STATE(79),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1070),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4138] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(80),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(996),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4265] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(81),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1122),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4392] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1449),
    1,
    sym_identifier,
    STATE(82),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1088),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4519] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(83),
    1,
    sym_comment,
    STATE(631),
    1,
    sym_type_spec,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4646] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(84),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1108),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4773] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(85),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(798),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [4900] = 37,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1443),
    1,
    anon_sym_STAR,
    STATE(86),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1352),
    1,
    sym_const_expr,
    STATE(1651),
    1,
    sym_verbatim_language,
    STATE(1652),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1445),
    4,
    aux_sym_verbatim_language_token1,
    aux_sym_verbatim_language_token2,
    aux_sym_verbatim_language_token3,
    aux_sym_verbatim_language_token4,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [5031] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(87),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1261),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [5158] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(79),
    1,
    anon_sym_fixed,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(103),
    1,
    anon_sym_any,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(107),
    1,
    anon_sym_map,
    ACTIONS(151),
    1,
    anon_sym_Object,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(88),
    1,
    sym_comment,
    STATE(636),
    1,
    sym_scoped_name,
    STATE(783),
    1,
    sym_base_type_spec,
    STATE(1125),
    1,
    sym_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(693),
    2,
    sym_simple_type_spec,
    sym_template_type_spec,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    STATE(778),
    4,
    sym_integer_type,
    sym_floating_pt_type,
    sym_any_type,
    sym_object_type,
    ACTIONS(77),
    5,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    sym_value_base_type,
    STATE(780),
    5,
    sym_string_type,
    sym_wide_string_type,
    sym_fixed_pt_type,
    sym_sequence_type,
    sym_map_type,
    [5285] = 37,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1443),
    1,
    anon_sym_STAR,
    STATE(89),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1400),
    1,
    sym_const_expr,
    STATE(1671),
    1,
    sym_verbatim_language,
    STATE(1672),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1445),
    4,
    aux_sym_verbatim_language_token1,
    aux_sym_verbatim_language_token2,
    aux_sym_verbatim_language_token3,
    aux_sym_verbatim_language_token4,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [5416] = 37,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1443),
    1,
    anon_sym_STAR,
    STATE(90),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1228),
    1,
    sym_const_expr,
    STATE(1229),
    1,
    sym_verbatim_language,
    STATE(1230),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1445),
    4,
    aux_sym_verbatim_language_token1,
    aux_sym_verbatim_language_token2,
    aux_sym_verbatim_language_token3,
    aux_sym_verbatim_language_token4,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [5547] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(91),
    1,
    sym_comment,
    ACTIONS(1453),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1451),
    44,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [5613] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(92),
    1,
    sym_comment,
    ACTIONS(1403),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1401),
    44,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_exception,
    anon_sym_abstract,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_valuetype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_import,
    anon_sym_Object,
    anon_sym_oneway,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [5679] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(93),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1578),
    1,
    sym_placement_kind,
    STATE(1582),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [5798] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(94),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1369),
    1,
    sym_const_expr,
    STATE(1656),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [5917] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(95),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1417),
    1,
    sym_const_expr,
    STATE(1676),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [6036] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(96),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1464),
    1,
    sym_const_expr,
    STATE(1696),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [6155] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(97),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1318),
    1,
    sym_const_expr,
    STATE(1636),
    1,
    sym_placement_kind,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(1447),
    6,
    aux_sym_placement_kind_token1,
    aux_sym_placement_kind_token2,
    aux_sym_placement_kind_token3,
    aux_sym_placement_kind_token4,
    aux_sym_placement_kind_token5,
    aux_sym_placement_kind_token6,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [6274] = 31,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    ACTIONS(1310),
    1,
    anon_sym_any,
    STATE(98),
    1,
    sym_comment,
    STATE(1113),
    1,
    sym_annotation_member_type,
    STATE(1145),
    1,
    sym_scoped_name,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(1199),
    2,
    sym_any_const_type,
    sym_const_type,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [6386] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1459),
    1,
    anon_sym_AT,
    ACTIONS(1462),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(176),
    1,
    sym_annotation_appl,
    STATE(181),
    1,
    sym_extend_annotation_appl,
    STATE(99),
    2,
    sym_comment,
    aux_sym_interface_dcl_repeat1,
    ACTIONS(1457),
    5,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    ACTIONS(1455),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6454] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1469),
    1,
    anon_sym_LPAREN,
    STATE(100),
    1,
    sym_comment,
    ACTIONS(1467),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1465),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6514] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1475),
    1,
    anon_sym_LPAREN,
    STATE(101),
    1,
    sym_comment,
    ACTIONS(1473),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1471),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6574] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1481),
    1,
    anon_sym_LPAREN,
    STATE(102),
    1,
    sym_comment,
    ACTIONS(1479),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1477),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6634] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1487),
    1,
    anon_sym_LPAREN,
    STATE(103),
    1,
    sym_comment,
    ACTIONS(1485),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1483),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6694] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1493),
    1,
    anon_sym_LPAREN,
    STATE(104),
    1,
    sym_comment,
    ACTIONS(1491),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1489),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6754] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1499),
    1,
    anon_sym_LPAREN,
    STATE(105),
    1,
    sym_comment,
    ACTIONS(1497),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1495),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6814] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1505),
    1,
    anon_sym_LPAREN,
    STATE(106),
    1,
    sym_comment,
    ACTIONS(1503),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1501),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6874] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(107),
    1,
    sym_comment,
    ACTIONS(1509),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1507),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6932] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1515),
    1,
    anon_sym_LPAREN,
    STATE(108),
    1,
    sym_comment,
    ACTIONS(1513),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1511),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [6992] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(109),
    1,
    sym_comment,
    ACTIONS(1519),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1517),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7050] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(110),
    1,
    sym_comment,
    ACTIONS(1523),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1521),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7108] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1529),
    1,
    anon_sym_LPAREN,
    STATE(111),
    1,
    sym_comment,
    ACTIONS(1527),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1525),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7168] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1535),
    1,
    anon_sym_LPAREN,
    STATE(112),
    1,
    sym_comment,
    ACTIONS(1533),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1531),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7228] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1541),
    1,
    anon_sym_LPAREN,
    STATE(113),
    1,
    sym_comment,
    ACTIONS(1539),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1537),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7288] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1547),
    1,
    anon_sym_LPAREN,
    STATE(114),
    1,
    sym_comment,
    ACTIONS(1545),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1543),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7348] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1553),
    1,
    anon_sym_LPAREN,
    STATE(115),
    1,
    sym_comment,
    ACTIONS(1551),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1549),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7408] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1559),
    1,
    anon_sym_LPAREN,
    STATE(116),
    1,
    sym_comment,
    ACTIONS(1557),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1555),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7468] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1565),
    1,
    anon_sym_LPAREN,
    STATE(117),
    1,
    sym_comment,
    ACTIONS(1563),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1561),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7528] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1571),
    1,
    anon_sym_LPAREN,
    STATE(118),
    1,
    sym_comment,
    ACTIONS(1569),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1567),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7588] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(119),
    1,
    sym_comment,
    ACTIONS(1575),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1573),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7645] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(120),
    1,
    sym_comment,
    ACTIONS(1579),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1577),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7702] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(121),
    1,
    sym_comment,
    ACTIONS(1583),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1581),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7759] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(122),
    1,
    sym_comment,
    ACTIONS(1587),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1585),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7816] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(123),
    1,
    sym_comment,
    ACTIONS(1591),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1589),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7873] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(124),
    1,
    sym_comment,
    ACTIONS(1595),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1593),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7930] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(125),
    1,
    sym_comment,
    ACTIONS(1599),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1597),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [7987] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1601),
    1,
    anon_sym_RPAREN,
    ACTIONS(1603),
    1,
    sym_identifier,
    STATE(126),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(916),
    1,
    sym_annotation_appl_param,
    STATE(1247),
    1,
    sym_const_expr,
    STATE(1313),
    1,
    sym_annotation_appl_params,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [8104] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(127),
    1,
    sym_comment,
    ACTIONS(1607),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1605),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8161] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(128),
    1,
    sym_comment,
    ACTIONS(1611),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1609),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8218] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(129),
    1,
    sym_comment,
    ACTIONS(1615),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1613),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8275] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(130),
    1,
    sym_comment,
    ACTIONS(1619),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1617),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8332] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(131),
    1,
    sym_comment,
    ACTIONS(1623),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1621),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8389] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(132),
    1,
    sym_comment,
    ACTIONS(1627),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1625),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8446] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(133),
    1,
    sym_comment,
    ACTIONS(1631),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1629),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8503] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1603),
    1,
    sym_identifier,
    ACTIONS(1633),
    1,
    anon_sym_RPAREN,
    STATE(134),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(916),
    1,
    sym_annotation_appl_param,
    STATE(1247),
    1,
    sym_const_expr,
    STATE(1366),
    1,
    sym_annotation_appl_params,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [8620] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(135),
    1,
    sym_comment,
    ACTIONS(1637),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1635),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8677] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(136),
    1,
    sym_comment,
    ACTIONS(1641),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1639),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8734] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(137),
    1,
    sym_comment,
    ACTIONS(1645),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1643),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8791] = 29,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    STATE(138),
    1,
    sym_comment,
    STATE(1157),
    1,
    sym_scoped_name,
    STATE(1492),
    1,
    sym_const_type,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [8896] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(139),
    1,
    sym_comment,
    ACTIONS(1649),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1647),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [8953] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(140),
    1,
    sym_comment,
    ACTIONS(1653),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1651),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9010] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1655),
    1,
    anon_sym_STAR,
    ACTIONS(1657),
    1,
    aux_sym_service_platform_token2,
    STATE(141),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1098),
    1,
    sym_const_expr,
    STATE(1411),
    1,
    sym_topic_platform,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [9127] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(142),
    1,
    sym_comment,
    ACTIONS(1661),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1659),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9184] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1655),
    1,
    anon_sym_STAR,
    ACTIONS(1657),
    1,
    aux_sym_service_platform_token2,
    STATE(143),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1102),
    1,
    sym_const_expr,
    STATE(1242),
    1,
    sym_topic_platform,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [9301] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(144),
    1,
    sym_comment,
    ACTIONS(1665),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1663),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9358] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(145),
    1,
    sym_comment,
    ACTIONS(1669),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1667),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9415] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(146),
    1,
    sym_comment,
    ACTIONS(1673),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1671),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9472] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1603),
    1,
    sym_identifier,
    ACTIONS(1675),
    1,
    anon_sym_RPAREN,
    STATE(147),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(916),
    1,
    sym_annotation_appl_param,
    STATE(1247),
    1,
    sym_const_expr,
    STATE(1414),
    1,
    sym_annotation_appl_params,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [9589] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(148),
    1,
    sym_comment,
    ACTIONS(1679),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1677),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9646] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(149),
    1,
    sym_comment,
    ACTIONS(1683),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1681),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9703] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(150),
    1,
    sym_comment,
    ACTIONS(1687),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1685),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9760] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(151),
    1,
    sym_comment,
    ACTIONS(1691),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1689),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9817] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1655),
    1,
    anon_sym_STAR,
    ACTIONS(1657),
    1,
    aux_sym_service_platform_token2,
    STATE(152),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1056),
    1,
    sym_const_expr,
    STATE(1310),
    1,
    sym_topic_platform,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [9934] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(153),
    1,
    sym_comment,
    ACTIONS(1695),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1693),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [9991] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(154),
    1,
    sym_comment,
    ACTIONS(1699),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1697),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10048] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(155),
    1,
    sym_comment,
    ACTIONS(1703),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1701),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10105] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1655),
    1,
    anon_sym_STAR,
    ACTIONS(1657),
    1,
    aux_sym_service_platform_token2,
    STATE(156),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1086),
    1,
    sym_const_expr,
    STATE(1363),
    1,
    sym_topic_platform,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [10222] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(157),
    1,
    sym_comment,
    ACTIONS(1707),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1705),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10279] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(158),
    1,
    sym_comment,
    ACTIONS(1711),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1709),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10336] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(159),
    1,
    sym_comment,
    ACTIONS(1715),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1713),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10393] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(160),
    1,
    sym_comment,
    ACTIONS(1719),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1717),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10450] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(161),
    1,
    sym_comment,
    ACTIONS(1723),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1721),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10507] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(162),
    1,
    sym_comment,
    ACTIONS(1727),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1725),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10564] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(163),
    1,
    sym_comment,
    ACTIONS(1731),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1729),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10621] = 29,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(95),
    1,
    anon_sym_longdouble,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(99),
    1,
    anon_sym_string,
    ACTIONS(101),
    1,
    anon_sym_wstring,
    ACTIONS(105),
    1,
    anon_sym_sequence,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1308),
    1,
    anon_sym_fixed,
    STATE(164),
    1,
    sym_comment,
    STATE(1157),
    1,
    sym_scoped_name,
    STATE(1518),
    1,
    sym_const_type,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    ACTIONS(93),
    2,
    anon_sym_float,
    anon_sym_double,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    ACTIONS(1306),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    STATE(1523),
    6,
    sym_fixed_pt_const_type,
    sym_integer_type,
    sym_floating_pt_type,
    sym_string_type,
    sym_wide_string_type,
    sym_sequence_type,
    [10726] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(165),
    1,
    sym_comment,
    ACTIONS(1735),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1733),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10783] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(166),
    1,
    sym_comment,
    ACTIONS(1739),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1737),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10840] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(167),
    1,
    sym_comment,
    ACTIONS(1743),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1741),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10897] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(168),
    1,
    sym_comment,
    ACTIONS(1747),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1745),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [10954] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(169),
    1,
    sym_comment,
    ACTIONS(1751),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1749),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11011] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1655),
    1,
    anon_sym_STAR,
    ACTIONS(1657),
    1,
    aux_sym_service_platform_token2,
    STATE(170),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1117),
    1,
    sym_const_expr,
    STATE(1458),
    1,
    sym_topic_platform,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [11128] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(171),
    1,
    sym_comment,
    ACTIONS(1755),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1753),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11185] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(172),
    1,
    sym_comment,
    ACTIONS(1759),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1757),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11242] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1603),
    1,
    sym_identifier,
    ACTIONS(1761),
    1,
    anon_sym_RPAREN,
    STATE(173),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(916),
    1,
    sym_annotation_appl_param,
    STATE(1247),
    1,
    sym_const_expr,
    STATE(1248),
    1,
    sym_annotation_appl_params,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [11359] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(174),
    1,
    sym_comment,
    ACTIONS(1765),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1763),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11416] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(175),
    1,
    sym_comment,
    ACTIONS(1769),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1767),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11473] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(176),
    1,
    sym_comment,
    ACTIONS(1773),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1771),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11530] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(177),
    1,
    sym_comment,
    ACTIONS(1777),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1775),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11587] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(178),
    1,
    sym_comment,
    ACTIONS(1781),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1779),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11644] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(179),
    1,
    sym_comment,
    ACTIONS(1785),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1783),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11701] = 35,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1603),
    1,
    sym_identifier,
    ACTIONS(1787),
    1,
    anon_sym_RPAREN,
    STATE(180),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(916),
    1,
    sym_annotation_appl_param,
    STATE(1247),
    1,
    sym_const_expr,
    STATE(1461),
    1,
    sym_annotation_appl_params,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [11818] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(181),
    1,
    sym_comment,
    ACTIONS(1791),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1789),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11875] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(182),
    1,
    sym_comment,
    ACTIONS(1795),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1793),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11932] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(183),
    1,
    sym_comment,
    ACTIONS(1799),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1797),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [11989] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(184),
    1,
    sym_comment,
    ACTIONS(1803),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1801),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [12046] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(185),
    1,
    sym_comment,
    ACTIONS(1807),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1805),
    36,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_void,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_Object,
    sym_value_base_type,
    anon_sym_native,
    sym_identifier,
    [12103] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1809),
    1,
    anon_sym_RPAREN,
    STATE(186),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1434),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12217] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1811),
    1,
    anon_sym_RPAREN,
    STATE(187),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1204),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12331] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1817),
    1,
    anon_sym_default,
    ACTIONS(1820),
    1,
    anon_sym_case,
    STATE(273),
    1,
    sym_case_label,
    STATE(188),
    2,
    sym_comment,
    aux_sym_case_repeat1,
    ACTIONS(1815),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1813),
    31,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [12393] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1823),
    1,
    anon_sym_RPAREN,
    STATE(189),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1387),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12507] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1825),
    1,
    anon_sym_RPAREN,
    STATE(190),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1339),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12621] = 34,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1827),
    1,
    anon_sym_RPAREN,
    STATE(191),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1286),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12735] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1829),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(192),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1365),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12846] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(193),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1350),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [12957] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1831),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(194),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1460),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13068] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1833),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(195),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1459),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13179] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(196),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1446),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13290] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(197),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1298),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13401] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(198),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1297),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13512] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(199),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1296),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13623] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(200),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1445),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13734] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(201),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1294),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13845] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(202),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1293),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [13956] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(203),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1444),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14067] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(204),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1291),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14178] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(205),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1290),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14289] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(206),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1442),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14400] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(207),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1205),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14511] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(208),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1441),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14622] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(209),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1287),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14733] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(210),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1210),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14844] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(211),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1211),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [14955] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(212),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1439),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15066] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(213),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1219),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15177] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(214),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1221),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15288] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(215),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1438),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15399] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(216),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1223),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15510] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(217),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1224),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15621] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(218),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1225),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15732] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(219),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1435),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15843] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1835),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(220),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1413),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [15954] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1837),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(221),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1412),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16065] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(222),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1399),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16176] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(223),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1398),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16287] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1839),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(224),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1244),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16398] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1841),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(225),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1246),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16509] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(226),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1133),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16620] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(227),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1397),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16731] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(228),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1395),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16842] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1843),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(229),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1311),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [16953] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1845),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(230),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1312),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17064] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(231),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1394),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17175] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(232),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1392),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17286] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(233),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1391),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17397] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(234),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1388),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17508] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(235),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1553),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17619] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(236),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1257),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17730] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(237),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1258),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17841] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(238),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1340),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [17952] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(239),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1559),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18063] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(240),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1343),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18174] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(241),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1260),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18285] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(242),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1344),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18396] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(243),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1431),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18507] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1847),
    1,
    aux_sym_annotation_appl_dds_request_topic_token2,
    STATE(244),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1364),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18618] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(245),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1346),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18729] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(246),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1423),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18840] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(247),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1594),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [18951] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(248),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1347),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19062] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(249),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1509),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19173] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(250),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1351),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19284] = 33,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(251),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(689),
    1,
    sym_const_expr,
    STATE(1349),
    1,
    sym_positive_int_const,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19395] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(252),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1323),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19503] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(253),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1404),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19611] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(254),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1469),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19719] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(255),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1354),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19827] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(256),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1468),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [19935] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(257),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1456),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20043] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(258),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1465),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20151] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(259),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1510),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20259] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(260),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1301),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20367] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(261),
    1,
    sym_comment,
    ACTIONS(1851),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1849),
    33,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_default,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_case,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [20421] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(262),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1355),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20529] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(263),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1356),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20637] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(264),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1302),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20745] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(265),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1453),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20853] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(266),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1452),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [20961] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(267),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1451),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21069] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(268),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1357),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21177] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(269),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1450),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21285] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(270),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1504),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21393] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(271),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1348),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21501] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(272),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1576),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21609] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(273),
    1,
    sym_comment,
    ACTIONS(1855),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1853),
    33,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_default,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_case,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [21663] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(274),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1569),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21771] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(275),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1358),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21879] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(276),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1568),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [21987] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(277),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1061),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22095] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(278),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1471),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22203] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(279),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1457),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22311] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(280),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1370),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22419] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(281),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1429),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22527] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(282),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1345),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22635] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(283),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1462),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22743] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(284),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1449),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22851] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(285),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1373),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [22959] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(286),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1374),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23067] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(287),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1295),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23175] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(288),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1341),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23283] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(289),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1376),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23391] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(290),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1326),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23499] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(291),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1389),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23607] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(292),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1303),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23715] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(293),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1322),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23823] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(294),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1393),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [23931] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(295),
    1,
    sym_comment,
    ACTIONS(1859),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1857),
    33,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_default,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_case,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [23985] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(296),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1319),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24093] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(297),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1396),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24201] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(298),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1305),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24309] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(299),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1304),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24417] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(300),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1237),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24525] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(301),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1292),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24633] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(302),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1288),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24741] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(303),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1402),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24849] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(304),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1403),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [24957] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(305),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1371),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25065] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(306),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1405),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25173] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(307),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1406),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25281] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(308),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1236),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25389] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(309),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1235),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25497] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(310),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1418),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25605] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(311),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1421),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25713] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(312),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1422),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25821] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(313),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1424),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [25929] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(314),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1234),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26037] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(315),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1170),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26145] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(316),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1233),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26253] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(317),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1222),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26361] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(318),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1440),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26469] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(319),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1443),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26577] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(320),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1240),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26685] = 32,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(321),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(580),
    1,
    sym_xor_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(595),
    1,
    sym_or_expr,
    STATE(1206),
    1,
    sym_const_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26793] = 30,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(322),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(579),
    1,
    sym_and_expr,
    STATE(582),
    1,
    sym_integer_sign,
    STATE(583),
    1,
    sym_xor_expr,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26895] = 29,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(323),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(563),
    1,
    sym_shift_expr,
    STATE(575),
    1,
    sym_and_expr,
    STATE(582),
    1,
    sym_integer_sign,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [26994] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1861),
    1,
    anon_sym_AT,
    ACTIONS(1864),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(399),
    1,
    sym_extend_annotation_appl,
    STATE(400),
    1,
    sym_annotation_appl,
    STATE(324),
    2,
    sym_comment,
    aux_sym_interface_dcl_repeat1,
    ACTIONS(1457),
    5,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    ACTIONS(1455),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27052] = 28,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(325),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(553),
    1,
    sym_add_expr,
    STATE(564),
    1,
    sym_shift_expr,
    STATE(582),
    1,
    sym_integer_sign,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [27148] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(326),
    1,
    sym_comment,
    STATE(353),
    1,
    sym_extend_annotation_appl,
    ACTIONS(1869),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1867),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27199] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(327),
    1,
    sym_comment,
    STATE(345),
    1,
    sym_extend_annotation_appl,
    ACTIONS(1873),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1871),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27250] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(328),
    1,
    sym_comment,
    STATE(347),
    1,
    sym_extend_annotation_appl,
    ACTIONS(1877),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1875),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27301] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(329),
    1,
    sym_comment,
    STATE(346),
    1,
    sym_extend_annotation_appl,
    ACTIONS(1881),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1879),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27352] = 27,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(330),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(477),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(554),
    1,
    sym_add_expr,
    STATE(582),
    1,
    sym_integer_sign,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [27445] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1883),
    1,
    anon_sym_LPAREN,
    STATE(331),
    1,
    sym_comment,
    ACTIONS(1485),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1483),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27495] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(332),
    1,
    sym_comment,
    ACTIONS(1679),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1677),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27543] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(333),
    1,
    sym_comment,
    ACTIONS(1519),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1517),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27591] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1885),
    1,
    anon_sym_LPAREN,
    STATE(334),
    1,
    sym_comment,
    ACTIONS(1503),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1501),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27641] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(335),
    1,
    sym_comment,
    ACTIONS(1807),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1805),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27689] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1887),
    1,
    anon_sym_LPAREN,
    STATE(336),
    1,
    sym_comment,
    ACTIONS(1513),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1511),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27739] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1889),
    1,
    anon_sym_LPAREN,
    STATE(337),
    1,
    sym_comment,
    ACTIONS(1497),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1495),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27789] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1891),
    1,
    anon_sym_LPAREN,
    STATE(338),
    1,
    sym_comment,
    ACTIONS(1473),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1471),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27839] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(339),
    1,
    sym_comment,
    ACTIONS(1523),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1521),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27887] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(340),
    1,
    sym_comment,
    ACTIONS(1895),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1893),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27935] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1897),
    1,
    anon_sym_LPAREN,
    STATE(341),
    1,
    sym_comment,
    ACTIONS(1479),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1477),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [27985] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1899),
    1,
    anon_sym_LPAREN,
    STATE(342),
    1,
    sym_comment,
    ACTIONS(1467),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1465),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28035] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1901),
    1,
    anon_sym_LPAREN,
    STATE(343),
    1,
    sym_comment,
    ACTIONS(1569),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1567),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28085] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(344),
    1,
    sym_comment,
    ACTIONS(1509),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1507),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28133] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(345),
    1,
    sym_comment,
    ACTIONS(1905),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1903),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28181] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(346),
    1,
    sym_comment,
    ACTIONS(1873),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1871),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28229] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(347),
    1,
    sym_comment,
    ACTIONS(1869),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1867),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28277] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1907),
    1,
    anon_sym_LPAREN,
    STATE(348),
    1,
    sym_comment,
    ACTIONS(1563),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1561),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28327] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1909),
    1,
    anon_sym_LPAREN,
    STATE(349),
    1,
    sym_comment,
    ACTIONS(1527),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1525),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28377] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1911),
    1,
    anon_sym_LPAREN,
    STATE(350),
    1,
    sym_comment,
    ACTIONS(1533),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1531),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28427] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1913),
    1,
    anon_sym_LPAREN,
    STATE(351),
    1,
    sym_comment,
    ACTIONS(1551),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1549),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28477] = 26,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(352),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(460),
    1,
    sym_mult_expr,
    STATE(482),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(582),
    1,
    sym_integer_sign,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [28567] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(353),
    1,
    sym_comment,
    ACTIONS(1917),
    8,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1915),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28615] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1919),
    1,
    anon_sym_LPAREN,
    STATE(354),
    1,
    sym_comment,
    ACTIONS(1491),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1489),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28665] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1921),
    1,
    anon_sym_LPAREN,
    STATE(355),
    1,
    sym_comment,
    ACTIONS(1557),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1555),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28715] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1923),
    1,
    anon_sym_LPAREN,
    STATE(356),
    1,
    sym_comment,
    ACTIONS(1539),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1537),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28765] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1925),
    1,
    anon_sym_LPAREN,
    STATE(357),
    1,
    sym_comment,
    ACTIONS(1545),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1543),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28815] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(358),
    1,
    sym_comment,
    ACTIONS(1661),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1659),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28862] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(359),
    1,
    sym_comment,
    ACTIONS(1673),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1671),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28909] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(360),
    1,
    sym_comment,
    ACTIONS(1683),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1681),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [28956] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(361),
    1,
    sym_comment,
    ACTIONS(1765),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1763),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29003] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(362),
    1,
    sym_comment,
    ACTIONS(1929),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1927),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [29050] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(363),
    1,
    sym_comment,
    ACTIONS(1755),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1753),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29097] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(364),
    1,
    sym_comment,
    ACTIONS(1751),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1749),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29144] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(365),
    1,
    sym_comment,
    ACTIONS(1747),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1745),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29191] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(366),
    1,
    sym_comment,
    ACTIONS(1743),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1741),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29238] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(367),
    1,
    sym_comment,
    ACTIONS(1739),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1737),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29285] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(368),
    1,
    sym_comment,
    ACTIONS(1707),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1705),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29332] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(369),
    1,
    sym_comment,
    ACTIONS(1735),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1733),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29379] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(370),
    1,
    sym_comment,
    ACTIONS(1731),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1729),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29426] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(371),
    1,
    sym_comment,
    ACTIONS(1727),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1725),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29473] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(372),
    1,
    sym_comment,
    ACTIONS(1723),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1721),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29520] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(373),
    1,
    sym_comment,
    ACTIONS(1587),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1585),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29567] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(374),
    1,
    sym_comment,
    ACTIONS(1799),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1797),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29614] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(375),
    1,
    sym_comment,
    ACTIONS(1719),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1717),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29661] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(376),
    1,
    sym_comment,
    ACTIONS(1715),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1713),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29708] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(377),
    1,
    sym_comment,
    ACTIONS(1933),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1931),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [29755] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(378),
    1,
    sym_comment,
    ACTIONS(1579),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1577),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29802] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(379),
    1,
    sym_comment,
    ACTIONS(1703),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1701),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29849] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(380),
    1,
    sym_comment,
    ACTIONS(1695),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1693),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29896] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(381),
    1,
    sym_comment,
    ACTIONS(1937),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1935),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [29943] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(382),
    1,
    sym_comment,
    ACTIONS(1687),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1685),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [29990] = 25,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(600),
    1,
    anon_sym_TILDE,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(383),
    1,
    sym_comment,
    STATE(432),
    1,
    sym_unary_operator,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(465),
    1,
    sym_unary_expr,
    STATE(489),
    1,
    sym_literal,
    STATE(494),
    1,
    sym_primary_expr,
    STATE(582),
    1,
    sym_integer_sign,
    ACTIONS(596),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [30077] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(384),
    1,
    sym_comment,
    ACTIONS(1623),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1621),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30124] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(385),
    1,
    sym_comment,
    ACTIONS(1803),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1801),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30171] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(386),
    1,
    sym_comment,
    ACTIONS(1669),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1667),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30218] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(387),
    1,
    sym_comment,
    ACTIONS(1941),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1939),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [30265] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(388),
    1,
    sym_comment,
    ACTIONS(1575),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1573),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30312] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(389),
    1,
    sym_comment,
    ACTIONS(1615),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1613),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30359] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(390),
    1,
    sym_comment,
    ACTIONS(1945),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1943),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [30406] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(391),
    1,
    sym_comment,
    ACTIONS(1769),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1767),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30453] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(392),
    1,
    sym_comment,
    ACTIONS(1699),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1697),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30500] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(393),
    1,
    sym_comment,
    ACTIONS(1653),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1651),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30547] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(394),
    1,
    sym_comment,
    ACTIONS(1777),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1775),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30594] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(395),
    1,
    sym_comment,
    ACTIONS(1599),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1597),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30641] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(396),
    1,
    sym_comment,
    ACTIONS(1711),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1709),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30688] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(397),
    1,
    sym_comment,
    ACTIONS(1785),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1783),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30735] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(398),
    1,
    sym_comment,
    ACTIONS(1949),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1947),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [30782] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(399),
    1,
    sym_comment,
    ACTIONS(1791),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1789),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30829] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(400),
    1,
    sym_comment,
    ACTIONS(1773),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1771),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30876] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(401),
    1,
    sym_comment,
    ACTIONS(1759),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1757),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30923] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(402),
    1,
    sym_comment,
    ACTIONS(1795),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1793),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [30970] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(403),
    1,
    sym_comment,
    ACTIONS(1781),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1779),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31017] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(404),
    1,
    sym_comment,
    ACTIONS(1649),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1647),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31064] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(405),
    1,
    sym_comment,
    ACTIONS(1691),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1689),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31111] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(406),
    1,
    sym_comment,
    ACTIONS(1665),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1663),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31158] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(407),
    1,
    sym_comment,
    ACTIONS(1583),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1581),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31205] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(408),
    1,
    sym_comment,
    ACTIONS(1591),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1589),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31252] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(409),
    1,
    sym_comment,
    ACTIONS(1595),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1593),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31299] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(410),
    1,
    sym_comment,
    ACTIONS(1607),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1605),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31346] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(411),
    1,
    sym_comment,
    ACTIONS(1953),
    6,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_RBRACE,
    ACTIONS(1951),
    27,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_attribute,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_typedef,
    sym_identifier,
    [31393] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(412),
    1,
    sym_comment,
    ACTIONS(1611),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1609),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31440] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(413),
    1,
    sym_comment,
    ACTIONS(1645),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1643),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31487] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(414),
    1,
    sym_comment,
    ACTIONS(1619),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1617),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31534] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(415),
    1,
    sym_comment,
    ACTIONS(1627),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1625),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31581] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(416),
    1,
    sym_comment,
    ACTIONS(1631),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1629),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31628] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(417),
    1,
    sym_comment,
    ACTIONS(1641),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1639),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31675] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(418),
    1,
    sym_comment,
    ACTIONS(1637),
    7,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1635),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [31722] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(419),
    1,
    sym_comment,
    ACTIONS(1957),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1955),
    29,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [31768] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(420),
    1,
    sym_comment,
    ACTIONS(1961),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1959),
    29,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [31814] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(421),
    1,
    sym_comment,
    ACTIONS(1965),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1963),
    29,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [31860] = 25,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(21),
    1,
    anon_sym_interface,
    ACTIONS(23),
    1,
    anon_sym_bitset,
    ACTIONS(25),
    1,
    anon_sym_bitmask,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(39),
    1,
    anon_sym_struct,
    ACTIONS(41),
    1,
    anon_sym_union,
    ACTIONS(43),
    1,
    anon_sym_enum,
    ACTIONS(49),
    1,
    anon_sym_typedef,
    ACTIONS(65),
    1,
    anon_sym_native,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(1969),
    1,
    anon_sym_module,
    STATE(422),
    1,
    sym_comment,
    STATE(448),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(1583),
    1,
    sym_interface_header,
    STATE(1585),
    1,
    sym_interface_kind,
    ACTIONS(17),
    2,
    anon_sym_local,
    anon_sym_abstract,
    STATE(1046),
    2,
    sym_union_forward_dcl,
    sym_union_def,
    STATE(1060),
    2,
    sym_struct_forward_dcl,
    sym_struct_def,
    STATE(1377),
    2,
    sym_interface_forward_dcl,
    sym_interface_def,
    STATE(1488),
    3,
    sym_typedef_dcl,
    sym_constr_type_dcl,
    sym_native_dcl,
    STATE(1059),
    5,
    sym_bitset_dcl,
    sym_bitmask_dcl,
    sym_enum_dcl,
    sym_union_dcl,
    sym_struct_dcl,
    [31946] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(423),
    1,
    sym_comment,
    ACTIONS(1973),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1971),
    29,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [31992] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(424),
    1,
    sym_comment,
    ACTIONS(1977),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1975),
    29,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [32038] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(425),
    1,
    sym_comment,
    ACTIONS(1981),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1979),
    29,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [32084] = 23,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(71),
    1,
    anon_sym_longlong,
    ACTIONS(73),
    1,
    anon_sym_int64,
    ACTIONS(75),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(81),
    1,
    sym_signed_tiny_int,
    ACTIONS(83),
    1,
    anon_sym_unsignedshort,
    ACTIONS(85),
    1,
    anon_sym_uint16,
    ACTIONS(89),
    1,
    anon_sym_unsignedlonglong,
    ACTIONS(91),
    1,
    anon_sym_uint64,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(426),
    1,
    sym_comment,
    STATE(1162),
    1,
    sym_scoped_name,
    STATE(1501),
    1,
    sym_integer_type,
    STATE(1502),
    1,
    sym_switch_type_spec,
    ACTIONS(67),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(69),
    2,
    anon_sym_long,
    anon_sym_int32,
    ACTIONS(87),
    2,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    ACTIONS(1983),
    4,
    sym_boolean_type,
    sym_octet_type,
    sym_char_type,
    sym_wide_char_type,
    [32165] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(427),
    1,
    sym_comment,
    ACTIONS(1985),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1987),
    28,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [32210] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(428),
    1,
    sym_comment,
    ACTIONS(1991),
    5,
    anon_sym_longlong,
    anon_sym_unsignedshort,
    anon_sym_unsignedlonglong,
    anon_sym_longdouble,
    anon_sym_COLON_COLON,
    ACTIONS(1989),
    26,
    anon_sym_short,
    anon_sym_int16,
    anon_sym_long,
    anon_sym_int32,
    anon_sym_int64,
    sym_unsigned_tiny_int,
    sym_boolean_type,
    anon_sym_fixed,
    sym_octet_type,
    sym_signed_tiny_int,
    anon_sym_uint16,
    anon_sym_unsignedlong,
    anon_sym_uint32,
    anon_sym_uint64,
    anon_sym_float,
    anon_sym_double,
    sym_char_type,
    sym_wide_char_type,
    anon_sym_string,
    anon_sym_wstring,
    anon_sym_any,
    anon_sym_sequence,
    anon_sym_map,
    anon_sym_Object,
    sym_value_base_type,
    sym_identifier,
    [32255] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(429),
    1,
    sym_comment,
    ACTIONS(1993),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1995),
    28,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [32300] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(430),
    1,
    sym_comment,
    ACTIONS(1999),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(1997),
    28,
    ts_builtin_sym_end,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [32345] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(431),
    1,
    sym_comment,
    ACTIONS(2001),
    3,
    anon_sym_POUNDdefine,
    sym_preproc_directive,
    anon_sym_AT,
    ACTIONS(2003),
    28,
    aux_sym_preproc_include_token1,
    anon_sym_exception,
    anon_sym_RBRACE,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_ATannotation,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_valuetype,
    anon_sym_eventtype,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_const,
    anon_sym_alias,
    anon_sym_custom,
    anon_sym_typedef,
    anon_sym_typeid,
    anon_sym_typeprefix,
    anon_sym_import,
    anon_sym_component,
    anon_sym_home,
    anon_sym_porttype,
    anon_sym_connector,
    anon_sym_native,
    [32390] = 22,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(598),
    1,
    anon_sym_LPAREN,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(612),
    1,
    anon_sym_L,
    ACTIONS(614),
    1,
    anon_sym_SQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(432),
    1,
    sym_comment,
    STATE(450),
    1,
    sym_scoped_name,
    STATE(455),
    1,
    sym_dec_number,
    STATE(459),
    1,
    sym_oct_number,
    STATE(489),
    1,
    sym_literal,
    STATE(490),
    1,
    sym_primary_expr,
    STATE(582),
    1,
    sym_integer_sign,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(616),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    ACTIONS(2005),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    STATE(492),
    8,
    sym_integer_literal,
    sym_floating_pt_literal,
    sym_fixed_pt_literal,
    sym_string_literal,
    sym_wide_string_literal,
    sym_char_literal,
    sym_wide_character_literal,
    sym_boolean_literal,
    [32468] = 22,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2007),
    1,
    anon_sym_RBRACE,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    ACTIONS(2017),
    1,
    anon_sym_emits,
    ACTIONS(2019),
    1,
    anon_sym_publishes,
    ACTIONS(2021),
    1,
    anon_sym_consumes,
    STATE(433),
    1,
    sym_comment,
    STATE(434),
    1,
    aux_sym_component_body_repeat1,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(556),
    1,
    sym_component_export,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(1176),
    1,
    sym_component_body,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1177),
    7,
    sym_attr_dcl,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_emits_dcl,
    sym_publishes_dcl,
    sym_consumes_dcl,
    sym_port_dcl,
    [32543] = 21,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    ACTIONS(2017),
    1,
    anon_sym_emits,
    ACTIONS(2019),
    1,
    anon_sym_publishes,
    ACTIONS(2021),
    1,
    anon_sym_consumes,
    ACTIONS(2025),
    1,
    anon_sym_RBRACE,
    STATE(434),
    1,
    sym_comment,
    STATE(436),
    1,
    aux_sym_component_body_repeat1,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(556),
    1,
    sym_component_export,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1177),
    7,
    sym_attr_dcl,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_emits_dcl,
    sym_publishes_dcl,
    sym_consumes_dcl,
    sym_port_dcl,
    [32615] = 19,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(69),
    1,
    anon_sym_long,
    ACTIONS(87),
    1,
    anon_sym_unsignedlong,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2029),
    1,
    anon_sym_int32,
    ACTIONS(2031),
    1,
    sym_unsigned_tiny_int,
    ACTIONS(2035),
    1,
    sym_signed_tiny_int,
    ACTIONS(2037),
    1,
    anon_sym_uint32,
    STATE(435),
    1,
    sym_comment,
    STATE(1466),
    1,
    sym_destination_type,
    STATE(1470),
    1,
    sym_integer_type,
    ACTIONS(71),
    2,
    anon_sym_longlong,
    anon_sym_int64,
    ACTIONS(83),
    2,
    anon_sym_unsignedshort,
    anon_sym_uint16,
    ACTIONS(89),
    2,
    anon_sym_unsignedlonglong,
    anon_sym_uint64,
    ACTIONS(2027),
    2,
    anon_sym_short,
    anon_sym_int16,
    ACTIONS(2033),
    2,
    sym_boolean_type,
    sym_octet_type,
    STATE(638),
    2,
    sym_unsigned_int,
    sym_signed_int,
    STATE(662),
    3,
    sym_signed_short_int,
    sym_signed_long_int,
    sym_signed_longlong_int,
    STATE(664),
    3,
    sym_unsigned_short_int,
    sym_unsigned_long_int,
    sym_unsigned_longlong_int,
    [32683] = 20,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2039),
    1,
    anon_sym_RBRACE,
    ACTIONS(2041),
    1,
    anon_sym_readonly,
    ACTIONS(2044),
    1,
    anon_sym_attribute,
    ACTIONS(2047),
    1,
    anon_sym_AT,
    ACTIONS(2050),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2053),
    1,
    anon_sym_provides,
    ACTIONS(2056),
    1,
    anon_sym_uses,
    ACTIONS(2059),
    1,
    anon_sym_emits,
    ACTIONS(2062),
    1,
    anon_sym_publishes,
    ACTIONS(2065),
    1,
    anon_sym_consumes,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(556),
    1,
    sym_component_export,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    ACTIONS(2068),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(436),
    2,
    sym_comment,
    aux_sym_component_body_repeat1,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1177),
    7,
    sym_attr_dcl,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_emits_dcl,
    sym_publishes_dcl,
    sym_consumes_dcl,
    sym_port_dcl,
    [32753] = 20,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    ACTIONS(2071),
    1,
    anon_sym_RBRACE,
    STATE(437),
    1,
    sym_comment,
    STATE(441),
    1,
    aux_sym_port_body_repeat1,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(568),
    1,
    sym_port_export,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(576),
    1,
    sym_port_ref,
    STATE(1543),
    1,
    sym_attr_dcl,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [32818] = 19,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2073),
    1,
    anon_sym_RBRACE,
    ACTIONS(2075),
    1,
    anon_sym_readonly,
    ACTIONS(2078),
    1,
    anon_sym_attribute,
    ACTIONS(2081),
    1,
    anon_sym_AT,
    ACTIONS(2084),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2087),
    1,
    anon_sym_provides,
    ACTIONS(2090),
    1,
    anon_sym_uses,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(566),
    1,
    sym_connector_export,
    STATE(567),
    1,
    sym_port_ref,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(1186),
    1,
    sym_attr_dcl,
    ACTIONS(2093),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(438),
    2,
    sym_comment,
    aux_sym_connector_dcl_repeat1,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [32881] = 20,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    ACTIONS(2096),
    1,
    anon_sym_RBRACE,
    STATE(438),
    1,
    aux_sym_connector_dcl_repeat1,
    STATE(439),
    1,
    sym_comment,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(566),
    1,
    sym_connector_export,
    STATE(567),
    1,
    sym_port_ref,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(1186),
    1,
    sym_attr_dcl,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [32946] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(440),
    1,
    sym_comment,
    ACTIONS(1521),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1523),
    18,
    anon_sym_COLON_COLON,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    anon_sym_supports,
    anon_sym_RBRACK,
    anon_sym_manages,
    anon_sym_primarykey,
    [32981] = 19,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2098),
    1,
    anon_sym_RBRACE,
    ACTIONS(2100),
    1,
    anon_sym_readonly,
    ACTIONS(2103),
    1,
    anon_sym_attribute,
    ACTIONS(2106),
    1,
    anon_sym_AT,
    ACTIONS(2109),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2112),
    1,
    anon_sym_provides,
    ACTIONS(2115),
    1,
    anon_sym_uses,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(568),
    1,
    sym_port_export,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(576),
    1,
    sym_port_ref,
    STATE(1543),
    1,
    sym_attr_dcl,
    ACTIONS(2118),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(441),
    2,
    sym_comment,
    aux_sym_port_body_repeat1,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [33044] = 20,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    ACTIONS(2121),
    1,
    anon_sym_RBRACE,
    STATE(437),
    1,
    aux_sym_port_body_repeat1,
    STATE(442),
    1,
    sym_comment,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(568),
    1,
    sym_port_export,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(576),
    1,
    sym_port_ref,
    STATE(1543),
    1,
    sym_attr_dcl,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [33109] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(443),
    1,
    sym_comment,
    ACTIONS(1517),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1519),
    18,
    anon_sym_COLON_COLON,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    anon_sym_supports,
    anon_sym_RBRACK,
    anon_sym_manages,
    anon_sym_primarykey,
    [33144] = 19,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    STATE(439),
    1,
    aux_sym_connector_dcl_repeat1,
    STATE(444),
    1,
    sym_comment,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(566),
    1,
    sym_connector_export,
    STATE(567),
    1,
    sym_port_ref,
    STATE(572),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(1186),
    1,
    sym_attr_dcl,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1183),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [33206] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(445),
    1,
    sym_comment,
    ACTIONS(1507),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(1509),
    17,
    anon_sym_COLON_COLON,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_DQUOTE,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    sym_identifier,
    [33240] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(446),
    1,
    sym_comment,
    ACTIONS(2123),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2125),
    17,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_DOT,
    aux_sym_floating_pt_literal_token1,
    aux_sym_fixed_pt_literal_token1,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33273] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2131),
    1,
    aux_sym_floating_pt_literal_token1,
    ACTIONS(2133),
    1,
    aux_sym_fixed_pt_literal_token1,
    STATE(447),
    1,
    sym_comment,
    ACTIONS(2127),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2129),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33309] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2135),
    1,
    anon_sym_AT,
    ACTIONS(2138),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(448),
    2,
    sym_comment,
    aux_sym_interface_dcl_repeat1,
    ACTIONS(1457),
    13,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33347] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2145),
    1,
    aux_sym_floating_pt_literal_token1,
    ACTIONS(2147),
    1,
    aux_sym_fixed_pt_literal_token1,
    STATE(449),
    1,
    sym_comment,
    ACTIONS(2141),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2143),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33383] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    STATE(450),
    1,
    sym_comment,
    ACTIONS(2151),
    3,
    anon_sym_GT,
    anon_sym_SLASH,
    anon_sym_COLON,
    ACTIONS(2153),
    13,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33416] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2155),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2157),
    1,
    anon_sym_LPAREN,
    STATE(451),
    1,
    sym_comment,
    ACTIONS(1539),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33449] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(452),
    1,
    sym_comment,
    ACTIONS(1519),
    17,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33478] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2163),
    1,
    anon_sym_DOT,
    STATE(453),
    1,
    sym_comment,
    ACTIONS(2159),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2161),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33511] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(454),
    1,
    sym_comment,
    ACTIONS(1523),
    17,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33540] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2169),
    1,
    anon_sym_DOT,
    STATE(455),
    1,
    sym_comment,
    ACTIONS(2165),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2167),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33573] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(456),
    1,
    sym_comment,
    ACTIONS(1509),
    17,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33602] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2171),
    1,
    anon_sym_LPAREN,
    STATE(457),
    1,
    sym_comment,
    ACTIONS(1557),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33632] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(458),
    1,
    sym_comment,
    ACTIONS(2173),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2175),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33662] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(459),
    1,
    sym_comment,
    ACTIONS(2165),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2167),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33692] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2177),
    1,
    anon_sym_GT,
    ACTIONS(2183),
    1,
    anon_sym_SLASH,
    STATE(460),
    1,
    sym_comment,
    ACTIONS(2181),
    2,
    anon_sym_STAR,
    anon_sym_PERCENT,
    ACTIONS(2179),
    12,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33726] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(461),
    1,
    sym_comment,
    ACTIONS(2185),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2187),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33756] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(462),
    1,
    sym_comment,
    ACTIONS(2189),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2191),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33786] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(463),
    1,
    sym_comment,
    ACTIONS(2193),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2195),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33816] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(464),
    1,
    sym_comment,
    ACTIONS(2197),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2199),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33846] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(465),
    1,
    sym_comment,
    ACTIONS(2201),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2203),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33876] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(466),
    1,
    sym_comment,
    ACTIONS(2207),
    5,
    anon_sym_0,
    anon_sym_L,
    anon_sym_TRUE,
    anon_sym_FALSE,
    sym_identifier,
    ACTIONS(2205),
    11,
    anon_sym_COLON_COLON,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_LPAREN,
    sym_bin_number,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    aux_sym_dec_number_token1,
    sym_hex_number,
    anon_sym_DQUOTE,
    anon_sym_SQUOTE,
    [33906] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(467),
    1,
    sym_comment,
    ACTIONS(2207),
    5,
    anon_sym_0,
    anon_sym_L,
    anon_sym_TRUE,
    anon_sym_FALSE,
    sym_identifier,
    ACTIONS(2205),
    11,
    anon_sym_COLON_COLON,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_LPAREN,
    sym_bin_number,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    aux_sym_dec_number_token1,
    sym_hex_number,
    anon_sym_DQUOTE,
    anon_sym_SQUOTE,
    [33936] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(468),
    1,
    sym_comment,
    ACTIONS(2209),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2211),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [33966] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2213),
    1,
    anon_sym_LPAREN,
    STATE(469),
    1,
    sym_comment,
    ACTIONS(1503),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [33996] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2215),
    1,
    anon_sym_LPAREN,
    STATE(470),
    1,
    sym_comment,
    ACTIONS(1513),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34026] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(471),
    1,
    sym_comment,
    ACTIONS(2217),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2219),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34056] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(472),
    1,
    sym_comment,
    ACTIONS(2221),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2223),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34086] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(473),
    1,
    sym_comment,
    ACTIONS(2127),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2129),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34116] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(474),
    1,
    sym_comment,
    ACTIONS(2225),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2227),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34146] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2229),
    1,
    anon_sym_LPAREN,
    STATE(475),
    1,
    sym_comment,
    ACTIONS(1497),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34176] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2231),
    1,
    anon_sym_LPAREN,
    STATE(476),
    1,
    sym_comment,
    ACTIONS(1473),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34206] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2183),
    1,
    anon_sym_SLASH,
    ACTIONS(2233),
    1,
    anon_sym_GT,
    STATE(477),
    1,
    sym_comment,
    ACTIONS(2181),
    2,
    anon_sym_STAR,
    anon_sym_PERCENT,
    ACTIONS(2235),
    12,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34240] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2237),
    1,
    anon_sym_LPAREN,
    STATE(478),
    1,
    sym_comment,
    ACTIONS(1485),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34270] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2239),
    1,
    anon_sym_LPAREN,
    STATE(479),
    1,
    sym_comment,
    ACTIONS(1479),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34300] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2241),
    1,
    anon_sym_LPAREN,
    STATE(480),
    1,
    sym_comment,
    ACTIONS(1467),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34330] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2243),
    1,
    anon_sym_LPAREN,
    STATE(481),
    1,
    sym_comment,
    ACTIONS(1545),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34360] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(482),
    1,
    sym_comment,
    ACTIONS(2245),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2247),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34390] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2249),
    1,
    anon_sym_LPAREN,
    STATE(483),
    1,
    sym_comment,
    ACTIONS(1491),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34420] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2251),
    1,
    anon_sym_LPAREN,
    STATE(484),
    1,
    sym_comment,
    ACTIONS(1533),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34450] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2253),
    1,
    anon_sym_LPAREN,
    STATE(485),
    1,
    sym_comment,
    ACTIONS(1527),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34480] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2255),
    1,
    anon_sym_LPAREN,
    STATE(486),
    1,
    sym_comment,
    ACTIONS(1563),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34510] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(487),
    1,
    sym_comment,
    ACTIONS(2159),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2161),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34540] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(488),
    1,
    sym_comment,
    ACTIONS(2257),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2259),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34570] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(489),
    1,
    sym_comment,
    ACTIONS(2151),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2153),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34600] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(490),
    1,
    sym_comment,
    ACTIONS(2261),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2263),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34630] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(491),
    1,
    sym_comment,
    ACTIONS(2265),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2267),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34660] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(492),
    1,
    sym_comment,
    ACTIONS(2269),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2271),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34690] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(493),
    1,
    sym_comment,
    ACTIONS(2273),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2275),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34720] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(494),
    1,
    sym_comment,
    ACTIONS(2277),
    2,
    anon_sym_GT,
    anon_sym_SLASH,
    ACTIONS(2279),
    14,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [34750] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2281),
    1,
    anon_sym_LPAREN,
    STATE(495),
    1,
    sym_comment,
    ACTIONS(1551),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34780] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2283),
    1,
    anon_sym_LPAREN,
    STATE(496),
    1,
    sym_comment,
    ACTIONS(1569),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34810] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(497),
    1,
    sym_comment,
    ACTIONS(1731),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34837] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(498),
    1,
    sym_comment,
    ACTIONS(1669),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34864] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(499),
    1,
    sym_comment,
    ACTIONS(1645),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34891] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(500),
    1,
    sym_comment,
    ACTIONS(1641),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34918] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(501),
    1,
    sym_comment,
    ACTIONS(1653),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34945] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(502),
    1,
    sym_comment,
    ACTIONS(1637),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34972] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(503),
    1,
    sym_comment,
    ACTIONS(1727),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [34999] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(504),
    1,
    sym_comment,
    ACTIONS(1631),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35026] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(505),
    1,
    sym_comment,
    ACTIONS(1627),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35053] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(506),
    1,
    sym_comment,
    ACTIONS(1619),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35080] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(507),
    1,
    sym_comment,
    ACTIONS(1615),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35107] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(508),
    1,
    sym_comment,
    ACTIONS(1773),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35134] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(509),
    1,
    sym_comment,
    ACTIONS(1611),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35161] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(510),
    1,
    sym_comment,
    ACTIONS(1791),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35188] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(511),
    1,
    sym_comment,
    ACTIONS(1607),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35215] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(512),
    1,
    sym_comment,
    ACTIONS(1683),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35242] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(513),
    1,
    sym_comment,
    ACTIONS(1575),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35269] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(514),
    1,
    sym_comment,
    ACTIONS(1807),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35296] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(515),
    1,
    sym_comment,
    ACTIONS(1623),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35323] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(516),
    1,
    sym_comment,
    ACTIONS(1595),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35350] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(517),
    1,
    sym_comment,
    ACTIONS(1591),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35377] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(518),
    1,
    sym_comment,
    ACTIONS(1583),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35404] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(519),
    1,
    sym_comment,
    ACTIONS(1665),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35431] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(520),
    1,
    sym_comment,
    ACTIONS(1691),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35458] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(521),
    1,
    sym_comment,
    ACTIONS(1785),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35485] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(522),
    1,
    sym_comment,
    ACTIONS(1781),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35512] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(523),
    1,
    sym_comment,
    ACTIONS(1799),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35539] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(524),
    1,
    sym_comment,
    ACTIONS(1699),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35566] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(525),
    1,
    sym_comment,
    ACTIONS(1587),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35593] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(526),
    1,
    sym_comment,
    ACTIONS(1803),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35620] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(527),
    1,
    sym_comment,
    ACTIONS(1711),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35647] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(528),
    1,
    sym_comment,
    ACTIONS(1649),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35674] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(529),
    1,
    sym_comment,
    ACTIONS(1795),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35701] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(530),
    1,
    sym_comment,
    ACTIONS(1599),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35728] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(531),
    1,
    sym_comment,
    ACTIONS(1707),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35755] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(532),
    1,
    sym_comment,
    ACTIONS(1673),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35782] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(533),
    1,
    sym_comment,
    ACTIONS(1777),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35809] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(534),
    1,
    sym_comment,
    ACTIONS(1687),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35836] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(535),
    1,
    sym_comment,
    ACTIONS(1735),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35863] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(536),
    1,
    sym_comment,
    ACTIONS(1695),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35890] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(537),
    1,
    sym_comment,
    ACTIONS(1739),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35917] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(538),
    1,
    sym_comment,
    ACTIONS(1743),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35944] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(539),
    1,
    sym_comment,
    ACTIONS(1769),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35971] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(540),
    1,
    sym_comment,
    ACTIONS(1747),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [35998] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(541),
    1,
    sym_comment,
    ACTIONS(1751),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36025] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(542),
    1,
    sym_comment,
    ACTIONS(1755),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36052] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(543),
    1,
    sym_comment,
    ACTIONS(1679),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36079] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(544),
    1,
    sym_comment,
    ACTIONS(1723),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36106] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(545),
    1,
    sym_comment,
    ACTIONS(1719),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36133] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(546),
    1,
    sym_comment,
    ACTIONS(1765),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36160] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(547),
    1,
    sym_comment,
    ACTIONS(1715),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36187] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(548),
    1,
    sym_comment,
    ACTIONS(1579),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36214] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(549),
    1,
    sym_comment,
    ACTIONS(1703),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36241] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(550),
    1,
    sym_comment,
    ACTIONS(1759),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36268] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(551),
    1,
    sym_comment,
    ACTIONS(1661),
    15,
    anon_sym_local,
    anon_sym_abstract,
    anon_sym_interface,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_bitset,
    anon_sym_bitmask,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_module,
    anon_sym_struct,
    anon_sym_union,
    anon_sym_enum,
    anon_sym_typedef,
    anon_sym_native,
    [36295] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1507),
    1,
    anon_sym_SLASH,
    ACTIONS(2285),
    1,
    anon_sym_COMMA,
    ACTIONS(2287),
    1,
    anon_sym_EQ,
    STATE(552),
    1,
    sym_comment,
    ACTIONS(1509),
    11,
    anon_sym_COLON_COLON,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    anon_sym_RPAREN,
    [36327] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2289),
    1,
    anon_sym_GT,
    STATE(553),
    1,
    sym_comment,
    ACTIONS(2293),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(2291),
    10,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [36356] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2295),
    1,
    anon_sym_GT,
    STATE(554),
    1,
    sym_comment,
    ACTIONS(2293),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    ACTIONS(2297),
    10,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [36385] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2151),
    1,
    anon_sym_SLASH,
    ACTIONS(2299),
    1,
    anon_sym_GT,
    ACTIONS(2301),
    1,
    anon_sym_COMMA,
    STATE(555),
    1,
    sym_comment,
    ACTIONS(2153),
    9,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    anon_sym_PLUS,
    anon_sym_DASH,
    anon_sym_STAR,
    anon_sym_PERCENT,
    [36418] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(556),
    1,
    sym_comment,
    ACTIONS(2303),
    12,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_emits,
    anon_sym_publishes,
    anon_sym_consumes,
    anon_sym_port,
    anon_sym_mirrorport,
    [36442] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(557),
    1,
    sym_comment,
    STATE(584),
    1,
    sym_integer_sign,
    STATE(1337),
    1,
    sym_integer_literal,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2005),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    STATE(459),
    2,
    sym_oct_number,
    sym_dec_number,
    [36480] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(558),
    1,
    sym_comment,
    STATE(584),
    1,
    sym_integer_sign,
    STATE(1201),
    1,
    sym_integer_literal,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2005),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    STATE(459),
    2,
    sym_oct_number,
    sym_dec_number,
    [36518] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(559),
    1,
    sym_comment,
    STATE(584),
    1,
    sym_integer_sign,
    STATE(1385),
    1,
    sym_integer_literal,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2005),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    STATE(459),
    2,
    sym_oct_number,
    sym_dec_number,
    [36556] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(560),
    1,
    sym_comment,
    STATE(584),
    1,
    sym_integer_sign,
    STATE(1284),
    1,
    sym_integer_literal,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2005),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    STATE(459),
    2,
    sym_oct_number,
    sym_dec_number,
    [36594] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(561),
    1,
    sym_comment,
    STATE(584),
    1,
    sym_integer_sign,
    STATE(1432),
    1,
    sym_integer_literal,
    ACTIONS(602),
    2,
    sym_bin_number,
    sym_hex_number,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2005),
    2,
    anon_sym_PLUS,
    anon_sym_DASH,
    STATE(459),
    2,
    sym_oct_number,
    sym_dec_number,
    [36632] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(562),
    1,
    sym_comment,
    ACTIONS(2305),
    12,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_emits,
    anon_sym_publishes,
    anon_sym_consumes,
    anon_sym_port,
    anon_sym_mirrorport,
    [36656] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2307),
    1,
    anon_sym_GT,
    STATE(563),
    1,
    sym_comment,
    ACTIONS(2311),
    2,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    ACTIONS(2309),
    8,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [36683] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2313),
    1,
    anon_sym_GT,
    STATE(564),
    1,
    sym_comment,
    ACTIONS(2311),
    2,
    anon_sym_GT_GT,
    anon_sym_LT_LT,
    ACTIONS(2315),
    8,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_AMP,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [36710] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2013),
    1,
    anon_sym_provides,
    ACTIONS(2015),
    1,
    anon_sym_uses,
    ACTIONS(2317),
    1,
    anon_sym_RBRACE,
    STATE(442),
    1,
    sym_port_ref,
    STATE(565),
    1,
    sym_comment,
    STATE(1266),
    1,
    sym_port_body,
    ACTIONS(2023),
    2,
    anon_sym_port,
    anon_sym_mirrorport,
    STATE(1188),
    3,
    sym_provides_dcl,
    sym_uses_dcl,
    sym_port_dcl,
    [36744] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(566),
    1,
    sym_comment,
    ACTIONS(2319),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [36765] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(567),
    1,
    sym_comment,
    ACTIONS(2321),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [36786] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(568),
    1,
    sym_comment,
    ACTIONS(2323),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [36807] = 12,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2325),
    1,
    anon_sym_COMMA,
    ACTIONS(2327),
    1,
    anon_sym_RBRACE,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2333),
    1,
    sym_identifier,
    STATE(569),
    1,
    sym_comment,
    STATE(607),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(944),
    1,
    sym_enumerator,
    [36844] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(570),
    1,
    sym_comment,
    ACTIONS(2335),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [36865] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(571),
    1,
    sym_comment,
    ACTIONS(2337),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [36886] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(31),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(1967),
    1,
    anon_sym_AT,
    ACTIONS(2009),
    1,
    anon_sym_readonly,
    ACTIONS(2011),
    1,
    anon_sym_attribute,
    STATE(448),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(508),
    1,
    sym_annotation_appl,
    STATE(510),
    1,
    sym_extend_annotation_appl,
    STATE(572),
    1,
    sym_comment,
    STATE(1279),
    2,
    sym_readonly_attr_spec,
    sym_attr_spec,
    [36921] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(573),
    1,
    sym_comment,
    ACTIONS(1519),
    9,
    anon_sym_COLON_COLON,
    anon_sym_LT,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_DQUOTE,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    sym_identifier,
    [36942] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(574),
    1,
    sym_comment,
    ACTIONS(1523),
    9,
    anon_sym_COLON_COLON,
    anon_sym_LT,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_DQUOTE,
    anon_sym_LBRACE,
    anon_sym_SEMI,
    sym_identifier,
    [36963] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2341),
    1,
    anon_sym_AMP,
    STATE(575),
    1,
    sym_comment,
    ACTIONS(2339),
    8,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [36986] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(576),
    1,
    sym_comment,
    ACTIONS(2343),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [37007] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(577),
    1,
    sym_comment,
    ACTIONS(2345),
    9,
    anon_sym_RBRACE,
    anon_sym_readonly,
    anon_sym_attribute,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    anon_sym_provides,
    anon_sym_uses,
    anon_sym_port,
    anon_sym_mirrorport,
    [37028] = 12,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2347),
    1,
    anon_sym_COMMA,
    ACTIONS(2349),
    1,
    anon_sym_RBRACE,
    ACTIONS(2351),
    1,
    sym_identifier,
    STATE(578),
    1,
    sym_comment,
    STATE(614),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(817),
    1,
    sym_bit_value,
    [37065] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2341),
    1,
    anon_sym_AMP,
    STATE(579),
    1,
    sym_comment,
    ACTIONS(2353),
    8,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_CARET,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [37088] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2357),
    1,
    anon_sym_CARET,
    STATE(580),
    1,
    sym_comment,
    ACTIONS(2355),
    7,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [37110] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2351),
    1,
    sym_identifier,
    ACTIONS(2359),
    1,
    anon_sym_RBRACE,
    STATE(581),
    1,
    sym_comment,
    STATE(614),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(1084),
    1,
    sym_bit_value,
    [37144] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(453),
    1,
    sym_dec_number,
    STATE(487),
    1,
    sym_oct_number,
    STATE(582),
    1,
    sym_comment,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2361),
    2,
    sym_bin_number,
    sym_hex_number,
    [37174] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2357),
    1,
    anon_sym_CARET,
    STATE(583),
    1,
    sym_comment,
    ACTIONS(2363),
    7,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_PIPE,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [37196] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(606),
    1,
    anon_sym_0,
    ACTIONS(608),
    1,
    aux_sym_dec_number_token1,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(584),
    1,
    sym_comment,
    ACTIONS(604),
    2,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    ACTIONS(2361),
    2,
    sym_bin_number,
    sym_hex_number,
    STATE(487),
    2,
    sym_oct_number,
    sym_dec_number,
    [37224] = 11,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2365),
    1,
    anon_sym_COMMA,
    ACTIONS(2367),
    1,
    anon_sym_SEMI,
    ACTIONS(2369),
    1,
    anon_sym_getraises,
    ACTIONS(2371),
    1,
    anon_sym_setraises,
    STATE(585),
    1,
    sym_comment,
    STATE(832),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    STATE(840),
    1,
    sym_get_excep_expr,
    STATE(1529),
    1,
    sym_set_excep_expr,
    STATE(1533),
    1,
    sym_attr_raises_expr,
    [37258] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2333),
    1,
    sym_identifier,
    ACTIONS(2373),
    1,
    anon_sym_RBRACE,
    STATE(586),
    1,
    sym_comment,
    STATE(607),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(1073),
    1,
    sym_enumerator,
    [37292] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(587),
    1,
    sym_comment,
    ACTIONS(1509),
    8,
    anon_sym_COLON_COLON,
    anon_sym_LT,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    anon_sym_supports,
    anon_sym_manages,
    anon_sym_primarykey,
    [37312] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2333),
    1,
    sym_identifier,
    ACTIONS(2375),
    1,
    anon_sym_RBRACE,
    STATE(588),
    1,
    sym_comment,
    STATE(607),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(1073),
    1,
    sym_enumerator,
    [37346] = 11,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2351),
    1,
    sym_identifier,
    ACTIONS(2377),
    1,
    anon_sym_RBRACE,
    STATE(589),
    1,
    sym_comment,
    STATE(614),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(1084),
    1,
    sym_bit_value,
    [37380] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2333),
    1,
    sym_identifier,
    STATE(590),
    1,
    sym_comment,
    STATE(607),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(1073),
    1,
    sym_enumerator,
    [37411] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2379),
    1,
    anon_sym_LBRACE,
    ACTIONS(2381),
    1,
    anon_sym_COLON,
    ACTIONS(2383),
    1,
    anon_sym_SEMI,
    ACTIONS(2385),
    1,
    anon_sym_supports,
    STATE(591),
    1,
    sym_comment,
    STATE(883),
    1,
    sym_value_inheritance,
    STATE(1194),
    1,
    sym_value_inheritance_spec,
    STATE(1384),
    1,
    sym_value_supports,
    [37442] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2381),
    1,
    anon_sym_COLON,
    ACTIONS(2385),
    1,
    anon_sym_supports,
    ACTIONS(2387),
    1,
    anon_sym_LBRACE,
    ACTIONS(2389),
    1,
    anon_sym_SEMI,
    STATE(592),
    1,
    sym_comment,
    STATE(883),
    1,
    sym_value_inheritance,
    STATE(1384),
    1,
    sym_value_supports,
    STATE(1427),
    1,
    sym_value_inheritance_spec,
    [37473] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(593),
    1,
    sym_comment,
    ACTIONS(2391),
    7,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    anon_sym_raises,
    anon_sym_getraises,
    anon_sym_setraises,
    anon_sym_default,
    [37492] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2393),
    1,
    anon_sym_RBRACE,
    ACTIONS(2395),
    1,
    anon_sym_default,
    ACTIONS(2398),
    1,
    anon_sym_case,
    STATE(43),
    1,
    aux_sym_case_repeat1,
    STATE(273),
    1,
    sym_case_label,
    STATE(890),
    1,
    sym_case,
    STATE(594),
    2,
    sym_comment,
    aux_sym_union_def_repeat1,
    [37521] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2403),
    1,
    anon_sym_PIPE,
    STATE(595),
    1,
    sym_comment,
    ACTIONS(2401),
    6,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_COLON,
    anon_sym_SEMI,
    anon_sym_RBRACK,
    [37542] = 10,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2351),
    1,
    sym_identifier,
    STATE(596),
    1,
    sym_comment,
    STATE(614),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(1084),
    1,
    sym_bit_value,
    [37573] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2405),
    1,
    anon_sym_RBRACE,
    ACTIONS(2407),
    1,
    anon_sym_default,
    ACTIONS(2409),
    1,
    anon_sym_case,
    STATE(43),
    1,
    aux_sym_case_repeat1,
    STATE(273),
    1,
    sym_case_label,
    STATE(597),
    1,
    sym_comment,
    STATE(598),
    1,
    aux_sym_union_def_repeat1,
    STATE(890),
    1,
    sym_case,
    [37604] = 10,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2407),
    1,
    anon_sym_default,
    ACTIONS(2409),
    1,
    anon_sym_case,
    ACTIONS(2411),
    1,
    anon_sym_RBRACE,
    STATE(43),
    1,
    aux_sym_case_repeat1,
    STATE(273),
    1,
    sym_case_label,
    STATE(594),
    1,
    aux_sym_union_def_repeat1,
    STATE(598),
    1,
    sym_comment,
    STATE(890),
    1,
    sym_case,
    [37635] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(1457),
    1,
    sym_identifier,
    ACTIONS(2413),
    1,
    anon_sym_AT,
    ACTIONS(2416),
    1,
    anon_sym_SLASH_SLASH_AT,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    STATE(599),
    2,
    sym_comment,
    aux_sym_interface_dcl_repeat1,
    [37661] = 8,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1455),
    1,
    aux_sym_extend_annotation_appl_token1,
    ACTIONS(2419),
    1,
    anon_sym_AT,
    ACTIONS(2422),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    STATE(600),
    2,
    sym_comment,
    aux_sym_interface_dcl_repeat1,
    [37687] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2429),
    1,
    anon_sym_0,
    STATE(601),
    1,
    sym_comment,
    ACTIONS(2427),
    5,
    sym_bin_number,
    aux_sym_oct_number_token1,
    aux_sym_oct_number_token2,
    aux_sym_dec_number_token1,
    sym_hex_number,
    [37707] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2435),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(602),
    1,
    sym_comment,
    STATE(624),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [37735] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2437),
    1,
    anon_sym_allowed_kinds,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(603),
    1,
    sym_comment,
    STATE(876),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [37759] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2443),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(600),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(604),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [37787] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2445),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(604),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(605),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [37815] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    ACTIONS(2447),
    1,
    anon_sym_allowed_kinds,
    STATE(606),
    1,
    sym_comment,
    STATE(932),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [37839] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2449),
    1,
    sym_identifier,
    STATE(599),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(607),
    1,
    sym_comment,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    [37867] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2451),
    1,
    anon_sym_Object,
    ACTIONS(2453),
    1,
    anon_sym_multiple,
    STATE(608),
    1,
    sym_comment,
    STATE(1050),
    1,
    sym_scoped_name,
    STATE(1309),
    1,
    sym_interface_type,
    [37895] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2455),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(609),
    1,
    sym_comment,
    STATE(623),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [37923] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2381),
    1,
    anon_sym_COLON,
    ACTIONS(2385),
    1,
    anon_sym_supports,
    ACTIONS(2457),
    1,
    anon_sym_LBRACE,
    STATE(610),
    1,
    sym_comment,
    STATE(883),
    1,
    sym_value_inheritance,
    STATE(1193),
    1,
    sym_value_inheritance_spec,
    STATE(1384),
    1,
    sym_value_supports,
    [37951] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(611),
    1,
    sym_comment,
    STATE(1160),
    1,
    sym_scoped_name,
    STATE(1498),
    1,
    sym_imported_scope,
    STATE(1499),
    1,
    sym_string_literal,
    [37979] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2463),
    1,
    anon_sym_LBRACK,
    STATE(612),
    1,
    sym_comment,
    STATE(625),
    1,
    aux_sym_array_declarator_repeat1,
    STATE(699),
    1,
    sym_fixed_array_size,
    ACTIONS(2461),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [38003] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    ACTIONS(2465),
    1,
    anon_sym_allowed_kinds,
    STATE(613),
    1,
    sym_comment,
    STATE(901),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38027] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2329),
    1,
    anon_sym_AT,
    ACTIONS(2331),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2467),
    1,
    sym_identifier,
    STATE(599),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(614),
    1,
    sym_comment,
    STATE(800),
    1,
    sym_annotation_appl,
    STATE(802),
    1,
    sym_extend_annotation_appl,
    [38055] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2381),
    1,
    anon_sym_COLON,
    ACTIONS(2385),
    1,
    anon_sym_supports,
    ACTIONS(2469),
    1,
    anon_sym_LBRACE,
    STATE(615),
    1,
    sym_comment,
    STATE(883),
    1,
    sym_value_inheritance,
    STATE(1259),
    1,
    sym_value_inheritance_spec,
    STATE(1384),
    1,
    sym_value_supports,
    [38083] = 9,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2471),
    1,
    anon_sym_LBRACE,
    ACTIONS(2473),
    1,
    anon_sym_COLON,
    ACTIONS(2475),
    1,
    anon_sym_SEMI,
    ACTIONS(2477),
    1,
    anon_sym_supports,
    STATE(616),
    1,
    sym_comment,
    STATE(1042),
    1,
    sym_component_inheritance_spec,
    STATE(1277),
    1,
    sym_supported_interface_spec,
    [38111] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2463),
    1,
    anon_sym_LBRACK,
    STATE(612),
    1,
    aux_sym_array_declarator_repeat1,
    STATE(617),
    1,
    sym_comment,
    STATE(699),
    1,
    sym_fixed_array_size,
    ACTIONS(2391),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [38135] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2479),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(600),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(618),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [38163] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    ACTIONS(2481),
    1,
    anon_sym_allowed_kinds,
    STATE(619),
    1,
    sym_comment,
    STATE(1037),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38187] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2483),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(618),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(620),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [38215] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2485),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(600),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(621),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [38243] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    ACTIONS(2487),
    1,
    anon_sym_allowed_kinds,
    STATE(622),
    1,
    sym_comment,
    STATE(915),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38267] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2489),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(600),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(623),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [38295] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2491),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(600),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(624),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [38323] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2495),
    1,
    anon_sym_LBRACK,
    STATE(699),
    1,
    sym_fixed_array_size,
    STATE(625),
    2,
    sym_comment,
    aux_sym_array_declarator_repeat1,
    ACTIONS(2493),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [38345] = 9,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2431),
    1,
    anon_sym_AT,
    ACTIONS(2433),
    1,
    anon_sym_SLASH_SLASH_AT,
    ACTIONS(2498),
    1,
    aux_sym_extend_annotation_appl_token1,
    STATE(621),
    1,
    aux_sym_interface_dcl_repeat1,
    STATE(626),
    1,
    sym_comment,
    STATE(959),
    1,
    sym_annotation_appl,
    STATE(960),
    1,
    sym_extend_annotation_appl,
    [38373] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2500),
    1,
    anon_sym_LT,
    STATE(627),
    1,
    sym_comment,
    ACTIONS(2502),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [38392] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2504),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2506),
    1,
    anon_sym_LPAREN,
    STATE(628),
    1,
    sym_comment,
    ACTIONS(1539),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [38413] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(629),
    1,
    sym_comment,
    ACTIONS(2508),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38430] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(630),
    1,
    sym_comment,
    STATE(943),
    1,
    sym_any_declarator,
    STATE(1268),
    1,
    sym_any_declarators,
    STATE(1076),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [38453] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(631),
    1,
    sym_comment,
    STATE(737),
    1,
    sym_declarator,
    STATE(1698),
    1,
    sym_declarators,
    STATE(851),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [38476] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(632),
    1,
    sym_comment,
    STATE(872),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38497] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(633),
    1,
    sym_comment,
    ACTIONS(1519),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [38514] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(634),
    1,
    sym_comment,
    STATE(958),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38535] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(635),
    1,
    sym_comment,
    ACTIONS(1509),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [38552] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    STATE(636),
    1,
    sym_comment,
    ACTIONS(2301),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [38571] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(637),
    1,
    sym_comment,
    STATE(894),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38592] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(638),
    1,
    sym_comment,
    ACTIONS(2514),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38609] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2365),
    1,
    anon_sym_COMMA,
    ACTIONS(2516),
    1,
    anon_sym_SEMI,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    STATE(639),
    1,
    sym_comment,
    STATE(835),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    STATE(1485),
    1,
    sym_raises_expr,
    [38634] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(640),
    1,
    sym_comment,
    ACTIONS(2520),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38651] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(641),
    1,
    sym_comment,
    ACTIONS(2522),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38668] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2524),
    1,
    anon_sym_COLON,
    ACTIONS(2526),
    1,
    anon_sym_supports,
    ACTIONS(2528),
    1,
    anon_sym_manages,
    STATE(642),
    1,
    sym_comment,
    STATE(914),
    1,
    sym_home_inheritance_spec,
    STATE(1269),
    1,
    sym_supported_interface_spec,
    [38693] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2530),
    1,
    anon_sym_LT,
    STATE(643),
    1,
    sym_comment,
    ACTIONS(2532),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [38712] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(644),
    1,
    sym_comment,
    ACTIONS(1507),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [38729] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(645),
    1,
    sym_comment,
    ACTIONS(2534),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38746] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2536),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2538),
    1,
    anon_sym_LPAREN,
    STATE(646),
    1,
    sym_comment,
    ACTIONS(1537),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [38767] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(647),
    1,
    sym_comment,
    STATE(737),
    1,
    sym_declarator,
    STATE(838),
    1,
    sym_declarators,
    STATE(851),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [38790] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(648),
    1,
    sym_comment,
    STATE(925),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38811] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(649),
    1,
    sym_comment,
    ACTIONS(1523),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [38828] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(650),
    1,
    sym_comment,
    ACTIONS(2540),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38845] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1449),
    1,
    sym_identifier,
    ACTIONS(2542),
    1,
    anon_sym_truncatable,
    STATE(651),
    1,
    sym_comment,
    STATE(697),
    1,
    sym_scoped_name,
    STATE(698),
    1,
    sym_value_name,
    [38870] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(652),
    1,
    sym_comment,
    ACTIONS(1517),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [38887] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(653),
    1,
    sym_comment,
    STATE(1057),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [38908] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(654),
    1,
    sym_comment,
    ACTIONS(2544),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [38925] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(655),
    1,
    sym_comment,
    ACTIONS(1521),
    5,
    anon_sym_COLON_COLON,
    anon_sym_LPAREN,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [38942] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2451),
    1,
    anon_sym_Object,
    STATE(656),
    1,
    sym_comment,
    STATE(1050),
    1,
    sym_scoped_name,
    STATE(1614),
    1,
    sym_interface_type,
    [38967] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2546),
    1,
    anon_sym_RBRACE,
    ACTIONS(2548),
    1,
    anon_sym_bitfield,
    STATE(657),
    1,
    sym_comment,
    STATE(660),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(815),
    1,
    sym_bitfield_spec,
    STATE(1154),
    1,
    sym_bitfield,
    [38992] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2439),
    1,
    aux_sym_data_representation_mask_token1,
    STATE(658),
    1,
    sym_comment,
    STATE(908),
    1,
    sym_data_representation_mask,
    ACTIONS(2441),
    3,
    aux_sym_data_representation_mask_token2,
    aux_sym_data_representation_mask_token3,
    aux_sym_data_representation_mask_token4,
    [39013] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2548),
    1,
    anon_sym_bitfield,
    ACTIONS(2550),
    1,
    anon_sym_RBRACE,
    STATE(659),
    1,
    sym_comment,
    STATE(660),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(815),
    1,
    sym_bitfield_spec,
    STATE(1154),
    1,
    sym_bitfield,
    [39038] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2552),
    1,
    anon_sym_RBRACE,
    ACTIONS(2554),
    1,
    anon_sym_bitfield,
    STATE(815),
    1,
    sym_bitfield_spec,
    STATE(1154),
    1,
    sym_bitfield,
    STATE(660),
    2,
    sym_comment,
    aux_sym_bitset_dcl_repeat1,
    [39061] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2548),
    1,
    anon_sym_bitfield,
    ACTIONS(2557),
    1,
    anon_sym_RBRACE,
    STATE(659),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(661),
    1,
    sym_comment,
    STATE(815),
    1,
    sym_bitfield_spec,
    STATE(1154),
    1,
    sym_bitfield,
    [39086] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(662),
    1,
    sym_comment,
    ACTIONS(2559),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [39103] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2548),
    1,
    anon_sym_bitfield,
    ACTIONS(2561),
    1,
    anon_sym_RBRACE,
    STATE(657),
    1,
    aux_sym_bitset_dcl_repeat1,
    STATE(663),
    1,
    sym_comment,
    STATE(815),
    1,
    sym_bitfield_spec,
    STATE(1154),
    1,
    sym_bitfield,
    [39128] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(664),
    1,
    sym_comment,
    ACTIONS(2563),
    5,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_SEMI,
    sym_identifier,
    [39145] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2567),
    1,
    anon_sym_interface,
    ACTIONS(2569),
    1,
    sym_identifier,
    STATE(665),
    1,
    sym_comment,
    STATE(1549),
    1,
    sym_interface_kind,
    ACTIONS(2565),
    2,
    anon_sym_local,
    anon_sym_abstract,
    [39168] = 8,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(157),
    1,
    sym_identifier,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2451),
    1,
    anon_sym_Object,
    STATE(666),
    1,
    sym_comment,
    STATE(1050),
    1,
    sym_scoped_name,
    STATE(1308),
    1,
    sym_interface_type,
    [39193] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(667),
    1,
    sym_comment,
    STATE(737),
    1,
    sym_declarator,
    STATE(928),
    1,
    sym_declarators,
    STATE(851),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [39216] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2571),
    1,
    anon_sym_LT,
    ACTIONS(2573),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2575),
    1,
    sym_identifier,
    STATE(668),
    1,
    sym_comment,
    STATE(1558),
    2,
    sym_string_literal,
    sym_system_lib_string,
    [39239] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    STATE(669),
    1,
    sym_comment,
    STATE(1104),
    1,
    sym_raises_expr,
    ACTIONS(2577),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [39259] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(670),
    1,
    sym_comment,
    ACTIONS(2579),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [39275] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2581),
    1,
    anon_sym_LPAREN,
    STATE(671),
    1,
    sym_comment,
    ACTIONS(1503),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39293] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2583),
    1,
    sym_escape_sequence,
    ACTIONS(2586),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2588),
    1,
    aux_sym_string_literal_token1,
    STATE(672),
    2,
    sym_comment,
    aux_sym_string_literal_repeat1,
    [39313] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2591),
    1,
    anon_sym_LPAREN,
    STATE(673),
    1,
    sym_comment,
    ACTIONS(1513),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39331] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2593),
    1,
    anon_sym_LPAREN,
    STATE(674),
    1,
    sym_comment,
    ACTIONS(1497),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39349] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2595),
    1,
    anon_sym_LPAREN,
    STATE(675),
    1,
    sym_comment,
    ACTIONS(1473),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39367] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2597),
    1,
    anon_sym_RPAREN,
    ACTIONS(2599),
    1,
    anon_sym_in,
    STATE(676),
    1,
    sym_comment,
    STATE(808),
    1,
    sym_init_param_dcl,
    STATE(1525),
    1,
    sym_init_param_dcls,
    [39389] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2601),
    1,
    anon_sym_LPAREN,
    STATE(677),
    1,
    sym_comment,
    ACTIONS(1485),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39407] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2603),
    1,
    anon_sym_LPAREN,
    STATE(678),
    1,
    sym_comment,
    ACTIONS(1479),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39425] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2605),
    1,
    anon_sym_LPAREN,
    STATE(679),
    1,
    sym_comment,
    ACTIONS(1467),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39443] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2607),
    1,
    anon_sym_LPAREN,
    STATE(680),
    1,
    sym_comment,
    ACTIONS(1545),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39461] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2609),
    1,
    anon_sym_LPAREN,
    STATE(681),
    1,
    sym_comment,
    ACTIONS(1557),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39479] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2611),
    1,
    anon_sym_LPAREN,
    STATE(682),
    1,
    sym_comment,
    ACTIONS(1491),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39497] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(683),
    1,
    sym_comment,
    STATE(1454),
    1,
    sym_try_construct_fail_action,
    ACTIONS(2613),
    3,
    aux_sym_try_construct_fail_action_token1,
    aux_sym_try_construct_fail_action_token2,
    aux_sym_try_construct_fail_action_token3,
    [39515] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2615),
    1,
    anon_sym_RPAREN,
    ACTIONS(2617),
    1,
    anon_sym_in,
    STATE(684),
    1,
    sym_comment,
    STATE(787),
    1,
    sym_factory_param_dcl,
    STATE(1516),
    1,
    sym_factory_param_dcls,
    [39537] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2599),
    1,
    anon_sym_in,
    ACTIONS(2619),
    1,
    anon_sym_RPAREN,
    STATE(685),
    1,
    sym_comment,
    STATE(808),
    1,
    sym_init_param_dcl,
    STATE(1514),
    1,
    sym_init_param_dcls,
    [39559] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(686),
    1,
    sym_comment,
    STATE(790),
    1,
    sym_declarator,
    STATE(851),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [39579] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2621),
    1,
    anon_sym_COMMA,
    STATE(687),
    1,
    sym_comment,
    STATE(784),
    1,
    aux_sym_declarators_repeat1,
    ACTIONS(2623),
    2,
    anon_sym_SEMI,
    anon_sym_default,
    [39599] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(688),
    1,
    sym_comment,
    STATE(1448),
    1,
    sym_service_platform,
    ACTIONS(2625),
    3,
    anon_sym_STAR,
    aux_sym_service_platform_token1,
    aux_sym_service_platform_token2,
    [39617] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(689),
    1,
    sym_comment,
    ACTIONS(2627),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_RBRACK,
    [39633] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2629),
    1,
    anon_sym_LPAREN,
    STATE(690),
    1,
    sym_comment,
    ACTIONS(1533),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39651] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2631),
    1,
    anon_sym_LPAREN,
    STATE(691),
    1,
    sym_comment,
    ACTIONS(1527),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39669] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2633),
    1,
    anon_sym_LPAREN,
    STATE(692),
    1,
    sym_comment,
    ACTIONS(1563),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39687] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(693),
    1,
    sym_comment,
    ACTIONS(2635),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [39703] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2637),
    1,
    anon_sym_LPAREN,
    STATE(694),
    1,
    sym_comment,
    ACTIONS(1569),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39721] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2639),
    1,
    anon_sym_LPAREN,
    STATE(695),
    1,
    sym_comment,
    ACTIONS(1551),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [39739] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(696),
    1,
    sym_comment,
    STATE(697),
    1,
    sym_scoped_name,
    STATE(771),
    1,
    sym_value_name,
    [39761] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    STATE(697),
    1,
    sym_comment,
    ACTIONS(2643),
    3,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    anon_sym_supports,
    [39779] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2645),
    1,
    anon_sym_COMMA,
    ACTIONS(2647),
    1,
    anon_sym_LBRACE,
    ACTIONS(2649),
    1,
    anon_sym_supports,
    STATE(698),
    1,
    sym_comment,
    STATE(774),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    [39801] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(699),
    1,
    sym_comment,
    ACTIONS(2651),
    4,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    anon_sym_LBRACK,
    [39817] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(700),
    1,
    sym_comment,
    STATE(1092),
    1,
    sym_any_declarator,
    STATE(1076),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [39837] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2653),
    1,
    sym_escape_sequence,
    ACTIONS(2655),
    1,
    anon_sym_DQUOTE,
    ACTIONS(2657),
    1,
    aux_sym_string_literal_token1,
    STATE(672),
    1,
    aux_sym_string_literal_repeat1,
    STATE(701),
    1,
    sym_comment,
    [39859] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2661),
    1,
    anon_sym_SQUOTE,
    STATE(702),
    1,
    sym_comment,
    STATE(703),
    1,
    aux_sym_char_literal_repeat1,
    ACTIONS(2659),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [39879] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2666),
    1,
    anon_sym_SQUOTE,
    ACTIONS(2663),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    STATE(703),
    2,
    sym_comment,
    aux_sym_char_literal_repeat1,
    [39897] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2668),
    1,
    anon_sym_COMMA,
    ACTIONS(2670),
    1,
    anon_sym_LBRACE,
    STATE(704),
    1,
    sym_comment,
    STATE(810),
    1,
    aux_sym_raises_expr_repeat1,
    [39919] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2672),
    1,
    anon_sym_LBRACE,
    ACTIONS(2674),
    1,
    anon_sym_primarykey,
    STATE(705),
    1,
    sym_comment,
    STATE(1526),
    1,
    sym_primary_key_spec,
    [39941] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(706),
    1,
    sym_comment,
    STATE(1437),
    1,
    sym_extensibility_kind,
    ACTIONS(2676),
    3,
    aux_sym_extensibility_kind_token1,
    aux_sym_extensibility_kind_token2,
    aux_sym_extensibility_kind_token3,
    [39959] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(707),
    1,
    sym_comment,
    STATE(935),
    1,
    sym_scoped_name,
    STATE(993),
    1,
    sym_interface_name,
    [39981] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2653),
    1,
    sym_escape_sequence,
    ACTIONS(2657),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2678),
    1,
    anon_sym_DQUOTE,
    STATE(708),
    1,
    sym_comment,
    STATE(709),
    1,
    aux_sym_string_literal_repeat1,
    [40003] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2653),
    1,
    sym_escape_sequence,
    ACTIONS(2657),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2680),
    1,
    anon_sym_DQUOTE,
    STATE(672),
    1,
    aux_sym_string_literal_repeat1,
    STATE(709),
    1,
    sym_comment,
    [40025] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2682),
    1,
    anon_sym_RPAREN,
    STATE(710),
    1,
    sym_comment,
    STATE(1285),
    1,
    sym_autoid_kind,
    ACTIONS(2684),
    2,
    aux_sym_autoid_kind_token1,
    aux_sym_autoid_kind_token2,
    [40045] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2686),
    1,
    anon_sym_LPAREN,
    STATE(711),
    1,
    sym_comment,
    ACTIONS(1549),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40063] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2688),
    1,
    anon_sym_LPAREN,
    STATE(712),
    1,
    sym_comment,
    ACTIONS(1567),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40081] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2690),
    1,
    anon_sym_LPAREN,
    STATE(713),
    1,
    sym_comment,
    ACTIONS(1561),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40099] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2692),
    1,
    anon_sym_LPAREN,
    STATE(714),
    1,
    sym_comment,
    ACTIONS(1525),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40117] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(715),
    1,
    sym_comment,
    STATE(1407),
    1,
    sym_try_construct_fail_action,
    ACTIONS(2613),
    3,
    aux_sym_try_construct_fail_action_token1,
    aux_sym_try_construct_fail_action_token2,
    aux_sym_try_construct_fail_action_token3,
    [40135] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2694),
    1,
    anon_sym_LPAREN,
    STATE(716),
    1,
    sym_comment,
    ACTIONS(1531),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40153] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2696),
    1,
    anon_sym_LPAREN,
    STATE(717),
    1,
    sym_comment,
    ACTIONS(1489),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40171] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2698),
    1,
    anon_sym_LPAREN,
    STATE(718),
    1,
    sym_comment,
    ACTIONS(1555),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40189] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2700),
    1,
    anon_sym_LPAREN,
    STATE(719),
    1,
    sym_comment,
    ACTIONS(1543),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40207] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2702),
    1,
    anon_sym_LPAREN,
    STATE(720),
    1,
    sym_comment,
    ACTIONS(1465),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40225] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2704),
    1,
    anon_sym_LPAREN,
    STATE(721),
    1,
    sym_comment,
    ACTIONS(1477),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40243] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2706),
    1,
    anon_sym_LPAREN,
    STATE(722),
    1,
    sym_comment,
    ACTIONS(1483),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40261] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(723),
    1,
    sym_comment,
    STATE(1401),
    1,
    sym_service_platform,
    ACTIONS(2625),
    3,
    anon_sym_STAR,
    aux_sym_service_platform_token1,
    aux_sym_service_platform_token2,
    [40279] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2708),
    1,
    anon_sym_LPAREN,
    STATE(724),
    1,
    sym_comment,
    ACTIONS(1471),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40297] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2710),
    1,
    anon_sym_LPAREN,
    STATE(725),
    1,
    sym_comment,
    ACTIONS(1495),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40315] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(726),
    1,
    sym_comment,
    STATE(821),
    1,
    sym_interface_name,
    STATE(935),
    1,
    sym_scoped_name,
    [40337] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2645),
    1,
    anon_sym_COMMA,
    ACTIONS(2712),
    1,
    anon_sym_LBRACE,
    ACTIONS(2714),
    1,
    anon_sym_supports,
    STATE(727),
    1,
    sym_comment,
    STATE(730),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    [40359] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2716),
    1,
    anon_sym_LPAREN,
    STATE(728),
    1,
    sym_comment,
    ACTIONS(1511),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40377] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2718),
    1,
    anon_sym_LPAREN,
    STATE(729),
    1,
    sym_comment,
    ACTIONS(1501),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [40395] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2720),
    1,
    anon_sym_COMMA,
    ACTIONS(2723),
    2,
    anon_sym_LBRACE,
    anon_sym_supports,
    STATE(730),
    2,
    sym_comment,
    aux_sym_value_inheritance_spec_repeat1,
    [40413] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(731),
    1,
    sym_comment,
    STATE(1325),
    1,
    sym_declarator,
    STATE(851),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [40433] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(732),
    1,
    sym_comment,
    STATE(935),
    1,
    sym_scoped_name,
    STATE(1116),
    1,
    sym_interface_name,
    [40455] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2653),
    1,
    sym_escape_sequence,
    ACTIONS(2657),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2725),
    1,
    anon_sym_DQUOTE,
    STATE(733),
    1,
    sym_comment,
    STATE(757),
    1,
    aux_sym_string_literal_repeat1,
    [40477] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2727),
    1,
    anon_sym_RPAREN,
    STATE(734),
    1,
    sym_comment,
    STATE(1338),
    1,
    sym_autoid_kind,
    ACTIONS(2684),
    2,
    aux_sym_autoid_kind_token1,
    aux_sym_autoid_kind_token2,
    [40497] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2668),
    1,
    anon_sym_COMMA,
    ACTIONS(2729),
    1,
    anon_sym_RPAREN,
    STATE(735),
    1,
    sym_comment,
    STATE(949),
    1,
    aux_sym_raises_expr_repeat1,
    [40519] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(736),
    1,
    sym_comment,
    ACTIONS(2731),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [40535] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2621),
    1,
    anon_sym_COMMA,
    STATE(687),
    1,
    aux_sym_declarators_repeat1,
    STATE(737),
    1,
    sym_comment,
    ACTIONS(2733),
    2,
    anon_sym_SEMI,
    anon_sym_default,
    [40555] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2510),
    1,
    sym_identifier,
    STATE(738),
    1,
    sym_comment,
    STATE(1333),
    1,
    sym_declarator,
    STATE(851),
    2,
    sym_simple_declarator,
    sym_array_declarator,
    [40575] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(739),
    1,
    sym_comment,
    STATE(1390),
    1,
    sym_extensibility_kind,
    ACTIONS(2676),
    3,
    aux_sym_extensibility_kind_token1,
    aux_sym_extensibility_kind_token2,
    aux_sym_extensibility_kind_token3,
    [40593] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2735),
    1,
    anon_sym_RPAREN,
    STATE(740),
    1,
    sym_comment,
    STATE(1386),
    1,
    sym_autoid_kind,
    ACTIONS(2684),
    2,
    aux_sym_autoid_kind_token1,
    aux_sym_autoid_kind_token2,
    [40613] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(741),
    1,
    sym_comment,
    ACTIONS(2737),
    4,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    anon_sym_LBRACK,
    [40629] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    STATE(742),
    1,
    sym_comment,
    ACTIONS(2739),
    3,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    [40647] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2741),
    1,
    anon_sym_COMMA,
    ACTIONS(2739),
    2,
    anon_sym_RPAREN,
    anon_sym_LBRACE,
    STATE(743),
    2,
    sym_comment,
    aux_sym_raises_expr_repeat1,
    [40665] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    STATE(744),
    1,
    sym_comment,
    STATE(1079),
    1,
    sym_raises_expr,
    ACTIONS(2744),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [40685] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2668),
    1,
    anon_sym_COMMA,
    ACTIONS(2746),
    1,
    anon_sym_RPAREN,
    STATE(745),
    1,
    sym_comment,
    STATE(936),
    1,
    aux_sym_raises_expr_repeat1,
    [40707] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2674),
    1,
    anon_sym_primarykey,
    ACTIONS(2748),
    1,
    anon_sym_LBRACE,
    STATE(746),
    1,
    sym_comment,
    STATE(1490),
    1,
    sym_primary_key_spec,
    [40729] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2750),
    1,
    anon_sym_RPAREN,
    STATE(747),
    1,
    sym_comment,
    STATE(1433),
    1,
    sym_autoid_kind,
    ACTIONS(2684),
    2,
    aux_sym_autoid_kind_token1,
    aux_sym_autoid_kind_token2,
    [40749] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(748),
    1,
    sym_comment,
    STATE(935),
    1,
    sym_scoped_name,
    STATE(1254),
    1,
    sym_interface_name,
    [40771] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2653),
    1,
    sym_escape_sequence,
    ACTIONS(2657),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2752),
    1,
    anon_sym_DQUOTE,
    STATE(701),
    1,
    aux_sym_string_literal_repeat1,
    STATE(749),
    1,
    sym_comment,
    [40793] = 6,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2754),
    1,
    anon_sym_SQUOTE,
    STATE(703),
    1,
    aux_sym_char_literal_repeat1,
    STATE(750),
    1,
    sym_comment,
    ACTIONS(2659),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [40813] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(751),
    1,
    sym_comment,
    STATE(1238),
    1,
    sym_try_construct_fail_action,
    ACTIONS(2613),
    3,
    aux_sym_try_construct_fail_action_token1,
    aux_sym_try_construct_fail_action_token2,
    aux_sym_try_construct_fail_action_token3,
    [40831] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(752),
    1,
    sym_comment,
    STATE(1359),
    1,
    sym_try_construct_fail_action,
    ACTIONS(2613),
    3,
    aux_sym_try_construct_fail_action_token1,
    aux_sym_try_construct_fail_action_token2,
    aux_sym_try_construct_fail_action_token3,
    [40849] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(753),
    1,
    sym_comment,
    STATE(1232),
    1,
    sym_service_platform,
    ACTIONS(2625),
    3,
    anon_sym_STAR,
    aux_sym_service_platform_token1,
    aux_sym_service_platform_token2,
    [40867] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(754),
    1,
    sym_comment,
    STATE(1208),
    1,
    sym_extensibility_kind,
    ACTIONS(2676),
    3,
    aux_sym_extensibility_kind_token1,
    aux_sym_extensibility_kind_token2,
    aux_sym_extensibility_kind_token3,
    [40885] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(755),
    1,
    sym_comment,
    STATE(1289),
    1,
    sym_extensibility_kind,
    ACTIONS(2676),
    3,
    aux_sym_extensibility_kind_token1,
    aux_sym_extensibility_kind_token2,
    aux_sym_extensibility_kind_token3,
    [40903] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2756),
    1,
    anon_sym_RPAREN,
    STATE(756),
    1,
    sym_comment,
    STATE(1203),
    1,
    sym_autoid_kind,
    ACTIONS(2684),
    2,
    aux_sym_autoid_kind_token1,
    aux_sym_autoid_kind_token2,
    [40923] = 7,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2653),
    1,
    sym_escape_sequence,
    ACTIONS(2657),
    1,
    aux_sym_string_literal_token1,
    ACTIONS(2758),
    1,
    anon_sym_DQUOTE,
    STATE(672),
    1,
    aux_sym_string_literal_repeat1,
    STATE(757),
    1,
    sym_comment,
    [40945] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(758),
    1,
    sym_comment,
    ACTIONS(2760),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [40961] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(759),
    1,
    sym_comment,
    ACTIONS(2762),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [40977] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2764),
    1,
    anon_sym_RPAREN,
    ACTIONS(2766),
    1,
    anon_sym_in,
    STATE(760),
    1,
    sym_comment,
    STATE(845),
    1,
    sym_in_param_dcl,
    STATE(1480),
    1,
    sym_in_parameter_dcls,
    [40999] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(761),
    1,
    sym_comment,
    STATE(1353),
    1,
    sym_service_platform,
    ACTIONS(2625),
    3,
    anon_sym_STAR,
    aux_sym_service_platform_token1,
    aux_sym_service_platform_token2,
    [41017] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(762),
    1,
    sym_comment,
    ACTIONS(2768),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41033] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    STATE(763),
    1,
    sym_comment,
    STATE(1128),
    1,
    sym_raises_expr,
    ACTIONS(2770),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [41053] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(764),
    1,
    sym_comment,
    ACTIONS(2772),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41069] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(765),
    1,
    sym_comment,
    STATE(1300),
    1,
    sym_service_platform,
    ACTIONS(2625),
    3,
    anon_sym_STAR,
    aux_sym_service_platform_token1,
    aux_sym_service_platform_token2,
    [41087] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2774),
    1,
    anon_sym_LBRACE,
    ACTIONS(2776),
    1,
    anon_sym_COLON,
    STATE(766),
    1,
    sym_comment,
    ACTIONS(2778),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [41107] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(767),
    1,
    sym_comment,
    STATE(886),
    1,
    sym_interface_name,
    STATE(935),
    1,
    sym_scoped_name,
    [41129] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2674),
    1,
    anon_sym_primarykey,
    ACTIONS(2780),
    1,
    anon_sym_LBRACE,
    STATE(768),
    1,
    sym_comment,
    STATE(1551),
    1,
    sym_primary_key_spec,
    [41151] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2782),
    1,
    anon_sym_LBRACE,
    ACTIONS(2784),
    1,
    anon_sym_COLON,
    ACTIONS(2786),
    1,
    anon_sym_SEMI,
    STATE(769),
    1,
    sym_comment,
    STATE(1214),
    1,
    sym_interface_inheritance_spec,
    [41173] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(770),
    1,
    sym_comment,
    STATE(1306),
    1,
    sym_try_construct_fail_action,
    ACTIONS(2613),
    3,
    aux_sym_try_construct_fail_action_token1,
    aux_sym_try_construct_fail_action_token2,
    aux_sym_try_construct_fail_action_token3,
    [41191] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2645),
    1,
    anon_sym_COMMA,
    ACTIONS(2788),
    1,
    anon_sym_LBRACE,
    ACTIONS(2790),
    1,
    anon_sym_supports,
    STATE(727),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    STATE(771),
    1,
    sym_comment,
    [41213] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(697),
    1,
    sym_scoped_name,
    STATE(772),
    1,
    sym_comment,
    STATE(966),
    1,
    sym_value_name,
    [41235] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(773),
    1,
    sym_comment,
    STATE(935),
    1,
    sym_scoped_name,
    STATE(962),
    1,
    sym_interface_name,
    [41257] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2645),
    1,
    anon_sym_COMMA,
    ACTIONS(2788),
    1,
    anon_sym_LBRACE,
    ACTIONS(2790),
    1,
    anon_sym_supports,
    STATE(730),
    1,
    aux_sym_value_inheritance_spec_repeat1,
    STATE(774),
    1,
    sym_comment,
    [41279] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(775),
    1,
    sym_comment,
    STATE(1342),
    1,
    sym_extensibility_kind,
    ACTIONS(2676),
    3,
    aux_sym_extensibility_kind_token1,
    aux_sym_extensibility_kind_token2,
    aux_sym_extensibility_kind_token3,
    [41297] = 7,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2670),
    1,
    anon_sym_manages,
    ACTIONS(2792),
    1,
    anon_sym_COMMA,
    STATE(776),
    1,
    sym_comment,
    STATE(983),
    1,
    aux_sym_raises_expr_repeat1,
    [41319] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(777),
    1,
    sym_comment,
    ACTIONS(2794),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41335] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(778),
    1,
    sym_comment,
    ACTIONS(2796),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41351] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(779),
    1,
    sym_comment,
    ACTIONS(2798),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41367] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(780),
    1,
    sym_comment,
    ACTIONS(2800),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41383] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(781),
    1,
    sym_comment,
    ACTIONS(2802),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41399] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(782),
    1,
    sym_comment,
    ACTIONS(2804),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41415] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(783),
    1,
    sym_comment,
    ACTIONS(2301),
    4,
    anon_sym_GT,
    anon_sym_COMMA,
    anon_sym_SEMI,
    sym_identifier,
    [41431] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2806),
    1,
    anon_sym_COMMA,
    ACTIONS(2809),
    2,
    anon_sym_SEMI,
    anon_sym_default,
    STATE(784),
    2,
    sym_comment,
    aux_sym_declarators_repeat1,
    [41449] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(704),
    1,
    sym_scoped_name,
    STATE(785),
    1,
    sym_comment,
    [41468] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(786),
    1,
    sym_comment,
    ACTIONS(1695),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [41483] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2811),
    1,
    anon_sym_COMMA,
    ACTIONS(2813),
    1,
    anon_sym_RPAREN,
    STATE(787),
    1,
    sym_comment,
    STATE(866),
    1,
    aux_sym_factory_param_dcls_repeat1,
    [41502] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    ACTIONS(2815),
    1,
    anon_sym_SEMI,
    STATE(788),
    1,
    sym_comment,
    STATE(1475),
    1,
    sym_raises_expr,
    [41521] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    STATE(789),
    1,
    sym_comment,
    ACTIONS(2739),
    2,
    anon_sym_COMMA,
    anon_sym_manages,
    [41538] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(790),
    1,
    sym_comment,
    ACTIONS(2809),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [41553] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2817),
    1,
    anon_sym_COMMA,
    ACTIONS(2820),
    1,
    anon_sym_SEMI,
    STATE(791),
    2,
    sym_comment,
    aux_sym_any_declarators_repeat1,
    [41570] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(792),
    1,
    sym_comment,
    STATE(1053),
    1,
    sym_scoped_name,
    [41589] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(793),
    1,
    sym_comment,
    STATE(1321),
    1,
    sym_topic_platform,
    ACTIONS(1655),
    2,
    anon_sym_STAR,
    aux_sym_service_platform_token2,
    [41606] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    STATE(794),
    1,
    sym_comment,
    STATE(1331),
    1,
    sym_string_literal,
    [41625] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(795),
    1,
    sym_comment,
    STATE(1054),
    1,
    sym_scoped_name,
    [41644] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(796),
    1,
    sym_comment,
    STATE(1055),
    1,
    sym_scoped_name,
    [41663] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2822),
    1,
    anon_sym_SEMI,
    ACTIONS(2824),
    1,
    anon_sym_context,
    STATE(797),
    1,
    sym_comment,
    STATE(1274),
    1,
    sym_context_expr,
    [41682] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(639),
    1,
    sym_simple_declarator,
    STATE(798),
    1,
    sym_comment,
    STATE(1539),
    1,
    sym_readonly_attr_declarator,
    [41701] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(799),
    1,
    sym_comment,
    STATE(1372),
    1,
    sym_topic_platform,
    ACTIONS(1655),
    2,
    anon_sym_STAR,
    aux_sym_service_platform_token2,
    [41718] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(800),
    1,
    sym_comment,
    ACTIONS(1773),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [41733] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2375),
    1,
    anon_sym_RBRACE,
    ACTIONS(2828),
    1,
    anon_sym_COMMA,
    STATE(801),
    1,
    sym_comment,
    STATE(933),
    1,
    aux_sym_enum_dcl_repeat1,
    [41752] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(802),
    1,
    sym_comment,
    ACTIONS(1791),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [41767] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    STATE(803),
    1,
    sym_comment,
    STATE(1329),
    1,
    sym_string_literal,
    [41786] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2830),
    1,
    anon_sym_RPAREN,
    STATE(804),
    1,
    sym_comment,
    STATE(830),
    1,
    sym_string_literal,
    [41805] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(805),
    1,
    sym_comment,
    ACTIONS(1711),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [41820] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(806),
    1,
    sym_comment,
    ACTIONS(1599),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [41835] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    ACTIONS(2832),
    1,
    anon_sym_SEMI,
    STATE(807),
    1,
    sym_comment,
    STATE(1476),
    1,
    sym_raises_expr,
    [41854] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2834),
    1,
    anon_sym_COMMA,
    ACTIONS(2836),
    1,
    anon_sym_RPAREN,
    STATE(808),
    1,
    sym_comment,
    STATE(861),
    1,
    aux_sym_init_param_dcls_repeat1,
    [41873] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(809),
    1,
    sym_comment,
    ACTIONS(1777),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [41888] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2668),
    1,
    anon_sym_COMMA,
    ACTIONS(2838),
    1,
    anon_sym_LBRACE,
    STATE(743),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(810),
    1,
    sym_comment,
    [41907] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2842),
    1,
    anon_sym_RPAREN,
    STATE(811),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [41926] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2844),
    1,
    anon_sym_GT,
    ACTIONS(2846),
    1,
    anon_sym_COMMA,
    STATE(812),
    1,
    sym_comment,
    STATE(967),
    1,
    aux_sym_actual_parameters_repeat1,
    [41945] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(813),
    1,
    sym_comment,
    STATE(1307),
    1,
    sym_boolean_literal,
    ACTIONS(2848),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [41962] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    ACTIONS(2850),
    1,
    anon_sym_SEMI,
    STATE(814),
    1,
    sym_comment,
    STATE(1477),
    1,
    sym_raises_expr,
    [41981] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2852),
    1,
    anon_sym_SEMI,
    ACTIONS(2854),
    1,
    sym_identifier,
    STATE(815),
    1,
    sym_comment,
    STATE(893),
    1,
    aux_sym_bitfield_repeat1,
    [42000] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(816),
    1,
    sym_comment,
    STATE(1045),
    1,
    sym_scoped_name,
    [42019] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2856),
    1,
    anon_sym_COMMA,
    ACTIONS(2858),
    1,
    anon_sym_RBRACE,
    STATE(817),
    1,
    sym_comment,
    STATE(889),
    1,
    aux_sym_bitmask_dcl_repeat1,
    [42038] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2860),
    1,
    anon_sym_LBRACE,
    ACTIONS(2862),
    1,
    anon_sym_COLON,
    STATE(818),
    1,
    sym_comment,
    STATE(1267),
    1,
    sym_connector_inherit_spec,
    [42057] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2864),
    1,
    anon_sym_GT,
    ACTIONS(2866),
    1,
    anon_sym_COMMA,
    STATE(819),
    1,
    sym_comment,
    STATE(970),
    1,
    aux_sym_formal_parameters_repeat1,
    [42076] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(820),
    1,
    sym_comment,
    STATE(1091),
    1,
    sym_scoped_name,
    [42095] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(2870),
    1,
    anon_sym_LBRACE,
    STATE(821),
    1,
    sym_comment,
    STATE(885),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [42114] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2872),
    1,
    anon_sym_SEMI,
    ACTIONS(2874),
    1,
    anon_sym_switch,
    ACTIONS(2876),
    1,
    sym_identifier,
    STATE(822),
    1,
    sym_comment,
    [42133] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(2870),
    1,
    anon_sym_LBRACE,
    STATE(823),
    1,
    sym_comment,
    STATE(875),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [42152] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(824),
    1,
    sym_comment,
    ACTIONS(1769),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42167] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2878),
    1,
    anon_sym_COMMA,
    ACTIONS(2880),
    1,
    anon_sym_RPAREN,
    STATE(825),
    1,
    sym_comment,
    STATE(853),
    1,
    aux_sym_parameter_dcls_repeat1,
    [42186] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(826),
    1,
    sym_comment,
    STATE(1467),
    1,
    sym_topic_platform,
    ACTIONS(1655),
    2,
    anon_sym_STAR,
    aux_sym_service_platform_token2,
    [42203] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2882),
    1,
    anon_sym_COMMA,
    ACTIONS(2884),
    1,
    anon_sym_RPAREN,
    STATE(827),
    1,
    sym_comment,
    STATE(972),
    1,
    aux_sym_annotation_appl_params_repeat1,
    [42222] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2886),
    1,
    anon_sym_interface,
    ACTIONS(2888),
    1,
    anon_sym_valuetype,
    ACTIONS(2890),
    1,
    anon_sym_eventtype,
    STATE(828),
    1,
    sym_comment,
    [42241] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(746),
    1,
    sym_scoped_name,
    STATE(829),
    1,
    sym_comment,
    [42260] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2892),
    1,
    anon_sym_COMMA,
    ACTIONS(2894),
    1,
    anon_sym_RPAREN,
    STATE(830),
    1,
    sym_comment,
    STATE(848),
    1,
    aux_sym_context_expr_repeat1,
    [42279] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2896),
    1,
    sym_identifier,
    STATE(831),
    1,
    sym_comment,
    STATE(1140),
    1,
    sym_scoped_name,
    [42298] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2365),
    1,
    anon_sym_COMMA,
    ACTIONS(2898),
    1,
    anon_sym_SEMI,
    STATE(832),
    1,
    sym_comment,
    STATE(841),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    [42317] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(2902),
    1,
    aux_sym_string_literal_token1,
    STATE(833),
    1,
    sym_comment,
    ACTIONS(2900),
    2,
    sym_escape_sequence,
    anon_sym_DQUOTE,
    [42334] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(834),
    1,
    sym_comment,
    STATE(1455),
    1,
    sym_boolean_literal,
    ACTIONS(2848),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [42351] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2365),
    1,
    anon_sym_COMMA,
    ACTIONS(2904),
    1,
    anon_sym_SEMI,
    STATE(835),
    1,
    sym_comment,
    STATE(841),
    1,
    aux_sym_readonly_attr_declarator_repeat1,
    [42370] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(750),
    1,
    aux_sym_char_literal_repeat1,
    STATE(836),
    1,
    sym_comment,
    ACTIONS(2659),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [42387] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(745),
    1,
    sym_scoped_name,
    STATE(837),
    1,
    sym_comment,
    [42406] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2906),
    1,
    anon_sym_SEMI,
    ACTIONS(2908),
    1,
    anon_sym_default,
    STATE(838),
    1,
    sym_comment,
    STATE(1508),
    1,
    sym_default,
    [42425] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(839),
    1,
    sym_comment,
    STATE(1152),
    1,
    sym_scoped_name,
    [42444] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2371),
    1,
    anon_sym_setraises,
    ACTIONS(2910),
    1,
    anon_sym_SEMI,
    STATE(840),
    1,
    sym_comment,
    STATE(1482),
    1,
    sym_set_excep_expr,
    [42463] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2912),
    1,
    anon_sym_COMMA,
    ACTIONS(2915),
    1,
    anon_sym_SEMI,
    STATE(841),
    2,
    sym_comment,
    aux_sym_readonly_attr_declarator_repeat1,
    [42480] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(794),
    1,
    sym_scoped_name,
    STATE(842),
    1,
    sym_comment,
    [42499] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(843),
    1,
    sym_comment,
    STATE(1503),
    1,
    sym_topic_platform,
    ACTIONS(1655),
    2,
    anon_sym_STAR,
    aux_sym_service_platform_token2,
    [42516] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1509),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(2917),
    1,
    anon_sym_LT,
    ACTIONS(2919),
    1,
    anon_sym_LBRACE,
    STATE(844),
    1,
    sym_comment,
    [42535] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2921),
    1,
    anon_sym_COMMA,
    ACTIONS(2923),
    1,
    anon_sym_RPAREN,
    STATE(845),
    1,
    sym_comment,
    STATE(900),
    1,
    aux_sym_in_parameter_dcls_repeat1,
    [42554] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2925),
    1,
    anon_sym_SEMI,
    ACTIONS(2927),
    1,
    sym_identifier,
    STATE(846),
    2,
    sym_comment,
    aux_sym_bitfield_repeat1,
    [42571] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(847),
    1,
    sym_comment,
    ACTIONS(1587),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42586] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2892),
    1,
    anon_sym_COMMA,
    ACTIONS(2930),
    1,
    anon_sym_RPAREN,
    STATE(848),
    1,
    sym_comment,
    STATE(903),
    1,
    aux_sym_context_expr_repeat1,
    [42605] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(849),
    1,
    sym_comment,
    ACTIONS(1707),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42620] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(850),
    1,
    sym_comment,
    ACTIONS(1679),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42635] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(851),
    1,
    sym_comment,
    ACTIONS(2932),
    3,
    anon_sym_COMMA,
    anon_sym_SEMI,
    anon_sym_default,
    [42650] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(852),
    1,
    sym_comment,
    ACTIONS(1683),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42665] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2878),
    1,
    anon_sym_COMMA,
    ACTIONS(2934),
    1,
    anon_sym_RPAREN,
    STATE(853),
    1,
    sym_comment,
    STATE(906),
    1,
    aux_sym_parameter_dcls_repeat1,
    [42684] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(854),
    1,
    sym_comment,
    ACTIONS(1699),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42699] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(855),
    1,
    sym_comment,
    ACTIONS(1785),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42714] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(449),
    1,
    sym_dec_number,
    STATE(856),
    1,
    sym_comment,
    ACTIONS(608),
    2,
    anon_sym_0,
    aux_sym_dec_number_token1,
    [42731] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(857),
    1,
    sym_comment,
    ACTIONS(1807),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42746] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(858),
    1,
    sym_comment,
    ACTIONS(1759),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42761] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    ACTIONS(2936),
    1,
    anon_sym_SEMI,
    STATE(859),
    1,
    sym_comment,
    STATE(1415),
    1,
    sym_raises_expr,
    [42780] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(860),
    1,
    sym_comment,
    ACTIONS(1661),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42795] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2834),
    1,
    anon_sym_COMMA,
    ACTIONS(2938),
    1,
    anon_sym_RPAREN,
    STATE(861),
    1,
    sym_comment,
    STATE(913),
    1,
    aux_sym_init_param_dcls_repeat1,
    [42814] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(862),
    1,
    sym_comment,
    ACTIONS(1795),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42829] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(863),
    1,
    sym_comment,
    ACTIONS(1781),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42844] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    ACTIONS(2940),
    1,
    anon_sym_SEMI,
    STATE(864),
    1,
    sym_comment,
    STATE(1410),
    1,
    sym_raises_expr,
    [42863] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(865),
    1,
    sym_comment,
    ACTIONS(1691),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [42878] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2811),
    1,
    anon_sym_COMMA,
    ACTIONS(2942),
    1,
    anon_sym_RPAREN,
    STATE(866),
    1,
    sym_comment,
    STATE(917),
    1,
    aux_sym_factory_param_dcls_repeat1,
    [42897] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2944),
    1,
    anon_sym_RPAREN,
    STATE(867),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [42916] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2518),
    1,
    anon_sym_raises,
    ACTIONS(2946),
    1,
    anon_sym_SEMI,
    STATE(868),
    1,
    sym_comment,
    STATE(1409),
    1,
    sym_raises_expr,
    [42935] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(869),
    1,
    sym_comment,
    STATE(1360),
    1,
    sym_boolean_literal,
    ACTIONS(2848),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [42952] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(870),
    1,
    sym_comment,
    ACTIONS(2948),
    3,
    sym_escape_sequence,
    anon_sym_SQUOTE,
    aux_sym_char_literal_token1,
    [42967] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(702),
    1,
    aux_sym_char_literal_repeat1,
    STATE(871),
    1,
    sym_comment,
    ACTIONS(2659),
    2,
    sym_escape_sequence,
    aux_sym_char_literal_token1,
    [42984] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2950),
    1,
    anon_sym_RPAREN,
    STATE(867),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(872),
    1,
    sym_comment,
    [43003] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2952),
    1,
    anon_sym_RPAREN,
    STATE(873),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [43022] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(874),
    1,
    sym_comment,
    ACTIONS(1665),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43037] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2954),
    1,
    anon_sym_COMMA,
    ACTIONS(2957),
    1,
    anon_sym_LBRACE,
    STATE(875),
    2,
    sym_comment,
    aux_sym_interface_inheritance_spec_repeat1,
    [43054] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2959),
    1,
    anon_sym_RPAREN,
    STATE(873),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(876),
    1,
    sym_comment,
    [43073] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(877),
    1,
    sym_comment,
    STATE(1239),
    1,
    sym_boolean_literal,
    ACTIONS(2848),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [43090] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(878),
    1,
    sym_comment,
    ACTIONS(1583),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43105] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(879),
    1,
    sym_comment,
    ACTIONS(1591),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43120] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(880),
    1,
    sym_comment,
    ACTIONS(1595),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43135] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(742),
    1,
    sym_scoped_name,
    STATE(881),
    1,
    sym_comment,
    [43154] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(882),
    1,
    sym_comment,
    ACTIONS(1607),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43169] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2385),
    1,
    anon_sym_supports,
    ACTIONS(2961),
    1,
    anon_sym_LBRACE,
    STATE(883),
    1,
    sym_comment,
    STATE(1255),
    1,
    sym_value_supports,
    [43188] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(884),
    1,
    sym_comment,
    ACTIONS(1611),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43203] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(2963),
    1,
    anon_sym_LBRACE,
    STATE(875),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(885),
    1,
    sym_comment,
    [43222] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(2963),
    1,
    anon_sym_LBRACE,
    STATE(886),
    1,
    sym_comment,
    STATE(924),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    [43241] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(887),
    1,
    sym_comment,
    ACTIONS(1615),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43256] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2965),
    1,
    anon_sym_RPAREN,
    STATE(888),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [43275] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2377),
    1,
    anon_sym_RBRACE,
    ACTIONS(2967),
    1,
    anon_sym_COMMA,
    STATE(889),
    1,
    sym_comment,
    STATE(931),
    1,
    aux_sym_bitmask_dcl_repeat1,
    [43294] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(890),
    1,
    sym_comment,
    ACTIONS(2969),
    3,
    anon_sym_RBRACE,
    anon_sym_default,
    anon_sym_case,
    [43309] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(891),
    1,
    sym_comment,
    ACTIONS(1619),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43324] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(892),
    1,
    sym_comment,
    ACTIONS(1627),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43339] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2854),
    1,
    sym_identifier,
    ACTIONS(2971),
    1,
    anon_sym_SEMI,
    STATE(846),
    1,
    aux_sym_bitfield_repeat1,
    STATE(893),
    1,
    sym_comment,
    [43358] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2973),
    1,
    anon_sym_RPAREN,
    STATE(888),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(894),
    1,
    sym_comment,
    [43377] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(735),
    1,
    sym_scoped_name,
    STATE(895),
    1,
    sym_comment,
    [43396] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2975),
    1,
    anon_sym_RPAREN,
    STATE(896),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [43415] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(897),
    1,
    sym_comment,
    ACTIONS(1631),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43430] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(898),
    1,
    sym_comment,
    ACTIONS(1637),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43445] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(899),
    1,
    sym_comment,
    ACTIONS(1641),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43460] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2921),
    1,
    anon_sym_COMMA,
    ACTIONS(2977),
    1,
    anon_sym_RPAREN,
    STATE(900),
    1,
    sym_comment,
    STATE(939),
    1,
    aux_sym_in_parameter_dcls_repeat1,
    [43479] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2979),
    1,
    anon_sym_RPAREN,
    STATE(896),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(901),
    1,
    sym_comment,
    [43498] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2981),
    1,
    anon_sym_RPAREN,
    STATE(902),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [43517] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2983),
    1,
    anon_sym_COMMA,
    ACTIONS(2986),
    1,
    anon_sym_RPAREN,
    STATE(903),
    2,
    sym_comment,
    aux_sym_context_expr_repeat1,
    [43534] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(904),
    1,
    sym_comment,
    ACTIONS(1645),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43549] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(905),
    1,
    sym_comment,
    ACTIONS(1649),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43564] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2988),
    1,
    anon_sym_COMMA,
    ACTIONS(2991),
    1,
    anon_sym_RPAREN,
    STATE(906),
    2,
    sym_comment,
    aux_sym_parameter_dcls_repeat1,
    [43581] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(907),
    1,
    sym_comment,
    ACTIONS(1653),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43596] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(2993),
    1,
    anon_sym_RPAREN,
    STATE(811),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(908),
    1,
    sym_comment,
    [43615] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(909),
    1,
    sym_comment,
    ACTIONS(1575),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43630] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(910),
    1,
    sym_comment,
    ACTIONS(1669),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43645] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(911),
    1,
    sym_comment,
    ACTIONS(1673),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43660] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(912),
    1,
    sym_comment,
    ACTIONS(1687),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43675] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2995),
    1,
    anon_sym_COMMA,
    ACTIONS(2998),
    1,
    anon_sym_RPAREN,
    STATE(913),
    2,
    sym_comment,
    aux_sym_init_param_dcls_repeat1,
    [43692] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2526),
    1,
    anon_sym_supports,
    ACTIONS(3000),
    1,
    anon_sym_manages,
    STATE(914),
    1,
    sym_comment,
    STATE(1189),
    1,
    sym_supported_interface_spec,
    [43711] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3002),
    1,
    anon_sym_RPAREN,
    STATE(902),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(915),
    1,
    sym_comment,
    [43730] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2882),
    1,
    anon_sym_COMMA,
    ACTIONS(3004),
    1,
    anon_sym_RPAREN,
    STATE(827),
    1,
    aux_sym_annotation_appl_params_repeat1,
    STATE(916),
    1,
    sym_comment,
    [43749] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3006),
    1,
    anon_sym_COMMA,
    ACTIONS(3009),
    1,
    anon_sym_RPAREN,
    STATE(917),
    2,
    sym_comment,
    aux_sym_factory_param_dcls_repeat1,
    [43766] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(918),
    1,
    sym_comment,
    STATE(1077),
    1,
    sym_scoped_name,
    [43785] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(919),
    1,
    sym_comment,
    ACTIONS(1703),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43800] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(920),
    1,
    sym_comment,
    ACTIONS(1579),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43815] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2866),
    1,
    anon_sym_COMMA,
    ACTIONS(3011),
    1,
    anon_sym_GT,
    STATE(819),
    1,
    aux_sym_formal_parameters_repeat1,
    STATE(921),
    1,
    sym_comment,
    [43834] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3013),
    1,
    anon_sym_RPAREN,
    STATE(922),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [43853] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(923),
    1,
    sym_comment,
    ACTIONS(1715),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43868] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(3015),
    1,
    anon_sym_LBRACE,
    STATE(875),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(924),
    1,
    sym_comment,
    [43887] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3017),
    1,
    anon_sym_RPAREN,
    STATE(922),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(925),
    1,
    sym_comment,
    [43906] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3019),
    1,
    anon_sym_RPAREN,
    STATE(926),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [43925] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(927),
    1,
    sym_comment,
    ACTIONS(1719),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43940] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2908),
    1,
    anon_sym_default,
    ACTIONS(3021),
    1,
    anon_sym_SEMI,
    STATE(928),
    1,
    sym_comment,
    STATE(1603),
    1,
    sym_default,
    [43959] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(929),
    1,
    sym_comment,
    ACTIONS(1723),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [43974] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2846),
    1,
    anon_sym_COMMA,
    ACTIONS(3023),
    1,
    anon_sym_GT,
    STATE(812),
    1,
    aux_sym_actual_parameters_repeat1,
    STATE(930),
    1,
    sym_comment,
    [43993] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3025),
    1,
    anon_sym_COMMA,
    ACTIONS(3028),
    1,
    anon_sym_RBRACE,
    STATE(931),
    2,
    sym_comment,
    aux_sym_bitmask_dcl_repeat1,
    [44010] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3030),
    1,
    anon_sym_RPAREN,
    STATE(926),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(932),
    1,
    sym_comment,
    [44029] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3032),
    1,
    anon_sym_COMMA,
    ACTIONS(3035),
    1,
    anon_sym_RBRACE,
    STATE(933),
    2,
    sym_comment,
    aux_sym_enum_dcl_repeat1,
    [44046] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(3037),
    1,
    anon_sym_LBRACE,
    STATE(875),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(934),
    1,
    sym_comment,
    [44065] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    STATE(935),
    1,
    sym_comment,
    ACTIONS(3039),
    2,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    [44082] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2668),
    1,
    anon_sym_COMMA,
    ACTIONS(3041),
    1,
    anon_sym_RPAREN,
    STATE(743),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(936),
    1,
    sym_comment,
    [44101] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(937),
    1,
    sym_comment,
    ACTIONS(1727),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44116] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(938),
    1,
    sym_comment,
    ACTIONS(1731),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44131] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3043),
    1,
    anon_sym_COMMA,
    ACTIONS(3046),
    1,
    anon_sym_RPAREN,
    STATE(939),
    2,
    sym_comment,
    aux_sym_in_parameter_dcls_repeat1,
    [44148] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(940),
    1,
    sym_comment,
    ACTIONS(1735),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44163] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2824),
    1,
    anon_sym_context,
    ACTIONS(3048),
    1,
    anon_sym_SEMI,
    STATE(941),
    1,
    sym_comment,
    STATE(1274),
    1,
    sym_context_expr,
    [44182] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3050),
    1,
    anon_sym_GT,
    ACTIONS(3052),
    1,
    anon_sym_COMMA,
    STATE(942),
    1,
    sym_comment,
    STATE(952),
    1,
    aux_sym_formal_parameter_names_repeat1,
    [44201] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3054),
    1,
    anon_sym_COMMA,
    ACTIONS(3056),
    1,
    anon_sym_SEMI,
    STATE(943),
    1,
    sym_comment,
    STATE(969),
    1,
    aux_sym_any_declarators_repeat1,
    [44220] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3058),
    1,
    anon_sym_COMMA,
    ACTIONS(3060),
    1,
    anon_sym_RBRACE,
    STATE(801),
    1,
    aux_sym_enum_dcl_repeat1,
    STATE(944),
    1,
    sym_comment,
    [44239] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(945),
    1,
    sym_comment,
    ACTIONS(1739),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44254] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(946),
    1,
    sym_comment,
    ACTIONS(3062),
    3,
    anon_sym_RBRACE,
    anon_sym_default,
    anon_sym_case,
    [44269] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(947),
    1,
    sym_comment,
    ACTIONS(1743),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44284] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(948),
    1,
    sym_comment,
    ACTIONS(1747),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44299] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2668),
    1,
    anon_sym_COMMA,
    ACTIONS(3064),
    1,
    anon_sym_RPAREN,
    STATE(743),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(949),
    1,
    sym_comment,
    [44318] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(950),
    1,
    sym_comment,
    ACTIONS(1751),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44333] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(951),
    1,
    sym_comment,
    STATE(971),
    1,
    sym_scoped_name,
    [44352] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3052),
    1,
    anon_sym_COMMA,
    ACTIONS(3066),
    1,
    anon_sym_GT,
    STATE(952),
    1,
    sym_comment,
    STATE(957),
    1,
    aux_sym_formal_parameter_names_repeat1,
    [44371] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3068),
    1,
    anon_sym_RPAREN,
    STATE(953),
    1,
    sym_comment,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    [44390] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2739),
    1,
    anon_sym_manages,
    ACTIONS(3070),
    1,
    anon_sym_COMMA,
    STATE(954),
    2,
    sym_comment,
    aux_sym_raises_expr_repeat1,
    [44407] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(955),
    1,
    sym_comment,
    ACTIONS(1755),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44422] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(803),
    1,
    sym_scoped_name,
    STATE(956),
    1,
    sym_comment,
    [44441] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3073),
    1,
    anon_sym_GT,
    ACTIONS(3075),
    1,
    anon_sym_COMMA,
    STATE(957),
    2,
    sym_comment,
    aux_sym_formal_parameter_names_repeat1,
    [44458] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3078),
    1,
    anon_sym_RPAREN,
    STATE(953),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(958),
    1,
    sym_comment,
    [44477] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(959),
    1,
    sym_comment,
    ACTIONS(1771),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44492] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(960),
    1,
    sym_comment,
    ACTIONS(1789),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44507] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(447),
    1,
    sym_dec_number,
    STATE(961),
    1,
    sym_comment,
    ACTIONS(608),
    2,
    anon_sym_0,
    aux_sym_dec_number_token1,
    [44524] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2712),
    1,
    anon_sym_LBRACE,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    STATE(823),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(962),
    1,
    sym_comment,
    [44543] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(963),
    1,
    sym_comment,
    ACTIONS(1709),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44558] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(964),
    1,
    sym_comment,
    ACTIONS(1597),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44573] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(965),
    1,
    sym_comment,
    ACTIONS(1775),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44588] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(966),
    1,
    sym_comment,
    ACTIONS(2723),
    3,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    anon_sym_supports,
    [44603] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3080),
    1,
    anon_sym_GT,
    ACTIONS(3082),
    1,
    anon_sym_COMMA,
    STATE(967),
    2,
    sym_comment,
    aux_sym_actual_parameters_repeat1,
    [44620] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(968),
    1,
    sym_comment,
    ACTIONS(1767),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44635] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3054),
    1,
    anon_sym_COMMA,
    ACTIONS(3085),
    1,
    anon_sym_SEMI,
    STATE(791),
    1,
    aux_sym_any_declarators_repeat1,
    STATE(969),
    1,
    sym_comment,
    [44654] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3087),
    1,
    anon_sym_GT,
    ACTIONS(3089),
    1,
    anon_sym_COMMA,
    STATE(970),
    2,
    sym_comment,
    aux_sym_formal_parameters_repeat1,
    [44671] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    STATE(971),
    1,
    sym_comment,
    ACTIONS(3092),
    2,
    anon_sym_LBRACE,
    anon_sym_supports,
    [44688] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3094),
    1,
    anon_sym_COMMA,
    ACTIONS(3097),
    1,
    anon_sym_RPAREN,
    STATE(972),
    2,
    sym_comment,
    aux_sym_annotation_appl_params_repeat1,
    [44705] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(973),
    1,
    sym_comment,
    ACTIONS(1765),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44720] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2287),
    1,
    anon_sym_EQ,
    STATE(974),
    1,
    sym_comment,
    ACTIONS(2285),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [44737] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2149),
    1,
    anon_sym_COLON_COLON,
    STATE(975),
    1,
    sym_comment,
    ACTIONS(3099),
    2,
    anon_sym_supports,
    anon_sym_manages,
    [44754] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(768),
    1,
    sym_scoped_name,
    STATE(976),
    1,
    sym_comment,
    [44773] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(977),
    1,
    sym_comment,
    STATE(1408),
    1,
    sym_boolean_literal,
    ACTIONS(2848),
    2,
    anon_sym_TRUE,
    anon_sym_FALSE,
    [44790] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(978),
    1,
    sym_comment,
    ACTIONS(1621),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44805] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3101),
    1,
    anon_sym_PIPE,
    ACTIONS(3104),
    1,
    anon_sym_RPAREN,
    STATE(979),
    2,
    sym_comment,
    aux_sym_annotation_appl_data_representation_repeat1,
    [44822] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(980),
    1,
    sym_comment,
    ACTIONS(1797),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44837] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(981),
    1,
    sym_comment,
    ACTIONS(1803),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44852] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(982),
    1,
    sym_comment,
    ACTIONS(1585),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44867] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2792),
    1,
    anon_sym_COMMA,
    ACTIONS(2838),
    1,
    anon_sym_manages,
    STATE(954),
    1,
    aux_sym_raises_expr_repeat1,
    STATE(983),
    1,
    sym_comment,
    [44886] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(789),
    1,
    sym_scoped_name,
    STATE(984),
    1,
    sym_comment,
    [44905] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(985),
    1,
    sym_comment,
    ACTIONS(1705),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44920] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3106),
    1,
    anon_sym_RPAREN,
    STATE(979),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(986),
    1,
    sym_comment,
    [44939] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(987),
    1,
    sym_comment,
    ACTIONS(1623),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44954] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    STATE(988),
    1,
    sym_comment,
    ACTIONS(1799),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    sym_identifier,
    [44969] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(989),
    1,
    sym_comment,
    ACTIONS(1677),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [44984] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(990),
    1,
    sym_comment,
    STATE(1052),
    1,
    sym_scoped_name,
    [45003] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(991),
    1,
    sym_comment,
    ACTIONS(1681),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45018] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(992),
    1,
    sym_comment,
    ACTIONS(1697),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45033] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2868),
    1,
    anon_sym_COMMA,
    ACTIONS(3108),
    1,
    anon_sym_LBRACE,
    STATE(934),
    1,
    aux_sym_interface_inheritance_spec_repeat1,
    STATE(993),
    1,
    sym_comment,
    [45052] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(994),
    1,
    sym_comment,
    ACTIONS(1783),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45067] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(995),
    1,
    sym_comment,
    ACTIONS(1805),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45082] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(585),
    1,
    sym_simple_declarator,
    STATE(996),
    1,
    sym_comment,
    STATE(1574),
    1,
    sym_attr_declarator,
    [45101] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(997),
    1,
    sym_comment,
    ACTIONS(1757),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45116] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(998),
    1,
    sym_comment,
    ACTIONS(1659),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45131] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(999),
    1,
    sym_comment,
    ACTIONS(1793),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45146] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1000),
    1,
    sym_comment,
    ACTIONS(1779),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45161] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1001),
    1,
    sym_comment,
    ACTIONS(1689),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45176] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1002),
    1,
    sym_comment,
    ACTIONS(1663),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45191] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1003),
    1,
    sym_comment,
    ACTIONS(1581),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45206] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1004),
    1,
    sym_comment,
    ACTIONS(1589),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45221] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1005),
    1,
    sym_comment,
    ACTIONS(1593),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45236] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1006),
    1,
    sym_comment,
    ACTIONS(1605),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45251] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1007),
    1,
    sym_comment,
    ACTIONS(1609),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45266] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1008),
    1,
    sym_comment,
    ACTIONS(1613),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45281] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1009),
    1,
    sym_comment,
    ACTIONS(1617),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45296] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1010),
    1,
    sym_comment,
    ACTIONS(1625),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45311] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1011),
    1,
    sym_comment,
    ACTIONS(1629),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45326] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1012),
    1,
    sym_comment,
    ACTIONS(1635),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45341] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1013),
    1,
    sym_comment,
    ACTIONS(1639),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45356] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1014),
    1,
    sym_comment,
    ACTIONS(1643),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45371] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1015),
    1,
    sym_comment,
    ACTIONS(1647),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45386] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1016),
    1,
    sym_comment,
    ACTIONS(1651),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45401] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1017),
    1,
    sym_comment,
    ACTIONS(1573),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45416] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1018),
    1,
    sym_comment,
    ACTIONS(1667),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45431] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1019),
    1,
    sym_comment,
    ACTIONS(1671),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45446] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1020),
    1,
    sym_comment,
    ACTIONS(1685),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45461] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1021),
    1,
    sym_comment,
    ACTIONS(1693),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45476] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1022),
    1,
    sym_comment,
    ACTIONS(1701),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45491] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1023),
    1,
    sym_comment,
    ACTIONS(1577),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45506] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1024),
    1,
    sym_comment,
    ACTIONS(1713),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45521] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1025),
    1,
    sym_comment,
    ACTIONS(1717),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45536] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1026),
    1,
    sym_comment,
    ACTIONS(1721),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45551] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1027),
    1,
    sym_comment,
    ACTIONS(1725),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45566] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1028),
    1,
    sym_comment,
    ACTIONS(1729),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45581] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1029),
    1,
    sym_comment,
    ACTIONS(1733),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45596] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1030),
    1,
    sym_comment,
    ACTIONS(1737),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45611] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1031),
    1,
    sym_comment,
    ACTIONS(1741),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45626] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1032),
    1,
    sym_comment,
    ACTIONS(1745),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45641] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1033),
    1,
    sym_comment,
    ACTIONS(1749),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45656] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1034),
    1,
    sym_comment,
    ACTIONS(1753),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45671] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1035),
    1,
    sym_comment,
    ACTIONS(1763),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45686] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1036),
    1,
    sym_comment,
    ACTIONS(1801),
    3,
    anon_sym_AT,
    anon_sym_SLASH_SLASH_AT,
    aux_sym_extend_annotation_appl_token1,
    [45701] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2840),
    1,
    anon_sym_PIPE,
    ACTIONS(3110),
    1,
    anon_sym_RPAREN,
    STATE(986),
    1,
    aux_sym_annotation_appl_data_representation_repeat1,
    STATE(1037),
    1,
    sym_comment,
    [45720] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2824),
    1,
    anon_sym_context,
    ACTIONS(3112),
    1,
    anon_sym_SEMI,
    STATE(1038),
    1,
    sym_comment,
    STATE(1274),
    1,
    sym_context_expr,
    [45739] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1039),
    1,
    sym_comment,
    STATE(1420),
    1,
    sym_topic_platform,
    ACTIONS(1655),
    2,
    anon_sym_STAR,
    aux_sym_service_platform_token2,
    [45756] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(776),
    1,
    sym_scoped_name,
    STATE(1040),
    1,
    sym_comment,
    [45775] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(97),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2459),
    1,
    sym_identifier,
    STATE(1041),
    1,
    sym_comment,
    STATE(1051),
    1,
    sym_scoped_name,
    [45794] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2477),
    1,
    anon_sym_supports,
    ACTIONS(3114),
    1,
    anon_sym_LBRACE,
    STATE(1042),
    1,
    sym_comment,
    STATE(1262),
    1,
    sym_supported_interface_spec,
    [45813] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(975),
    1,
    sym_scoped_name,
    STATE(1043),
    1,
    sym_comment,
    [45832] = 6,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(594),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2641),
    1,
    sym_identifier,
    STATE(705),
    1,
    sym_scoped_name,
    STATE(1044),
    1,
    sym_comment,
    [45851] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3116),
    1,
    anon_sym_LT,
    STATE(1045),
    1,
    sym_comment,
    [45867] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1046),
    1,
    sym_comment,
    ACTIONS(3118),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [45881] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3120),
    1,
    aux_sym_max_expr_token1,
    STATE(1047),
    1,
    sym_comment,
    STATE(1416),
    1,
    sym_max_expr,
    [45897] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3122),
    1,
    aux_sym_min_expr_token1,
    STATE(1048),
    1,
    sym_comment,
    STATE(1690),
    1,
    sym_min_expr,
    [45913] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1049),
    1,
    sym_comment,
    ACTIONS(3124),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [45927] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3126),
    1,
    sym_identifier,
    STATE(1050),
    1,
    sym_comment,
    [45943] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3128),
    1,
    sym_identifier,
    STATE(1051),
    1,
    sym_comment,
    [45959] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3130),
    1,
    anon_sym_LBRACE,
    STATE(1052),
    1,
    sym_comment,
    [45975] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3132),
    1,
    sym_identifier,
    STATE(1053),
    1,
    sym_comment,
    [45991] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3134),
    1,
    sym_identifier,
    STATE(1054),
    1,
    sym_comment,
    [46007] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3136),
    1,
    sym_identifier,
    STATE(1055),
    1,
    sym_comment,
    [46023] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3138),
    1,
    anon_sym_COMMA,
    ACTIONS(3140),
    1,
    anon_sym_RPAREN,
    STATE(1056),
    1,
    sym_comment,
    [46039] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1057),
    1,
    sym_comment,
    ACTIONS(3104),
    2,
    anon_sym_PIPE,
    anon_sym_RPAREN,
    [46053] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1058),
    1,
    sym_comment,
    ACTIONS(1799),
    2,
    anon_sym_PIPE,
    anon_sym_RPAREN,
    [46067] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1059),
    1,
    sym_comment,
    ACTIONS(3142),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46081] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1060),
    1,
    sym_comment,
    ACTIONS(3144),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46095] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1061),
    1,
    sym_comment,
    ACTIONS(3146),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46109] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1062),
    1,
    sym_comment,
    STATE(1493),
    1,
    sym_simple_declarator,
    [46125] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1063),
    1,
    sym_comment,
    ACTIONS(3097),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46139] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1064),
    1,
    sym_comment,
    ACTIONS(3087),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [46153] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1065),
    1,
    sym_comment,
    ACTIONS(3080),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [46167] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1066),
    1,
    sym_comment,
    ACTIONS(3148),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46181] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1067),
    1,
    sym_comment,
    ACTIONS(3073),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [46195] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1068),
    1,
    sym_comment,
    ACTIONS(3150),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [46209] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1069),
    1,
    sym_comment,
    ACTIONS(3152),
    2,
    anon_sym_SEMI,
    anon_sym_setraises,
    [46223] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3154),
    1,
    anon_sym_GT,
    ACTIONS(3156),
    1,
    anon_sym_COMMA,
    STATE(1070),
    1,
    sym_comment,
    [46239] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1071),
    1,
    sym_comment,
    ACTIONS(3158),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [46253] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1072),
    1,
    sym_comment,
    ACTIONS(3160),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46267] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1073),
    1,
    sym_comment,
    ACTIONS(3035),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [46281] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1074),
    1,
    sym_comment,
    ACTIONS(3162),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [46295] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1075),
    1,
    sym_comment,
    ACTIONS(3164),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46309] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1076),
    1,
    sym_comment,
    ACTIONS(3166),
    2,
    anon_sym_COMMA,
    anon_sym_SEMI,
    [46323] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3168),
    1,
    anon_sym_LBRACE,
    STATE(1077),
    1,
    sym_comment,
    [46339] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1078),
    1,
    sym_comment,
    ACTIONS(3170),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46353] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1079),
    1,
    sym_comment,
    ACTIONS(3172),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [46367] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1080),
    1,
    sym_comment,
    ACTIONS(3046),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46381] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1081),
    1,
    sym_comment,
    ACTIONS(3174),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46395] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3176),
    1,
    anon_sym_SEMI,
    ACTIONS(3178),
    1,
    anon_sym_default,
    STATE(1082),
    1,
    sym_comment,
    [46411] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1083),
    1,
    sym_comment,
    ACTIONS(3180),
    2,
    anon_sym_SEMI,
    anon_sym_setraises,
    [46425] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1084),
    1,
    sym_comment,
    ACTIONS(3028),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [46439] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3182),
    1,
    anon_sym_LBRACE,
    ACTIONS(3184),
    1,
    anon_sym_COLON,
    STATE(1085),
    1,
    sym_comment,
    [46455] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3186),
    1,
    anon_sym_COMMA,
    ACTIONS(3188),
    1,
    anon_sym_RPAREN,
    STATE(1086),
    1,
    sym_comment,
    [46471] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1087),
    1,
    sym_comment,
    ACTIONS(3190),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [46485] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3192),
    1,
    anon_sym_GT,
    ACTIONS(3194),
    1,
    anon_sym_COMMA,
    STATE(1088),
    1,
    sym_comment,
    [46501] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1089),
    1,
    sym_comment,
    ACTIONS(3196),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46515] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3198),
    1,
    sym_identifier,
    STATE(1090),
    1,
    sym_comment,
    STATE(1336),
    1,
    sym_formal_parameter_names,
    [46531] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3200),
    1,
    anon_sym_LBRACE,
    STATE(1091),
    1,
    sym_comment,
    [46547] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1092),
    1,
    sym_comment,
    ACTIONS(2820),
    2,
    anon_sym_COMMA,
    anon_sym_SEMI,
    [46561] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3202),
    1,
    anon_sym_LT,
    ACTIONS(3204),
    1,
    sym_identifier,
    STATE(1093),
    1,
    sym_comment,
    [46577] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1094),
    1,
    sym_comment,
    ACTIONS(3206),
    2,
    anon_sym_RBRACE,
    anon_sym_bitfield,
    [46591] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1095),
    1,
    sym_comment,
    ACTIONS(3009),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46605] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1096),
    1,
    sym_comment,
    ACTIONS(3208),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46619] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1097),
    1,
    sym_comment,
    ACTIONS(2998),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46633] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3210),
    1,
    anon_sym_COMMA,
    ACTIONS(3212),
    1,
    anon_sym_RPAREN,
    STATE(1098),
    1,
    sym_comment,
    [46649] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1099),
    1,
    sym_comment,
    ACTIONS(3214),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46663] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1100),
    1,
    sym_comment,
    ACTIONS(3216),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46677] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1101),
    1,
    sym_comment,
    ACTIONS(3218),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46691] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3220),
    1,
    anon_sym_COMMA,
    ACTIONS(3222),
    1,
    anon_sym_RPAREN,
    STATE(1102),
    1,
    sym_comment,
    [46707] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1103),
    1,
    sym_comment,
    ACTIONS(2991),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46721] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1104),
    1,
    sym_comment,
    ACTIONS(2744),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [46735] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1105),
    1,
    sym_comment,
    ACTIONS(2986),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [46749] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2766),
    1,
    anon_sym_in,
    STATE(1080),
    1,
    sym_in_param_dcl,
    STATE(1106),
    1,
    sym_comment,
    [46765] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1107),
    1,
    sym_comment,
    ACTIONS(3224),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [46779] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1081),
    1,
    sym_simple_declarator,
    STATE(1108),
    1,
    sym_comment,
    [46795] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1109),
    1,
    sym_comment,
    ACTIONS(3226),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46809] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1110),
    1,
    sym_comment,
    ACTIONS(3228),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46823] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1111),
    1,
    sym_comment,
    ACTIONS(3230),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [46837] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1112),
    1,
    sym_comment,
    ACTIONS(3232),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [46851] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1082),
    1,
    sym_simple_declarator,
    STATE(1113),
    1,
    sym_comment,
    [46867] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3234),
    1,
    anon_sym_SEMI,
    ACTIONS(3236),
    1,
    anon_sym_default,
    STATE(1114),
    1,
    sym_comment,
    [46883] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3120),
    1,
    aux_sym_max_expr_token1,
    STATE(1115),
    1,
    sym_comment,
    STATE(1368),
    1,
    sym_max_expr,
    [46899] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1116),
    1,
    sym_comment,
    ACTIONS(2957),
    2,
    anon_sym_COMMA,
    anon_sym_LBRACE,
    [46913] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3238),
    1,
    anon_sym_COMMA,
    ACTIONS(3240),
    1,
    anon_sym_RPAREN,
    STATE(1117),
    1,
    sym_comment,
    [46929] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2617),
    1,
    anon_sym_in,
    STATE(1095),
    1,
    sym_factory_param_dcl,
    STATE(1118),
    1,
    sym_comment,
    [46945] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1096),
    1,
    sym_simple_declarator,
    STATE(1119),
    1,
    sym_comment,
    [46961] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1120),
    1,
    sym_comment,
    STATE(1139),
    1,
    sym_simple_declarator,
    [46977] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2599),
    1,
    anon_sym_in,
    STATE(1097),
    1,
    sym_init_param_dcl,
    STATE(1121),
    1,
    sym_comment,
    [46993] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1099),
    1,
    sym_simple_declarator,
    STATE(1122),
    1,
    sym_comment,
    [47009] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3242),
    1,
    anon_sym_LPAREN,
    STATE(1123),
    1,
    sym_comment,
    STATE(1137),
    1,
    sym_exception_list,
    [47025] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3122),
    1,
    aux_sym_min_expr_token1,
    STATE(1124),
    1,
    sym_comment,
    STATE(1218),
    1,
    sym_min_expr,
    [47041] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1101),
    1,
    sym_simple_declarator,
    STATE(1125),
    1,
    sym_comment,
    [47057] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3120),
    1,
    aux_sym_max_expr_token1,
    STATE(1126),
    1,
    sym_comment,
    STATE(1586),
    1,
    sym_max_expr,
    [47073] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1127),
    1,
    sym_comment,
    ACTIONS(3244),
    2,
    anon_sym_COMMA,
    anon_sym_RPAREN,
    [47087] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1128),
    1,
    sym_comment,
    ACTIONS(2577),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [47101] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1129),
    1,
    sym_comment,
    ACTIONS(3246),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47115] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1130),
    1,
    sym_comment,
    ACTIONS(3248),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47129] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3242),
    1,
    anon_sym_LPAREN,
    STATE(1131),
    1,
    sym_comment,
    STATE(1483),
    1,
    sym_exception_list,
    [47145] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1132),
    1,
    sym_comment,
    ACTIONS(3250),
    2,
    anon_sym_RBRACE,
    anon_sym_bitfield,
    [47159] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3252),
    1,
    anon_sym_GT,
    ACTIONS(3254),
    1,
    anon_sym_COMMA,
    STATE(1133),
    1,
    sym_comment,
    [47175] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(610),
    1,
    anon_sym_DQUOTE,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1105),
    1,
    sym_string_literal,
    STATE(1134),
    1,
    sym_comment,
    [47191] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3256),
    1,
    anon_sym_valuetype,
    ACTIONS(3258),
    1,
    anon_sym_eventtype,
    STATE(1135),
    1,
    sym_comment,
    [47207] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1136),
    1,
    sym_comment,
    ACTIONS(3260),
    2,
    anon_sym_SEMI,
    anon_sym_context,
    [47221] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1137),
    1,
    sym_comment,
    ACTIONS(3262),
    2,
    anon_sym_SEMI,
    anon_sym_setraises,
    [47235] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3264),
    1,
    anon_sym_DQUOTE,
    ACTIONS(3266),
    1,
    anon_sym_SQUOTE,
    STATE(1138),
    1,
    sym_comment,
    [47251] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1139),
    1,
    sym_comment,
    ACTIONS(2915),
    2,
    anon_sym_COMMA,
    anon_sym_SEMI,
    [47265] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3268),
    1,
    anon_sym_LT,
    STATE(1140),
    1,
    sym_comment,
    [47281] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3120),
    1,
    aux_sym_max_expr_token1,
    STATE(1141),
    1,
    sym_comment,
    STATE(1463),
    1,
    sym_max_expr,
    [47297] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3270),
    1,
    sym_identifier,
    STATE(1063),
    1,
    sym_annotation_appl_param,
    STATE(1142),
    1,
    sym_comment,
    [47313] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1127),
    1,
    sym_simple_declarator,
    STATE(1143),
    1,
    sym_comment,
    [47329] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2826),
    1,
    sym_identifier,
    STATE(1114),
    1,
    sym_simple_declarator,
    STATE(1144),
    1,
    sym_comment,
    [47345] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3272),
    1,
    sym_identifier,
    STATE(1145),
    1,
    sym_comment,
    [47361] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1146),
    1,
    sym_comment,
    ACTIONS(3274),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47375] = 5,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3276),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(3278),
    1,
    sym_preproc_arg,
    STATE(1147),
    1,
    sym_comment,
    [47391] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1148),
    1,
    sym_comment,
    ACTIONS(3280),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47405] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1149),
    1,
    sym_comment,
    ACTIONS(3282),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [47419] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1150),
    1,
    sym_comment,
    ACTIONS(3284),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47433] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3122),
    1,
    aux_sym_min_expr_token1,
    STATE(1151),
    1,
    sym_comment,
    STATE(1630),
    1,
    sym_min_expr,
    [47449] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3286),
    1,
    anon_sym_LBRACE,
    STATE(1152),
    1,
    sym_comment,
    [47465] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1153),
    1,
    sym_comment,
    ACTIONS(3288),
    2,
    anon_sym_GT,
    anon_sym_COMMA,
    [47479] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1154),
    1,
    sym_comment,
    ACTIONS(3290),
    2,
    anon_sym_RBRACE,
    anon_sym_bitfield,
    [47493] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3292),
    1,
    anon_sym_LBRACE,
    ACTIONS(3294),
    1,
    anon_sym_SEMI,
    STATE(1155),
    1,
    sym_comment,
    [47509] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1156),
    1,
    sym_comment,
    ACTIONS(3296),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47523] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3298),
    1,
    sym_identifier,
    STATE(1157),
    1,
    sym_comment,
    [47539] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1158),
    1,
    sym_comment,
    ACTIONS(3300),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47553] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3122),
    1,
    aux_sym_min_expr_token1,
    STATE(1159),
    1,
    sym_comment,
    STATE(1650),
    1,
    sym_min_expr,
    [47569] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3302),
    1,
    anon_sym_SEMI,
    STATE(1160),
    1,
    sym_comment,
    [47585] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3122),
    1,
    aux_sym_min_expr_token1,
    STATE(1161),
    1,
    sym_comment,
    STATE(1670),
    1,
    sym_min_expr,
    [47601] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2512),
    1,
    anon_sym_COLON_COLON,
    ACTIONS(3304),
    1,
    anon_sym_RPAREN,
    STATE(1162),
    1,
    sym_comment,
    [47617] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1163),
    1,
    sym_comment,
    ACTIONS(3306),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47631] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1164),
    1,
    sym_comment,
    ACTIONS(3308),
    2,
    anon_sym_COMMA,
    anon_sym_RBRACE,
    [47645] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1165),
    1,
    sym_comment,
    ACTIONS(3310),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47659] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1166),
    1,
    sym_comment,
    ACTIONS(3312),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47673] = 5,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3120),
    1,
    aux_sym_max_expr_token1,
    STATE(1167),
    1,
    sym_comment,
    STATE(1317),
    1,
    sym_max_expr,
    [47689] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    STATE(1168),
    1,
    sym_comment,
    ACTIONS(3314),
    2,
    anon_sym_SEMI,
    sym_identifier,
    [47703] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3316),
    1,
    anon_sym_RBRACE,
    STATE(1169),
    1,
    sym_comment,
    [47716] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3318),
    1,
    anon_sym_RPAREN,
    STATE(1170),
    1,
    sym_comment,
    [47729] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3320),
    1,
    anon_sym_SEMI,
    STATE(1171),
    1,
    sym_comment,
    [47742] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3322),
    1,
    anon_sym_RBRACE,
    STATE(1172),
    1,
    sym_comment,
    [47755] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3324),
    1,
    sym_identifier,
    STATE(1173),
    1,
    sym_comment,
    [47768] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3326),
    1,
    sym_identifier,
    STATE(1174),
    1,
    sym_comment,
    [47781] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3328),
    1,
    anon_sym_SEMI,
    STATE(1175),
    1,
    sym_comment,
    [47794] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3330),
    1,
    anon_sym_RBRACE,
    STATE(1176),
    1,
    sym_comment,
    [47807] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3332),
    1,
    anon_sym_SEMI,
    STATE(1177),
    1,
    sym_comment,
    [47820] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3334),
    1,
    anon_sym_SEMI,
    STATE(1178),
    1,
    sym_comment,
    [47833] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3336),
    1,
    sym_identifier,
    STATE(1179),
    1,
    sym_comment,
    [47846] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3338),
    1,
    anon_sym_SEMI,
    STATE(1180),
    1,
    sym_comment,
    [47859] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3340),
    1,
    anon_sym_LBRACE,
    STATE(1181),
    1,
    sym_comment,
    [47872] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3342),
    1,
    anon_sym_SEMI,
    STATE(1182),
    1,
    sym_comment,
    [47885] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3344),
    1,
    anon_sym_SEMI,
    STATE(1183),
    1,
    sym_comment,
    [47898] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3346),
    1,
    sym_identifier,
    STATE(1184),
    1,
    sym_comment,
    [47911] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3348),
    1,
    anon_sym_LBRACE,
    STATE(1185),
    1,
    sym_comment,
    [47924] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3350),
    1,
    anon_sym_SEMI,
    STATE(1186),
    1,
    sym_comment,
    [47937] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2822),
    1,
    anon_sym_SEMI,
    STATE(1187),
    1,
    sym_comment,
    [47950] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3352),
    1,
    anon_sym_SEMI,
    STATE(1188),
    1,
    sym_comment,
    [47963] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3354),
    1,
    anon_sym_manages,
    STATE(1189),
    1,
    sym_comment,
    [47976] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3356),
    1,
    aux_sym_preproc_call_token1,
    STATE(1190),
    1,
    sym_comment,
    [47989] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2175),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1191),
    1,
    sym_comment,
    [48002] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3358),
    1,
    anon_sym_SEMI,
    STATE(1192),
    1,
    sym_comment,
    [48015] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3360),
    1,
    anon_sym_LBRACE,
    STATE(1193),
    1,
    sym_comment,
    [48028] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3362),
    1,
    anon_sym_LBRACE,
    STATE(1194),
    1,
    sym_comment,
    [48041] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3364),
    1,
    anon_sym_LT,
    STATE(1195),
    1,
    sym_comment,
    [48054] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2858),
    1,
    anon_sym_RBRACE,
    STATE(1196),
    1,
    sym_comment,
    [48067] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3366),
    1,
    sym_identifier,
    STATE(1197),
    1,
    sym_comment,
    [48080] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3368),
    1,
    anon_sym_SEMI,
    STATE(1198),
    1,
    sym_comment,
    [48093] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3272),
    1,
    sym_identifier,
    STATE(1199),
    1,
    sym_comment,
    [48106] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3370),
    1,
    anon_sym_SEMI,
    STATE(1200),
    1,
    sym_comment,
    [48119] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3372),
    1,
    anon_sym_RPAREN,
    STATE(1201),
    1,
    sym_comment,
    [48132] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3374),
    1,
    anon_sym_RPAREN,
    STATE(1202),
    1,
    sym_comment,
    [48145] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3376),
    1,
    anon_sym_RPAREN,
    STATE(1203),
    1,
    sym_comment,
    [48158] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3378),
    1,
    anon_sym_RPAREN,
    STATE(1204),
    1,
    sym_comment,
    [48171] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3380),
    1,
    anon_sym_RPAREN,
    STATE(1205),
    1,
    sym_comment,
    [48184] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3382),
    1,
    anon_sym_RPAREN,
    STATE(1206),
    1,
    sym_comment,
    [48197] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3384),
    1,
    anon_sym_RPAREN,
    STATE(1207),
    1,
    sym_comment,
    [48210] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3386),
    1,
    anon_sym_RPAREN,
    STATE(1208),
    1,
    sym_comment,
    [48223] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3388),
    1,
    anon_sym_void,
    STATE(1209),
    1,
    sym_comment,
    [48236] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3390),
    1,
    anon_sym_RPAREN,
    STATE(1210),
    1,
    sym_comment,
    [48249] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3392),
    1,
    anon_sym_RPAREN,
    STATE(1211),
    1,
    sym_comment,
    [48262] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3256),
    1,
    anon_sym_valuetype,
    STATE(1212),
    1,
    sym_comment,
    [48275] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3394),
    1,
    anon_sym_attribute,
    STATE(1213),
    1,
    sym_comment,
    [48288] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3396),
    1,
    anon_sym_LBRACE,
    STATE(1214),
    1,
    sym_comment,
    [48301] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3398),
    1,
    sym_identifier,
    STATE(1215),
    1,
    sym_comment,
    [48314] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2888),
    1,
    anon_sym_valuetype,
    STATE(1216),
    1,
    sym_comment,
    [48327] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3400),
    1,
    anon_sym_EQ,
    STATE(1217),
    1,
    sym_comment,
    [48340] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3402),
    1,
    anon_sym_COMMA,
    STATE(1218),
    1,
    sym_comment,
    [48353] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3404),
    1,
    anon_sym_RPAREN,
    STATE(1219),
    1,
    sym_comment,
    [48366] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3406),
    1,
    anon_sym_SEMI,
    STATE(1220),
    1,
    sym_comment,
    [48379] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3408),
    1,
    anon_sym_RPAREN,
    STATE(1221),
    1,
    sym_comment,
    [48392] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3410),
    1,
    anon_sym_RPAREN,
    STATE(1222),
    1,
    sym_comment,
    [48405] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3412),
    1,
    anon_sym_RPAREN,
    STATE(1223),
    1,
    sym_comment,
    [48418] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3414),
    1,
    anon_sym_RPAREN,
    STATE(1224),
    1,
    sym_comment,
    [48431] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3416),
    1,
    anon_sym_RPAREN,
    STATE(1225),
    1,
    sym_comment,
    [48444] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3418),
    1,
    anon_sym_COMMA,
    STATE(1226),
    1,
    sym_comment,
    [48457] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3420),
    1,
    anon_sym_COMMA,
    STATE(1227),
    1,
    sym_comment,
    [48470] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3422),
    1,
    anon_sym_RPAREN,
    STATE(1228),
    1,
    sym_comment,
    [48483] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3424),
    1,
    anon_sym_COMMA,
    STATE(1229),
    1,
    sym_comment,
    [48496] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3426),
    1,
    anon_sym_COMMA,
    STATE(1230),
    1,
    sym_comment,
    [48509] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3428),
    1,
    anon_sym_RPAREN,
    STATE(1231),
    1,
    sym_comment,
    [48522] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3430),
    1,
    anon_sym_RPAREN,
    STATE(1232),
    1,
    sym_comment,
    [48535] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3432),
    1,
    anon_sym_RPAREN,
    STATE(1233),
    1,
    sym_comment,
    [48548] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3434),
    1,
    anon_sym_RPAREN,
    STATE(1234),
    1,
    sym_comment,
    [48561] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3436),
    1,
    anon_sym_RPAREN,
    STATE(1235),
    1,
    sym_comment,
    [48574] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3438),
    1,
    anon_sym_RPAREN,
    STATE(1236),
    1,
    sym_comment,
    [48587] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3440),
    1,
    anon_sym_RPAREN,
    STATE(1237),
    1,
    sym_comment,
    [48600] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3442),
    1,
    anon_sym_RPAREN,
    STATE(1238),
    1,
    sym_comment,
    [48613] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3444),
    1,
    anon_sym_RPAREN,
    STATE(1239),
    1,
    sym_comment,
    [48626] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3446),
    1,
    anon_sym_RPAREN,
    STATE(1240),
    1,
    sym_comment,
    [48639] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3448),
    1,
    anon_sym_RPAREN,
    STATE(1241),
    1,
    sym_comment,
    [48652] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3450),
    1,
    anon_sym_RPAREN,
    STATE(1242),
    1,
    sym_comment,
    [48665] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3452),
    1,
    anon_sym_EQ,
    STATE(1243),
    1,
    sym_comment,
    [48678] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3454),
    1,
    anon_sym_RPAREN,
    STATE(1244),
    1,
    sym_comment,
    [48691] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3456),
    1,
    anon_sym_EQ,
    STATE(1245),
    1,
    sym_comment,
    [48704] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3458),
    1,
    anon_sym_RPAREN,
    STATE(1246),
    1,
    sym_comment,
    [48717] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3004),
    1,
    anon_sym_RPAREN,
    STATE(1247),
    1,
    sym_comment,
    [48730] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3460),
    1,
    anon_sym_RPAREN,
    STATE(1248),
    1,
    sym_comment,
    [48743] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3204),
    1,
    sym_identifier,
    STATE(1249),
    1,
    sym_comment,
    [48756] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3462),
    1,
    anon_sym_GT,
    STATE(1250),
    1,
    sym_comment,
    [48769] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3464),
    1,
    sym_identifier,
    STATE(1251),
    1,
    sym_comment,
    [48782] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3466),
    1,
    anon_sym_SEMI,
    STATE(1252),
    1,
    sym_comment,
    [48795] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3468),
    1,
    anon_sym_GT,
    STATE(1253),
    1,
    sym_comment,
    [48808] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3470),
    1,
    anon_sym_LBRACE,
    STATE(1254),
    1,
    sym_comment,
    [48821] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2647),
    1,
    anon_sym_LBRACE,
    STATE(1255),
    1,
    sym_comment,
    [48834] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3060),
    1,
    anon_sym_RBRACE,
    STATE(1256),
    1,
    sym_comment,
    [48847] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3472),
    1,
    anon_sym_GT,
    STATE(1257),
    1,
    sym_comment,
    [48860] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3474),
    1,
    anon_sym_GT,
    STATE(1258),
    1,
    sym_comment,
    [48873] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3476),
    1,
    anon_sym_LBRACE,
    STATE(1259),
    1,
    sym_comment,
    [48886] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3478),
    1,
    anon_sym_COMMA,
    STATE(1260),
    1,
    sym_comment,
    [48899] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3480),
    1,
    anon_sym_COMMA,
    STATE(1261),
    1,
    sym_comment,
    [48912] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3482),
    1,
    anon_sym_LBRACE,
    STATE(1262),
    1,
    sym_comment,
    [48925] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1623),
    1,
    anon_sym_RPAREN,
    STATE(1263),
    1,
    sym_comment,
    [48938] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3484),
    1,
    anon_sym_EQ,
    STATE(1264),
    1,
    sym_comment,
    [48951] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3486),
    1,
    anon_sym_SEMI,
    STATE(1265),
    1,
    sym_comment,
    [48964] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3488),
    1,
    anon_sym_RBRACE,
    STATE(1266),
    1,
    sym_comment,
    [48977] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3490),
    1,
    anon_sym_LBRACE,
    STATE(1267),
    1,
    sym_comment,
    [48990] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3492),
    1,
    anon_sym_SEMI,
    STATE(1268),
    1,
    sym_comment,
    [49003] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3000),
    1,
    anon_sym_manages,
    STATE(1269),
    1,
    sym_comment,
    [49016] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3494),
    1,
    sym_identifier,
    STATE(1270),
    1,
    sym_comment,
    [49029] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3496),
    1,
    anon_sym_SEMI,
    STATE(1271),
    1,
    sym_comment,
    [49042] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3498),
    1,
    anon_sym_LPAREN,
    STATE(1272),
    1,
    sym_comment,
    [49055] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3500),
    1,
    sym_identifier,
    STATE(1273),
    1,
    sym_comment,
    [49068] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3502),
    1,
    anon_sym_SEMI,
    STATE(1274),
    1,
    sym_comment,
    [49081] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3504),
    1,
    anon_sym_LPAREN,
    STATE(1275),
    1,
    sym_comment,
    [49094] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3506),
    1,
    sym_identifier,
    STATE(1276),
    1,
    sym_comment,
    [49107] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3114),
    1,
    anon_sym_LBRACE,
    STATE(1277),
    1,
    sym_comment,
    [49120] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3508),
    1,
    sym_identifier,
    STATE(1278),
    1,
    sym_comment,
    [49133] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3510),
    1,
    anon_sym_SEMI,
    STATE(1279),
    1,
    sym_comment,
    [49146] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3512),
    1,
    anon_sym_LPAREN,
    STATE(1280),
    1,
    sym_comment,
    [49159] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3514),
    1,
    anon_sym_SEMI,
    STATE(1281),
    1,
    sym_comment,
    [49172] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3112),
    1,
    anon_sym_SEMI,
    STATE(1282),
    1,
    sym_comment,
    [49185] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3126),
    1,
    sym_identifier,
    STATE(1283),
    1,
    sym_comment,
    [49198] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3516),
    1,
    anon_sym_RPAREN,
    STATE(1284),
    1,
    sym_comment,
    [49211] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3518),
    1,
    anon_sym_RPAREN,
    STATE(1285),
    1,
    sym_comment,
    [49224] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3520),
    1,
    anon_sym_RPAREN,
    STATE(1286),
    1,
    sym_comment,
    [49237] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3522),
    1,
    anon_sym_RPAREN,
    STATE(1287),
    1,
    sym_comment,
    [49250] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3524),
    1,
    anon_sym_RPAREN,
    STATE(1288),
    1,
    sym_comment,
    [49263] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3526),
    1,
    anon_sym_RPAREN,
    STATE(1289),
    1,
    sym_comment,
    [49276] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3528),
    1,
    anon_sym_RPAREN,
    STATE(1290),
    1,
    sym_comment,
    [49289] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3530),
    1,
    anon_sym_RPAREN,
    STATE(1291),
    1,
    sym_comment,
    [49302] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3532),
    1,
    anon_sym_RPAREN,
    STATE(1292),
    1,
    sym_comment,
    [49315] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3534),
    1,
    anon_sym_RPAREN,
    STATE(1293),
    1,
    sym_comment,
    [49328] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3536),
    1,
    anon_sym_RPAREN,
    STATE(1294),
    1,
    sym_comment,
    [49341] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3538),
    1,
    anon_sym_RPAREN,
    STATE(1295),
    1,
    sym_comment,
    [49354] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3540),
    1,
    anon_sym_RPAREN,
    STATE(1296),
    1,
    sym_comment,
    [49367] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3542),
    1,
    anon_sym_RPAREN,
    STATE(1297),
    1,
    sym_comment,
    [49380] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3544),
    1,
    anon_sym_RPAREN,
    STATE(1298),
    1,
    sym_comment,
    [49393] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3546),
    1,
    anon_sym_RPAREN,
    STATE(1299),
    1,
    sym_comment,
    [49406] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3548),
    1,
    anon_sym_RPAREN,
    STATE(1300),
    1,
    sym_comment,
    [49419] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3550),
    1,
    anon_sym_RPAREN,
    STATE(1301),
    1,
    sym_comment,
    [49432] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3552),
    1,
    anon_sym_RPAREN,
    STATE(1302),
    1,
    sym_comment,
    [49445] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3554),
    1,
    anon_sym_RPAREN,
    STATE(1303),
    1,
    sym_comment,
    [49458] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3556),
    1,
    anon_sym_RPAREN,
    STATE(1304),
    1,
    sym_comment,
    [49471] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3558),
    1,
    anon_sym_RPAREN,
    STATE(1305),
    1,
    sym_comment,
    [49484] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3560),
    1,
    anon_sym_RPAREN,
    STATE(1306),
    1,
    sym_comment,
    [49497] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3562),
    1,
    anon_sym_RPAREN,
    STATE(1307),
    1,
    sym_comment,
    [49510] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3564),
    1,
    sym_identifier,
    STATE(1308),
    1,
    sym_comment,
    [49523] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3566),
    1,
    sym_identifier,
    STATE(1309),
    1,
    sym_comment,
    [49536] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3568),
    1,
    anon_sym_RPAREN,
    STATE(1310),
    1,
    sym_comment,
    [49549] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3570),
    1,
    anon_sym_RPAREN,
    STATE(1311),
    1,
    sym_comment,
    [49562] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3572),
    1,
    anon_sym_RPAREN,
    STATE(1312),
    1,
    sym_comment,
    [49575] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3574),
    1,
    anon_sym_RPAREN,
    STATE(1313),
    1,
    sym_comment,
    [49588] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3576),
    1,
    anon_sym_SEMI,
    STATE(1314),
    1,
    sym_comment,
    [49601] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3578),
    1,
    anon_sym_LPAREN,
    STATE(1315),
    1,
    sym_comment,
    [49614] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3580),
    1,
    anon_sym_LPAREN,
    STATE(1316),
    1,
    sym_comment,
    [49627] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3582),
    1,
    anon_sym_RPAREN,
    STATE(1317),
    1,
    sym_comment,
    [49640] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3584),
    1,
    anon_sym_RPAREN,
    STATE(1318),
    1,
    sym_comment,
    [49653] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3586),
    1,
    anon_sym_RPAREN,
    STATE(1319),
    1,
    sym_comment,
    [49666] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3588),
    1,
    anon_sym_SEMI,
    STATE(1320),
    1,
    sym_comment,
    [49679] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3590),
    1,
    anon_sym_RPAREN,
    STATE(1321),
    1,
    sym_comment,
    [49692] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3592),
    1,
    anon_sym_RPAREN,
    STATE(1322),
    1,
    sym_comment,
    [49705] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3594),
    1,
    anon_sym_RPAREN,
    STATE(1323),
    1,
    sym_comment,
    [49718] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3596),
    1,
    anon_sym_SEMI,
    STATE(1324),
    1,
    sym_comment,
    [49731] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3598),
    1,
    anon_sym_SEMI,
    STATE(1325),
    1,
    sym_comment,
    [49744] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3600),
    1,
    anon_sym_RPAREN,
    STATE(1326),
    1,
    sym_comment,
    [49757] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3602),
    1,
    sym_identifier,
    STATE(1327),
    1,
    sym_comment,
    [49770] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3604),
    1,
    sym_identifier,
    STATE(1328),
    1,
    sym_comment,
    [49783] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3606),
    1,
    anon_sym_SEMI,
    STATE(1329),
    1,
    sym_comment,
    [49796] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3608),
    1,
    sym_identifier,
    STATE(1330),
    1,
    sym_comment,
    [49809] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3610),
    1,
    anon_sym_SEMI,
    STATE(1331),
    1,
    sym_comment,
    [49822] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3612),
    1,
    sym_identifier,
    STATE(1332),
    1,
    sym_comment,
    [49835] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3614),
    1,
    anon_sym_SEMI,
    STATE(1333),
    1,
    sym_comment,
    [49848] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3616),
    1,
    anon_sym_SEMI,
    STATE(1334),
    1,
    sym_comment,
    [49861] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3048),
    1,
    anon_sym_SEMI,
    STATE(1335),
    1,
    sym_comment,
    [49874] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3618),
    1,
    anon_sym_GT,
    STATE(1336),
    1,
    sym_comment,
    [49887] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3620),
    1,
    anon_sym_RPAREN,
    STATE(1337),
    1,
    sym_comment,
    [49900] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3622),
    1,
    anon_sym_RPAREN,
    STATE(1338),
    1,
    sym_comment,
    [49913] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3624),
    1,
    anon_sym_RPAREN,
    STATE(1339),
    1,
    sym_comment,
    [49926] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3626),
    1,
    anon_sym_RPAREN,
    STATE(1340),
    1,
    sym_comment,
    [49939] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3628),
    1,
    anon_sym_RPAREN,
    STATE(1341),
    1,
    sym_comment,
    [49952] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3630),
    1,
    anon_sym_RPAREN,
    STATE(1342),
    1,
    sym_comment,
    [49965] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3632),
    1,
    anon_sym_RPAREN,
    STATE(1343),
    1,
    sym_comment,
    [49978] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3634),
    1,
    anon_sym_RPAREN,
    STATE(1344),
    1,
    sym_comment,
    [49991] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3636),
    1,
    anon_sym_RPAREN,
    STATE(1345),
    1,
    sym_comment,
    [50004] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3638),
    1,
    anon_sym_RPAREN,
    STATE(1346),
    1,
    sym_comment,
    [50017] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3640),
    1,
    anon_sym_RPAREN,
    STATE(1347),
    1,
    sym_comment,
    [50030] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3642),
    1,
    anon_sym_RPAREN,
    STATE(1348),
    1,
    sym_comment,
    [50043] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3644),
    1,
    anon_sym_RPAREN,
    STATE(1349),
    1,
    sym_comment,
    [50056] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3646),
    1,
    anon_sym_RPAREN,
    STATE(1350),
    1,
    sym_comment,
    [50069] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3648),
    1,
    anon_sym_RPAREN,
    STATE(1351),
    1,
    sym_comment,
    [50082] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3650),
    1,
    anon_sym_RPAREN,
    STATE(1352),
    1,
    sym_comment,
    [50095] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3652),
    1,
    anon_sym_RPAREN,
    STATE(1353),
    1,
    sym_comment,
    [50108] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3654),
    1,
    anon_sym_RPAREN,
    STATE(1354),
    1,
    sym_comment,
    [50121] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3656),
    1,
    anon_sym_RPAREN,
    STATE(1355),
    1,
    sym_comment,
    [50134] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3658),
    1,
    anon_sym_RPAREN,
    STATE(1356),
    1,
    sym_comment,
    [50147] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3660),
    1,
    anon_sym_RPAREN,
    STATE(1357),
    1,
    sym_comment,
    [50160] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3662),
    1,
    anon_sym_RPAREN,
    STATE(1358),
    1,
    sym_comment,
    [50173] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3664),
    1,
    anon_sym_RPAREN,
    STATE(1359),
    1,
    sym_comment,
    [50186] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3666),
    1,
    anon_sym_RPAREN,
    STATE(1360),
    1,
    sym_comment,
    [50199] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3668),
    1,
    anon_sym_SEMI,
    STATE(1361),
    1,
    sym_comment,
    [50212] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3670),
    1,
    anon_sym_SEMI,
    STATE(1362),
    1,
    sym_comment,
    [50225] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3672),
    1,
    anon_sym_RPAREN,
    STATE(1363),
    1,
    sym_comment,
    [50238] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3674),
    1,
    anon_sym_RPAREN,
    STATE(1364),
    1,
    sym_comment,
    [50251] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3676),
    1,
    anon_sym_RPAREN,
    STATE(1365),
    1,
    sym_comment,
    [50264] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3678),
    1,
    anon_sym_RPAREN,
    STATE(1366),
    1,
    sym_comment,
    [50277] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3680),
    1,
    anon_sym_SEMI,
    STATE(1367),
    1,
    sym_comment,
    [50290] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3682),
    1,
    anon_sym_RPAREN,
    STATE(1368),
    1,
    sym_comment,
    [50303] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3684),
    1,
    anon_sym_RPAREN,
    STATE(1369),
    1,
    sym_comment,
    [50316] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3686),
    1,
    anon_sym_RPAREN,
    STATE(1370),
    1,
    sym_comment,
    [50329] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3688),
    1,
    anon_sym_COLON,
    STATE(1371),
    1,
    sym_comment,
    [50342] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3690),
    1,
    anon_sym_RPAREN,
    STATE(1372),
    1,
    sym_comment,
    [50355] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3692),
    1,
    anon_sym_RPAREN,
    STATE(1373),
    1,
    sym_comment,
    [50368] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3694),
    1,
    anon_sym_RPAREN,
    STATE(1374),
    1,
    sym_comment,
    [50381] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3696),
    1,
    anon_sym_SEMI,
    STATE(1375),
    1,
    sym_comment,
    [50394] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3698),
    1,
    anon_sym_RPAREN,
    STATE(1376),
    1,
    sym_comment,
    [50407] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3700),
    1,
    anon_sym_SEMI,
    STATE(1377),
    1,
    sym_comment,
    [50420] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3702),
    1,
    sym_identifier,
    STATE(1378),
    1,
    sym_comment,
    [50433] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3704),
    1,
    anon_sym_EQ,
    STATE(1379),
    1,
    sym_comment,
    [50446] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3706),
    1,
    anon_sym_SEMI,
    STATE(1380),
    1,
    sym_comment,
    [50459] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3708),
    1,
    anon_sym_LPAREN,
    STATE(1381),
    1,
    sym_comment,
    [50472] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3710),
    1,
    sym_identifier,
    STATE(1382),
    1,
    sym_comment,
    [50485] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3712),
    1,
    anon_sym_SEMI,
    STATE(1383),
    1,
    sym_comment,
    [50498] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2961),
    1,
    anon_sym_LBRACE,
    STATE(1384),
    1,
    sym_comment,
    [50511] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3714),
    1,
    anon_sym_RPAREN,
    STATE(1385),
    1,
    sym_comment,
    [50524] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3716),
    1,
    anon_sym_RPAREN,
    STATE(1386),
    1,
    sym_comment,
    [50537] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3718),
    1,
    anon_sym_RPAREN,
    STATE(1387),
    1,
    sym_comment,
    [50550] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3720),
    1,
    anon_sym_RPAREN,
    STATE(1388),
    1,
    sym_comment,
    [50563] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3722),
    1,
    anon_sym_RPAREN,
    STATE(1389),
    1,
    sym_comment,
    [50576] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3724),
    1,
    anon_sym_RPAREN,
    STATE(1390),
    1,
    sym_comment,
    [50589] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3726),
    1,
    anon_sym_RPAREN,
    STATE(1391),
    1,
    sym_comment,
    [50602] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3728),
    1,
    anon_sym_RPAREN,
    STATE(1392),
    1,
    sym_comment,
    [50615] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3730),
    1,
    anon_sym_RPAREN,
    STATE(1393),
    1,
    sym_comment,
    [50628] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3732),
    1,
    anon_sym_RPAREN,
    STATE(1394),
    1,
    sym_comment,
    [50641] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3734),
    1,
    anon_sym_RPAREN,
    STATE(1395),
    1,
    sym_comment,
    [50654] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3736),
    1,
    anon_sym_RPAREN,
    STATE(1396),
    1,
    sym_comment,
    [50667] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3738),
    1,
    anon_sym_RPAREN,
    STATE(1397),
    1,
    sym_comment,
    [50680] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3740),
    1,
    anon_sym_RPAREN,
    STATE(1398),
    1,
    sym_comment,
    [50693] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3742),
    1,
    anon_sym_RPAREN,
    STATE(1399),
    1,
    sym_comment,
    [50706] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3744),
    1,
    anon_sym_RPAREN,
    STATE(1400),
    1,
    sym_comment,
    [50719] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3746),
    1,
    anon_sym_RPAREN,
    STATE(1401),
    1,
    sym_comment,
    [50732] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3748),
    1,
    anon_sym_RPAREN,
    STATE(1402),
    1,
    sym_comment,
    [50745] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3750),
    1,
    anon_sym_RPAREN,
    STATE(1403),
    1,
    sym_comment,
    [50758] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3752),
    1,
    anon_sym_RPAREN,
    STATE(1404),
    1,
    sym_comment,
    [50771] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3754),
    1,
    anon_sym_RPAREN,
    STATE(1405),
    1,
    sym_comment,
    [50784] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3756),
    1,
    anon_sym_RPAREN,
    STATE(1406),
    1,
    sym_comment,
    [50797] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3758),
    1,
    anon_sym_RPAREN,
    STATE(1407),
    1,
    sym_comment,
    [50810] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3760),
    1,
    anon_sym_RPAREN,
    STATE(1408),
    1,
    sym_comment,
    [50823] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3762),
    1,
    anon_sym_SEMI,
    STATE(1409),
    1,
    sym_comment,
    [50836] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3764),
    1,
    anon_sym_SEMI,
    STATE(1410),
    1,
    sym_comment,
    [50849] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3766),
    1,
    anon_sym_RPAREN,
    STATE(1411),
    1,
    sym_comment,
    [50862] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3768),
    1,
    anon_sym_RPAREN,
    STATE(1412),
    1,
    sym_comment,
    [50875] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3770),
    1,
    anon_sym_RPAREN,
    STATE(1413),
    1,
    sym_comment,
    [50888] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3772),
    1,
    anon_sym_RPAREN,
    STATE(1414),
    1,
    sym_comment,
    [50901] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3774),
    1,
    anon_sym_SEMI,
    STATE(1415),
    1,
    sym_comment,
    [50914] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3776),
    1,
    anon_sym_RPAREN,
    STATE(1416),
    1,
    sym_comment,
    [50927] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3778),
    1,
    anon_sym_RPAREN,
    STATE(1417),
    1,
    sym_comment,
    [50940] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3780),
    1,
    anon_sym_RPAREN,
    STATE(1418),
    1,
    sym_comment,
    [50953] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3782),
    1,
    anon_sym_SEMI,
    STATE(1419),
    1,
    sym_comment,
    [50966] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3784),
    1,
    anon_sym_RPAREN,
    STATE(1420),
    1,
    sym_comment,
    [50979] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3786),
    1,
    anon_sym_RPAREN,
    STATE(1421),
    1,
    sym_comment,
    [50992] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3788),
    1,
    anon_sym_RPAREN,
    STATE(1422),
    1,
    sym_comment,
    [51005] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3790),
    1,
    anon_sym_GT,
    STATE(1423),
    1,
    sym_comment,
    [51018] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3792),
    1,
    anon_sym_RPAREN,
    STATE(1424),
    1,
    sym_comment,
    [51031] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3794),
    1,
    anon_sym_COLON,
    STATE(1425),
    1,
    sym_comment,
    [51044] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3796),
    1,
    sym_identifier,
    STATE(1426),
    1,
    sym_comment,
    [51057] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2469),
    1,
    anon_sym_LBRACE,
    STATE(1427),
    1,
    sym_comment,
    [51070] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3798),
    1,
    anon_sym_SEMI,
    STATE(1428),
    1,
    sym_comment,
    [51083] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3800),
    1,
    anon_sym_RPAREN,
    STATE(1429),
    1,
    sym_comment,
    [51096] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3802),
    1,
    sym_identifier,
    STATE(1430),
    1,
    sym_comment,
    [51109] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3804),
    1,
    anon_sym_RPAREN,
    STATE(1431),
    1,
    sym_comment,
    [51122] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3806),
    1,
    anon_sym_RPAREN,
    STATE(1432),
    1,
    sym_comment,
    [51135] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3808),
    1,
    anon_sym_RPAREN,
    STATE(1433),
    1,
    sym_comment,
    [51148] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3810),
    1,
    anon_sym_RPAREN,
    STATE(1434),
    1,
    sym_comment,
    [51161] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3812),
    1,
    anon_sym_RPAREN,
    STATE(1435),
    1,
    sym_comment,
    [51174] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3814),
    1,
    anon_sym_SEMI,
    STATE(1436),
    1,
    sym_comment,
    [51187] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3816),
    1,
    anon_sym_RPAREN,
    STATE(1437),
    1,
    sym_comment,
    [51200] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3818),
    1,
    anon_sym_RPAREN,
    STATE(1438),
    1,
    sym_comment,
    [51213] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3820),
    1,
    anon_sym_RPAREN,
    STATE(1439),
    1,
    sym_comment,
    [51226] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3822),
    1,
    anon_sym_RPAREN,
    STATE(1440),
    1,
    sym_comment,
    [51239] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3824),
    1,
    anon_sym_RPAREN,
    STATE(1441),
    1,
    sym_comment,
    [51252] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3826),
    1,
    anon_sym_RPAREN,
    STATE(1442),
    1,
    sym_comment,
    [51265] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3828),
    1,
    anon_sym_RPAREN,
    STATE(1443),
    1,
    sym_comment,
    [51278] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3830),
    1,
    anon_sym_RPAREN,
    STATE(1444),
    1,
    sym_comment,
    [51291] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3832),
    1,
    anon_sym_RPAREN,
    STATE(1445),
    1,
    sym_comment,
    [51304] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3834),
    1,
    anon_sym_RPAREN,
    STATE(1446),
    1,
    sym_comment,
    [51317] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3836),
    1,
    anon_sym_RPAREN,
    STATE(1447),
    1,
    sym_comment,
    [51330] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3838),
    1,
    anon_sym_RPAREN,
    STATE(1448),
    1,
    sym_comment,
    [51343] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3840),
    1,
    anon_sym_RPAREN,
    STATE(1449),
    1,
    sym_comment,
    [51356] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3842),
    1,
    anon_sym_RPAREN,
    STATE(1450),
    1,
    sym_comment,
    [51369] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3844),
    1,
    anon_sym_RPAREN,
    STATE(1451),
    1,
    sym_comment,
    [51382] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3846),
    1,
    anon_sym_RPAREN,
    STATE(1452),
    1,
    sym_comment,
    [51395] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3848),
    1,
    anon_sym_RPAREN,
    STATE(1453),
    1,
    sym_comment,
    [51408] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3850),
    1,
    anon_sym_RPAREN,
    STATE(1454),
    1,
    sym_comment,
    [51421] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3852),
    1,
    anon_sym_RPAREN,
    STATE(1455),
    1,
    sym_comment,
    [51434] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3854),
    1,
    anon_sym_SEMI,
    STATE(1456),
    1,
    sym_comment,
    [51447] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3856),
    1,
    anon_sym_RPAREN,
    STATE(1457),
    1,
    sym_comment,
    [51460] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3858),
    1,
    anon_sym_RPAREN,
    STATE(1458),
    1,
    sym_comment,
    [51473] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3860),
    1,
    anon_sym_RPAREN,
    STATE(1459),
    1,
    sym_comment,
    [51486] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3862),
    1,
    anon_sym_RPAREN,
    STATE(1460),
    1,
    sym_comment,
    [51499] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3864),
    1,
    anon_sym_RPAREN,
    STATE(1461),
    1,
    sym_comment,
    [51512] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3866),
    1,
    anon_sym_SEMI,
    STATE(1462),
    1,
    sym_comment,
    [51525] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3868),
    1,
    anon_sym_RPAREN,
    STATE(1463),
    1,
    sym_comment,
    [51538] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3870),
    1,
    anon_sym_RPAREN,
    STATE(1464),
    1,
    sym_comment,
    [51551] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3872),
    1,
    anon_sym_RPAREN,
    STATE(1465),
    1,
    sym_comment,
    [51564] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3874),
    1,
    anon_sym_GT,
    STATE(1466),
    1,
    sym_comment,
    [51577] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3876),
    1,
    anon_sym_RPAREN,
    STATE(1467),
    1,
    sym_comment,
    [51590] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3878),
    1,
    anon_sym_RPAREN,
    STATE(1468),
    1,
    sym_comment,
    [51603] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3880),
    1,
    anon_sym_RPAREN,
    STATE(1469),
    1,
    sym_comment,
    [51616] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3882),
    1,
    anon_sym_GT,
    STATE(1470),
    1,
    sym_comment,
    [51629] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3884),
    1,
    anon_sym_RPAREN,
    STATE(1471),
    1,
    sym_comment,
    [51642] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3886),
    1,
    sym_identifier,
    STATE(1472),
    1,
    sym_comment,
    [51655] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3888),
    1,
    sym_identifier,
    STATE(1473),
    1,
    sym_comment,
    [51668] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3890),
    1,
    sym_identifier,
    STATE(1474),
    1,
    sym_comment,
    [51681] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2946),
    1,
    anon_sym_SEMI,
    STATE(1475),
    1,
    sym_comment,
    [51694] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2940),
    1,
    anon_sym_SEMI,
    STATE(1476),
    1,
    sym_comment,
    [51707] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2936),
    1,
    anon_sym_SEMI,
    STATE(1477),
    1,
    sym_comment,
    [51720] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3892),
    1,
    anon_sym_RPAREN,
    STATE(1478),
    1,
    sym_comment,
    [51733] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3894),
    1,
    anon_sym_SEMI,
    STATE(1479),
    1,
    sym_comment,
    [51746] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3896),
    1,
    anon_sym_RPAREN,
    STATE(1480),
    1,
    sym_comment,
    [51759] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3898),
    1,
    anon_sym_LBRACE,
    STATE(1481),
    1,
    sym_comment,
    [51772] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3900),
    1,
    anon_sym_SEMI,
    STATE(1482),
    1,
    sym_comment,
    [51785] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3902),
    1,
    anon_sym_SEMI,
    STATE(1483),
    1,
    sym_comment,
    [51798] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2259),
    1,
    aux_sym_preproc_call_token1,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    STATE(1484),
    1,
    sym_comment,
    [51811] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2904),
    1,
    anon_sym_SEMI,
    STATE(1485),
    1,
    sym_comment,
    [51824] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3904),
    1,
    anon_sym_GT,
    STATE(1486),
    1,
    sym_comment,
    [51837] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3906),
    1,
    anon_sym_LPAREN,
    STATE(1487),
    1,
    sym_comment,
    [51850] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3908),
    1,
    anon_sym_SEMI,
    STATE(1488),
    1,
    sym_comment,
    [51863] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3910),
    1,
    anon_sym_LPAREN,
    STATE(1489),
    1,
    sym_comment,
    [51876] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3912),
    1,
    anon_sym_LBRACE,
    STATE(1490),
    1,
    sym_comment,
    [51889] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3914),
    1,
    sym_identifier,
    STATE(1491),
    1,
    sym_comment,
    [51902] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3916),
    1,
    sym_identifier,
    STATE(1492),
    1,
    sym_comment,
    [51915] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3918),
    1,
    anon_sym_SEMI,
    STATE(1493),
    1,
    sym_comment,
    [51928] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3920),
    1,
    anon_sym_LBRACE,
    STATE(1494),
    1,
    sym_comment,
    [51941] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3922),
    1,
    anon_sym_SEMI,
    STATE(1495),
    1,
    sym_comment,
    [51954] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3924),
    1,
    anon_sym_SEMI,
    STATE(1496),
    1,
    sym_comment,
    [51967] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3926),
    1,
    anon_sym_SEMI,
    STATE(1497),
    1,
    sym_comment,
    [51980] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3928),
    1,
    anon_sym_SEMI,
    STATE(1498),
    1,
    sym_comment,
    [51993] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3302),
    1,
    anon_sym_SEMI,
    STATE(1499),
    1,
    sym_comment,
    [52006] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3930),
    1,
    sym_identifier,
    STATE(1500),
    1,
    sym_comment,
    [52019] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3304),
    1,
    anon_sym_RPAREN,
    STATE(1501),
    1,
    sym_comment,
    [52032] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3932),
    1,
    anon_sym_RPAREN,
    STATE(1502),
    1,
    sym_comment,
    [52045] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3934),
    1,
    anon_sym_RPAREN,
    STATE(1503),
    1,
    sym_comment,
    [52058] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3936),
    1,
    anon_sym_SEMI,
    STATE(1504),
    1,
    sym_comment,
    [52071] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3938),
    1,
    anon_sym_SEMI,
    STATE(1505),
    1,
    sym_comment,
    [52084] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3940),
    1,
    anon_sym_SEMI,
    STATE(1506),
    1,
    sym_comment,
    [52097] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3942),
    1,
    anon_sym_SEMI,
    STATE(1507),
    1,
    sym_comment,
    [52110] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3944),
    1,
    anon_sym_SEMI,
    STATE(1508),
    1,
    sym_comment,
    [52123] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3946),
    1,
    anon_sym_RBRACK,
    STATE(1509),
    1,
    sym_comment,
    [52136] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3948),
    1,
    anon_sym_SEMI,
    STATE(1510),
    1,
    sym_comment,
    [52149] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3950),
    1,
    anon_sym_LT,
    STATE(1511),
    1,
    sym_comment,
    [52162] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3952),
    1,
    anon_sym_SEMI,
    STATE(1512),
    1,
    sym_comment,
    [52175] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3954),
    1,
    anon_sym_LT,
    STATE(1513),
    1,
    sym_comment,
    [52188] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3956),
    1,
    anon_sym_RPAREN,
    STATE(1514),
    1,
    sym_comment,
    [52201] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3958),
    1,
    sym_identifier,
    STATE(1515),
    1,
    sym_comment,
    [52214] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3960),
    1,
    anon_sym_RPAREN,
    STATE(1516),
    1,
    sym_comment,
    [52227] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3962),
    1,
    sym_identifier,
    STATE(1517),
    1,
    sym_comment,
    [52240] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3964),
    1,
    sym_identifier,
    STATE(1518),
    1,
    sym_comment,
    [52253] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3966),
    1,
    anon_sym_SEMI,
    STATE(1519),
    1,
    sym_comment,
    [52266] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3202),
    1,
    anon_sym_LT,
    STATE(1520),
    1,
    sym_comment,
    [52279] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(3968),
    1,
    aux_sym_comment_token1,
    STATE(1521),
    1,
    sym_comment,
    [52292] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3970),
    1,
    sym_identifier,
    STATE(1522),
    1,
    sym_comment,
    [52305] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3298),
    1,
    sym_identifier,
    STATE(1523),
    1,
    sym_comment,
    [52318] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3972),
    1,
    anon_sym_LBRACE,
    STATE(1524),
    1,
    sym_comment,
    [52331] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3974),
    1,
    anon_sym_RPAREN,
    STATE(1525),
    1,
    sym_comment,
    [52344] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2780),
    1,
    anon_sym_LBRACE,
    STATE(1526),
    1,
    sym_comment,
    [52357] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(1304),
    1,
    anon_sym_RPAREN,
    STATE(1527),
    1,
    sym_comment,
    [52370] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3976),
    1,
    anon_sym_SEMI,
    STATE(1528),
    1,
    sym_comment,
    [52383] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2910),
    1,
    anon_sym_SEMI,
    STATE(1529),
    1,
    sym_comment,
    [52396] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3978),
    1,
    anon_sym_LPAREN,
    STATE(1530),
    1,
    sym_comment,
    [52409] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3980),
    1,
    anon_sym_LPAREN,
    STATE(1531),
    1,
    sym_comment,
    [52422] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3982),
    1,
    anon_sym_LPAREN,
    STATE(1532),
    1,
    sym_comment,
    [52435] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2898),
    1,
    anon_sym_SEMI,
    STATE(1533),
    1,
    sym_comment,
    [52448] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3984),
    1,
    anon_sym_SEMI,
    STATE(1534),
    1,
    sym_comment,
    [52461] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3986),
    1,
    anon_sym_LPAREN,
    STATE(1535),
    1,
    sym_comment,
    [52474] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3988),
    1,
    anon_sym_LPAREN,
    STATE(1536),
    1,
    sym_comment,
    [52487] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3990),
    1,
    anon_sym_LPAREN,
    STATE(1537),
    1,
    sym_comment,
    [52500] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3992),
    1,
    anon_sym_LPAREN,
    STATE(1538),
    1,
    sym_comment,
    [52513] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3994),
    1,
    anon_sym_SEMI,
    STATE(1539),
    1,
    sym_comment,
    [52526] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3996),
    1,
    anon_sym_LPAREN,
    STATE(1540),
    1,
    sym_comment,
    [52539] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(3998),
    1,
    anon_sym_LPAREN,
    STATE(1541),
    1,
    sym_comment,
    [52552] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4000),
    1,
    anon_sym_LPAREN,
    STATE(1542),
    1,
    sym_comment,
    [52565] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4002),
    1,
    anon_sym_SEMI,
    STATE(1543),
    1,
    sym_comment,
    [52578] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4004),
    1,
    anon_sym_LPAREN,
    STATE(1544),
    1,
    sym_comment,
    [52591] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4006),
    1,
    anon_sym_LPAREN,
    STATE(1545),
    1,
    sym_comment,
    [52604] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4008),
    1,
    anon_sym_LPAREN,
    STATE(1546),
    1,
    sym_comment,
    [52617] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4010),
    1,
    anon_sym_LPAREN,
    STATE(1547),
    1,
    sym_comment,
    [52630] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4012),
    1,
    sym_identifier,
    STATE(1548),
    1,
    sym_comment,
    [52643] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4014),
    1,
    sym_identifier,
    STATE(1549),
    1,
    sym_comment,
    [52656] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4016),
    1,
    anon_sym_LBRACE,
    STATE(1550),
    1,
    sym_comment,
    [52669] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2748),
    1,
    anon_sym_LBRACE,
    STATE(1551),
    1,
    sym_comment,
    [52682] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4018),
    1,
    anon_sym_LBRACE,
    STATE(1552),
    1,
    sym_comment,
    [52695] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4020),
    1,
    anon_sym_GT,
    STATE(1553),
    1,
    sym_comment,
    [52708] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4022),
    1,
    sym_identifier,
    STATE(1554),
    1,
    sym_comment,
    [52721] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4024),
    1,
    sym_identifier,
    STATE(1555),
    1,
    sym_comment,
    [52734] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4026),
    1,
    sym_identifier,
    STATE(1556),
    1,
    sym_comment,
    [52747] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4028),
    1,
    anon_sym_LBRACE,
    STATE(1557),
    1,
    sym_comment,
    [52760] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(4030),
    1,
    aux_sym_preproc_call_token1,
    STATE(1558),
    1,
    sym_comment,
    [52773] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4032),
    1,
    anon_sym_GT,
    STATE(1559),
    1,
    sym_comment,
    [52786] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(4034),
    1,
    sym_system_lib_path,
    STATE(1560),
    1,
    sym_comment,
    [52799] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(4036),
    1,
    aux_sym_preproc_call_token1,
    STATE(1561),
    1,
    sym_comment,
    [52812] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4038),
    1,
    anon_sym_LBRACE,
    STATE(1562),
    1,
    sym_comment,
    [52825] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4040),
    1,
    anon_sym_SLASH,
    STATE(1563),
    1,
    sym_comment,
    [52838] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4042),
    1,
    anon_sym_LPAREN,
    STATE(1564),
    1,
    sym_comment,
    [52851] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4044),
    1,
    anon_sym_SEMI,
    STATE(1565),
    1,
    sym_comment,
    [52864] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4046),
    1,
    anon_sym_LBRACE,
    STATE(1566),
    1,
    sym_comment,
    [52877] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4048),
    1,
    anon_sym_SEMI,
    STATE(1567),
    1,
    sym_comment,
    [52890] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4050),
    1,
    anon_sym_RPAREN,
    STATE(1568),
    1,
    sym_comment,
    [52903] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4052),
    1,
    anon_sym_RPAREN,
    STATE(1569),
    1,
    sym_comment,
    [52916] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4054),
    1,
    anon_sym_LBRACE,
    STATE(1570),
    1,
    sym_comment,
    [52929] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4056),
    1,
    anon_sym_SEMI,
    STATE(1571),
    1,
    sym_comment,
    [52942] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4058),
    1,
    anon_sym_LBRACE,
    STATE(1572),
    1,
    sym_comment,
    [52955] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4060),
    1,
    anon_sym_LBRACE,
    STATE(1573),
    1,
    sym_comment,
    [52968] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4062),
    1,
    anon_sym_SEMI,
    STATE(1574),
    1,
    sym_comment,
    [52981] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4064),
    1,
    anon_sym_SEMI,
    STATE(1575),
    1,
    sym_comment,
    [52994] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4066),
    1,
    anon_sym_RPAREN,
    STATE(1576),
    1,
    sym_comment,
    [53007] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4068),
    1,
    anon_sym_SEMI,
    STATE(1577),
    1,
    sym_comment,
    [53020] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4070),
    1,
    anon_sym_COMMA,
    STATE(1578),
    1,
    sym_comment,
    [53033] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4072),
    1,
    anon_sym_LBRACE,
    STATE(1579),
    1,
    sym_comment,
    [53046] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4074),
    1,
    sym_identifier,
    STATE(1580),
    1,
    sym_comment,
    [53059] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4076),
    1,
    anon_sym_SEMI,
    STATE(1581),
    1,
    sym_comment,
    [53072] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4078),
    1,
    anon_sym_RPAREN,
    STATE(1582),
    1,
    sym_comment,
    [53085] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4080),
    1,
    anon_sym_LBRACE,
    STATE(1583),
    1,
    sym_comment,
    [53098] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4082),
    1,
    anon_sym_SEMI,
    STATE(1584),
    1,
    sym_comment,
    [53111] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4084),
    1,
    sym_identifier,
    STATE(1585),
    1,
    sym_comment,
    [53124] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4086),
    1,
    anon_sym_RPAREN,
    STATE(1586),
    1,
    sym_comment,
    [53137] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4088),
    1,
    anon_sym_SEMI,
    STATE(1587),
    1,
    sym_comment,
    [53150] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4090),
    1,
    ts_builtin_sym_end,
    STATE(1588),
    1,
    sym_comment,
    [53163] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4092),
    1,
    anon_sym_EQ,
    STATE(1589),
    1,
    sym_comment,
    [53176] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4094),
    1,
    sym_identifier,
    STATE(1590),
    1,
    sym_comment,
    [53189] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4096),
    1,
    sym_identifier,
    STATE(1591),
    1,
    sym_comment,
    [53202] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4098),
    1,
    sym_identifier,
    STATE(1592),
    1,
    sym_comment,
    [53215] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4100),
    1,
    sym_identifier,
    STATE(1593),
    1,
    sym_comment,
    [53228] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4102),
    1,
    anon_sym_COMMA,
    STATE(1594),
    1,
    sym_comment,
    [53241] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4104),
    1,
    anon_sym_SEMI,
    STATE(1595),
    1,
    sym_comment,
    [53254] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4106),
    1,
    anon_sym_SEMI,
    STATE(1596),
    1,
    sym_comment,
    [53267] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4108),
    1,
    anon_sym_SEMI,
    STATE(1597),
    1,
    sym_comment,
    [53280] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4110),
    1,
    sym_identifier,
    STATE(1598),
    1,
    sym_comment,
    [53293] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4112),
    1,
    sym_identifier,
    STATE(1599),
    1,
    sym_comment,
    [53306] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4114),
    1,
    sym_identifier,
    STATE(1600),
    1,
    sym_comment,
    [53319] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4116),
    1,
    sym_identifier,
    STATE(1601),
    1,
    sym_comment,
    [53332] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4118),
    1,
    sym_identifier,
    STATE(1602),
    1,
    sym_comment,
    [53345] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4120),
    1,
    anon_sym_SEMI,
    STATE(1603),
    1,
    sym_comment,
    [53358] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4122),
    1,
    anon_sym_SEMI,
    STATE(1604),
    1,
    sym_comment,
    [53371] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4124),
    1,
    anon_sym_SEMI,
    STATE(1605),
    1,
    sym_comment,
    [53384] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4126),
    1,
    sym_identifier,
    STATE(1606),
    1,
    sym_comment,
    [53397] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4128),
    1,
    sym_identifier,
    STATE(1607),
    1,
    sym_comment,
    [53410] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4130),
    1,
    sym_identifier,
    STATE(1608),
    1,
    sym_comment,
    [53423] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4132),
    1,
    anon_sym_SEMI,
    STATE(1609),
    1,
    sym_comment,
    [53436] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4134),
    1,
    anon_sym_SEMI,
    STATE(1610),
    1,
    sym_comment,
    [53449] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2886),
    1,
    anon_sym_interface,
    STATE(1611),
    1,
    sym_comment,
    [53462] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4136),
    1,
    sym_identifier,
    STATE(1612),
    1,
    sym_comment,
    [53475] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4138),
    1,
    anon_sym_SEMI,
    STATE(1613),
    1,
    sym_comment,
    [53488] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4140),
    1,
    sym_identifier,
    STATE(1614),
    1,
    sym_comment,
    [53501] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(4142),
    1,
    aux_sym_preproc_define_token1,
    STATE(1615),
    1,
    sym_comment,
    [53514] = 4,
    ACTIONS(3),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(2425),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(4144),
    1,
    aux_sym_comment_token2,
    STATE(1616),
    1,
    sym_comment,
    [53527] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4146),
    1,
    anon_sym_LPAREN,
    STATE(1617),
    1,
    sym_comment,
    [53540] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4148),
    1,
    anon_sym_LPAREN,
    STATE(1618),
    1,
    sym_comment,
    [53553] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4150),
    1,
    anon_sym_LPAREN,
    STATE(1619),
    1,
    sym_comment,
    [53566] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4152),
    1,
    anon_sym_LPAREN,
    STATE(1620),
    1,
    sym_comment,
    [53579] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4154),
    1,
    anon_sym_LPAREN,
    STATE(1621),
    1,
    sym_comment,
    [53592] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4156),
    1,
    anon_sym_LPAREN,
    STATE(1622),
    1,
    sym_comment,
    [53605] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4158),
    1,
    anon_sym_LPAREN,
    STATE(1623),
    1,
    sym_comment,
    [53618] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4160),
    1,
    anon_sym_LPAREN,
    STATE(1624),
    1,
    sym_comment,
    [53631] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4162),
    1,
    anon_sym_LPAREN,
    STATE(1625),
    1,
    sym_comment,
    [53644] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4164),
    1,
    anon_sym_LPAREN,
    STATE(1626),
    1,
    sym_comment,
    [53657] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4166),
    1,
    anon_sym_LPAREN,
    STATE(1627),
    1,
    sym_comment,
    [53670] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4168),
    1,
    anon_sym_LPAREN,
    STATE(1628),
    1,
    sym_comment,
    [53683] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4170),
    1,
    anon_sym_LPAREN,
    STATE(1629),
    1,
    sym_comment,
    [53696] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4172),
    1,
    anon_sym_COMMA,
    STATE(1630),
    1,
    sym_comment,
    [53709] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4174),
    1,
    anon_sym_COMMA,
    STATE(1631),
    1,
    sym_comment,
    [53722] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4176),
    1,
    anon_sym_COMMA,
    STATE(1632),
    1,
    sym_comment,
    [53735] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4178),
    1,
    anon_sym_EQ,
    STATE(1633),
    1,
    sym_comment,
    [53748] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4180),
    1,
    anon_sym_EQ,
    STATE(1634),
    1,
    sym_comment,
    [53761] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4182),
    1,
    anon_sym_EQ,
    STATE(1635),
    1,
    sym_comment,
    [53774] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4184),
    1,
    anon_sym_COMMA,
    STATE(1636),
    1,
    sym_comment,
    [53787] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4186),
    1,
    anon_sym_LPAREN,
    STATE(1637),
    1,
    sym_comment,
    [53800] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4188),
    1,
    anon_sym_LPAREN,
    STATE(1638),
    1,
    sym_comment,
    [53813] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4190),
    1,
    anon_sym_LPAREN,
    STATE(1639),
    1,
    sym_comment,
    [53826] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4192),
    1,
    anon_sym_LPAREN,
    STATE(1640),
    1,
    sym_comment,
    [53839] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4194),
    1,
    anon_sym_LPAREN,
    STATE(1641),
    1,
    sym_comment,
    [53852] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4196),
    1,
    anon_sym_LPAREN,
    STATE(1642),
    1,
    sym_comment,
    [53865] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4198),
    1,
    anon_sym_LPAREN,
    STATE(1643),
    1,
    sym_comment,
    [53878] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4200),
    1,
    anon_sym_LPAREN,
    STATE(1644),
    1,
    sym_comment,
    [53891] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4202),
    1,
    anon_sym_LPAREN,
    STATE(1645),
    1,
    sym_comment,
    [53904] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4204),
    1,
    anon_sym_LPAREN,
    STATE(1646),
    1,
    sym_comment,
    [53917] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4206),
    1,
    anon_sym_LPAREN,
    STATE(1647),
    1,
    sym_comment,
    [53930] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4208),
    1,
    anon_sym_LPAREN,
    STATE(1648),
    1,
    sym_comment,
    [53943] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4210),
    1,
    anon_sym_LPAREN,
    STATE(1649),
    1,
    sym_comment,
    [53956] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4212),
    1,
    anon_sym_COMMA,
    STATE(1650),
    1,
    sym_comment,
    [53969] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4214),
    1,
    anon_sym_COMMA,
    STATE(1651),
    1,
    sym_comment,
    [53982] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4216),
    1,
    anon_sym_COMMA,
    STATE(1652),
    1,
    sym_comment,
    [53995] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4218),
    1,
    anon_sym_EQ,
    STATE(1653),
    1,
    sym_comment,
    [54008] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4220),
    1,
    anon_sym_EQ,
    STATE(1654),
    1,
    sym_comment,
    [54021] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4222),
    1,
    anon_sym_EQ,
    STATE(1655),
    1,
    sym_comment,
    [54034] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4224),
    1,
    anon_sym_COMMA,
    STATE(1656),
    1,
    sym_comment,
    [54047] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4226),
    1,
    anon_sym_LPAREN,
    STATE(1657),
    1,
    sym_comment,
    [54060] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4228),
    1,
    anon_sym_LPAREN,
    STATE(1658),
    1,
    sym_comment,
    [54073] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4230),
    1,
    anon_sym_LPAREN,
    STATE(1659),
    1,
    sym_comment,
    [54086] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4232),
    1,
    anon_sym_LPAREN,
    STATE(1660),
    1,
    sym_comment,
    [54099] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4234),
    1,
    anon_sym_LPAREN,
    STATE(1661),
    1,
    sym_comment,
    [54112] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4236),
    1,
    anon_sym_LPAREN,
    STATE(1662),
    1,
    sym_comment,
    [54125] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4238),
    1,
    anon_sym_LPAREN,
    STATE(1663),
    1,
    sym_comment,
    [54138] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4240),
    1,
    anon_sym_LPAREN,
    STATE(1664),
    1,
    sym_comment,
    [54151] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4242),
    1,
    anon_sym_LPAREN,
    STATE(1665),
    1,
    sym_comment,
    [54164] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4244),
    1,
    anon_sym_LPAREN,
    STATE(1666),
    1,
    sym_comment,
    [54177] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4246),
    1,
    anon_sym_LPAREN,
    STATE(1667),
    1,
    sym_comment,
    [54190] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4248),
    1,
    anon_sym_LPAREN,
    STATE(1668),
    1,
    sym_comment,
    [54203] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4250),
    1,
    anon_sym_LPAREN,
    STATE(1669),
    1,
    sym_comment,
    [54216] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4252),
    1,
    anon_sym_COMMA,
    STATE(1670),
    1,
    sym_comment,
    [54229] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4254),
    1,
    anon_sym_COMMA,
    STATE(1671),
    1,
    sym_comment,
    [54242] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4256),
    1,
    anon_sym_COMMA,
    STATE(1672),
    1,
    sym_comment,
    [54255] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4258),
    1,
    anon_sym_EQ,
    STATE(1673),
    1,
    sym_comment,
    [54268] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4260),
    1,
    anon_sym_EQ,
    STATE(1674),
    1,
    sym_comment,
    [54281] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4262),
    1,
    anon_sym_EQ,
    STATE(1675),
    1,
    sym_comment,
    [54294] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4264),
    1,
    anon_sym_COMMA,
    STATE(1676),
    1,
    sym_comment,
    [54307] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4266),
    1,
    anon_sym_LPAREN,
    STATE(1677),
    1,
    sym_comment,
    [54320] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4268),
    1,
    anon_sym_LPAREN,
    STATE(1678),
    1,
    sym_comment,
    [54333] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4270),
    1,
    anon_sym_LPAREN,
    STATE(1679),
    1,
    sym_comment,
    [54346] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4272),
    1,
    anon_sym_LPAREN,
    STATE(1680),
    1,
    sym_comment,
    [54359] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4274),
    1,
    anon_sym_LPAREN,
    STATE(1681),
    1,
    sym_comment,
    [54372] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4276),
    1,
    anon_sym_LPAREN,
    STATE(1682),
    1,
    sym_comment,
    [54385] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4278),
    1,
    anon_sym_LPAREN,
    STATE(1683),
    1,
    sym_comment,
    [54398] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4280),
    1,
    anon_sym_LPAREN,
    STATE(1684),
    1,
    sym_comment,
    [54411] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4282),
    1,
    anon_sym_LPAREN,
    STATE(1685),
    1,
    sym_comment,
    [54424] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4284),
    1,
    anon_sym_LPAREN,
    STATE(1686),
    1,
    sym_comment,
    [54437] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4286),
    1,
    anon_sym_LPAREN,
    STATE(1687),
    1,
    sym_comment,
    [54450] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4288),
    1,
    anon_sym_LPAREN,
    STATE(1688),
    1,
    sym_comment,
    [54463] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4290),
    1,
    anon_sym_LPAREN,
    STATE(1689),
    1,
    sym_comment,
    [54476] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4292),
    1,
    anon_sym_COMMA,
    STATE(1690),
    1,
    sym_comment,
    [54489] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4294),
    1,
    anon_sym_COMMA,
    STATE(1691),
    1,
    sym_comment,
    [54502] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4296),
    1,
    anon_sym_COMMA,
    STATE(1692),
    1,
    sym_comment,
    [54515] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4298),
    1,
    anon_sym_EQ,
    STATE(1693),
    1,
    sym_comment,
    [54528] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4300),
    1,
    anon_sym_EQ,
    STATE(1694),
    1,
    sym_comment,
    [54541] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4302),
    1,
    anon_sym_EQ,
    STATE(1695),
    1,
    sym_comment,
    [54554] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4304),
    1,
    anon_sym_COMMA,
    STATE(1696),
    1,
    sym_comment,
    [54567] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4306),
    1,
    anon_sym_SEMI,
    STATE(1697),
    1,
    sym_comment,
    [54580] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4308),
    1,
    anon_sym_SEMI,
    STATE(1698),
    1,
    sym_comment,
    [54593] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4310),
    1,
    anon_sym_LPAREN,
    STATE(1699),
    1,
    sym_comment,
    [54606] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4312),
    1,
    anon_sym_LPAREN,
    STATE(1700),
    1,
    sym_comment,
    [54619] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4314),
    1,
    anon_sym_LPAREN,
    STATE(1701),
    1,
    sym_comment,
    [54632] = 4,
    ACTIONS(5),
    1,
    anon_sym_SLASH_STAR,
    ACTIONS(618),
    1,
    anon_sym_SLASH_SLASH,
    ACTIONS(4316),
    1,
    anon_sym_LPAREN,
    STATE(1702),
    1,
    sym_comment,
    [54645] = 1,
    ACTIONS(4318),
    1,
    ts_builtin_sym_end,
    [54649] = 1,
    ACTIONS(4320),
    1,
    ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
    [SMALL_STATE(45)] = 0,
    [SMALL_STATE(46)] = 151,
    [SMALL_STATE(47)] = 302,
    [SMALL_STATE(48)] = 453,
    [SMALL_STATE(49)] = 602,
    [SMALL_STATE(50)] = 753,
    [SMALL_STATE(51)] = 904,
    [SMALL_STATE(52)] = 1055,
    [SMALL_STATE(53)] = 1199,
    [SMALL_STATE(54)] = 1347,
    [SMALL_STATE(55)] = 1491,
    [SMALL_STATE(56)] = 1629,
    [SMALL_STATE(57)] = 1771,
    [SMALL_STATE(58)] = 1913,
    [SMALL_STATE(59)] = 2054,
    [SMALL_STATE(60)] = 2195,
    [SMALL_STATE(61)] = 2336,
    [SMALL_STATE(62)] = 2475,
    [SMALL_STATE(63)] = 2616,
    [SMALL_STATE(64)] = 2685,
    [SMALL_STATE(65)] = 2754,
    [SMALL_STATE(66)] = 2823,
    [SMALL_STATE(67)] = 2892,
    [SMALL_STATE(68)] = 3019,
    [SMALL_STATE(69)] = 3088,
    [SMALL_STATE(70)] = 3157,
    [SMALL_STATE(71)] = 3226,
    [SMALL_STATE(72)] = 3294,
    [SMALL_STATE(73)] = 3418,
    [SMALL_STATE(74)] = 3486,
    [SMALL_STATE(75)] = 3554,
    [SMALL_STATE(76)] = 3622,
    [SMALL_STATE(77)] = 3749,
    [SMALL_STATE(78)] = 3880,
    [SMALL_STATE(79)] = 4011,
    [SMALL_STATE(80)] = 4138,
    [SMALL_STATE(81)] = 4265,
    [SMALL_STATE(82)] = 4392,
    [SMALL_STATE(83)] = 4519,
    [SMALL_STATE(84)] = 4646,
    [SMALL_STATE(85)] = 4773,
    [SMALL_STATE(86)] = 4900,
    [SMALL_STATE(87)] = 5031,
    [SMALL_STATE(88)] = 5158,
    [SMALL_STATE(89)] = 5285,
    [SMALL_STATE(90)] = 5416,
    [SMALL_STATE(91)] = 5547,
    [SMALL_STATE(92)] = 5613,
    [SMALL_STATE(93)] = 5679,
    [SMALL_STATE(94)] = 5798,
    [SMALL_STATE(95)] = 5917,
    [SMALL_STATE(96)] = 6036,
    [SMALL_STATE(97)] = 6155,
    [SMALL_STATE(98)] = 6274,
    [SMALL_STATE(99)] = 6386,
    [SMALL_STATE(100)] = 6454,
    [SMALL_STATE(101)] = 6514,
    [SMALL_STATE(102)] = 6574,
    [SMALL_STATE(103)] = 6634,
    [SMALL_STATE(104)] = 6694,
    [SMALL_STATE(105)] = 6754,
    [SMALL_STATE(106)] = 6814,
    [SMALL_STATE(107)] = 6874,
    [SMALL_STATE(108)] = 6932,
    [SMALL_STATE(109)] = 6992,
    [SMALL_STATE(110)] = 7050,
    [SMALL_STATE(111)] = 7108,
    [SMALL_STATE(112)] = 7168,
    [SMALL_STATE(113)] = 7228,
    [SMALL_STATE(114)] = 7288,
    [SMALL_STATE(115)] = 7348,
    [SMALL_STATE(116)] = 7408,
    [SMALL_STATE(117)] = 7468,
    [SMALL_STATE(118)] = 7528,
    [SMALL_STATE(119)] = 7588,
    [SMALL_STATE(120)] = 7645,
    [SMALL_STATE(121)] = 7702,
    [SMALL_STATE(122)] = 7759,
    [SMALL_STATE(123)] = 7816,
    [SMALL_STATE(124)] = 7873,
    [SMALL_STATE(125)] = 7930,
    [SMALL_STATE(126)] = 7987,
    [SMALL_STATE(127)] = 8104,
    [SMALL_STATE(128)] = 8161,
    [SMALL_STATE(129)] = 8218,
    [SMALL_STATE(130)] = 8275,
    [SMALL_STATE(131)] = 8332,
    [SMALL_STATE(132)] = 8389,
    [SMALL_STATE(133)] = 8446,
    [SMALL_STATE(134)] = 8503,
    [SMALL_STATE(135)] = 8620,
    [SMALL_STATE(136)] = 8677,
    [SMALL_STATE(137)] = 8734,
    [SMALL_STATE(138)] = 8791,
    [SMALL_STATE(139)] = 8896,
    [SMALL_STATE(140)] = 8953,
    [SMALL_STATE(141)] = 9010,
    [SMALL_STATE(142)] = 9127,
    [SMALL_STATE(143)] = 9184,
    [SMALL_STATE(144)] = 9301,
    [SMALL_STATE(145)] = 9358,
    [SMALL_STATE(146)] = 9415,
    [SMALL_STATE(147)] = 9472,
    [SMALL_STATE(148)] = 9589,
    [SMALL_STATE(149)] = 9646,
    [SMALL_STATE(150)] = 9703,
    [SMALL_STATE(151)] = 9760,
    [SMALL_STATE(152)] = 9817,
    [SMALL_STATE(153)] = 9934,
    [SMALL_STATE(154)] = 9991,
    [SMALL_STATE(155)] = 10048,
    [SMALL_STATE(156)] = 10105,
    [SMALL_STATE(157)] = 10222,
    [SMALL_STATE(158)] = 10279,
    [SMALL_STATE(159)] = 10336,
    [SMALL_STATE(160)] = 10393,
    [SMALL_STATE(161)] = 10450,
    [SMALL_STATE(162)] = 10507,
    [SMALL_STATE(163)] = 10564,
    [SMALL_STATE(164)] = 10621,
    [SMALL_STATE(165)] = 10726,
    [SMALL_STATE(166)] = 10783,
    [SMALL_STATE(167)] = 10840,
    [SMALL_STATE(168)] = 10897,
    [SMALL_STATE(169)] = 10954,
    [SMALL_STATE(170)] = 11011,
    [SMALL_STATE(171)] = 11128,
    [SMALL_STATE(172)] = 11185,
    [SMALL_STATE(173)] = 11242,
    [SMALL_STATE(174)] = 11359,
    [SMALL_STATE(175)] = 11416,
    [SMALL_STATE(176)] = 11473,
    [SMALL_STATE(177)] = 11530,
    [SMALL_STATE(178)] = 11587,
    [SMALL_STATE(179)] = 11644,
    [SMALL_STATE(180)] = 11701,
    [SMALL_STATE(181)] = 11818,
    [SMALL_STATE(182)] = 11875,
    [SMALL_STATE(183)] = 11932,
    [SMALL_STATE(184)] = 11989,
    [SMALL_STATE(185)] = 12046,
    [SMALL_STATE(186)] = 12103,
    [SMALL_STATE(187)] = 12217,
    [SMALL_STATE(188)] = 12331,
    [SMALL_STATE(189)] = 12393,
    [SMALL_STATE(190)] = 12507,
    [SMALL_STATE(191)] = 12621,
    [SMALL_STATE(192)] = 12735,
    [SMALL_STATE(193)] = 12846,
    [SMALL_STATE(194)] = 12957,
    [SMALL_STATE(195)] = 13068,
    [SMALL_STATE(196)] = 13179,
    [SMALL_STATE(197)] = 13290,
    [SMALL_STATE(198)] = 13401,
    [SMALL_STATE(199)] = 13512,
    [SMALL_STATE(200)] = 13623,
    [SMALL_STATE(201)] = 13734,
    [SMALL_STATE(202)] = 13845,
    [SMALL_STATE(203)] = 13956,
    [SMALL_STATE(204)] = 14067,
    [SMALL_STATE(205)] = 14178,
    [SMALL_STATE(206)] = 14289,
    [SMALL_STATE(207)] = 14400,
    [SMALL_STATE(208)] = 14511,
    [SMALL_STATE(209)] = 14622,
    [SMALL_STATE(210)] = 14733,
    [SMALL_STATE(211)] = 14844,
    [SMALL_STATE(212)] = 14955,
    [SMALL_STATE(213)] = 15066,
    [SMALL_STATE(214)] = 15177,
    [SMALL_STATE(215)] = 15288,
    [SMALL_STATE(216)] = 15399,
    [SMALL_STATE(217)] = 15510,
    [SMALL_STATE(218)] = 15621,
    [SMALL_STATE(219)] = 15732,
    [SMALL_STATE(220)] = 15843,
    [SMALL_STATE(221)] = 15954,
    [SMALL_STATE(222)] = 16065,
    [SMALL_STATE(223)] = 16176,
    [SMALL_STATE(224)] = 16287,
    [SMALL_STATE(225)] = 16398,
    [SMALL_STATE(226)] = 16509,
    [SMALL_STATE(227)] = 16620,
    [SMALL_STATE(228)] = 16731,
    [SMALL_STATE(229)] = 16842,
    [SMALL_STATE(230)] = 16953,
    [SMALL_STATE(231)] = 17064,
    [SMALL_STATE(232)] = 17175,
    [SMALL_STATE(233)] = 17286,
    [SMALL_STATE(234)] = 17397,
    [SMALL_STATE(235)] = 17508,
    [SMALL_STATE(236)] = 17619,
    [SMALL_STATE(237)] = 17730,
    [SMALL_STATE(238)] = 17841,
    [SMALL_STATE(239)] = 17952,
    [SMALL_STATE(240)] = 18063,
    [SMALL_STATE(241)] = 18174,
    [SMALL_STATE(242)] = 18285,
    [SMALL_STATE(243)] = 18396,
    [SMALL_STATE(244)] = 18507,
    [SMALL_STATE(245)] = 18618,
    [SMALL_STATE(246)] = 18729,
    [SMALL_STATE(247)] = 18840,
    [SMALL_STATE(248)] = 18951,
    [SMALL_STATE(249)] = 19062,
    [SMALL_STATE(250)] = 19173,
    [SMALL_STATE(251)] = 19284,
    [SMALL_STATE(252)] = 19395,
    [SMALL_STATE(253)] = 19503,
    [SMALL_STATE(254)] = 19611,
    [SMALL_STATE(255)] = 19719,
    [SMALL_STATE(256)] = 19827,
    [SMALL_STATE(257)] = 19935,
    [SMALL_STATE(258)] = 20043,
    [SMALL_STATE(259)] = 20151,
    [SMALL_STATE(260)] = 20259,
    [SMALL_STATE(261)] = 20367,
    [SMALL_STATE(262)] = 20421,
    [SMALL_STATE(263)] = 20529,
    [SMALL_STATE(264)] = 20637,
    [SMALL_STATE(265)] = 20745,
    [SMALL_STATE(266)] = 20853,
    [SMALL_STATE(267)] = 20961,
    [SMALL_STATE(268)] = 21069,
    [SMALL_STATE(269)] = 21177,
    [SMALL_STATE(270)] = 21285,
    [SMALL_STATE(271)] = 21393,
    [SMALL_STATE(272)] = 21501,
    [SMALL_STATE(273)] = 21609,
    [SMALL_STATE(274)] = 21663,
    [SMALL_STATE(275)] = 21771,
    [SMALL_STATE(276)] = 21879,
    [SMALL_STATE(277)] = 21987,
    [SMALL_STATE(278)] = 22095,
    [SMALL_STATE(279)] = 22203,
    [SMALL_STATE(280)] = 22311,
    [SMALL_STATE(281)] = 22419,
    [SMALL_STATE(282)] = 22527,
    [SMALL_STATE(283)] = 22635,
    [SMALL_STATE(284)] = 22743,
    [SMALL_STATE(285)] = 22851,
    [SMALL_STATE(286)] = 22959,
    [SMALL_STATE(287)] = 23067,
    [SMALL_STATE(288)] = 23175,
    [SMALL_STATE(289)] = 23283,
    [SMALL_STATE(290)] = 23391,
    [SMALL_STATE(291)] = 23499,
    [SMALL_STATE(292)] = 23607,
    [SMALL_STATE(293)] = 23715,
    [SMALL_STATE(294)] = 23823,
    [SMALL_STATE(295)] = 23931,
    [SMALL_STATE(296)] = 23985,
    [SMALL_STATE(297)] = 24093,
    [SMALL_STATE(298)] = 24201,
    [SMALL_STATE(299)] = 24309,
    [SMALL_STATE(300)] = 24417,
    [SMALL_STATE(301)] = 24525,
    [SMALL_STATE(302)] = 24633,
    [SMALL_STATE(303)] = 24741,
    [SMALL_STATE(304)] = 24849,
    [SMALL_STATE(305)] = 24957,
    [SMALL_STATE(306)] = 25065,
    [SMALL_STATE(307)] = 25173,
    [SMALL_STATE(308)] = 25281,
    [SMALL_STATE(309)] = 25389,
    [SMALL_STATE(310)] = 25497,
    [SMALL_STATE(311)] = 25605,
    [SMALL_STATE(312)] = 25713,
    [SMALL_STATE(313)] = 25821,
    [SMALL_STATE(314)] = 25929,
    [SMALL_STATE(315)] = 26037,
    [SMALL_STATE(316)] = 26145,
    [SMALL_STATE(317)] = 26253,
    [SMALL_STATE(318)] = 26361,
    [SMALL_STATE(319)] = 26469,
    [SMALL_STATE(320)] = 26577,
    [SMALL_STATE(321)] = 26685,
    [SMALL_STATE(322)] = 26793,
    [SMALL_STATE(323)] = 26895,
    [SMALL_STATE(324)] = 26994,
    [SMALL_STATE(325)] = 27052,
    [SMALL_STATE(326)] = 27148,
    [SMALL_STATE(327)] = 27199,
    [SMALL_STATE(328)] = 27250,
    [SMALL_STATE(329)] = 27301,
    [SMALL_STATE(330)] = 27352,
    [SMALL_STATE(331)] = 27445,
    [SMALL_STATE(332)] = 27495,
    [SMALL_STATE(333)] = 27543,
    [SMALL_STATE(334)] = 27591,
    [SMALL_STATE(335)] = 27641,
    [SMALL_STATE(336)] = 27689,
    [SMALL_STATE(337)] = 27739,
    [SMALL_STATE(338)] = 27789,
    [SMALL_STATE(339)] = 27839,
    [SMALL_STATE(340)] = 27887,
    [SMALL_STATE(341)] = 27935,
    [SMALL_STATE(342)] = 27985,
    [SMALL_STATE(343)] = 28035,
    [SMALL_STATE(344)] = 28085,
    [SMALL_STATE(345)] = 28133,
    [SMALL_STATE(346)] = 28181,
    [SMALL_STATE(347)] = 28229,
    [SMALL_STATE(348)] = 28277,
    [SMALL_STATE(349)] = 28327,
    [SMALL_STATE(350)] = 28377,
    [SMALL_STATE(351)] = 28427,
    [SMALL_STATE(352)] = 28477,
    [SMALL_STATE(353)] = 28567,
    [SMALL_STATE(354)] = 28615,
    [SMALL_STATE(355)] = 28665,
    [SMALL_STATE(356)] = 28715,
    [SMALL_STATE(357)] = 28765,
    [SMALL_STATE(358)] = 28815,
    [SMALL_STATE(359)] = 28862,
    [SMALL_STATE(360)] = 28909,
    [SMALL_STATE(361)] = 28956,
    [SMALL_STATE(362)] = 29003,
    [SMALL_STATE(363)] = 29050,
    [SMALL_STATE(364)] = 29097,
    [SMALL_STATE(365)] = 29144,
    [SMALL_STATE(366)] = 29191,
    [SMALL_STATE(367)] = 29238,
    [SMALL_STATE(368)] = 29285,
    [SMALL_STATE(369)] = 29332,
    [SMALL_STATE(370)] = 29379,
    [SMALL_STATE(371)] = 29426,
    [SMALL_STATE(372)] = 29473,
    [SMALL_STATE(373)] = 29520,
    [SMALL_STATE(374)] = 29567,
    [SMALL_STATE(375)] = 29614,
    [SMALL_STATE(376)] = 29661,
    [SMALL_STATE(377)] = 29708,
    [SMALL_STATE(378)] = 29755,
    [SMALL_STATE(379)] = 29802,
    [SMALL_STATE(380)] = 29849,
    [SMALL_STATE(381)] = 29896,
    [SMALL_STATE(382)] = 29943,
    [SMALL_STATE(383)] = 29990,
    [SMALL_STATE(384)] = 30077,
    [SMALL_STATE(385)] = 30124,
    [SMALL_STATE(386)] = 30171,
    [SMALL_STATE(387)] = 30218,
    [SMALL_STATE(388)] = 30265,
    [SMALL_STATE(389)] = 30312,
    [SMALL_STATE(390)] = 30359,
    [SMALL_STATE(391)] = 30406,
    [SMALL_STATE(392)] = 30453,
    [SMALL_STATE(393)] = 30500,
    [SMALL_STATE(394)] = 30547,
    [SMALL_STATE(395)] = 30594,
    [SMALL_STATE(396)] = 30641,
    [SMALL_STATE(397)] = 30688,
    [SMALL_STATE(398)] = 30735,
    [SMALL_STATE(399)] = 30782,
    [SMALL_STATE(400)] = 30829,
    [SMALL_STATE(401)] = 30876,
    [SMALL_STATE(402)] = 30923,
    [SMALL_STATE(403)] = 30970,
    [SMALL_STATE(404)] = 31017,
    [SMALL_STATE(405)] = 31064,
    [SMALL_STATE(406)] = 31111,
    [SMALL_STATE(407)] = 31158,
    [SMALL_STATE(408)] = 31205,
    [SMALL_STATE(409)] = 31252,
    [SMALL_STATE(410)] = 31299,
    [SMALL_STATE(411)] = 31346,
    [SMALL_STATE(412)] = 31393,
    [SMALL_STATE(413)] = 31440,
    [SMALL_STATE(414)] = 31487,
    [SMALL_STATE(415)] = 31534,
    [SMALL_STATE(416)] = 31581,
    [SMALL_STATE(417)] = 31628,
    [SMALL_STATE(418)] = 31675,
    [SMALL_STATE(419)] = 31722,
    [SMALL_STATE(420)] = 31768,
    [SMALL_STATE(421)] = 31814,
    [SMALL_STATE(422)] = 31860,
    [SMALL_STATE(423)] = 31946,
    [SMALL_STATE(424)] = 31992,
    [SMALL_STATE(425)] = 32038,
    [SMALL_STATE(426)] = 32084,
    [SMALL_STATE(427)] = 32165,
    [SMALL_STATE(428)] = 32210,
    [SMALL_STATE(429)] = 32255,
    [SMALL_STATE(430)] = 32300,
    [SMALL_STATE(431)] = 32345,
    [SMALL_STATE(432)] = 32390,
    [SMALL_STATE(433)] = 32468,
    [SMALL_STATE(434)] = 32543,
    [SMALL_STATE(435)] = 32615,
    [SMALL_STATE(436)] = 32683,
    [SMALL_STATE(437)] = 32753,
    [SMALL_STATE(438)] = 32818,
    [SMALL_STATE(439)] = 32881,
    [SMALL_STATE(440)] = 32946,
    [SMALL_STATE(441)] = 32981,
    [SMALL_STATE(442)] = 33044,
    [SMALL_STATE(443)] = 33109,
    [SMALL_STATE(444)] = 33144,
    [SMALL_STATE(445)] = 33206,
    [SMALL_STATE(446)] = 33240,
    [SMALL_STATE(447)] = 33273,
    [SMALL_STATE(448)] = 33309,
    [SMALL_STATE(449)] = 33347,
    [SMALL_STATE(450)] = 33383,
    [SMALL_STATE(451)] = 33416,
    [SMALL_STATE(452)] = 33449,
    [SMALL_STATE(453)] = 33478,
    [SMALL_STATE(454)] = 33511,
    [SMALL_STATE(455)] = 33540,
    [SMALL_STATE(456)] = 33573,
    [SMALL_STATE(457)] = 33602,
    [SMALL_STATE(458)] = 33632,
    [SMALL_STATE(459)] = 33662,
    [SMALL_STATE(460)] = 33692,
    [SMALL_STATE(461)] = 33726,
    [SMALL_STATE(462)] = 33756,
    [SMALL_STATE(463)] = 33786,
    [SMALL_STATE(464)] = 33816,
    [SMALL_STATE(465)] = 33846,
    [SMALL_STATE(466)] = 33876,
    [SMALL_STATE(467)] = 33906,
    [SMALL_STATE(468)] = 33936,
    [SMALL_STATE(469)] = 33966,
    [SMALL_STATE(470)] = 33996,
    [SMALL_STATE(471)] = 34026,
    [SMALL_STATE(472)] = 34056,
    [SMALL_STATE(473)] = 34086,
    [SMALL_STATE(474)] = 34116,
    [SMALL_STATE(475)] = 34146,
    [SMALL_STATE(476)] = 34176,
    [SMALL_STATE(477)] = 34206,
    [SMALL_STATE(478)] = 34240,
    [SMALL_STATE(479)] = 34270,
    [SMALL_STATE(480)] = 34300,
    [SMALL_STATE(481)] = 34330,
    [SMALL_STATE(482)] = 34360,
    [SMALL_STATE(483)] = 34390,
    [SMALL_STATE(484)] = 34420,
    [SMALL_STATE(485)] = 34450,
    [SMALL_STATE(486)] = 34480,
    [SMALL_STATE(487)] = 34510,
    [SMALL_STATE(488)] = 34540,
    [SMALL_STATE(489)] = 34570,
    [SMALL_STATE(490)] = 34600,
    [SMALL_STATE(491)] = 34630,
    [SMALL_STATE(492)] = 34660,
    [SMALL_STATE(493)] = 34690,
    [SMALL_STATE(494)] = 34720,
    [SMALL_STATE(495)] = 34750,
    [SMALL_STATE(496)] = 34780,
    [SMALL_STATE(497)] = 34810,
    [SMALL_STATE(498)] = 34837,
    [SMALL_STATE(499)] = 34864,
    [SMALL_STATE(500)] = 34891,
    [SMALL_STATE(501)] = 34918,
    [SMALL_STATE(502)] = 34945,
    [SMALL_STATE(503)] = 34972,
    [SMALL_STATE(504)] = 34999,
    [SMALL_STATE(505)] = 35026,
    [SMALL_STATE(506)] = 35053,
    [SMALL_STATE(507)] = 35080,
    [SMALL_STATE(508)] = 35107,
    [SMALL_STATE(509)] = 35134,
    [SMALL_STATE(510)] = 35161,
    [SMALL_STATE(511)] = 35188,
    [SMALL_STATE(512)] = 35215,
    [SMALL_STATE(513)] = 35242,
    [SMALL_STATE(514)] = 35269,
    [SMALL_STATE(515)] = 35296,
    [SMALL_STATE(516)] = 35323,
    [SMALL_STATE(517)] = 35350,
    [SMALL_STATE(518)] = 35377,
    [SMALL_STATE(519)] = 35404,
    [SMALL_STATE(520)] = 35431,
    [SMALL_STATE(521)] = 35458,
    [SMALL_STATE(522)] = 35485,
    [SMALL_STATE(523)] = 35512,
    [SMALL_STATE(524)] = 35539,
    [SMALL_STATE(525)] = 35566,
    [SMALL_STATE(526)] = 35593,
    [SMALL_STATE(527)] = 35620,
    [SMALL_STATE(528)] = 35647,
    [SMALL_STATE(529)] = 35674,
    [SMALL_STATE(530)] = 35701,
    [SMALL_STATE(531)] = 35728,
    [SMALL_STATE(532)] = 35755,
    [SMALL_STATE(533)] = 35782,
    [SMALL_STATE(534)] = 35809,
    [SMALL_STATE(535)] = 35836,
    [SMALL_STATE(536)] = 35863,
    [SMALL_STATE(537)] = 35890,
    [SMALL_STATE(538)] = 35917,
    [SMALL_STATE(539)] = 35944,
    [SMALL_STATE(540)] = 35971,
    [SMALL_STATE(541)] = 35998,
    [SMALL_STATE(542)] = 36025,
    [SMALL_STATE(543)] = 36052,
    [SMALL_STATE(544)] = 36079,
    [SMALL_STATE(545)] = 36106,
    [SMALL_STATE(546)] = 36133,
    [SMALL_STATE(547)] = 36160,
    [SMALL_STATE(548)] = 36187,
    [SMALL_STATE(549)] = 36214,
    [SMALL_STATE(550)] = 36241,
    [SMALL_STATE(551)] = 36268,
    [SMALL_STATE(552)] = 36295,
    [SMALL_STATE(553)] = 36327,
    [SMALL_STATE(554)] = 36356,
    [SMALL_STATE(555)] = 36385,
    [SMALL_STATE(556)] = 36418,
    [SMALL_STATE(557)] = 36442,
    [SMALL_STATE(558)] = 36480,
    [SMALL_STATE(559)] = 36518,
    [SMALL_STATE(560)] = 36556,
    [SMALL_STATE(561)] = 36594,
    [SMALL_STATE(562)] = 36632,
    [SMALL_STATE(563)] = 36656,
    [SMALL_STATE(564)] = 36683,
    [SMALL_STATE(565)] = 36710,
    [SMALL_STATE(566)] = 36744,
    [SMALL_STATE(567)] = 36765,
    [SMALL_STATE(568)] = 36786,
    [SMALL_STATE(569)] = 36807,
    [SMALL_STATE(570)] = 36844,
    [SMALL_STATE(571)] = 36865,
    [SMALL_STATE(572)] = 36886,
    [SMALL_STATE(573)] = 36921,
    [SMALL_STATE(574)] = 36942,
    [SMALL_STATE(575)] = 36963,
    [SMALL_STATE(576)] = 36986,
    [SMALL_STATE(577)] = 37007,
    [SMALL_STATE(578)] = 37028,
    [SMALL_STATE(579)] = 37065,
    [SMALL_STATE(580)] = 37088,
    [SMALL_STATE(581)] = 37110,
    [SMALL_STATE(582)] = 37144,
    [SMALL_STATE(583)] = 37174,
    [SMALL_STATE(584)] = 37196,
    [SMALL_STATE(585)] = 37224,
    [SMALL_STATE(586)] = 37258,
    [SMALL_STATE(587)] = 37292,
    [SMALL_STATE(588)] = 37312,
    [SMALL_STATE(589)] = 37346,
    [SMALL_STATE(590)] = 37380,
    [SMALL_STATE(591)] = 37411,
    [SMALL_STATE(592)] = 37442,
    [SMALL_STATE(593)] = 37473,
    [SMALL_STATE(594)] = 37492,
    [SMALL_STATE(595)] = 37521,
    [SMALL_STATE(596)] = 37542,
    [SMALL_STATE(597)] = 37573,
    [SMALL_STATE(598)] = 37604,
    [SMALL_STATE(599)] = 37635,
    [SMALL_STATE(600)] = 37661,
    [SMALL_STATE(601)] = 37687,
    [SMALL_STATE(602)] = 37707,
    [SMALL_STATE(603)] = 37735,
    [SMALL_STATE(604)] = 37759,
    [SMALL_STATE(605)] = 37787,
    [SMALL_STATE(606)] = 37815,
    [SMALL_STATE(607)] = 37839,
    [SMALL_STATE(608)] = 37867,
    [SMALL_STATE(609)] = 37895,
    [SMALL_STATE(610)] = 37923,
    [SMALL_STATE(611)] = 37951,
    [SMALL_STATE(612)] = 37979,
    [SMALL_STATE(613)] = 38003,
    [SMALL_STATE(614)] = 38027,
    [SMALL_STATE(615)] = 38055,
    [SMALL_STATE(616)] = 38083,
    [SMALL_STATE(617)] = 38111,
    [SMALL_STATE(618)] = 38135,
    [SMALL_STATE(619)] = 38163,
    [SMALL_STATE(620)] = 38187,
    [SMALL_STATE(621)] = 38215,
    [SMALL_STATE(622)] = 38243,
    [SMALL_STATE(623)] = 38267,
    [SMALL_STATE(624)] = 38295,
    [SMALL_STATE(625)] = 38323,
    [SMALL_STATE(626)] = 38345,
    [SMALL_STATE(627)] = 38373,
    [SMALL_STATE(628)] = 38392,
    [SMALL_STATE(629)] = 38413,
    [SMALL_STATE(630)] = 38430,
    [SMALL_STATE(631)] = 38453,
    [SMALL_STATE(632)] = 38476,
    [SMALL_STATE(633)] = 38497,
    [SMALL_STATE(634)] = 38514,
    [SMALL_STATE(635)] = 38535,
    [SMALL_STATE(636)] = 38552,
    [SMALL_STATE(637)] = 38571,
    [SMALL_STATE(638)] = 38592,
    [SMALL_STATE(639)] = 38609,
    [SMALL_STATE(640)] = 38634,
    [SMALL_STATE(641)] = 38651,
    [SMALL_STATE(642)] = 38668,
    [SMALL_STATE(643)] = 38693,
    [SMALL_STATE(644)] = 38712,
    [SMALL_STATE(645)] = 38729,
    [SMALL_STATE(646)] = 38746,
    [SMALL_STATE(647)] = 38767,
    [SMALL_STATE(648)] = 38790,
    [SMALL_STATE(649)] = 38811,
    [SMALL_STATE(650)] = 38828,
    [SMALL_STATE(651)] = 38845,
    [SMALL_STATE(652)] = 38870,
    [SMALL_STATE(653)] = 38887,
    [SMALL_STATE(654)] = 38908,
    [SMALL_STATE(655)] = 38925,
    [SMALL_STATE(656)] = 38942,
    [SMALL_STATE(657)] = 38967,
    [SMALL_STATE(658)] = 38992,
    [SMALL_STATE(659)] = 39013,
    [SMALL_STATE(660)] = 39038,
    [SMALL_STATE(661)] = 39061,
    [SMALL_STATE(662)] = 39086,
    [SMALL_STATE(663)] = 39103,
    [SMALL_STATE(664)] = 39128,
    [SMALL_STATE(665)] = 39145,
    [SMALL_STATE(666)] = 39168,
    [SMALL_STATE(667)] = 39193,
    [SMALL_STATE(668)] = 39216,
    [SMALL_STATE(669)] = 39239,
    [SMALL_STATE(670)] = 39259,
    [SMALL_STATE(671)] = 39275,
    [SMALL_STATE(672)] = 39293,
    [SMALL_STATE(673)] = 39313,
    [SMALL_STATE(674)] = 39331,
    [SMALL_STATE(675)] = 39349,
    [SMALL_STATE(676)] = 39367,
    [SMALL_STATE(677)] = 39389,
    [SMALL_STATE(678)] = 39407,
    [SMALL_STATE(679)] = 39425,
    [SMALL_STATE(680)] = 39443,
    [SMALL_STATE(681)] = 39461,
    [SMALL_STATE(682)] = 39479,
    [SMALL_STATE(683)] = 39497,
    [SMALL_STATE(684)] = 39515,
    [SMALL_STATE(685)] = 39537,
    [SMALL_STATE(686)] = 39559,
    [SMALL_STATE(687)] = 39579,
    [SMALL_STATE(688)] = 39599,
    [SMALL_STATE(689)] = 39617,
    [SMALL_STATE(690)] = 39633,
    [SMALL_STATE(691)] = 39651,
    [SMALL_STATE(692)] = 39669,
    [SMALL_STATE(693)] = 39687,
    [SMALL_STATE(694)] = 39703,
    [SMALL_STATE(695)] = 39721,
    [SMALL_STATE(696)] = 39739,
    [SMALL_STATE(697)] = 39761,
    [SMALL_STATE(698)] = 39779,
    [SMALL_STATE(699)] = 39801,
    [SMALL_STATE(700)] = 39817,
    [SMALL_STATE(701)] = 39837,
    [SMALL_STATE(702)] = 39859,
    [SMALL_STATE(703)] = 39879,
    [SMALL_STATE(704)] = 39897,
    [SMALL_STATE(705)] = 39919,
    [SMALL_STATE(706)] = 39941,
    [SMALL_STATE(707)] = 39959,
    [SMALL_STATE(708)] = 39981,
    [SMALL_STATE(709)] = 40003,
    [SMALL_STATE(710)] = 40025,
    [SMALL_STATE(711)] = 40045,
    [SMALL_STATE(712)] = 40063,
    [SMALL_STATE(713)] = 40081,
    [SMALL_STATE(714)] = 40099,
    [SMALL_STATE(715)] = 40117,
    [SMALL_STATE(716)] = 40135,
    [SMALL_STATE(717)] = 40153,
    [SMALL_STATE(718)] = 40171,
    [SMALL_STATE(719)] = 40189,
    [SMALL_STATE(720)] = 40207,
    [SMALL_STATE(721)] = 40225,
    [SMALL_STATE(722)] = 40243,
    [SMALL_STATE(723)] = 40261,
    [SMALL_STATE(724)] = 40279,
    [SMALL_STATE(725)] = 40297,
    [SMALL_STATE(726)] = 40315,
    [SMALL_STATE(727)] = 40337,
    [SMALL_STATE(728)] = 40359,
    [SMALL_STATE(729)] = 40377,
    [SMALL_STATE(730)] = 40395,
    [SMALL_STATE(731)] = 40413,
    [SMALL_STATE(732)] = 40433,
    [SMALL_STATE(733)] = 40455,
    [SMALL_STATE(734)] = 40477,
    [SMALL_STATE(735)] = 40497,
    [SMALL_STATE(736)] = 40519,
    [SMALL_STATE(737)] = 40535,
    [SMALL_STATE(738)] = 40555,
    [SMALL_STATE(739)] = 40575,
    [SMALL_STATE(740)] = 40593,
    [SMALL_STATE(741)] = 40613,
    [SMALL_STATE(742)] = 40629,
    [SMALL_STATE(743)] = 40647,
    [SMALL_STATE(744)] = 40665,
    [SMALL_STATE(745)] = 40685,
    [SMALL_STATE(746)] = 40707,
    [SMALL_STATE(747)] = 40729,
    [SMALL_STATE(748)] = 40749,
    [SMALL_STATE(749)] = 40771,
    [SMALL_STATE(750)] = 40793,
    [SMALL_STATE(751)] = 40813,
    [SMALL_STATE(752)] = 40831,
    [SMALL_STATE(753)] = 40849,
    [SMALL_STATE(754)] = 40867,
    [SMALL_STATE(755)] = 40885,
    [SMALL_STATE(756)] = 40903,
    [SMALL_STATE(757)] = 40923,
    [SMALL_STATE(758)] = 40945,
    [SMALL_STATE(759)] = 40961,
    [SMALL_STATE(760)] = 40977,
    [SMALL_STATE(761)] = 40999,
    [SMALL_STATE(762)] = 41017,
    [SMALL_STATE(763)] = 41033,
    [SMALL_STATE(764)] = 41053,
    [SMALL_STATE(765)] = 41069,
    [SMALL_STATE(766)] = 41087,
    [SMALL_STATE(767)] = 41107,
    [SMALL_STATE(768)] = 41129,
    [SMALL_STATE(769)] = 41151,
    [SMALL_STATE(770)] = 41173,
    [SMALL_STATE(771)] = 41191,
    [SMALL_STATE(772)] = 41213,
    [SMALL_STATE(773)] = 41235,
    [SMALL_STATE(774)] = 41257,
    [SMALL_STATE(775)] = 41279,
    [SMALL_STATE(776)] = 41297,
    [SMALL_STATE(777)] = 41319,
    [SMALL_STATE(778)] = 41335,
    [SMALL_STATE(779)] = 41351,
    [SMALL_STATE(780)] = 41367,
    [SMALL_STATE(781)] = 41383,
    [SMALL_STATE(782)] = 41399,
    [SMALL_STATE(783)] = 41415,
    [SMALL_STATE(784)] = 41431,
    [SMALL_STATE(785)] = 41449,
    [SMALL_STATE(786)] = 41468,
    [SMALL_STATE(787)] = 41483,
    [SMALL_STATE(788)] = 41502,
    [SMALL_STATE(789)] = 41521,
    [SMALL_STATE(790)] = 41538,
    [SMALL_STATE(791)] = 41553,
    [SMALL_STATE(792)] = 41570,
    [SMALL_STATE(793)] = 41589,
    [SMALL_STATE(794)] = 41606,
    [SMALL_STATE(795)] = 41625,
    [SMALL_STATE(796)] = 41644,
    [SMALL_STATE(797)] = 41663,
    [SMALL_STATE(798)] = 41682,
    [SMALL_STATE(799)] = 41701,
    [SMALL_STATE(800)] = 41718,
    [SMALL_STATE(801)] = 41733,
    [SMALL_STATE(802)] = 41752,
    [SMALL_STATE(803)] = 41767,
    [SMALL_STATE(804)] = 41786,
    [SMALL_STATE(805)] = 41805,
    [SMALL_STATE(806)] = 41820,
    [SMALL_STATE(807)] = 41835,
    [SMALL_STATE(808)] = 41854,
    [SMALL_STATE(809)] = 41873,
    [SMALL_STATE(810)] = 41888,
    [SMALL_STATE(811)] = 41907,
    [SMALL_STATE(812)] = 41926,
    [SMALL_STATE(813)] = 41945,
    [SMALL_STATE(814)] = 41962,
    [SMALL_STATE(815)] = 41981,
    [SMALL_STATE(816)] = 42000,
    [SMALL_STATE(817)] = 42019,
    [SMALL_STATE(818)] = 42038,
    [SMALL_STATE(819)] = 42057,
    [SMALL_STATE(820)] = 42076,
    [SMALL_STATE(821)] = 42095,
    [SMALL_STATE(822)] = 42114,
    [SMALL_STATE(823)] = 42133,
    [SMALL_STATE(824)] = 42152,
    [SMALL_STATE(825)] = 42167,
    [SMALL_STATE(826)] = 42186,
    [SMALL_STATE(827)] = 42203,
    [SMALL_STATE(828)] = 42222,
    [SMALL_STATE(829)] = 42241,
    [SMALL_STATE(830)] = 42260,
    [SMALL_STATE(831)] = 42279,
    [SMALL_STATE(832)] = 42298,
    [SMALL_STATE(833)] = 42317,
    [SMALL_STATE(834)] = 42334,
    [SMALL_STATE(835)] = 42351,
    [SMALL_STATE(836)] = 42370,
    [SMALL_STATE(837)] = 42387,
    [SMALL_STATE(838)] = 42406,
    [SMALL_STATE(839)] = 42425,
    [SMALL_STATE(840)] = 42444,
    [SMALL_STATE(841)] = 42463,
    [SMALL_STATE(842)] = 42480,
    [SMALL_STATE(843)] = 42499,
    [SMALL_STATE(844)] = 42516,
    [SMALL_STATE(845)] = 42535,
    [SMALL_STATE(846)] = 42554,
    [SMALL_STATE(847)] = 42571,
    [SMALL_STATE(848)] = 42586,
    [SMALL_STATE(849)] = 42605,
    [SMALL_STATE(850)] = 42620,
    [SMALL_STATE(851)] = 42635,
    [SMALL_STATE(852)] = 42650,
    [SMALL_STATE(853)] = 42665,
    [SMALL_STATE(854)] = 42684,
    [SMALL_STATE(855)] = 42699,
    [SMALL_STATE(856)] = 42714,
    [SMALL_STATE(857)] = 42731,
    [SMALL_STATE(858)] = 42746,
    [SMALL_STATE(859)] = 42761,
    [SMALL_STATE(860)] = 42780,
    [SMALL_STATE(861)] = 42795,
    [SMALL_STATE(862)] = 42814,
    [SMALL_STATE(863)] = 42829,
    [SMALL_STATE(864)] = 42844,
    [SMALL_STATE(865)] = 42863,
    [SMALL_STATE(866)] = 42878,
    [SMALL_STATE(867)] = 42897,
    [SMALL_STATE(868)] = 42916,
    [SMALL_STATE(869)] = 42935,
    [SMALL_STATE(870)] = 42952,
    [SMALL_STATE(871)] = 42967,
    [SMALL_STATE(872)] = 42984,
    [SMALL_STATE(873)] = 43003,
    [SMALL_STATE(874)] = 43022,
    [SMALL_STATE(875)] = 43037,
    [SMALL_STATE(876)] = 43054,
    [SMALL_STATE(877)] = 43073,
    [SMALL_STATE(878)] = 43090,
    [SMALL_STATE(879)] = 43105,
    [SMALL_STATE(880)] = 43120,
    [SMALL_STATE(881)] = 43135,
    [SMALL_STATE(882)] = 43154,
    [SMALL_STATE(883)] = 43169,
    [SMALL_STATE(884)] = 43188,
    [SMALL_STATE(885)] = 43203,
    [SMALL_STATE(886)] = 43222,
    [SMALL_STATE(887)] = 43241,
    [SMALL_STATE(888)] = 43256,
    [SMALL_STATE(889)] = 43275,
    [SMALL_STATE(890)] = 43294,
    [SMALL_STATE(891)] = 43309,
    [SMALL_STATE(892)] = 43324,
    [SMALL_STATE(893)] = 43339,
    [SMALL_STATE(894)] = 43358,
    [SMALL_STATE(895)] = 43377,
    [SMALL_STATE(896)] = 43396,
    [SMALL_STATE(897)] = 43415,
    [SMALL_STATE(898)] = 43430,
    [SMALL_STATE(899)] = 43445,
    [SMALL_STATE(900)] = 43460,
    [SMALL_STATE(901)] = 43479,
    [SMALL_STATE(902)] = 43498,
    [SMALL_STATE(903)] = 43517,
    [SMALL_STATE(904)] = 43534,
    [SMALL_STATE(905)] = 43549,
    [SMALL_STATE(906)] = 43564,
    [SMALL_STATE(907)] = 43581,
    [SMALL_STATE(908)] = 43596,
    [SMALL_STATE(909)] = 43615,
    [SMALL_STATE(910)] = 43630,
    [SMALL_STATE(911)] = 43645,
    [SMALL_STATE(912)] = 43660,
    [SMALL_STATE(913)] = 43675,
    [SMALL_STATE(914)] = 43692,
    [SMALL_STATE(915)] = 43711,
    [SMALL_STATE(916)] = 43730,
    [SMALL_STATE(917)] = 43749,
    [SMALL_STATE(918)] = 43766,
    [SMALL_STATE(919)] = 43785,
    [SMALL_STATE(920)] = 43800,
    [SMALL_STATE(921)] = 43815,
    [SMALL_STATE(922)] = 43834,
    [SMALL_STATE(923)] = 43853,
    [SMALL_STATE(924)] = 43868,
    [SMALL_STATE(925)] = 43887,
    [SMALL_STATE(926)] = 43906,
    [SMALL_STATE(927)] = 43925,
    [SMALL_STATE(928)] = 43940,
    [SMALL_STATE(929)] = 43959,
    [SMALL_STATE(930)] = 43974,
    [SMALL_STATE(931)] = 43993,
    [SMALL_STATE(932)] = 44010,
    [SMALL_STATE(933)] = 44029,
    [SMALL_STATE(934)] = 44046,
    [SMALL_STATE(935)] = 44065,
    [SMALL_STATE(936)] = 44082,
    [SMALL_STATE(937)] = 44101,
    [SMALL_STATE(938)] = 44116,
    [SMALL_STATE(939)] = 44131,
    [SMALL_STATE(940)] = 44148,
    [SMALL_STATE(941)] = 44163,
    [SMALL_STATE(942)] = 44182,
    [SMALL_STATE(943)] = 44201,
    [SMALL_STATE(944)] = 44220,
    [SMALL_STATE(945)] = 44239,
    [SMALL_STATE(946)] = 44254,
    [SMALL_STATE(947)] = 44269,
    [SMALL_STATE(948)] = 44284,
    [SMALL_STATE(949)] = 44299,
    [SMALL_STATE(950)] = 44318,
    [SMALL_STATE(951)] = 44333,
    [SMALL_STATE(952)] = 44352,
    [SMALL_STATE(953)] = 44371,
    [SMALL_STATE(954)] = 44390,
    [SMALL_STATE(955)] = 44407,
    [SMALL_STATE(956)] = 44422,
    [SMALL_STATE(957)] = 44441,
    [SMALL_STATE(958)] = 44458,
    [SMALL_STATE(959)] = 44477,
    [SMALL_STATE(960)] = 44492,
    [SMALL_STATE(961)] = 44507,
    [SMALL_STATE(962)] = 44524,
    [SMALL_STATE(963)] = 44543,
    [SMALL_STATE(964)] = 44558,
    [SMALL_STATE(965)] = 44573,
    [SMALL_STATE(966)] = 44588,
    [SMALL_STATE(967)] = 44603,
    [SMALL_STATE(968)] = 44620,
    [SMALL_STATE(969)] = 44635,
    [SMALL_STATE(970)] = 44654,
    [SMALL_STATE(971)] = 44671,
    [SMALL_STATE(972)] = 44688,
    [SMALL_STATE(973)] = 44705,
    [SMALL_STATE(974)] = 44720,
    [SMALL_STATE(975)] = 44737,
    [SMALL_STATE(976)] = 44754,
    [SMALL_STATE(977)] = 44773,
    [SMALL_STATE(978)] = 44790,
    [SMALL_STATE(979)] = 44805,
    [SMALL_STATE(980)] = 44822,
    [SMALL_STATE(981)] = 44837,
    [SMALL_STATE(982)] = 44852,
    [SMALL_STATE(983)] = 44867,
    [SMALL_STATE(984)] = 44886,
    [SMALL_STATE(985)] = 44905,
    [SMALL_STATE(986)] = 44920,
    [SMALL_STATE(987)] = 44939,
    [SMALL_STATE(988)] = 44954,
    [SMALL_STATE(989)] = 44969,
    [SMALL_STATE(990)] = 44984,
    [SMALL_STATE(991)] = 45003,
    [SMALL_STATE(992)] = 45018,
    [SMALL_STATE(993)] = 45033,
    [SMALL_STATE(994)] = 45052,
    [SMALL_STATE(995)] = 45067,
    [SMALL_STATE(996)] = 45082,
    [SMALL_STATE(997)] = 45101,
    [SMALL_STATE(998)] = 45116,
    [SMALL_STATE(999)] = 45131,
    [SMALL_STATE(1000)] = 45146,
    [SMALL_STATE(1001)] = 45161,
    [SMALL_STATE(1002)] = 45176,
    [SMALL_STATE(1003)] = 45191,
    [SMALL_STATE(1004)] = 45206,
    [SMALL_STATE(1005)] = 45221,
    [SMALL_STATE(1006)] = 45236,
    [SMALL_STATE(1007)] = 45251,
    [SMALL_STATE(1008)] = 45266,
    [SMALL_STATE(1009)] = 45281,
    [SMALL_STATE(1010)] = 45296,
    [SMALL_STATE(1011)] = 45311,
    [SMALL_STATE(1012)] = 45326,
    [SMALL_STATE(1013)] = 45341,
    [SMALL_STATE(1014)] = 45356,
    [SMALL_STATE(1015)] = 45371,
    [SMALL_STATE(1016)] = 45386,
    [SMALL_STATE(1017)] = 45401,
    [SMALL_STATE(1018)] = 45416,
    [SMALL_STATE(1019)] = 45431,
    [SMALL_STATE(1020)] = 45446,
    [SMALL_STATE(1021)] = 45461,
    [SMALL_STATE(1022)] = 45476,
    [SMALL_STATE(1023)] = 45491,
    [SMALL_STATE(1024)] = 45506,
    [SMALL_STATE(1025)] = 45521,
    [SMALL_STATE(1026)] = 45536,
    [SMALL_STATE(1027)] = 45551,
    [SMALL_STATE(1028)] = 45566,
    [SMALL_STATE(1029)] = 45581,
    [SMALL_STATE(1030)] = 45596,
    [SMALL_STATE(1031)] = 45611,
    [SMALL_STATE(1032)] = 45626,
    [SMALL_STATE(1033)] = 45641,
    [SMALL_STATE(1034)] = 45656,
    [SMALL_STATE(1035)] = 45671,
    [SMALL_STATE(1036)] = 45686,
    [SMALL_STATE(1037)] = 45701,
    [SMALL_STATE(1038)] = 45720,
    [SMALL_STATE(1039)] = 45739,
    [SMALL_STATE(1040)] = 45756,
    [SMALL_STATE(1041)] = 45775,
    [SMALL_STATE(1042)] = 45794,
    [SMALL_STATE(1043)] = 45813,
    [SMALL_STATE(1044)] = 45832,
    [SMALL_STATE(1045)] = 45851,
    [SMALL_STATE(1046)] = 45867,
    [SMALL_STATE(1047)] = 45881,
    [SMALL_STATE(1048)] = 45897,
    [SMALL_STATE(1049)] = 45913,
    [SMALL_STATE(1050)] = 45927,
    [SMALL_STATE(1051)] = 45943,
    [SMALL_STATE(1052)] = 45959,
    [SMALL_STATE(1053)] = 45975,
    [SMALL_STATE(1054)] = 45991,
    [SMALL_STATE(1055)] = 46007,
    [SMALL_STATE(1056)] = 46023,
    [SMALL_STATE(1057)] = 46039,
    [SMALL_STATE(1058)] = 46053,
    [SMALL_STATE(1059)] = 46067,
    [SMALL_STATE(1060)] = 46081,
    [SMALL_STATE(1061)] = 46095,
    [SMALL_STATE(1062)] = 46109,
    [SMALL_STATE(1063)] = 46125,
    [SMALL_STATE(1064)] = 46139,
    [SMALL_STATE(1065)] = 46153,
    [SMALL_STATE(1066)] = 46167,
    [SMALL_STATE(1067)] = 46181,
    [SMALL_STATE(1068)] = 46195,
    [SMALL_STATE(1069)] = 46209,
    [SMALL_STATE(1070)] = 46223,
    [SMALL_STATE(1071)] = 46239,
    [SMALL_STATE(1072)] = 46253,
    [SMALL_STATE(1073)] = 46267,
    [SMALL_STATE(1074)] = 46281,
    [SMALL_STATE(1075)] = 46295,
    [SMALL_STATE(1076)] = 46309,
    [SMALL_STATE(1077)] = 46323,
    [SMALL_STATE(1078)] = 46339,
    [SMALL_STATE(1079)] = 46353,
    [SMALL_STATE(1080)] = 46367,
    [SMALL_STATE(1081)] = 46381,
    [SMALL_STATE(1082)] = 46395,
    [SMALL_STATE(1083)] = 46411,
    [SMALL_STATE(1084)] = 46425,
    [SMALL_STATE(1085)] = 46439,
    [SMALL_STATE(1086)] = 46455,
    [SMALL_STATE(1087)] = 46471,
    [SMALL_STATE(1088)] = 46485,
    [SMALL_STATE(1089)] = 46501,
    [SMALL_STATE(1090)] = 46515,
    [SMALL_STATE(1091)] = 46531,
    [SMALL_STATE(1092)] = 46547,
    [SMALL_STATE(1093)] = 46561,
    [SMALL_STATE(1094)] = 46577,
    [SMALL_STATE(1095)] = 46591,
    [SMALL_STATE(1096)] = 46605,
    [SMALL_STATE(1097)] = 46619,
    [SMALL_STATE(1098)] = 46633,
    [SMALL_STATE(1099)] = 46649,
    [SMALL_STATE(1100)] = 46663,
    [SMALL_STATE(1101)] = 46677,
    [SMALL_STATE(1102)] = 46691,
    [SMALL_STATE(1103)] = 46707,
    [SMALL_STATE(1104)] = 46721,
    [SMALL_STATE(1105)] = 46735,
    [SMALL_STATE(1106)] = 46749,
    [SMALL_STATE(1107)] = 46765,
    [SMALL_STATE(1108)] = 46779,
    [SMALL_STATE(1109)] = 46795,
    [SMALL_STATE(1110)] = 46809,
    [SMALL_STATE(1111)] = 46823,
    [SMALL_STATE(1112)] = 46837,
    [SMALL_STATE(1113)] = 46851,
    [SMALL_STATE(1114)] = 46867,
    [SMALL_STATE(1115)] = 46883,
    [SMALL_STATE(1116)] = 46899,
    [SMALL_STATE(1117)] = 46913,
    [SMALL_STATE(1118)] = 46929,
    [SMALL_STATE(1119)] = 46945,
    [SMALL_STATE(1120)] = 46961,
    [SMALL_STATE(1121)] = 46977,
    [SMALL_STATE(1122)] = 46993,
    [SMALL_STATE(1123)] = 47009,
    [SMALL_STATE(1124)] = 47025,
    [SMALL_STATE(1125)] = 47041,
    [SMALL_STATE(1126)] = 47057,
    [SMALL_STATE(1127)] = 47073,
    [SMALL_STATE(1128)] = 47087,
    [SMALL_STATE(1129)] = 47101,
    [SMALL_STATE(1130)] = 47115,
    [SMALL_STATE(1131)] = 47129,
    [SMALL_STATE(1132)] = 47145,
    [SMALL_STATE(1133)] = 47159,
    [SMALL_STATE(1134)] = 47175,
    [SMALL_STATE(1135)] = 47191,
    [SMALL_STATE(1136)] = 47207,
    [SMALL_STATE(1137)] = 47221,
    [SMALL_STATE(1138)] = 47235,
    [SMALL_STATE(1139)] = 47251,
    [SMALL_STATE(1140)] = 47265,
    [SMALL_STATE(1141)] = 47281,
    [SMALL_STATE(1142)] = 47297,
    [SMALL_STATE(1143)] = 47313,
    [SMALL_STATE(1144)] = 47329,
    [SMALL_STATE(1145)] = 47345,
    [SMALL_STATE(1146)] = 47361,
    [SMALL_STATE(1147)] = 47375,
    [SMALL_STATE(1148)] = 47391,
    [SMALL_STATE(1149)] = 47405,
    [SMALL_STATE(1150)] = 47419,
    [SMALL_STATE(1151)] = 47433,
    [SMALL_STATE(1152)] = 47449,
    [SMALL_STATE(1153)] = 47465,
    [SMALL_STATE(1154)] = 47479,
    [SMALL_STATE(1155)] = 47493,
    [SMALL_STATE(1156)] = 47509,
    [SMALL_STATE(1157)] = 47523,
    [SMALL_STATE(1158)] = 47539,
    [SMALL_STATE(1159)] = 47553,
    [SMALL_STATE(1160)] = 47569,
    [SMALL_STATE(1161)] = 47585,
    [SMALL_STATE(1162)] = 47601,
    [SMALL_STATE(1163)] = 47617,
    [SMALL_STATE(1164)] = 47631,
    [SMALL_STATE(1165)] = 47645,
    [SMALL_STATE(1166)] = 47659,
    [SMALL_STATE(1167)] = 47673,
    [SMALL_STATE(1168)] = 47689,
    [SMALL_STATE(1169)] = 47703,
    [SMALL_STATE(1170)] = 47716,
    [SMALL_STATE(1171)] = 47729,
    [SMALL_STATE(1172)] = 47742,
    [SMALL_STATE(1173)] = 47755,
    [SMALL_STATE(1174)] = 47768,
    [SMALL_STATE(1175)] = 47781,
    [SMALL_STATE(1176)] = 47794,
    [SMALL_STATE(1177)] = 47807,
    [SMALL_STATE(1178)] = 47820,
    [SMALL_STATE(1179)] = 47833,
    [SMALL_STATE(1180)] = 47846,
    [SMALL_STATE(1181)] = 47859,
    [SMALL_STATE(1182)] = 47872,
    [SMALL_STATE(1183)] = 47885,
    [SMALL_STATE(1184)] = 47898,
    [SMALL_STATE(1185)] = 47911,
    [SMALL_STATE(1186)] = 47924,
    [SMALL_STATE(1187)] = 47937,
    [SMALL_STATE(1188)] = 47950,
    [SMALL_STATE(1189)] = 47963,
    [SMALL_STATE(1190)] = 47976,
    [SMALL_STATE(1191)] = 47989,
    [SMALL_STATE(1192)] = 48002,
    [SMALL_STATE(1193)] = 48015,
    [SMALL_STATE(1194)] = 48028,
    [SMALL_STATE(1195)] = 48041,
    [SMALL_STATE(1196)] = 48054,
    [SMALL_STATE(1197)] = 48067,
    [SMALL_STATE(1198)] = 48080,
    [SMALL_STATE(1199)] = 48093,
    [SMALL_STATE(1200)] = 48106,
    [SMALL_STATE(1201)] = 48119,
    [SMALL_STATE(1202)] = 48132,
    [SMALL_STATE(1203)] = 48145,
    [SMALL_STATE(1204)] = 48158,
    [SMALL_STATE(1205)] = 48171,
    [SMALL_STATE(1206)] = 48184,
    [SMALL_STATE(1207)] = 48197,
    [SMALL_STATE(1208)] = 48210,
    [SMALL_STATE(1209)] = 48223,
    [SMALL_STATE(1210)] = 48236,
    [SMALL_STATE(1211)] = 48249,
    [SMALL_STATE(1212)] = 48262,
    [SMALL_STATE(1213)] = 48275,
    [SMALL_STATE(1214)] = 48288,
    [SMALL_STATE(1215)] = 48301,
    [SMALL_STATE(1216)] = 48314,
    [SMALL_STATE(1217)] = 48327,
    [SMALL_STATE(1218)] = 48340,
    [SMALL_STATE(1219)] = 48353,
    [SMALL_STATE(1220)] = 48366,
    [SMALL_STATE(1221)] = 48379,
    [SMALL_STATE(1222)] = 48392,
    [SMALL_STATE(1223)] = 48405,
    [SMALL_STATE(1224)] = 48418,
    [SMALL_STATE(1225)] = 48431,
    [SMALL_STATE(1226)] = 48444,
    [SMALL_STATE(1227)] = 48457,
    [SMALL_STATE(1228)] = 48470,
    [SMALL_STATE(1229)] = 48483,
    [SMALL_STATE(1230)] = 48496,
    [SMALL_STATE(1231)] = 48509,
    [SMALL_STATE(1232)] = 48522,
    [SMALL_STATE(1233)] = 48535,
    [SMALL_STATE(1234)] = 48548,
    [SMALL_STATE(1235)] = 48561,
    [SMALL_STATE(1236)] = 48574,
    [SMALL_STATE(1237)] = 48587,
    [SMALL_STATE(1238)] = 48600,
    [SMALL_STATE(1239)] = 48613,
    [SMALL_STATE(1240)] = 48626,
    [SMALL_STATE(1241)] = 48639,
    [SMALL_STATE(1242)] = 48652,
    [SMALL_STATE(1243)] = 48665,
    [SMALL_STATE(1244)] = 48678,
    [SMALL_STATE(1245)] = 48691,
    [SMALL_STATE(1246)] = 48704,
    [SMALL_STATE(1247)] = 48717,
    [SMALL_STATE(1248)] = 48730,
    [SMALL_STATE(1249)] = 48743,
    [SMALL_STATE(1250)] = 48756,
    [SMALL_STATE(1251)] = 48769,
    [SMALL_STATE(1252)] = 48782,
    [SMALL_STATE(1253)] = 48795,
    [SMALL_STATE(1254)] = 48808,
    [SMALL_STATE(1255)] = 48821,
    [SMALL_STATE(1256)] = 48834,
    [SMALL_STATE(1257)] = 48847,
    [SMALL_STATE(1258)] = 48860,
    [SMALL_STATE(1259)] = 48873,
    [SMALL_STATE(1260)] = 48886,
    [SMALL_STATE(1261)] = 48899,
    [SMALL_STATE(1262)] = 48912,
    [SMALL_STATE(1263)] = 48925,
    [SMALL_STATE(1264)] = 48938,
    [SMALL_STATE(1265)] = 48951,
    [SMALL_STATE(1266)] = 48964,
    [SMALL_STATE(1267)] = 48977,
    [SMALL_STATE(1268)] = 48990,
    [SMALL_STATE(1269)] = 49003,
    [SMALL_STATE(1270)] = 49016,
    [SMALL_STATE(1271)] = 49029,
    [SMALL_STATE(1272)] = 49042,
    [SMALL_STATE(1273)] = 49055,
    [SMALL_STATE(1274)] = 49068,
    [SMALL_STATE(1275)] = 49081,
    [SMALL_STATE(1276)] = 49094,
    [SMALL_STATE(1277)] = 49107,
    [SMALL_STATE(1278)] = 49120,
    [SMALL_STATE(1279)] = 49133,
    [SMALL_STATE(1280)] = 49146,
    [SMALL_STATE(1281)] = 49159,
    [SMALL_STATE(1282)] = 49172,
    [SMALL_STATE(1283)] = 49185,
    [SMALL_STATE(1284)] = 49198,
    [SMALL_STATE(1285)] = 49211,
    [SMALL_STATE(1286)] = 49224,
    [SMALL_STATE(1287)] = 49237,
    [SMALL_STATE(1288)] = 49250,
    [SMALL_STATE(1289)] = 49263,
    [SMALL_STATE(1290)] = 49276,
    [SMALL_STATE(1291)] = 49289,
    [SMALL_STATE(1292)] = 49302,
    [SMALL_STATE(1293)] = 49315,
    [SMALL_STATE(1294)] = 49328,
    [SMALL_STATE(1295)] = 49341,
    [SMALL_STATE(1296)] = 49354,
    [SMALL_STATE(1297)] = 49367,
    [SMALL_STATE(1298)] = 49380,
    [SMALL_STATE(1299)] = 49393,
    [SMALL_STATE(1300)] = 49406,
    [SMALL_STATE(1301)] = 49419,
    [SMALL_STATE(1302)] = 49432,
    [SMALL_STATE(1303)] = 49445,
    [SMALL_STATE(1304)] = 49458,
    [SMALL_STATE(1305)] = 49471,
    [SMALL_STATE(1306)] = 49484,
    [SMALL_STATE(1307)] = 49497,
    [SMALL_STATE(1308)] = 49510,
    [SMALL_STATE(1309)] = 49523,
    [SMALL_STATE(1310)] = 49536,
    [SMALL_STATE(1311)] = 49549,
    [SMALL_STATE(1312)] = 49562,
    [SMALL_STATE(1313)] = 49575,
    [SMALL_STATE(1314)] = 49588,
    [SMALL_STATE(1315)] = 49601,
    [SMALL_STATE(1316)] = 49614,
    [SMALL_STATE(1317)] = 49627,
    [SMALL_STATE(1318)] = 49640,
    [SMALL_STATE(1319)] = 49653,
    [SMALL_STATE(1320)] = 49666,
    [SMALL_STATE(1321)] = 49679,
    [SMALL_STATE(1322)] = 49692,
    [SMALL_STATE(1323)] = 49705,
    [SMALL_STATE(1324)] = 49718,
    [SMALL_STATE(1325)] = 49731,
    [SMALL_STATE(1326)] = 49744,
    [SMALL_STATE(1327)] = 49757,
    [SMALL_STATE(1328)] = 49770,
    [SMALL_STATE(1329)] = 49783,
    [SMALL_STATE(1330)] = 49796,
    [SMALL_STATE(1331)] = 49809,
    [SMALL_STATE(1332)] = 49822,
    [SMALL_STATE(1333)] = 49835,
    [SMALL_STATE(1334)] = 49848,
    [SMALL_STATE(1335)] = 49861,
    [SMALL_STATE(1336)] = 49874,
    [SMALL_STATE(1337)] = 49887,
    [SMALL_STATE(1338)] = 49900,
    [SMALL_STATE(1339)] = 49913,
    [SMALL_STATE(1340)] = 49926,
    [SMALL_STATE(1341)] = 49939,
    [SMALL_STATE(1342)] = 49952,
    [SMALL_STATE(1343)] = 49965,
    [SMALL_STATE(1344)] = 49978,
    [SMALL_STATE(1345)] = 49991,
    [SMALL_STATE(1346)] = 50004,
    [SMALL_STATE(1347)] = 50017,
    [SMALL_STATE(1348)] = 50030,
    [SMALL_STATE(1349)] = 50043,
    [SMALL_STATE(1350)] = 50056,
    [SMALL_STATE(1351)] = 50069,
    [SMALL_STATE(1352)] = 50082,
    [SMALL_STATE(1353)] = 50095,
    [SMALL_STATE(1354)] = 50108,
    [SMALL_STATE(1355)] = 50121,
    [SMALL_STATE(1356)] = 50134,
    [SMALL_STATE(1357)] = 50147,
    [SMALL_STATE(1358)] = 50160,
    [SMALL_STATE(1359)] = 50173,
    [SMALL_STATE(1360)] = 50186,
    [SMALL_STATE(1361)] = 50199,
    [SMALL_STATE(1362)] = 50212,
    [SMALL_STATE(1363)] = 50225,
    [SMALL_STATE(1364)] = 50238,
    [SMALL_STATE(1365)] = 50251,
    [SMALL_STATE(1366)] = 50264,
    [SMALL_STATE(1367)] = 50277,
    [SMALL_STATE(1368)] = 50290,
    [SMALL_STATE(1369)] = 50303,
    [SMALL_STATE(1370)] = 50316,
    [SMALL_STATE(1371)] = 50329,
    [SMALL_STATE(1372)] = 50342,
    [SMALL_STATE(1373)] = 50355,
    [SMALL_STATE(1374)] = 50368,
    [SMALL_STATE(1375)] = 50381,
    [SMALL_STATE(1376)] = 50394,
    [SMALL_STATE(1377)] = 50407,
    [SMALL_STATE(1378)] = 50420,
    [SMALL_STATE(1379)] = 50433,
    [SMALL_STATE(1380)] = 50446,
    [SMALL_STATE(1381)] = 50459,
    [SMALL_STATE(1382)] = 50472,
    [SMALL_STATE(1383)] = 50485,
    [SMALL_STATE(1384)] = 50498,
    [SMALL_STATE(1385)] = 50511,
    [SMALL_STATE(1386)] = 50524,
    [SMALL_STATE(1387)] = 50537,
    [SMALL_STATE(1388)] = 50550,
    [SMALL_STATE(1389)] = 50563,
    [SMALL_STATE(1390)] = 50576,
    [SMALL_STATE(1391)] = 50589,
    [SMALL_STATE(1392)] = 50602,
    [SMALL_STATE(1393)] = 50615,
    [SMALL_STATE(1394)] = 50628,
    [SMALL_STATE(1395)] = 50641,
    [SMALL_STATE(1396)] = 50654,
    [SMALL_STATE(1397)] = 50667,
    [SMALL_STATE(1398)] = 50680,
    [SMALL_STATE(1399)] = 50693,
    [SMALL_STATE(1400)] = 50706,
    [SMALL_STATE(1401)] = 50719,
    [SMALL_STATE(1402)] = 50732,
    [SMALL_STATE(1403)] = 50745,
    [SMALL_STATE(1404)] = 50758,
    [SMALL_STATE(1405)] = 50771,
    [SMALL_STATE(1406)] = 50784,
    [SMALL_STATE(1407)] = 50797,
    [SMALL_STATE(1408)] = 50810,
    [SMALL_STATE(1409)] = 50823,
    [SMALL_STATE(1410)] = 50836,
    [SMALL_STATE(1411)] = 50849,
    [SMALL_STATE(1412)] = 50862,
    [SMALL_STATE(1413)] = 50875,
    [SMALL_STATE(1414)] = 50888,
    [SMALL_STATE(1415)] = 50901,
    [SMALL_STATE(1416)] = 50914,
    [SMALL_STATE(1417)] = 50927,
    [SMALL_STATE(1418)] = 50940,
    [SMALL_STATE(1419)] = 50953,
    [SMALL_STATE(1420)] = 50966,
    [SMALL_STATE(1421)] = 50979,
    [SMALL_STATE(1422)] = 50992,
    [SMALL_STATE(1423)] = 51005,
    [SMALL_STATE(1424)] = 51018,
    [SMALL_STATE(1425)] = 51031,
    [SMALL_STATE(1426)] = 51044,
    [SMALL_STATE(1427)] = 51057,
    [SMALL_STATE(1428)] = 51070,
    [SMALL_STATE(1429)] = 51083,
    [SMALL_STATE(1430)] = 51096,
    [SMALL_STATE(1431)] = 51109,
    [SMALL_STATE(1432)] = 51122,
    [SMALL_STATE(1433)] = 51135,
    [SMALL_STATE(1434)] = 51148,
    [SMALL_STATE(1435)] = 51161,
    [SMALL_STATE(1436)] = 51174,
    [SMALL_STATE(1437)] = 51187,
    [SMALL_STATE(1438)] = 51200,
    [SMALL_STATE(1439)] = 51213,
    [SMALL_STATE(1440)] = 51226,
    [SMALL_STATE(1441)] = 51239,
    [SMALL_STATE(1442)] = 51252,
    [SMALL_STATE(1443)] = 51265,
    [SMALL_STATE(1444)] = 51278,
    [SMALL_STATE(1445)] = 51291,
    [SMALL_STATE(1446)] = 51304,
    [SMALL_STATE(1447)] = 51317,
    [SMALL_STATE(1448)] = 51330,
    [SMALL_STATE(1449)] = 51343,
    [SMALL_STATE(1450)] = 51356,
    [SMALL_STATE(1451)] = 51369,
    [SMALL_STATE(1452)] = 51382,
    [SMALL_STATE(1453)] = 51395,
    [SMALL_STATE(1454)] = 51408,
    [SMALL_STATE(1455)] = 51421,
    [SMALL_STATE(1456)] = 51434,
    [SMALL_STATE(1457)] = 51447,
    [SMALL_STATE(1458)] = 51460,
    [SMALL_STATE(1459)] = 51473,
    [SMALL_STATE(1460)] = 51486,
    [SMALL_STATE(1461)] = 51499,
    [SMALL_STATE(1462)] = 51512,
    [SMALL_STATE(1463)] = 51525,
    [SMALL_STATE(1464)] = 51538,
    [SMALL_STATE(1465)] = 51551,
    [SMALL_STATE(1466)] = 51564,
    [SMALL_STATE(1467)] = 51577,
    [SMALL_STATE(1468)] = 51590,
    [SMALL_STATE(1469)] = 51603,
    [SMALL_STATE(1470)] = 51616,
    [SMALL_STATE(1471)] = 51629,
    [SMALL_STATE(1472)] = 51642,
    [SMALL_STATE(1473)] = 51655,
    [SMALL_STATE(1474)] = 51668,
    [SMALL_STATE(1475)] = 51681,
    [SMALL_STATE(1476)] = 51694,
    [SMALL_STATE(1477)] = 51707,
    [SMALL_STATE(1478)] = 51720,
    [SMALL_STATE(1479)] = 51733,
    [SMALL_STATE(1480)] = 51746,
    [SMALL_STATE(1481)] = 51759,
    [SMALL_STATE(1482)] = 51772,
    [SMALL_STATE(1483)] = 51785,
    [SMALL_STATE(1484)] = 51798,
    [SMALL_STATE(1485)] = 51811,
    [SMALL_STATE(1486)] = 51824,
    [SMALL_STATE(1487)] = 51837,
    [SMALL_STATE(1488)] = 51850,
    [SMALL_STATE(1489)] = 51863,
    [SMALL_STATE(1490)] = 51876,
    [SMALL_STATE(1491)] = 51889,
    [SMALL_STATE(1492)] = 51902,
    [SMALL_STATE(1493)] = 51915,
    [SMALL_STATE(1494)] = 51928,
    [SMALL_STATE(1495)] = 51941,
    [SMALL_STATE(1496)] = 51954,
    [SMALL_STATE(1497)] = 51967,
    [SMALL_STATE(1498)] = 51980,
    [SMALL_STATE(1499)] = 51993,
    [SMALL_STATE(1500)] = 52006,
    [SMALL_STATE(1501)] = 52019,
    [SMALL_STATE(1502)] = 52032,
    [SMALL_STATE(1503)] = 52045,
    [SMALL_STATE(1504)] = 52058,
    [SMALL_STATE(1505)] = 52071,
    [SMALL_STATE(1506)] = 52084,
    [SMALL_STATE(1507)] = 52097,
    [SMALL_STATE(1508)] = 52110,
    [SMALL_STATE(1509)] = 52123,
    [SMALL_STATE(1510)] = 52136,
    [SMALL_STATE(1511)] = 52149,
    [SMALL_STATE(1512)] = 52162,
    [SMALL_STATE(1513)] = 52175,
    [SMALL_STATE(1514)] = 52188,
    [SMALL_STATE(1515)] = 52201,
    [SMALL_STATE(1516)] = 52214,
    [SMALL_STATE(1517)] = 52227,
    [SMALL_STATE(1518)] = 52240,
    [SMALL_STATE(1519)] = 52253,
    [SMALL_STATE(1520)] = 52266,
    [SMALL_STATE(1521)] = 52279,
    [SMALL_STATE(1522)] = 52292,
    [SMALL_STATE(1523)] = 52305,
    [SMALL_STATE(1524)] = 52318,
    [SMALL_STATE(1525)] = 52331,
    [SMALL_STATE(1526)] = 52344,
    [SMALL_STATE(1527)] = 52357,
    [SMALL_STATE(1528)] = 52370,
    [SMALL_STATE(1529)] = 52383,
    [SMALL_STATE(1530)] = 52396,
    [SMALL_STATE(1531)] = 52409,
    [SMALL_STATE(1532)] = 52422,
    [SMALL_STATE(1533)] = 52435,
    [SMALL_STATE(1534)] = 52448,
    [SMALL_STATE(1535)] = 52461,
    [SMALL_STATE(1536)] = 52474,
    [SMALL_STATE(1537)] = 52487,
    [SMALL_STATE(1538)] = 52500,
    [SMALL_STATE(1539)] = 52513,
    [SMALL_STATE(1540)] = 52526,
    [SMALL_STATE(1541)] = 52539,
    [SMALL_STATE(1542)] = 52552,
    [SMALL_STATE(1543)] = 52565,
    [SMALL_STATE(1544)] = 52578,
    [SMALL_STATE(1545)] = 52591,
    [SMALL_STATE(1546)] = 52604,
    [SMALL_STATE(1547)] = 52617,
    [SMALL_STATE(1548)] = 52630,
    [SMALL_STATE(1549)] = 52643,
    [SMALL_STATE(1550)] = 52656,
    [SMALL_STATE(1551)] = 52669,
    [SMALL_STATE(1552)] = 52682,
    [SMALL_STATE(1553)] = 52695,
    [SMALL_STATE(1554)] = 52708,
    [SMALL_STATE(1555)] = 52721,
    [SMALL_STATE(1556)] = 52734,
    [SMALL_STATE(1557)] = 52747,
    [SMALL_STATE(1558)] = 52760,
    [SMALL_STATE(1559)] = 52773,
    [SMALL_STATE(1560)] = 52786,
    [SMALL_STATE(1561)] = 52799,
    [SMALL_STATE(1562)] = 52812,
    [SMALL_STATE(1563)] = 52825,
    [SMALL_STATE(1564)] = 52838,
    [SMALL_STATE(1565)] = 52851,
    [SMALL_STATE(1566)] = 52864,
    [SMALL_STATE(1567)] = 52877,
    [SMALL_STATE(1568)] = 52890,
    [SMALL_STATE(1569)] = 52903,
    [SMALL_STATE(1570)] = 52916,
    [SMALL_STATE(1571)] = 52929,
    [SMALL_STATE(1572)] = 52942,
    [SMALL_STATE(1573)] = 52955,
    [SMALL_STATE(1574)] = 52968,
    [SMALL_STATE(1575)] = 52981,
    [SMALL_STATE(1576)] = 52994,
    [SMALL_STATE(1577)] = 53007,
    [SMALL_STATE(1578)] = 53020,
    [SMALL_STATE(1579)] = 53033,
    [SMALL_STATE(1580)] = 53046,
    [SMALL_STATE(1581)] = 53059,
    [SMALL_STATE(1582)] = 53072,
    [SMALL_STATE(1583)] = 53085,
    [SMALL_STATE(1584)] = 53098,
    [SMALL_STATE(1585)] = 53111,
    [SMALL_STATE(1586)] = 53124,
    [SMALL_STATE(1587)] = 53137,
    [SMALL_STATE(1588)] = 53150,
    [SMALL_STATE(1589)] = 53163,
    [SMALL_STATE(1590)] = 53176,
    [SMALL_STATE(1591)] = 53189,
    [SMALL_STATE(1592)] = 53202,
    [SMALL_STATE(1593)] = 53215,
    [SMALL_STATE(1594)] = 53228,
    [SMALL_STATE(1595)] = 53241,
    [SMALL_STATE(1596)] = 53254,
    [SMALL_STATE(1597)] = 53267,
    [SMALL_STATE(1598)] = 53280,
    [SMALL_STATE(1599)] = 53293,
    [SMALL_STATE(1600)] = 53306,
    [SMALL_STATE(1601)] = 53319,
    [SMALL_STATE(1602)] = 53332,
    [SMALL_STATE(1603)] = 53345,
    [SMALL_STATE(1604)] = 53358,
    [SMALL_STATE(1605)] = 53371,
    [SMALL_STATE(1606)] = 53384,
    [SMALL_STATE(1607)] = 53397,
    [SMALL_STATE(1608)] = 53410,
    [SMALL_STATE(1609)] = 53423,
    [SMALL_STATE(1610)] = 53436,
    [SMALL_STATE(1611)] = 53449,
    [SMALL_STATE(1612)] = 53462,
    [SMALL_STATE(1613)] = 53475,
    [SMALL_STATE(1614)] = 53488,
    [SMALL_STATE(1615)] = 53501,
    [SMALL_STATE(1616)] = 53514,
    [SMALL_STATE(1617)] = 53527,
    [SMALL_STATE(1618)] = 53540,
    [SMALL_STATE(1619)] = 53553,
    [SMALL_STATE(1620)] = 53566,
    [SMALL_STATE(1621)] = 53579,
    [SMALL_STATE(1622)] = 53592,
    [SMALL_STATE(1623)] = 53605,
    [SMALL_STATE(1624)] = 53618,
    [SMALL_STATE(1625)] = 53631,
    [SMALL_STATE(1626)] = 53644,
    [SMALL_STATE(1627)] = 53657,
    [SMALL_STATE(1628)] = 53670,
    [SMALL_STATE(1629)] = 53683,
    [SMALL_STATE(1630)] = 53696,
    [SMALL_STATE(1631)] = 53709,
    [SMALL_STATE(1632)] = 53722,
    [SMALL_STATE(1633)] = 53735,
    [SMALL_STATE(1634)] = 53748,
    [SMALL_STATE(1635)] = 53761,
    [SMALL_STATE(1636)] = 53774,
    [SMALL_STATE(1637)] = 53787,
    [SMALL_STATE(1638)] = 53800,
    [SMALL_STATE(1639)] = 53813,
    [SMALL_STATE(1640)] = 53826,
    [SMALL_STATE(1641)] = 53839,
    [SMALL_STATE(1642)] = 53852,
    [SMALL_STATE(1643)] = 53865,
    [SMALL_STATE(1644)] = 53878,
    [SMALL_STATE(1645)] = 53891,
    [SMALL_STATE(1646)] = 53904,
    [SMALL_STATE(1647)] = 53917,
    [SMALL_STATE(1648)] = 53930,
    [SMALL_STATE(1649)] = 53943,
    [SMALL_STATE(1650)] = 53956,
    [SMALL_STATE(1651)] = 53969,
    [SMALL_STATE(1652)] = 53982,
    [SMALL_STATE(1653)] = 53995,
    [SMALL_STATE(1654)] = 54008,
    [SMALL_STATE(1655)] = 54021,
    [SMALL_STATE(1656)] = 54034,
    [SMALL_STATE(1657)] = 54047,
    [SMALL_STATE(1658)] = 54060,
    [SMALL_STATE(1659)] = 54073,
    [SMALL_STATE(1660)] = 54086,
    [SMALL_STATE(1661)] = 54099,
    [SMALL_STATE(1662)] = 54112,
    [SMALL_STATE(1663)] = 54125,
    [SMALL_STATE(1664)] = 54138,
    [SMALL_STATE(1665)] = 54151,
    [SMALL_STATE(1666)] = 54164,
    [SMALL_STATE(1667)] = 54177,
    [SMALL_STATE(1668)] = 54190,
    [SMALL_STATE(1669)] = 54203,
    [SMALL_STATE(1670)] = 54216,
    [SMALL_STATE(1671)] = 54229,
    [SMALL_STATE(1672)] = 54242,
    [SMALL_STATE(1673)] = 54255,
    [SMALL_STATE(1674)] = 54268,
    [SMALL_STATE(1675)] = 54281,
    [SMALL_STATE(1676)] = 54294,
    [SMALL_STATE(1677)] = 54307,
    [SMALL_STATE(1678)] = 54320,
    [SMALL_STATE(1679)] = 54333,
    [SMALL_STATE(1680)] = 54346,
    [SMALL_STATE(1681)] = 54359,
    [SMALL_STATE(1682)] = 54372,
    [SMALL_STATE(1683)] = 54385,
    [SMALL_STATE(1684)] = 54398,
    [SMALL_STATE(1685)] = 54411,
    [SMALL_STATE(1686)] = 54424,
    [SMALL_STATE(1687)] = 54437,
    [SMALL_STATE(1688)] = 54450,
    [SMALL_STATE(1689)] = 54463,
    [SMALL_STATE(1690)] = 54476,
    [SMALL_STATE(1691)] = 54489,
    [SMALL_STATE(1692)] = 54502,
    [SMALL_STATE(1693)] = 54515,
    [SMALL_STATE(1694)] = 54528,
    [SMALL_STATE(1695)] = 54541,
    [SMALL_STATE(1696)] = 54554,
    [SMALL_STATE(1697)] = 54567,
    [SMALL_STATE(1698)] = 54580,
    [SMALL_STATE(1699)] = 54593,
    [SMALL_STATE(1700)] = 54606,
    [SMALL_STATE(1701)] = 54619,
    [SMALL_STATE(1702)] = 54632,
    [SMALL_STATE(1703)] = 54645,
    [SMALL_STATE(1704)] = 54649,
};

static const TSParseActionEntry ts_parse_actions[] = {
    [0] = { .entry = { .count = 0, .reusable = false } },
    [1] = { .entry = { .count = 1, .reusable = false } },
    RECOVER(),
    [3] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1521),
    [5] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1616),
    [7] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_specification, 0, 0, 0),
    [9] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1615),
    [11] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1147),
    [13] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(668),
    [15] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1612),
    [17] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1611),
    [19] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(828),
    [21] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1608),
    [23] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1607),
    [25] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1606),
    [27] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(665),
    [29] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(34),
    [31] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(41),
    [33] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(831),
    [35] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1602),
    [37] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1601),
    [39] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1600),
    [41] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1599),
    [43] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1598),
    [45] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(164),
    [47] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1135),
    [49] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(44),
    [51] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(842),
    [53] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(956),
    [55] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(611),
    [57] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1593),
    [59] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1592),
    [61] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1591),
    [63] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1590),
    [65] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1062),
    [67] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(645),
    [69] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(640),
    [71] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(641),
    [73] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(641),
    [75] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(664),
    [77] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(778),
    [79] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1513),
    [81] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(662),
    [83] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(654),
    [85] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(654),
    [87] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(650),
    [89] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(629),
    [91] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(629),
    [93] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(758),
    [95] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(758),
    [97] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1328),
    [99] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(643),
    [101] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(627),
    [103] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(781),
    [105] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1520),
    [107] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1511),
    [109] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1612),
    [111] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1334),
    [113] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1216),
    [115] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1215),
    [117] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1213),
    [119] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(80),
    [121] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1607),
    [123] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1606),
    [125] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(35),
    [127] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(39),
    [129] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1602),
    [131] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1600),
    [133] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1599),
    [135] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1598),
    [137] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(164),
    [139] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1212),
    [141] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(83),
    [143] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1179),
    [145] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(44),
    [147] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(842),
    [149] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(611),
    [151] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(777),
    [153] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1209),
    [155] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1062),
    [157] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(445),
    [159] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(645),
    [162] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(640),
    [165] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [168] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [171] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(664),
    [174] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(778),
    [177] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1513),
    [180] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(662),
    [183] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [186] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [189] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(650),
    [192] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [195] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [198] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [201] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [204] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1328),
    [207] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(643),
    [210] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(627),
    [213] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(781),
    [216] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1520),
    [219] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1511),
    [222] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1612),
    [225] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    [227] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1216),
    [230] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1215),
    [233] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1213),
    [236] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(80),
    [239] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1607),
    [242] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1606),
    [245] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(35),
    [248] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(39),
    [251] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1602),
    [254] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1600),
    [257] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1599),
    [260] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1598),
    [263] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(164),
    [266] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1212),
    [269] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(83),
    [272] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1179),
    [275] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(44),
    [278] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(842),
    [281] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(611),
    [284] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(777),
    [287] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1209),
    [290] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1062),
    [293] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(445),
    [296] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1281),
    [298] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1175),
    [300] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1174),
    [302] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1173),
    [304] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1180),
    [306] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1436),
    [308] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(645),
    [311] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(640),
    [314] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [317] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [320] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(664),
    [323] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(778),
    [326] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1513),
    [329] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(662),
    [332] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [335] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [338] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(650),
    [341] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [344] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [347] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [350] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [353] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1328),
    [356] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(643),
    [359] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(627),
    [362] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(781),
    [365] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1520),
    [368] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1511),
    [371] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1612),
    [374] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    [376] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1216),
    [379] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1215),
    [382] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1213),
    [385] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(80),
    [388] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1607),
    [391] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1606),
    [394] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(35),
    [397] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(39),
    [400] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1602),
    [403] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1600),
    [406] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1599),
    [409] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1598),
    [412] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(164),
    [415] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1212),
    [418] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1174),
    [421] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(44),
    [424] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(842),
    [427] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(611),
    [430] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(777),
    [433] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1209),
    [436] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1173),
    [439] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1062),
    [442] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(445),
    [445] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_body, 1, 0, 0),
    [447] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1220),
    [449] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1380),
    [451] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1597),
    [453] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(645),
    [456] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(640),
    [459] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [462] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [465] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(664),
    [468] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(778),
    [471] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1513),
    [474] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(662),
    [477] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [480] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [483] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(650),
    [486] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [489] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [492] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [495] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [498] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1328),
    [501] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(643),
    [504] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(627),
    [507] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(781),
    [510] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1520),
    [513] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1511),
    [516] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1612),
    [519] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    [521] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1216),
    [524] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1215),
    [527] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1213),
    [530] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(80),
    [533] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1607),
    [536] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1606),
    [539] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(35),
    [542] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(39),
    [545] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1602),
    [548] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1600),
    [551] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1599),
    [554] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1598),
    [557] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(164),
    [560] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1212),
    [563] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(44),
    [566] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(842),
    [569] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(611),
    [572] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(777),
    [575] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1209),
    [578] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1062),
    [581] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(445),
    [584] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1596),
    [586] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1506),
    [588] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_body, 1, 0, 0),
    [590] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1383),
    [592] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1507),
    [594] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1378),
    [596] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(466),
    [598] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(279),
    [600] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(467),
    [602] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(459),
    [604] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(462),
    [606] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(446),
    [608] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(446),
    [610] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(708),
    [612] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1138),
    [614] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(836),
    [616] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(468),
    [618] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1521),
    [620] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1496),
    [622] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(816),
    [624] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1428),
    [626] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1615),
    [629] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1147),
    [632] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(668),
    [635] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1612),
    [638] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    [640] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1611),
    [643] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(828),
    [646] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1608),
    [649] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1607),
    [652] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1606),
    [655] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(665),
    [658] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(34),
    [661] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(41),
    [664] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(831),
    [667] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1602),
    [670] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1601),
    [673] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1600),
    [676] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1599),
    [679] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1598),
    [682] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(164),
    [685] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(816),
    [688] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1135),
    [691] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(44),
    [694] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(842),
    [697] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(956),
    [700] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(611),
    [703] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1593),
    [706] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1592),
    [709] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1591),
    [712] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1590),
    [715] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1062),
    [718] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    [720] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1615),
    [723] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1147),
    [726] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(668),
    [729] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1612),
    [732] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1611),
    [735] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(828),
    [738] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1608),
    [741] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1607),
    [744] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1606),
    [747] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(665),
    [750] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(34),
    [753] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(41),
    [756] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(831),
    [759] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1602),
    [762] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1601),
    [765] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1600),
    [768] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1599),
    [771] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1598),
    [774] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(164),
    [777] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1135),
    [780] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(44),
    [783] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(842),
    [786] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(956),
    [789] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(611),
    [792] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1593),
    [795] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1592),
    [798] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1591),
    [801] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1590),
    [804] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1062),
    [807] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1497),
    [809] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1512),
    [811] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_specification, 1, 0, 0),
    [813] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1252),
    [815] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1473),
    [817] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1677),
    [819] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(671),
    [821] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(673),
    [823] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1678),
    [825] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1679),
    [827] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1680),
    [829] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(805),
    [831] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(806),
    [833] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(809),
    [835] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(674),
    [837] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(675),
    [839] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(824),
    [841] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1681),
    [843] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1487),
    [845] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1682),
    [847] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1683),
    [849] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1684),
    [851] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1685),
    [853] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(677),
    [855] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(678),
    [857] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1686),
    [859] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(679),
    [861] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(680),
    [863] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(681),
    [865] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(682),
    [867] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(690),
    [869] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(691),
    [871] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(692),
    [873] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(987),
    [875] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(694),
    [877] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1687),
    [879] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(988),
    [881] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(695),
    [883] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(847),
    [885] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1688),
    [887] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1689),
    [889] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(635),
    [891] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1548),
    [893] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1547),
    [895] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(469),
    [897] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(470),
    [899] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1546),
    [901] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1545),
    [903] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1544),
    [905] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(527),
    [907] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(530),
    [909] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(533),
    [911] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(475),
    [913] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(476),
    [915] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(539),
    [917] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1542),
    [919] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1541),
    [921] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1540),
    [923] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1538),
    [925] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1537),
    [927] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1536),
    [929] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(478),
    [931] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(479),
    [933] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1535),
    [935] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(480),
    [937] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(481),
    [939] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(457),
    [941] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(483),
    [943] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(484),
    [945] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(485),
    [947] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(486),
    [949] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(515),
    [951] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(496),
    [953] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1532),
    [955] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(523),
    [957] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(495),
    [959] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(525),
    [961] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1531),
    [963] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1530),
    [965] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(456),
    [967] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1426),
    [969] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1637),
    [971] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(106),
    [973] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(108),
    [975] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1638),
    [977] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1639),
    [979] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1640),
    [981] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(158),
    [983] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(125),
    [985] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(177),
    [987] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(105),
    [989] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(101),
    [991] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(175),
    [993] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1641),
    [995] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1702),
    [997] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1642),
    [999] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1643),
    [1001] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1644),
    [1003] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1645),
    [1005] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(103),
    [1007] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(102),
    [1009] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1646),
    [1011] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(100),
    [1013] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(114),
    [1015] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(116),
    [1017] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(104),
    [1019] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(112),
    [1021] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(111),
    [1023] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(117),
    [1025] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(131),
    [1027] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(118),
    [1029] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1647),
    [1031] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(183),
    [1033] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(115),
    [1035] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(122),
    [1037] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1648),
    [1039] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1649),
    [1041] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(107),
    [1043] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1273),
    [1045] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1617),
    [1047] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(729),
    [1049] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(728),
    [1051] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1618),
    [1053] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1619),
    [1055] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1620),
    [1057] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(963),
    [1059] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(964),
    [1061] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(965),
    [1063] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(725),
    [1065] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(724),
    [1067] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(968),
    [1069] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1621),
    [1071] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1701),
    [1073] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1622),
    [1075] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1623),
    [1077] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1624),
    [1079] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1625),
    [1081] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(722),
    [1083] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(721),
    [1085] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1626),
    [1087] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(720),
    [1089] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(719),
    [1091] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(718),
    [1093] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(717),
    [1095] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(716),
    [1097] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(714),
    [1099] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(713),
    [1101] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(978),
    [1103] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(712),
    [1105] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1627),
    [1107] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(980),
    [1109] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(711),
    [1111] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(982),
    [1113] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1628),
    [1115] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1629),
    [1117] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(644),
    [1119] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1472),
    [1121] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1657),
    [1123] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(334),
    [1125] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(336),
    [1127] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1658),
    [1129] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1659),
    [1131] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1660),
    [1133] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(396),
    [1135] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(395),
    [1137] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(394),
    [1139] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(337),
    [1141] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(338),
    [1143] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(391),
    [1145] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1661),
    [1147] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1564),
    [1149] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1662),
    [1151] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1663),
    [1153] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1664),
    [1155] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1665),
    [1157] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(331),
    [1159] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(341),
    [1161] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1666),
    [1163] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(342),
    [1165] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(357),
    [1167] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(355),
    [1169] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(354),
    [1171] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(350),
    [1173] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(349),
    [1175] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(348),
    [1177] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(384),
    [1179] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(343),
    [1181] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1667),
    [1183] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(374),
    [1185] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(351),
    [1187] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(373),
    [1189] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1668),
    [1191] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1669),
    [1193] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(344),
    [1195] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1425),
    [1197] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(42),
    [1199] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(40),
    [1201] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(305),
    [1203] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1375),
    [1205] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1148),
    [1207] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1192),
    [1209] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(645),
    [1212] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(640),
    [1215] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [1218] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [1221] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(664),
    [1224] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(778),
    [1227] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1513),
    [1230] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(662),
    [1233] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [1236] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [1239] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(650),
    [1242] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [1245] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [1248] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [1251] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [1254] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1328),
    [1257] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(643),
    [1260] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(627),
    [1263] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(781),
    [1266] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1520),
    [1269] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1511),
    [1272] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    [1274] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(42),
    [1277] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(40),
    [1280] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(777),
    [1283] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(445),
    [1286] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1078),
    [1288] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1066),
    [1290] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1158),
    [1292] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(763),
    [1294] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(428),
    [1296] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_header, 2, 0, 0),
    [1298] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(651),
    [1300] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_forward_dcl, 2, 0, 0),
    [1302] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(748),
    [1304] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(669),
    [1306] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1523),
    [1308] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1522),
    [1310] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1197),
    [1312] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1367),
    [1314] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(98),
    [1316] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1595),
    [1318] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(645),
    [1321] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(640),
    [1324] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [1327] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(641),
    [1330] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(664),
    [1333] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1523),
    [1336] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1522),
    [1339] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(662),
    [1342] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [1345] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(654),
    [1348] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(650),
    [1351] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [1354] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(629),
    [1357] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [1360] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(758),
    [1363] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1328),
    [1366] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(643),
    [1369] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(627),
    [1372] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1197),
    [1375] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1520),
    [1378] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    [1380] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(98),
    [1383] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1598),
    [1386] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(164),
    [1389] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(44),
    [1392] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(445),
    [1395] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1198),
    [1397] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_init_dcl, 5, 0, 0),
    [1399] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_dcl, 5, 0, 0),
    [1401] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_export, 2, 0, 0),
    [1403] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_export, 2, 0, 0),
    [1405] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_init_dcl, 6, 0, 0),
    [1407] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_dcl, 6, 0, 0),
    [1409] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_init_dcl, 7, 0, 0),
    [1411] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_dcl, 7, 0, 0),
    [1413] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1093),
    [1415] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1249),
    [1417] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(138),
    [1419] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_state_member, 4, 0, 0),
    [1421] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_state_member, 4, 0, 0),
    [1423] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_value_element, 1, 0, 0),
    [1425] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_element, 1, 0, 0),
    [1427] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_value_def_repeat1, 1, 0, 0),
    [1429] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_value_def_repeat1, 1, 0, 0),
    [1431] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_home_export, 1, 0, 0),
    [1433] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_export, 1, 0, 0),
    [1435] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_home_export, 2, 0, 0),
    [1437] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_export, 2, 0, 0),
    [1439] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_home_body_repeat1, 1, 0, 0),
    [1441] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_home_body_repeat1, 1, 0, 0),
    [1443] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1226),
    [1445] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1226),
    [1447] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1227),
    [1449] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(587),
    [1451] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_interface_body_repeat1, 1, 0, 0),
    [1453] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_body_repeat1, 1, 0, 0),
    [1455] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    [1457] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    [1459] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(35),
    [1462] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(39),
    [1465] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_service, 1, 0, 2),
    [1467] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_service, 1, 0, 2),
    [1469] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(761),
    [1471] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_must_understand, 1, 0, 2),
    [1473] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_must_understand, 1, 0, 2),
    [1475] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(242),
    [1477] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_nested, 1, 0, 2),
    [1479] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_nested, 1, 0, 2),
    [1481] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(250),
    [1483] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_external, 1, 0, 2),
    [1485] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_external, 1, 0, 2),
    [1487] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(193),
    [1489] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_hashid, 1, 0, 2),
    [1491] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_hashid, 1, 0, 2),
    [1493] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(263),
    [1495] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_key, 1, 0, 2),
    [1497] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_key, 1, 0, 2),
    [1499] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(240),
    [1501] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_autoid, 1, 0, 2),
    [1503] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_autoid, 1, 0, 2),
    [1505] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(734),
    [1507] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_scoped_name, 1, 0, 0),
    [1509] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_scoped_name, 1, 0, 0),
    [1511] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_optional, 1, 0, 2),
    [1513] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_optional, 1, 0, 2),
    [1515] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(190),
    [1517] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_scoped_name, 2, 0, 0),
    [1519] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_scoped_name, 2, 0, 0),
    [1521] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_scoped_name, 3, 0, 0),
    [1523] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_scoped_name, 3, 0, 0),
    [1525] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_ignore_literal_names, 1, 0, 2),
    [1527] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_ignore_literal_names, 1, 0, 2),
    [1529] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(275),
    [1531] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_default_nested, 1, 0, 2),
    [1533] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_default_nested, 1, 0, 2),
    [1535] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(268),
    [1537] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_custom_body, 1, 0, 0),
    [1539] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_custom_body, 1, 0, 0),
    [1541] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(134),
    [1543] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_oneway, 1, 0, 2),
    [1545] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_oneway, 1, 0, 2),
    [1547] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(255),
    [1549] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_topic, 1, 0, 2),
    [1551] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_topic, 1, 0, 2),
    [1553] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(156),
    [1555] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_ami, 1, 0, 2),
    [1557] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_ami, 1, 0, 2),
    [1559] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(262),
    [1561] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_try_construct, 1, 0, 2),
    [1563] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_try_construct, 1, 0, 2),
    [1565] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(752),
    [1567] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_non_serialized, 1, 0, 2),
    [1569] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_non_serialized, 1, 0, 2),
    [1571] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(869),
    [1573] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_default_nested, 4, 0, 2),
    [1575] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_default_nested, 4, 0, 2),
    [1577] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_topic, 4, 0, 8),
    [1579] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_topic, 4, 0, 8),
    [1581] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_key, 4, 0, 2),
    [1583] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_key, 4, 0, 2),
    [1585] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_builtin_body, 1, 0, 0),
    [1587] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_builtin_body, 1, 0, 0),
    [1589] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_must_understand, 4, 0, 2),
    [1591] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_must_understand, 4, 0, 2),
    [1593] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_default, 4, 0, 2),
    [1595] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_default, 4, 0, 2),
    [1597] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_appendable, 1, 0, 2),
    [1599] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_appendable, 1, 0, 2),
    [1601] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(994),
    [1603] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(552),
    [1605] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_min, 4, 0, 5),
    [1607] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_min, 4, 0, 5),
    [1609] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_max, 4, 0, 5),
    [1611] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_max, 4, 0, 5),
    [1613] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_unit, 4, 0, 2),
    [1615] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_unit, 4, 0, 2),
    [1617] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_bit_bound, 4, 0, 2),
    [1619] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_bit_bound, 4, 0, 2),
    [1621] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_try_construct_fail_action, 1, 0, 0),
    [1623] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_try_construct_fail_action, 1, 0, 0),
    [1625] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_external, 4, 0, 2),
    [1627] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_external, 4, 0, 2),
    [1629] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_nested, 4, 0, 2),
    [1631] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_nested, 4, 0, 2),
    [1633] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(179),
    [1635] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 4, 0, 6),
    [1637] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 4, 0, 6),
    [1639] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_service, 4, 0, 2),
    [1641] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_service, 4, 0, 2),
    [1643] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_oneway, 4, 0, 2),
    [1645] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_oneway, 4, 0, 2),
    [1647] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_ami, 4, 0, 2),
    [1649] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_ami, 4, 0, 2),
    [1651] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_hashid, 4, 0, 2),
    [1653] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_hashid, 4, 0, 2),
    [1655] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1241),
    [1657] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1241),
    [1659] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_autoid, 4, 0, 2),
    [1661] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_autoid, 4, 0, 2),
    [1663] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_extensibility, 4, 0, 2),
    [1665] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_extensibility, 4, 0, 2),
    [1667] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_ignore_literal_names, 4, 0, 2),
    [1669] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_ignore_literal_names, 4, 0, 2),
    [1671] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_try_construct, 4, 0, 2),
    [1673] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_try_construct, 4, 0, 2),
    [1675] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(397),
    [1677] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_extend_annotation_appl, 3, 0, 0),
    [1679] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_extend_annotation_appl, 3, 0, 0),
    [1681] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_autoid, 3, 0, 2),
    [1683] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_autoid, 3, 0, 2),
    [1685] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_non_serialized, 4, 0, 2),
    [1687] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_non_serialized, 4, 0, 2),
    [1689] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_value, 4, 0, 2),
    [1691] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_value, 4, 0, 2),
    [1693] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_data_representation, 4, 0, 2),
    [1695] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_data_representation, 4, 0, 2),
    [1697] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_optional, 3, 0, 2),
    [1699] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_optional, 3, 0, 2),
    [1701] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_topic, 4, 0, 7),
    [1703] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_topic, 4, 0, 7),
    [1705] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl, 2, 0, 0),
    [1707] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl, 2, 0, 0),
    [1709] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_final, 1, 0, 2),
    [1711] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_final, 1, 0, 2),
    [1713] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_dds_request_topic, 4, 0, 2),
    [1715] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_dds_request_topic, 4, 0, 2),
    [1717] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_dds_reply_topic, 4, 0, 2),
    [1719] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_dds_reply_topic, 4, 0, 2),
    [1721] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_custom_body, 4, 0, 0),
    [1723] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_custom_body, 4, 0, 0),
    [1725] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_data_representation, 5, 0, 2),
    [1727] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_data_representation, 5, 0, 2),
    [1729] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_range, 6, 0, 12),
    [1731] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_range, 6, 0, 12),
    [1733] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 13),
    [1735] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 13),
    [1737] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 14),
    [1739] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 6, 0, 14),
    [1741] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_data_representation, 6, 0, 2),
    [1743] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_data_representation, 6, 0, 2),
    [1745] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_topic, 6, 0, 15),
    [1747] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_topic, 6, 0, 15),
    [1749] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_dds_request_topic, 6, 0, 2),
    [1751] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_dds_request_topic, 6, 0, 2),
    [1753] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_dds_reply_topic, 6, 0, 2),
    [1755] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_dds_reply_topic, 6, 0, 2),
    [1757] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_id, 4, 0, 2),
    [1759] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_id, 4, 0, 2),
    [1761] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(521),
    [1763] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_data_representation, 7, 0, 2),
    [1765] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_data_representation, 7, 0, 2),
    [1767] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_default_literal, 1, 0, 2),
    [1769] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_default_literal, 1, 0, 2),
    [1771] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_interface_dcl_repeat1, 1, 0, 0),
    [1773] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 1, 0, 0),
    [1775] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_mutable, 1, 0, 2),
    [1777] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_mutable, 1, 0, 2),
    [1779] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_position, 4, 0, 2),
    [1781] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_position, 4, 0, 2),
    [1783] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_custom_body, 3, 0, 0),
    [1785] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_custom_body, 3, 0, 0),
    [1787] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(855),
    [1789] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl, 1, 0, 0),
    [1791] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl, 1, 0, 0),
    [1793] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_optional, 4, 0, 2),
    [1795] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_optional, 4, 0, 2),
    [1797] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_data_representation_mask, 1, 0, 0),
    [1799] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_data_representation_mask, 1, 0, 0),
    [1801] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_appl_verbatim, 8, 0, 16),
    [1803] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_verbatim, 8, 0, 16),
    [1805] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_extend_annotation_appl, 4, 0, 0),
    [1807] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_extend_annotation_appl, 4, 0, 0),
    [1809] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(854),
    [1811] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(524),
    [1813] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_case_repeat1, 2, 0, 0),
    [1815] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_case_repeat1, 2, 0, 0),
    [1817] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_case_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1425),
    [1820] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_case_repeat1, 2, 0, 0),
    SHIFT_REPEAT(305),
    [1823] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(392),
    [1825] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(154),
    [1827] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(992),
    [1829] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1655),
    [1831] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1695),
    [1833] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1694),
    [1835] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1675),
    [1837] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1674),
    [1839] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1243),
    [1841] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1245),
    [1843] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1634),
    [1845] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1635),
    [1847] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1654),
    [1849] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_case_label, 3, 0, 0),
    [1851] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case_label, 3, 0, 0),
    [1853] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_case_repeat1, 1, 0, 0),
    [1855] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_case_repeat1, 1, 0, 0),
    [1857] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_case_label, 2, 0, 0),
    [1859] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case_label, 2, 0, 0),
    [1861] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(42),
    [1864] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(40),
    [1867] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 5, 0, 11),
    [1869] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 5, 0, 11),
    [1871] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 4, 0, 9),
    [1873] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 4, 0, 9),
    [1875] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 4, 0, 11),
    [1877] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 4, 0, 11),
    [1879] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 3, 0, 9),
    [1881] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 3, 0, 9),
    [1883] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(223),
    [1885] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(740),
    [1887] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(189),
    [1889] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(233),
    [1891] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(232),
    [1893] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_except_dcl_repeat1, 1, 0, 0),
    [1895] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_except_dcl_repeat1, 1, 0, 0),
    [1897] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(222),
    [1899] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(723),
    [1901] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(977),
    [1903] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 5, 0, 9),
    [1905] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 5, 0, 9),
    [1907] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(715),
    [1909] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(307),
    [1911] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(306),
    [1913] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(141),
    [1915] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_member, 6, 0, 11),
    [1917] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_member, 6, 0, 11),
    [1919] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(253),
    [1921] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(304),
    [1923] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(147),
    [1925] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(303),
    [1927] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_member, 3, 0, 0),
    [1929] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member, 3, 0, 0),
    [1931] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_member, 4, 0, 0),
    [1933] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member, 4, 0, 0),
    [1935] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_body, 1, 0, 0),
    [1937] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_body, 1, 0, 0),
    [1939] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_member, 5, 0, 0),
    [1941] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member, 5, 0, 0),
    [1943] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 1, 0, 0),
    [1945] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_dcl_repeat1, 1, 0, 0),
    [1947] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_body, 2, 0, 0),
    [1949] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_body, 2, 0, 0),
    [1951] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_annotation_member, 6, 0, 0),
    [1953] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member, 6, 0, 0),
    [1955] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_include, 3, 0, 4),
    [1957] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_include, 3, 0, 4),
    [1959] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_definition, 1, 0, 0),
    [1961] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_definition, 1, 0, 0),
    [1963] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_definition, 2, 0, 0),
    [1965] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_definition, 2, 0, 0),
    [1967] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(34),
    [1969] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1491),
    [1971] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_define, 2, 0, 0),
    [1973] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_define, 2, 0, 0),
    [1975] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_call, 2, 0, 1),
    [1977] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_call, 2, 0, 1),
    [1979] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_preproc_call, 3, 0, 3),
    [1981] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_preproc_call, 3, 0, 3),
    [1983] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1501),
    [1985] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_tpl_definition, 1, 0, 0),
    [1987] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_tpl_definition, 1, 0, 0),
    [1989] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_param_attribute, 1, 0, 0),
    [1991] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_param_attribute, 1, 0, 0),
    [1993] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_tpl_definition, 2, 0, 0),
    [1995] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_tpl_definition, 2, 0, 0),
    [1997] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_specification_repeat1, 1, 0, 0),
    [1999] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_specification_repeat1, 1, 0, 0),
    [2001] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 1, 0, 0),
    [2003] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_template_module_dcl_repeat1, 1, 0, 0),
    [2005] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(601),
    [2007] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1178),
    [2009] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1213),
    [2011] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(80),
    [2013] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(666),
    [2015] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(608),
    [2017] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1041),
    [2019] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(792),
    [2021] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(795),
    [2023] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(796),
    [2025] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_body, 1, 0, 0),
    [2027] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(645),
    [2029] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(640),
    [2031] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(664),
    [2033] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1470),
    [2035] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(662),
    [2037] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(650),
    [2039] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    [2041] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1213),
    [2044] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(80),
    [2047] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(34),
    [2050] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(41),
    [2053] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(666),
    [2056] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(608),
    [2059] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1041),
    [2062] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(792),
    [2065] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(795),
    [2068] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(796),
    [2071] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_body, 2, 0, 0),
    [2073] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    [2075] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1213),
    [2078] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(80),
    [2081] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(34),
    [2084] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(41),
    [2087] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(666),
    [2090] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(608),
    [2093] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(796),
    [2096] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1361),
    [2098] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    [2100] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1213),
    [2103] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(80),
    [2106] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(34),
    [2109] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(41),
    [2112] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(666),
    [2115] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(608),
    [2118] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 2, 0, 0),
    SHIFT_REPEAT(796),
    [2121] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_body, 1, 0, 0),
    [2123] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_dec_number, 1, 0, 0),
    [2125] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_dec_number, 1, 0, 0),
    [2127] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_floating_pt_literal, 4, 0, 0),
    [2129] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_floating_pt_literal, 4, 0, 0),
    [2131] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(493),
    [2133] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(491),
    [2135] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(34),
    [2138] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(41),
    [2141] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_floating_pt_literal, 3, 0, 0),
    [2143] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_floating_pt_literal, 3, 0, 0),
    [2145] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(473),
    [2147] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(474),
    [2149] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1382),
    [2151] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_primary_expr, 1, 0, 0),
    [2153] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_primary_expr, 1, 0, 0),
    [2155] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1430),
    [2157] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(173),
    [2159] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_integer_literal, 2, 0, 0),
    [2161] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_integer_literal, 2, 0, 0),
    [2163] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(961),
    [2165] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_integer_literal, 1, 0, 0),
    [2167] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_integer_literal, 1, 0, 0),
    [2169] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(856),
    [2171] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(314),
    [2173] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_string_literal, 3, 0, 0),
    [2175] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_literal, 3, 0, 0),
    [2177] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_add_expr, 3, 0, 0),
    [2179] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_add_expr, 3, 0, 0),
    [2181] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(383),
    [2183] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(383),
    [2185] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_char_literal, 3, 0, 0),
    [2187] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_char_literal, 3, 0, 0),
    [2189] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_oct_number, 1, 0, 0),
    [2191] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_oct_number, 1, 0, 0),
    [2193] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_wide_string_literal, 3, 0, 0),
    [2195] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_wide_string_literal, 3, 0, 0),
    [2197] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_primary_expr, 3, 0, 0),
    [2199] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_primary_expr, 3, 0, 0),
    [2201] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_mult_expr, 3, 0, 0),
    [2203] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_mult_expr, 3, 0, 0),
    [2205] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unary_operator, 1, 0, 0),
    [2207] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_unary_operator, 1, 0, 0),
    [2209] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_boolean_literal, 1, 0, 0),
    [2211] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_boolean_literal, 1, 0, 0),
    [2213] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(756),
    [2215] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(187),
    [2217] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_wide_string_literal, 4, 0, 0),
    [2219] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_wide_string_literal, 4, 0, 0),
    [2221] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_wide_character_literal, 4, 0, 0),
    [2223] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_wide_character_literal, 4, 0, 0),
    [2225] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_fixed_pt_literal, 4, 0, 0),
    [2227] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_pt_literal, 4, 0, 0),
    [2229] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(210),
    [2231] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(211),
    [2233] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_add_expr, 1, 0, 0),
    [2235] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_add_expr, 1, 0, 0),
    [2237] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(217),
    [2239] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(218),
    [2241] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(753),
    [2243] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(316),
    [2245] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_mult_expr, 1, 0, 0),
    [2247] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_mult_expr, 1, 0, 0),
    [2249] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(309),
    [2251] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(308),
    [2253] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(300),
    [2255] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(751),
    [2257] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_string_literal, 2, 0, 0),
    [2259] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_literal, 2, 0, 0),
    [2261] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_unary_expr, 2, 0, 0),
    [2263] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unary_expr, 2, 0, 0),
    [2265] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_fixed_pt_literal, 5, 0, 0),
    [2267] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_pt_literal, 5, 0, 0),
    [2269] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_literal, 1, 0, 0),
    [2271] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_literal, 1, 0, 0),
    [2273] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_floating_pt_literal, 5, 0, 0),
    [2275] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_floating_pt_literal, 5, 0, 0),
    [2277] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_unary_expr, 1, 0, 0),
    [2279] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unary_expr, 1, 0, 0),
    [2281] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(143),
    [2283] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(877),
    [2285] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_param, 1, 0, 0),
    [2287] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(277),
    [2289] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_shift_expr, 1, 0, 0),
    [2291] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_shift_expr, 1, 0, 0),
    [2293] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(352),
    [2295] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_shift_expr, 3, 0, 0),
    [2297] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_shift_expr, 3, 0, 0),
    [2299] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_simple_type_spec, 1, 0, 0),
    [2301] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_simple_type_spec, 1, 0, 0),
    [2303] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_component_body_repeat1, 1, 0, 0),
    [2305] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_export, 2, 0, 0),
    [2307] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_and_expr, 1, 0, 0),
    [2309] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_and_expr, 1, 0, 0),
    [2311] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(330),
    [2313] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_and_expr, 3, 0, 0),
    [2315] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_and_expr, 3, 0, 0),
    [2317] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1265),
    [2319] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_connector_dcl_repeat1, 1, 0, 0),
    [2321] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_export, 1, 0, 0),
    [2323] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_port_body_repeat1, 1, 0, 0),
    [2325] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1256),
    [2327] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1075),
    [2329] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(32),
    [2331] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(37),
    [2333] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1074),
    [2335] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_export, 2, 0, 0),
    [2337] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_ref, 2, 0, 0),
    [2339] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_xor_expr, 3, 0, 0),
    [2341] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(325),
    [2343] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_export, 1, 0, 0),
    [2345] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_export, 2, 0, 0),
    [2347] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1196),
    [2349] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1150),
    [2351] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1149),
    [2353] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_xor_expr, 1, 0, 0),
    [2355] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_or_expr, 1, 0, 0),
    [2357] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(323),
    [2359] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1165),
    [2361] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(487),
    [2363] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_or_expr, 3, 0, 0),
    [2365] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1120),
    [2367] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_declarator, 1, 0, 0),
    [2369] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1123),
    [2371] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1131),
    [2373] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1146),
    [2375] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1072),
    [2377] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1129),
    [2379] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(19),
    [2381] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(651),
    [2383] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_forward_dcl, 3, 0, 0),
    [2385] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(748),
    [2387] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_header, 2, 0, 0),
    [2389] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_forward_dcl, 2, 0, 0),
    [2391] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_simple_declarator, 1, 0, 0),
    [2393] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 2, 0, 0),
    [2395] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1425),
    [2398] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 2, 0, 0),
    SHIFT_REPEAT(305),
    [2401] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_const_expr, 1, 0, 0),
    [2403] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(322),
    [2405] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1111),
    [2407] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1425),
    [2409] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(305),
    [2411] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1089),
    [2413] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(32),
    [2416] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(37),
    [2419] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(38),
    [2422] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_interface_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(36),
    [2425] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1616),
    [2427] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_integer_sign, 1, 0, 0),
    [2429] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_integer_sign, 1, 0, 0),
    [2431] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(38),
    [2433] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(36),
    [2435] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(850),
    [2437] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1693),
    [2439] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1058),
    [2441] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1058),
    [2443] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(335),
    [2445] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(332),
    [2447] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1653),
    [2449] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1164),
    [2451] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1283),
    [2453] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(656),
    [2455] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(543),
    [2457] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(11),
    [2459] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(445),
    [2461] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_array_declarator, 2, 0, 0),
    [2463] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(249),
    [2465] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1264),
    [2467] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1112),
    [2469] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_header, 3, 0, 0),
    [2471] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_header, 2, 0, 0),
    [2473] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(951),
    [2475] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_forward_dcl, 2, 0, 0),
    [2477] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(785),
    [2479] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(185),
    [2481] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1633),
    [2483] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(148),
    [2485] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(995),
    [2487] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1673),
    [2489] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(514),
    [2491] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(857),
    [2493] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
    [2495] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
    SHIFT_REPEAT(249),
    [2498] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(989),
    [2500] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(237),
    [2502] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_wide_string_type, 1, 0, 0),
    [2504] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1474),
    [2506] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(180),
    [2508] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_longlong_int, 1, 0, 0),
    [2510] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(617),
    [2512] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1332),
    [2514] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_integer_type, 1, 0, 0),
    [2516] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_readonly_attr_declarator, 1, 0, 0),
    [2518] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1489),
    [2520] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_long_int, 1, 0, 0),
    [2522] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_longlong_int, 1, 0, 0),
    [2524] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1043),
    [2526] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1040),
    [2528] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1044),
    [2530] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(236),
    [2532] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_type, 1, 0, 0),
    [2534] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_short_int, 1, 0, 0),
    [2536] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1278),
    [2538] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(126),
    [2540] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_long_int, 1, 0, 0),
    [2542] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(696),
    [2544] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_short_int, 1, 0, 0),
    [2546] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1109),
    [2548] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1195),
    [2550] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1166),
    [2552] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitset_dcl_repeat1, 2, 0, 0),
    [2554] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_bitset_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1195),
    [2557] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1130),
    [2559] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_signed_int, 1, 0, 0),
    [2561] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1156),
    [2563] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_unsigned_int, 1, 0, 0),
    [2565] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1611),
    [2567] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1608),
    [2569] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1550),
    [2571] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1560),
    [2573] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(733),
    [2575] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1558),
    [2577] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 5, 0, 0),
    [2579] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_wide_string_type, 4, 0, 0),
    [2581] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(747),
    [2583] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
    SHIFT_REPEAT(833),
    [2586] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
    [2588] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
    SHIFT_REPEAT(833),
    [2591] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(186),
    [2593] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(215),
    [2595] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(212),
    [2597] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(814),
    [2599] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(81),
    [2601] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(200),
    [2603] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(196),
    [2605] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(688),
    [2607] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(284),
    [2609] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(269),
    [2611] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(267),
    [2613] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1263),
    [2615] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(807),
    [2617] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(76),
    [2619] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(788),
    [2621] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(686),
    [2623] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_declarators, 2, 0, 0),
    [2625] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1231),
    [2627] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_positive_int_const, 1, 0, 0),
    [2629] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(266),
    [2631] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(265),
    [2633] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(683),
    [2635] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_spec, 1, 0, 0),
    [2637] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(834),
    [2639] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(170),
    [2641] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(587),
    [2643] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_name, 1, 0, 0),
    [2645] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(772),
    [2647] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 2, 0, 0),
    [2649] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(773),
    [2651] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_array_declarator_repeat1, 1, 0, 0),
    [2653] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(833),
    [2655] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(471),
    [2657] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(833),
    [2659] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(870),
    [2661] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(472),
    [2663] = { .entry = { .count = 2, .reusable = false } },
    REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0),
    SHIFT_REPEAT(870),
    [2666] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0),
    [2668] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(881),
    [2670] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_supported_interface_spec, 2, 0, 0),
    [2672] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 4, 0, 0),
    [2674] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(820),
    [2676] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1207),
    [2678] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(488),
    [2680] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(458),
    [2682] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(991),
    [2684] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1202),
    [2686] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(152),
    [2688] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(813),
    [2690] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(770),
    [2692] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(298),
    [2694] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(299),
    [2696] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(292),
    [2698] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(264),
    [2700] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(260),
    [2702] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(765),
    [2704] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(197),
    [2706] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(198),
    [2708] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(204),
    [2710] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(205),
    [2712] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 4, 0, 0),
    [2714] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(767),
    [2716] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(191),
    [2718] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(710),
    [2720] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_value_inheritance_spec_repeat1, 2, 0, 0),
    SHIFT_REPEAT(772),
    [2723] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_value_inheritance_spec_repeat1, 2, 0, 0),
    [2725] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1484),
    [2727] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(149),
    [2729] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1071),
    [2731] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_map_type, 8, 0, 0),
    [2733] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_declarators, 1, 0, 0),
    [2735] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(360),
    [2737] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_array_size, 3, 0, 0),
    [2739] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_raises_expr_repeat1, 2, 0, 0),
    [2741] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_raises_expr_repeat1, 2, 0, 0),
    SHIFT_REPEAT(881),
    [2744] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 6, 0, 0),
    [2746] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1083),
    [2748] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 6, 0, 0),
    [2750] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(852),
    [2752] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(463),
    [2754] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(461),
    [2756] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(512),
    [2758] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1191),
    [2760] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_floating_pt_type, 1, 0, 0),
    [2762] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_map_type, 6, 0, 0),
    [2764] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1136),
    [2766] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(84),
    [2768] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_pt_type, 6, 0, 0),
    [2770] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 4, 0, 0),
    [2772] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_sequence_type, 6, 0, 0),
    [2774] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(49),
    [2776] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(918),
    [2778] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_forward_dcl, 2, 0, 0),
    [2780] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 5, 0, 0),
    [2782] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_header, 2, 0, 0),
    [2784] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(707),
    [2786] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_forward_dcl, 2, 0, 0),
    [2788] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 3, 0, 0),
    [2790] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(726),
    [2792] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(984),
    [2794] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_object_type, 1, 0, 0),
    [2796] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_base_type_spec, 1, 0, 0),
    [2798] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_string_type, 4, 0, 0),
    [2800] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_type_spec, 1, 0, 0),
    [2802] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_type, 1, 0, 0),
    [2804] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_sequence_type, 4, 0, 0),
    [2806] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_declarators_repeat1, 2, 0, 0),
    SHIFT_REPEAT(686),
    [2809] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_declarators_repeat1, 2, 0, 0),
    [2811] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1118),
    [2813] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_param_dcls, 1, 0, 0),
    [2815] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_finder_dcl, 4, 0, 0),
    [2817] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_any_declarators_repeat1, 2, 0, 0),
    SHIFT_REPEAT(700),
    [2820] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_any_declarators_repeat1, 2, 0, 0),
    [2822] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(92),
    [2824] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1272),
    [2826] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(593),
    [2828] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(586),
    [2830] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1528),
    [2832] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_dcl, 4, 0, 0),
    [2834] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1121),
    [2836] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_param_dcls, 1, 0, 0),
    [2838] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_supported_interface_spec, 3, 0, 0),
    [2840] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(653),
    [2842] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(546),
    [2844] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_actual_parameters, 2, 0, 0),
    [2846] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(25),
    [2848] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(468),
    [2850] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(63),
    [2852] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1094),
    [2854] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1100),
    [2856] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(589),
    [2858] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1110),
    [2860] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_header, 2, 0, 0),
    [2862] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(990),
    [2864] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameters, 2, 0, 0),
    [2866] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(72),
    [2868] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(732),
    [2870] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 5, 0, 0),
    [2872] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_forward_dcl, 2, 0, 0),
    [2874] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1381),
    [2876] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(sym_union_forward_dcl, 2, 0, 0),
    [2878] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(55),
    [2880] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_parameter_dcls, 1, 0, 0),
    [2882] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1142),
    [2884] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_params, 2, 0, 0),
    [2886] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1556),
    [2888] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1555),
    [2890] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1554),
    [2892] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1134),
    [2894] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1479),
    [2896] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(844),
    [2898] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_declarator, 2, 0, 0),
    [2900] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
    [2902] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
    [2904] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_readonly_attr_declarator, 2, 0, 0),
    [2906] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(328),
    [2908] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(259),
    [2910] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_raises_expr, 1, 0, 0),
    [2912] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_readonly_attr_declarator_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1120),
    [2915] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_readonly_attr_declarator_repeat1, 2, 0, 0),
    [2917] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(67),
    [2919] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(30),
    [2921] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1106),
    [2923] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_in_parameter_dcls, 1, 0, 0),
    [2925] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitfield_repeat1, 2, 0, 0),
    [2927] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_bitfield_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1100),
    [2930] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1419),
    [2932] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_declarator, 1, 0, 0),
    [2934] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_parameter_dcls, 2, 0, 0),
    [2936] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(65),
    [2938] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_param_dcls, 2, 0, 0),
    [2940] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_dcl, 5, 0, 0),
    [2942] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_param_dcls, 2, 0, 0),
    [2944] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(973),
    [2946] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_finder_dcl, 5, 0, 0),
    [2948] = { .entry = { .count = 1, .reusable = false } },
    REDUCE(aux_sym_char_literal_repeat1, 1, 0, 0),
    [2950] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(947),
    [2952] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(937),
    [2954] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_interface_inheritance_spec_repeat1, 2, 0, 0),
    SHIFT_REPEAT(732),
    [2957] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_interface_inheritance_spec_repeat1, 2, 0, 0),
    [2959] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(786),
    [2961] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 1, 0, 0),
    [2963] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 6, 0, 0),
    [2965] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(361),
    [2967] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(581),
    [2969] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_union_def_repeat1, 1, 0, 0),
    [2971] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1132),
    [2973] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(366),
    [2975] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(503),
    [2977] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_in_parameter_dcls, 2, 0, 0),
    [2979] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(536),
    [2981] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(371),
    [2983] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_context_expr_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1134),
    [2986] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_context_expr_repeat1, 2, 0, 0),
    [2988] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_parameter_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(55),
    [2991] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_parameter_dcls_repeat1, 2, 0, 0),
    [2993] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(538),
    [2995] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_init_param_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1121),
    [2998] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_init_param_dcls_repeat1, 2, 0, 0),
    [3000] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(976),
    [3002] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(380),
    [3004] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_params, 1, 0, 0),
    [3006] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_factory_param_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1118),
    [3009] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_factory_param_dcls_repeat1, 2, 0, 0),
    [3011] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameters, 1, 0, 0),
    [3013] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(174),
    [3015] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_inheritance_spec, 7, 0, 0),
    [3017] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(167),
    [3019] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(162),
    [3021] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(329),
    [3023] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_actual_parameters, 1, 0, 0),
    [3025] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_bitmask_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(596),
    [3028] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitmask_dcl_repeat1, 2, 0, 0),
    [3030] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(153),
    [3032] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_enum_dcl_repeat1, 2, 0, 0),
    SHIFT_REPEAT(590),
    [3035] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_enum_dcl_repeat1, 2, 0, 0),
    [3037] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_inheritance_spec, 3, 0, 0),
    [3039] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_name, 1, 0, 0),
    [3041] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1069),
    [3043] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_in_parameter_dcls_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1106),
    [3046] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_in_parameter_dcls_repeat1, 2, 0, 0),
    [3048] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(71),
    [3050] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_names, 1, 0, 0),
    [3052] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1330),
    [3054] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(700),
    [3056] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_declarators, 1, 0, 0),
    [3058] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(588),
    [3060] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1163),
    [3062] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_case, 3, 0, 0),
    [3064] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1068),
    [3066] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_names, 2, 0, 0),
    [3068] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1035),
    [3070] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_raises_expr_repeat1, 2, 0, 0),
    SHIFT_REPEAT(984),
    [3073] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_formal_parameter_names_repeat1, 2, 0, 0),
    [3075] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_formal_parameter_names_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1330),
    [3078] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1031),
    [3080] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_actual_parameters_repeat1, 2, 0, 0),
    [3082] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_actual_parameters_repeat1, 2, 0, 0),
    SHIFT_REPEAT(25),
    [3085] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_declarators, 2, 0, 0),
    [3087] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_formal_parameters_repeat1, 2, 0, 0),
    [3089] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_formal_parameters_repeat1, 2, 0, 0),
    SHIFT_REPEAT(72),
    [3092] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_inheritance_spec, 2, 0, 0),
    [3094] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_appl_params_repeat1, 2, 0, 0),
    SHIFT_REPEAT(1142),
    [3097] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_appl_params_repeat1, 2, 0, 0),
    [3099] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_inheritance_spec, 2, 0, 0),
    [3101] = { .entry = { .count = 2, .reusable = true } },
    REDUCE(aux_sym_annotation_appl_data_representation_repeat1, 2, 0, 0),
    SHIFT_REPEAT(653),
    [3104] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_annotation_appl_data_representation_repeat1, 2, 0, 0),
    [3106] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1027),
    [3108] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_inheritance_spec, 2, 0, 0),
    [3110] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1021),
    [3112] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(64),
    [3114] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_header, 3, 0, 0),
    [3116] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1090),
    [3118] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_dcl, 1, 0, 0),
    [3120] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1589),
    [3122] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1217),
    [3124] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield_spec, 6, 0, 0),
    [3126] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_type, 1, 0, 0),
    [3128] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1610),
    [3130] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_inherit_spec, 2, 0, 0),
    [3132] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1609),
    [3134] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1605),
    [3136] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1604),
    [3138] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(793),
    [3140] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1022),
    [3142] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_constr_type_dcl, 1, 0, 0),
    [3144] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_dcl, 1, 0, 0),
    [3146] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_appl_param, 3, 0, 0),
    [3148] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 6, 0, 10),
    [3150] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_raises_expr, 5, 0, 0),
    [3152] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_exception_list, 4, 0, 0),
    [3154] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(782),
    [3156] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(239),
    [3158] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_raises_expr, 4, 0, 0),
    [3160] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 6, 0, 0),
    [3162] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enumerator, 1, 0, 0),
    [3164] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 4, 0, 0),
    [3166] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_declarator, 1, 0, 0),
    [3168] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(50),
    [3170] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 4, 0, 0),
    [3172] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_dcl, 7, 0, 0),
    [3174] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_in_param_dcl, 3, 0, 0),
    [3176] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(377),
    [3178] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(283),
    [3180] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_exception_list, 3, 0, 0),
    [3182] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(663),
    [3184] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(839),
    [3186] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(799),
    [3188] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(155),
    [3190] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_actual_parameter, 1, 0, 0),
    [3192] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(759),
    [3194] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(246),
    [3196] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_def, 9, 0, 0),
    [3198] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(942),
    [3200] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_primary_key_spec, 2, 0, 0),
    [3202] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(79),
    [3204] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_type, 1, 0, 0),
    [3206] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield, 2, 0, 0),
    [3208] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_param_dcl, 3, 0, 0),
    [3210] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1039),
    [3212] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(379),
    [3214] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_init_param_dcl, 3, 0, 0),
    [3216] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitfield_repeat1, 1, 0, 0),
    [3218] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_param_dcl, 3, 0, 0),
    [3220] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(843),
    [3222] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(549),
    [3224] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_oneway_dcl, 6, 0, 0),
    [3226] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 5, 0, 0),
    [3228] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 5, 0, 0),
    [3230] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_union_def, 8, 0, 0),
    [3232] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bit_value, 2, 0, 0),
    [3234] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(362),
    [3236] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(257),
    [3238] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(826),
    [3240] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(919),
    [3242] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(837),
    [3244] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_param_dcl, 2, 0, 0),
    [3246] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 6, 0, 0),
    [3248] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 6, 0, 0),
    [3250] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield, 3, 0, 0),
    [3252] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1168),
    [3254] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(435),
    [3256] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1517),
    [3258] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1515),
    [3260] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_oneway_dcl, 5, 0, 0),
    [3262] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_get_excep_expr, 2, 0, 0),
    [3264] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(749),
    [3266] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(871),
    [3268] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(21),
    [3270] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(974),
    [3272] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_member_type, 1, 0, 0),
    [3274] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 7, 0, 0),
    [3276] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(424),
    [3278] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1561),
    [3280] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 7, 0, 10),
    [3282] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bit_value, 1, 0, 0),
    [3284] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 4, 0, 0),
    [3286] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(661),
    [3288] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter, 2, 0, 0),
    [3290] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(aux_sym_bitset_dcl_repeat1, 1, 0, 0),
    [3292] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(565),
    [3294] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_forward_dcl, 2, 0, 0),
    [3296] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 4, 0, 0),
    [3298] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_const_type, 1, 0, 0),
    [3300] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_struct_def, 5, 0, 0),
    [3302] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_imported_scope, 1, 0, 0),
    [3304] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_switch_type_spec, 1, 0, 0),
    [3306] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enum_dcl, 5, 0, 0),
    [3308] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_enumerator, 2, 0, 0),
    [3310] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitmask_dcl, 7, 0, 0),
    [3312] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitset_dcl, 7, 0, 0),
    [3314] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_bitfield_spec, 4, 0, 0),
    [3316] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1271),
    [3318] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(865),
    [3320] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(74),
    [3322] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1362),
    [3324] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1316),
    [3326] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1315),
    [3328] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_dcl, 3, 0, 0),
    [3330] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1314),
    [3332] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(562),
    [3334] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_def, 3, 0, 0),
    [3336] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1280),
    [3338] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_def, 3, 0, 0),
    [3340] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_header, 3, 0, 0),
    [3342] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_box_def, 3, 0, 0),
    [3344] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_dcl, 1, 0, 0),
    [3346] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1275),
    [3348] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(31),
    [3350] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(570),
    [3352] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(571),
    [3354] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(829),
    [3356] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_system_lib_string, 3, 0, 0),
    [3358] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_except_dcl, 4, 0, 0),
    [3360] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(14),
    [3362] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(15),
    [3364] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(226),
    [3366] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_any_const_type, 1, 0, 0),
    [3368] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_dcl, 4, 0, 0),
    [3370] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(398),
    [3372] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(550),
    [3374] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_autoid_kind, 1, 0, 0),
    [3376] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(551),
    [3378] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(529),
    [3380] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(522),
    [3382] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(520),
    [3384] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_extensibility_kind, 1, 0, 0),
    [3386] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(519),
    [3388] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1270),
    [3390] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(518),
    [3392] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(517),
    [3394] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(85),
    [3396] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_header, 3, 0, 0),
    [3398] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_type_spec, 1, 0, 0),
    [3400] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(247),
    [3402] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1126),
    [3404] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(511),
    [3406] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_def, 3, 0, 0),
    [3408] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(509),
    [3410] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(507),
    [3412] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(506),
    [3414] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(505),
    [3416] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(504),
    [3418] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_verbatim_language, 1, 0, 0),
    [3420] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_placement_kind, 1, 0, 0),
    [3422] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(502),
    [3424] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(93),
    [3426] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(272),
    [3428] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_service_platform, 1, 0, 0),
    [3430] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(500),
    [3432] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(499),
    [3434] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(528),
    [3436] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(501),
    [3438] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(513),
    [3440] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(498),
    [3442] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(532),
    [3444] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(534),
    [3446] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(516),
    [3448] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_topic_platform, 1, 0, 0),
    [3450] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(548),
    [3452] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(274),
    [3454] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(547),
    [3456] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(276),
    [3458] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(545),
    [3460] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(544),
    [3462] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1494),
    [3464] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1153),
    [3466] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_module_dcl, 4, 0, 0),
    [3468] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1500),
    [3470] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_supports, 2, 0, 0),
    [3472] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(779),
    [3474] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(670),
    [3476] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_header, 4, 0, 0),
    [3478] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(235),
    [3480] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(82),
    [3482] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_header, 4, 0, 0),
    [3484] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(658),
    [3486] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_def, 4, 0, 0),
    [3488] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1534),
    [3490] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_header, 3, 0, 0),
    [3492] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_declarator, 2, 0, 0),
    [3494] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1700),
    [3496] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_def, 4, 0, 0),
    [3498] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(804),
    [3500] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(652),
    [3502] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_op_with_context, 2, 0, 0),
    [3504] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(52),
    [3506] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1699),
    [3508] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(655),
    [3510] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_dcl, 2, 0, 0),
    [3512] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(676),
    [3514] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_def, 4, 0, 0),
    [3516] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(997),
    [3518] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(998),
    [3520] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(999),
    [3522] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1000),
    [3524] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1001),
    [3526] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1002),
    [3528] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1003),
    [3530] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1004),
    [3532] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1005),
    [3534] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1006),
    [3536] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1007),
    [3538] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1008),
    [3540] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1009),
    [3542] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1010),
    [3544] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1011),
    [3546] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1012),
    [3548] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1013),
    [3550] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1014),
    [3552] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1015),
    [3554] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1016),
    [3556] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1017),
    [3558] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1018),
    [3560] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1019),
    [3562] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1020),
    [3564] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1697),
    [3566] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1613),
    [3568] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1023),
    [3570] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1024),
    [3572] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1025),
    [3574] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1026),
    [3576] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_def, 4, 0, 0),
    [3578] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(684),
    [3580] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(685),
    [3582] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1028),
    [3584] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1029),
    [3586] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1030),
    [3588] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(946),
    [3590] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1032),
    [3592] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1033),
    [3594] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1034),
    [3596] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_ref, 6, 0, 0),
    [3598] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_element_spec, 3, 0, 0),
    [3600] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1036),
    [3602] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1324),
    [3604] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(573),
    [3606] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_prefix_dcl, 3, 0, 0),
    [3608] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1067),
    [3610] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_id_dcl, 3, 0, 0),
    [3612] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(574),
    [3614] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_element_spec, 2, 0, 0),
    [3616] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_def, 4, 0, 0),
    [3618] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1327),
    [3620] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(172),
    [3622] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(142),
    [3624] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(182),
    [3626] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(178),
    [3628] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(151),
    [3630] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(144),
    [3632] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(121),
    [3634] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(123),
    [3636] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(124),
    [3638] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(127),
    [3640] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(128),
    [3642] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(129),
    [3644] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(130),
    [3646] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(132),
    [3648] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(133),
    [3650] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(135),
    [3652] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(136),
    [3654] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(137),
    [3656] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(139),
    [3658] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(140),
    [3660] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(119),
    [3662] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(145),
    [3664] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(146),
    [3666] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(150),
    [3668] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_connector_dcl, 4, 0, 0),
    [3670] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_dcl, 4, 0, 0),
    [3672] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(120),
    [3674] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(159),
    [3676] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(160),
    [3678] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(161),
    [3680] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_dcl, 5, 0, 0),
    [3682] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(163),
    [3684] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(165),
    [3686] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(166),
    [3688] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(261),
    [3690] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(168),
    [3692] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(169),
    [3694] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(171),
    [3696] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_except_dcl, 5, 0, 0),
    [3698] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(184),
    [3700] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_dcl, 2, 0, 0),
    [3702] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(443),
    [3704] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(270),
    [3706] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_abs_def, 5, 0, 0),
    [3708] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(426),
    [3710] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(440),
    [3712] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_abs_def, 5, 0, 0),
    [3714] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(401),
    [3716] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(358),
    [3718] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(402),
    [3720] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(403),
    [3722] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(405),
    [3724] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(406),
    [3726] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(407),
    [3728] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(408),
    [3730] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(409),
    [3732] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(410),
    [3734] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(412),
    [3736] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(389),
    [3738] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(414),
    [3740] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(415),
    [3742] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(416),
    [3744] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(418),
    [3746] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(417),
    [3748] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(413),
    [3750] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(404),
    [3752] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(393),
    [3754] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(388),
    [3756] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(386),
    [3758] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(359),
    [3760] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(382),
    [3762] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_finder_dcl, 6, 0, 0),
    [3764] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_factory_dcl, 6, 0, 0),
    [3766] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(378),
    [3768] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(376),
    [3770] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(375),
    [3772] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(372),
    [3774] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(66),
    [3776] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(370),
    [3778] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(369),
    [3780] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(367),
    [3782] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_context_expr, 5, 0, 0),
    [3784] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(365),
    [3786] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(364),
    [3788] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(363),
    [3790] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(736),
    [3792] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(385),
    [3794] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(295),
    [3796] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(109),
    [3798] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_dcl, 8, 0, 0),
    [3800] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(526),
    [3802] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(454),
    [3804] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_max_expr, 3, 0, 0),
    [3806] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(858),
    [3808] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(860),
    [3810] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(862),
    [3812] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(863),
    [3814] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_def, 3, 0, 0),
    [3816] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(874),
    [3818] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(878),
    [3820] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(879),
    [3822] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(880),
    [3824] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(882),
    [3826] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(884),
    [3828] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(887),
    [3830] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(891),
    [3832] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(892),
    [3834] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(897),
    [3836] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(898),
    [3838] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(899),
    [3840] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(904),
    [3842] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(905),
    [3844] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(907),
    [3846] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(909),
    [3848] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(910),
    [3850] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(911),
    [3852] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(912),
    [3854] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(387),
    [3856] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(464),
    [3858] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(920),
    [3860] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(923),
    [3862] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(927),
    [3864] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(929),
    [3866] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(411),
    [3868] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(938),
    [3870] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(940),
    [3872] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(945),
    [3874] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1049),
    [3876] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(948),
    [3878] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(950),
    [3880] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(955),
    [3882] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_destination_type, 1, 0, 0),
    [3884] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(981),
    [3886] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(333),
    [3888] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(633),
    [3890] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(649),
    [3892] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(744),
    [3894] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_context_expr, 4, 0, 0),
    [3896] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1107),
    [3898] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(58),
    [3900] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_raises_expr, 2, 0, 0),
    [3902] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_set_excep_expr, 2, 0, 0),
    [3904] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1190),
    [3906] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1048),
    [3908] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_dcl, 2, 0, 0),
    [3910] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(895),
    [3912] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_home_header, 7, 0, 0),
    [3914] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1185),
    [3916] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_formal_parameter_type, 2, 0, 0),
    [3918] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_native_dcl, 2, 0, 0),
    [3920] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(22),
    [3922] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(429),
    [3924] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_dcl, 7, 0, 0),
    [3926] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_module_dcl, 5, 0, 0),
    [3928] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_import_dcl, 2, 0, 0),
    [3930] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1565),
    [3932] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1562),
    [3934] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(540),
    [3936] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_const_dcl, 5, 0, 0),
    [3938] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_typedef_dcl, 2, 0, 0),
    [3940] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_abs_def, 7, 0, 0),
    [3942] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_abs_def, 7, 0, 0),
    [3944] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(326),
    [3946] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(741),
    [3948] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_default, 2, 0, 0),
    [3950] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(87),
    [3952] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_module_dcl, 6, 0, 0),
    [3954] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(241),
    [3956] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(868),
    [3958] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(615),
    [3960] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(864),
    [3962] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_kind, 2, 0, 0),
    [3964] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1379),
    [3966] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_uses_dcl, 4, 0, 0),
    [3968] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1703),
    [3970] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_fixed_pt_const_type, 1, 0, 0),
    [3972] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(569),
    [3974] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(859),
    [3976] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_context_expr, 3, 0, 0),
    [3978] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(225),
    [3980] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(224),
    [3982] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(613),
    [3984] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_def, 5, 0, 0),
    [3986] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(90),
    [3988] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(216),
    [3990] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(317),
    [3992] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(214),
    [3994] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_readonly_attr_spec, 4, 0, 0),
    [3996] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(213),
    [3998] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1124),
    [4000] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(320),
    [4002] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(577),
    [4004] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(754),
    [4006] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(321),
    [4008] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(207),
    [4010] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(558),
    [4012] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(452),
    [4014] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1481),
    [4016] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(62),
    [4018] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(578),
    [4020] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(762),
    [4022] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(591),
    [4024] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(610),
    [4026] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_kind, 2, 0, 0),
    [4028] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(47),
    [4030] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(419),
    [4032] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(764),
    [4034] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1486),
    [4036] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(425),
    [4038] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(597),
    [4040] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1704),
    [4042] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1161),
    [4044] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_template_module_inst, 6, 0, 0),
    [4046] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(444),
    [4048] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_porttype_dcl, 1, 0, 0),
    [4050] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(542),
    [4052] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(541),
    [4054] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(7),
    [4056] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_dcl, 1, 0, 0),
    [4058] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(5),
    [4060] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(433),
    [4062] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_attr_spec, 3, 0, 0),
    [4064] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_component_dcl, 1, 0, 0),
    [4066] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(537),
    [4068] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_type_dcl, 1, 0, 0),
    [4070] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(281),
    [4072] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(6),
    [4074] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(53),
    [4076] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_dcl, 1, 0, 0),
    [4078] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(535),
    [4080] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(10),
    [4082] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_dcl, 1, 0, 0),
    [4084] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(769),
    [4086] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(497),
    [4088] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(421),
    [4090] = { .entry = { .count = 1, .reusable = true } },
    ACCEPT_INPUT(),
    [4092] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(243),
    [4094] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(818),
    [4096] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1155),
    [4098] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(642),
    [4100] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(616),
    [4102] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_min_expr, 3, 0, 0),
    [4104] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_annotation_dcl, 6, 0, 0),
    [4106] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_event_abs_def, 6, 0, 0),
    [4108] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_abs_def, 6, 0, 0),
    [4110] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1524),
    [4112] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(822),
    [4114] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(766),
    [4116] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(592),
    [4118] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_value_kind, 1, 0, 0),
    [4120] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(327),
    [4122] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_port_dcl, 3, 0, 0),
    [4124] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_consumes_dcl, 3, 0, 0),
    [4126] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1552),
    [4128] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1085),
    [4130] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_interface_kind, 1, 0, 0),
    [4132] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_publishes_dcl, 3, 0, 0),
    [4134] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_emits_dcl, 3, 0, 0),
    [4136] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1557),
    [4138] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_uses_dcl, 3, 0, 0),
    [4140] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1519),
    [4142] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(423),
    [4144] = { .entry = { .count = 1, .reusable = false } },
    SHIFT(1563),
    [4146] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(560),
    [4148] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(209),
    [4150] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(302),
    [4152] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(755),
    [4154] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(301),
    [4156] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(202),
    [4158] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(201),
    [4160] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(287),
    [4162] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(199),
    [4164] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(77),
    [4166] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(619),
    [4168] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(229),
    [4170] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(230),
    [4172] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1167),
    [4174] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(97),
    [4176] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(296),
    [4178] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(634),
    [4180] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(293),
    [4182] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(252),
    [4184] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(290),
    [4186] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(557),
    [4188] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(238),
    [4190] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(288),
    [4192] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(775),
    [4194] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(282),
    [4196] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(245),
    [4198] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(248),
    [4200] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(271),
    [4202] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(251),
    [4204] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(86),
    [4206] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(606),
    [4208] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(244),
    [4210] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(192),
    [4212] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1115),
    [4214] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(94),
    [4216] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(280),
    [4218] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(648),
    [4220] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(285),
    [4222] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(286),
    [4224] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(289),
    [4226] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(559),
    [4228] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(234),
    [4230] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(291),
    [4232] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(739),
    [4234] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(294),
    [4236] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(231),
    [4238] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(228),
    [4240] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(297),
    [4242] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(227),
    [4244] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(89),
    [4246] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(622),
    [4248] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(221),
    [4250] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(220),
    [4252] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1047),
    [4254] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(95),
    [4256] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(310),
    [4258] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(637),
    [4260] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(311),
    [4262] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(312),
    [4264] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(313),
    [4266] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(561),
    [4268] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(219),
    [4270] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(315),
    [4272] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(706),
    [4274] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(318),
    [4276] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(208),
    [4278] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(206),
    [4280] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(319),
    [4282] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(203),
    [4284] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(78),
    [4286] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(603),
    [4288] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(195),
    [4290] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(194),
    [4292] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1141),
    [4294] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(96),
    [4296] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(258),
    [4298] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(632),
    [4300] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(256),
    [4302] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(254),
    [4304] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(278),
    [4306] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_provides_dcl, 3, 0, 0),
    [4308] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(68),
    [4310] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(54),
    [4312] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(760),
    [4314] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1151),
    [4316] = { .entry = { .count = 1, .reusable = true } },
    SHIFT(1159),
    [4318] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_comment, 2, 0, 0),
    [4320] = { .entry = { .count = 1, .reusable = true } },
    REDUCE(sym_comment, 3, 0, 0),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_idl(void) {
    static const TSLanguage language = {
        .version = LANGUAGE_VERSION,
        .symbol_count = SYMBOL_COUNT,
        .alias_count = ALIAS_COUNT,
        .token_count = TOKEN_COUNT,
        .external_token_count = EXTERNAL_TOKEN_COUNT,
        .state_count = STATE_COUNT,
        .large_state_count = LARGE_STATE_COUNT,
        .production_id_count = PRODUCTION_ID_COUNT,
        .field_count = FIELD_COUNT,
        .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
        .parse_table = &ts_parse_table[0][0],
        .small_parse_table = ts_small_parse_table,
        .small_parse_table_map = ts_small_parse_table_map,
        .parse_actions = ts_parse_actions,
        .symbol_names = ts_symbol_names,
        .field_names = ts_field_names,
        .field_map_slices = ts_field_map_slices,
        .field_map_entries = ts_field_map_entries,
        .symbol_metadata = ts_symbol_metadata,
        .public_symbol_map = ts_symbol_map,
        .alias_map = ts_non_terminal_alias_map,
        .alias_sequences = &ts_alias_sequences[0][0],
        .lex_modes = ts_lex_modes,
        .lex_fn = ts_lex,
        .primary_state_ids = ts_primary_state_ids,
    };
    return &language;
}
#ifdef __cplusplus
}
#endif
